@@ -34,13 +34,7 @@ install_pkgs() {
 
 verify_enable_platform() {
     feature="$1"
-    if [ "$OS_MAJOR" -gt 6 ]; then
-        if [ "$feature" = "USB_ENABLED" ]; then
-            echo "false"
-        else
-            verify_gcc_enable "$feature"
-        fi
-    fi
+    verify_gcc_enable "$feature"
 }
 
 add_os_flags() {
@@ -51,11 +45,6 @@ install_bison() {
     INSTALLED+=("bison")
 }
 
-install_libusb() {
-    INSTALLED+=("libusb-devel")
-}
-
-
 bootstrap_cmake(){
     install_cmake_from_binary
 }
@@ -70,7 +59,7 @@ bootstrap_compiler() {
 }
 
 build_deps() {
-    COMMAND="install_pkgs libuuid libuuid-devel libtool patch epel-release"
+    COMMAND="install_pkgs libuuid libuuid-devel libtool patch epel-release perl"
     INSTALLED=()
     for option in "${OPTIONS[@]}" ; do
         option_value="${!option}"
@@ -82,33 +71,19 @@ build_deps() {
                 VALUE=${cmake_opt#*:}
                 if [ "$KEY" = "$option" ]; then
                     FOUND_VALUE="$VALUE"
-                    if [ "$FOUND_VALUE" = "libpcap" ]; then
-                        INSTALLED+=("libpcap-devel")
-                    elif [ "$FOUND_VALUE" = "libusb" ]; then
-                        install_libusb
-                    elif [ "$FOUND_VALUE" = "libpng" ]; then
-                        INSTALLED+=("libpng-devel")
-                    elif [ "$FOUND_VALUE" = "bison" ]; then
+                    if [ "$FOUND_VALUE" = "bison" ]; then
                         install_bison
                     elif [ "$FOUND_VALUE" = "flex" ]; then
                         INSTALLED+=("flex")
                     elif [ "$FOUND_VALUE" = "automake" ]; then
                         INSTALLED+=("automake")
-                    elif [ "$FOUND_VALUE" = "jnibuild" ]; then
-                        INSTALLED+=("java-1.8.0-openjdk")
-                        INSTALLED+=("java-1.8.0-openjdk-devel")
-                        INSTALLED+=("maven")
                     elif [ "$FOUND_VALUE" = "python" ]; then
                         INSTALLED+=("python36-devel")
-                    elif [ "$FOUND_VALUE" = "gpsd" ]; then
-                        INSTALLED+=("gpsd-devel")
                     elif [ "$FOUND_VALUE" = "libarchive" ]; then
                         INSTALLED+=("xz-devel")
                         INSTALLED+=("bzip2-devel")
                     elif [ "$FOUND_VALUE" = "libssh2" ]; then
                         INSTALLED+=("libssh2-devel")
-                    elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
-                        INSTALLED+=("perl")
                     fi
                 fi
             done
