@@ -15,23 +15,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include <vector>
+#include <filesystem>
 #include <iostream>
 #include <string>
 #include <string_view>
-#include <filesystem>
+#include <vector>
 
-#include "MainHelper.h"
-#include "properties/Configure.h"
 #include "Controller.h"
+#include "Defaults.h"
+#include "Exception.h"
+#include "MainHelper.h"
+#include "agent/agent_version.h"
+#include "argparse/argparse.hpp"
 #include "c2/ControllerSocketProtocol.h"
+#include "controllers/SSLContextService.h"
+#include "core/ConfigurationFactory.h"
 #include "core/controller/ControllerService.h"
 #include "core/extension/ExtensionManager.h"
-#include "core/ConfigurationFactory.h"
-#include "Exception.h"
-#include "argparse/argparse.hpp"
+#include "properties/Configure.h"
 #include "range/v3/algorithm/contains.hpp"
-#include "agent/agent_version.h"
+#include "utils/Environment.h"
 
 namespace minifi = org::apache::nifi::minifi;
 
@@ -39,7 +42,7 @@ std::shared_ptr<minifi::core::controller::ControllerService> getControllerServic
     const std::string &service_name) {
   std::string nifi_configuration_class_name = "adaptiveconfiguration";
 
-  minifi::core::extension::ExtensionManager::get().initialize(configuration);
+  minifi::core::extension::ExtensionManagerImpl::get().initialize(configuration);
 
   configuration->get(minifi::Configure::nifi_configuration_class_name, nifi_configuration_class_name);
   auto flow_configuration = minifi::core::createFlowConfiguration(
@@ -61,14 +64,14 @@ std::shared_ptr<minifi::core::controller::ControllerService> getControllerServic
   return controller->getControllerServiceImplementation();
 }
 
-std::shared_ptr<minifi::controllers::SSLContextService> getSSLContextService(const std::shared_ptr<minifi::Configure>& configuration) {
-  std::shared_ptr<minifi::controllers::SSLContextService> secure_context;
+std::shared_ptr<minifi::controllers::SSLContextServiceInterface> getSSLContextService(const std::shared_ptr<minifi::Configure>& configuration) {
+  std::shared_ptr<minifi::controllers::SSLContextServiceInterface> secure_context;
   std::string context_name;
   // if the user wishes to use a controller service we need to instantiate the flow
   if (configuration->get(minifi::Configure::controller_ssl_context_service, context_name) && !context_name.empty()) {
     const auto service = getControllerService(configuration, context_name);
     if (nullptr != service) {
-      secure_context = std::dynamic_pointer_cast<minifi::controllers::SSLContextService>(service);
+      secure_context = std::dynamic_pointer_cast<minifi::controllers::SSLContextServiceInterface>(service);
     }
     if (secure_context == nullptr) {
       throw minifi::Exception(minifi::GENERAL_EXCEPTION, "SSL Context was set, but the context name '" + context_name + "' could not be found");
@@ -90,19 +93,20 @@ std::shared_ptr<minifi::controllers::SSLContextService> getSSLContextService(con
 int main(int argc, char **argv) {
   const auto logger = minifi::core::logging::LoggerConfiguration::getConfiguration().getLogger("controller");
 
-  const auto minifi_home = determineMinifiHome(logger);
-  if (minifi_home.empty()) {
-    // determineMinifiHome already logged everything we need
+  const auto locations = minifi::determineLocations(logger);
+  if (!locations) {
+    // determineLocations already logged everything we need
     return -1;
   }
+  minifi::utils::Environment::setEnvironmentVariable(std::string(MINIFI_HOME_ENV_KEY).c_str(), locations->working_dir_.string().c_str());
 
-  const auto configuration = std::make_shared<minifi::Configure>();
-  configuration->setHome(minifi_home);
-  configuration->loadConfigureFile(DEFAULT_NIFI_PROPERTIES_FILE);
 
-  const auto log_properties = std::make_shared<minifi::core::logging::LoggerProperties>();
-  log_properties->setHome(minifi_home);
-  log_properties->loadConfigureFile(DEFAULT_LOG_PROPERTIES_FILE);
+  const auto configuration = std::make_shared<minifi::ConfigureImpl>();
+  configuration->loadConfigureFile(locations->properties_path_);
+
+  const auto log_properties = std::make_shared<minifi::core::logging::LoggerProperties>(locations->logs_dir_);
+  log_properties->loadConfigureFile(locations->log_properties_path_, "nifi.log.");
+
   minifi::core::logging::LoggerConfiguration::getConfiguration().initialize(log_properties);
 
   minifi::utils::net::SocketData socket_data;
@@ -147,6 +151,9 @@ int main(int argc, char **argv) {
   argument_parser.add_argument("--updateflow")
     .metavar("FLOW_CONFIG_PATH")
     .help("Updates the flow of the agent using the provided flow file");
+  argument_parser.add_argument("--flowstatus")
+    .metavar("FLOW_STATUS_QUERY")
+    .help("Returns flow status for the provided query");
 
   auto addFlagOption = [&](std::string_view name, const std::string& help) {
     argument_parser.add_argument(name)
@@ -271,6 +278,12 @@ int main(int argc, char **argv) {
       else
         std::cout << "Debug bundle written to " << std::filesystem::path(*debug_path) / "debug.tar.gz";
     }
+
+    if (const auto& status_query = argument_parser.present("--flowstatus")) {
+      if (!minifi::controller::getFlowStatus(socket_data, *status_query, std::cout)) {
+        std::cout << "Could not connect to remote host " << socket_data.host << ":" << socket_data.port << std::endl;
+      }
+    }
   } catch (const std::exception &exc) {
     // catch anything thrown within try block that derives from std::exception
     std::cerr << exc.what() << std::endl;
