@@ -66,9 +66,8 @@ bootstrap_compiler() {
 }
 build_deps(){
 
-    COMMAND="brew install cmake"
+    COMMAND="brew install cmake perl bzip2"
     INSTALLED=()
-    INSTALLED+=("bzip2")
     for option in "${OPTIONS[@]}" ; do
         option_value="${!option}"
         if [ "$option_value" = "${TRUE}" ]; then
@@ -79,34 +78,21 @@ build_deps(){
                 VALUE=${cmake_opt#*:}
                 if [ "$KEY" = "$option" ]; then
                     FOUND_VALUE="$VALUE"
-                    if [ "$FOUND_VALUE" = "libpcap" ]; then
-                        INSTALLED+=("libpcap")
-                    elif [ "$FOUND_VALUE" = "libusb" ]; then
-                        INSTALLED+=("libusb")
-                    elif [ "$FOUND_VALUE" = "libpng" ]; then
-                        INSTALLED+=("libpng")
-                    elif [ "$FOUND_VALUE" = "bison" ]; then
+                    if [ "$FOUND_VALUE" = "bison" ]; then
                         install_bison
                     elif [ "$FOUND_VALUE" = "flex" ]; then
                         INSTALLED+=("flex")
                     elif [ "$FOUND_VALUE" = "python" ]; then
                         INSTALLED+=("python")
-                    elif [ "$FOUND_VALUE" = "jnibuild" ]; then
-                        brew cask install java8 > /dev/null 2>&1
-                        INSTALLED+=("maven")
                     elif [ "$FOUND_VALUE" = "libtool" ]; then
                         INSTALLED+=("libtool")
                     elif [ "$FOUND_VALUE" = "automake" ]; then
                         INSTALLED+=("automake")
                         INSTALLED+=("autoconf")
-                    elif [ "$FOUND_VALUE" = "gpsd" ]; then
-                        INSTALLED+=("gpsd")
                     elif [ "$FOUND_VALUE" = "libarchive" ]; then
                         INSTALLED+=("bzip2")
                     elif [ "$FOUND_VALUE" = "libssh2" ]; then
                         INSTALLED+=("libssh2")
-                    elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
-                        INSTALLED+=("perl")
                     fi
                 fi
             done
