@@ -18,8 +18,8 @@ from .containers.MinifiContainer import MinifiOptions
 from .containers.MinifiContainer import MinifiContainer
 from .containers.NifiContainer import NifiContainer
 from .containers.NifiContainer import NiFiOptions
-from .containers.ZookeeperContainer import ZookeeperContainer
 from .containers.KafkaBrokerContainer import KafkaBrokerContainer
+from .containers.KinesisServerContainer import KinesisServerContainer
 from .containers.S3ServerContainer import S3ServerContainer
 from .containers.AzureStorageServerContainer import AzureStorageServerContainer
 from .containers.FakeGcsServerContainer import FakeGcsServerContainer
@@ -121,15 +121,6 @@ class ContainerStore:
                                                                              image_store=self.image_store,
                                                                              command=command))
         elif engine == 'kafka-broker':
-            zookeeper_name = self.get_container_name_with_postfix('zookeeper')
-            if zookeeper_name not in self.containers:
-                self.containers.setdefault(zookeeper_name,
-                                           ZookeeperContainer(feature_context=feature_context,
-                                                              name=zookeeper_name,
-                                                              vols=self.vols,
-                                                              network=self.network,
-                                                              image_store=self.image_store,
-                                                              command=command))
             return self.containers.setdefault(container_name,
                                               KafkaBrokerContainer(feature_context=feature_context,
                                                                    name=container_name,
@@ -153,6 +144,14 @@ class ContainerStore:
                                                                 network=self.network,
                                                                 image_store=self.image_store,
                                                                 command=command))
+        elif engine == 'kinesis-server':
+            return self.containers.setdefault(container_name,
+                                              KinesisServerContainer(feature_context=feature_context,
+                                                                     name=container_name,
+                                                                     vols=self.vols,
+                                                                     network=self.network,
+                                                                     image_store=self.image_store,
+                                                                     command=command))
         elif engine == 'azure-storage-server':
             return self.containers.setdefault(container_name,
                                               AzureStorageServerContainer(feature_context=feature_context,
@@ -314,6 +313,9 @@ class ContainerStore:
         else:
             raise Exception('invalid flow engine: \'%s\'' % engine)
 
+    def acquire_transient_minifi(self, context, container_name: str, engine='minifi-cpp'):
+        self.acquire_container(context=context, container_name=container_name, engine=engine, command=["/bin/sh", "-c", "timeout 10s {run_minifi} && sleep 100".format(run_minifi=MinifiContainer.MINIFI_LOCATIONS.run_minifi_cmd)])
+
     def deploy_container(self, container_name: str):
         container_name = self.get_container_name_with_postfix(container_name)
         if container_name is None or container_name not in self.containers:
@@ -382,6 +384,9 @@ class ContainerStore:
     def remove_python_requirements_txt_in_minifi(self):
         self.minifi_options.remove_python_requirements_txt = True
 
+    def use_nifi_python_processors_without_dependencies_in_minifi(self):
+        self.minifi_options.use_nifi_python_processors_without_dependencies = True
+
     def set_yaml_in_minifi(self):
         self.minifi_options.config_format = "yaml"
 
@@ -397,6 +402,15 @@ class ContainerStore:
     def enable_example_minifi_python_processors(self):
         self.minifi_options.enable_example_minifi_python_processors = True
 
+    def enable_openssl_fips_mode_in_minifi(self):
+        self.minifi_options.enable_openssl_fips_mode = True
+
+    def disable_openssl_fips_mode_in_minifi(self):
+        self.minifi_options.enable_openssl_fips_mode = False
+
+    def llama_model_is_downloaded_in_minifi(self):
+        self.minifi_options.download_llama_model = True
+
     def get_startup_finished_log_entry(self, container_name):
         container_name = self.get_container_name_with_postfix(container_name)
         return self.containers[container_name].get_startup_finished_log_entry()
