@@ -30,6 +30,7 @@ from .checkers.AwsChecker import AwsChecker
 from .checkers.AzureChecker import AzureChecker
 from .checkers.ElasticSearchChecker import ElasticSearchChecker
 from .checkers.GcsChecker import GcsChecker
+from .checkers.KafkaHelper import KafkaHelper
 from .checkers.PostgresChecker import PostgresChecker
 from .checkers.PrometheusChecker import PrometheusChecker
 from .checkers.SplunkChecker import SplunkChecker
@@ -56,6 +57,7 @@ class DockerTestCluster:
         self.minifi_controller_executor = MinifiControllerExecutor(self.container_communicator)
         self.modbus_checker = ModbusChecker(self.container_communicator)
         self.couchbase_checker = CouchbaseChecker()
+        self.kafka_checker = KafkaHelper(self.container_communicator, feature_id)
 
     def cleanup(self):
         self.container_store.cleanup()
@@ -66,6 +68,9 @@ class DockerTestCluster:
     def acquire_container(self, context, name: str, engine: str = 'minifi-cpp', command=None):
         return self.container_store.acquire_container(context=context, container_name=name, engine=engine, command=command)
 
+    def acquire_transient_minifi(self, context, name: str, engine: str = 'minifi-cpp'):
+        return self.container_store.acquire_transient_minifi(context=context, container_name=name, engine=engine)
+
     def deploy_container(self, name):
         self.container_store.deploy_container(name)
 
@@ -102,6 +107,12 @@ class DockerTestCluster:
     def enable_prometheus_with_ssl_in_minifi(self):
         self.container_store.enable_prometheus_with_ssl_in_minifi()
 
+    def enable_openssl_fips_mode_in_minifi(self):
+        self.container_store.enable_openssl_fips_mode_in_minifi()
+
+    def disable_openssl_fips_mode_in_minifi(self):
+        self.container_store.disable_openssl_fips_mode_in_minifi()
+
     def enable_sql_in_minifi(self):
         self.container_store.enable_sql_in_minifi()
 
@@ -123,6 +134,9 @@ class DockerTestCluster:
     def remove_python_requirements_txt_in_minifi(self):
         self.container_store.remove_python_requirements_txt_in_minifi()
 
+    def use_nifi_python_processors_without_dependencies_in_minifi(self):
+        self.container_store.use_nifi_python_processors_without_dependencies_in_minifi()
+
     def set_yaml_in_minifi(self):
         self.container_store.set_yaml_in_minifi()
 
@@ -138,6 +152,9 @@ class DockerTestCluster:
     def enable_example_minifi_python_processors(self):
         self.container_store.enable_example_minifi_python_processors()
 
+    def llama_model_is_downloaded_in_minifi(self):
+        self.container_store.llama_model_is_downloaded_in_minifi()
+
     def get_app_log(self, container_name):
         container_name = self.container_store.get_container_name_with_postfix(container_name)
         log_source = self.container_store.log_source(container_name)
@@ -190,6 +207,10 @@ class DockerTestCluster:
                  and output.count("TCP_MISS") >= output.count("TCP_DENIED"))
                  or output.count("TCP_DENIED") == 0 and "TCP_MISS" in output)
 
+    def check_kinesis_server_record_data(self, container_name, record_data):
+        container_name = self.container_store.get_container_name_with_postfix(container_name)
+        return self.aws_checker.check_kinesis_server_record_data(container_name, record_data)
+
     def check_s3_server_object_data(self, container_name, test_data):
         container_name = self.container_store.get_container_name_with_postfix(container_name)
         return self.aws_checker.check_s3_server_object_data(container_name, test_data)
@@ -270,9 +291,13 @@ class DockerTestCluster:
     def segfault_happened(self):
         return self.segfault
 
-    def wait_for_kafka_consumer_to_be_registered(self, kafka_container_name):
+    def wait_for_kafka_consumer_to_be_registered(self, kafka_container_name: str, count: int):
         kafka_container_name = self.container_store.get_container_name_with_postfix(kafka_container_name)
-        return self.wait_for_app_logs_regex(kafka_container_name, "Assignment received from leader.*for group docker_test_group", 60)
+        return self.wait_for_app_logs_regex(kafka_container_name, "Assignment received from leader.*for group docker_test_group", 60, count)
+
+    def wait_for_kafka_consumer_to_be_reregistered(self, kafka_container_name):
+        kafka_container_name = self.container_store.get_container_name_with_postfix(kafka_container_name)
+        return self.wait_for_app_logs_regex(kafka_container_name, "Assignment received from leader.*for group docker_test_group.*Assignment received from leader.*for group docker_test_group.", 60)
 
     def wait_for_metric_class_on_prometheus(self, metric_class, timeout_seconds):
         return self.prometheus_checker.wait_for_metric_class_on_prometheus(metric_class, timeout_seconds)
@@ -307,7 +332,7 @@ class DockerTestCluster:
 
     def wait_for_container_startup_to_finish(self, container_name):
         container_name = self.container_store.get_container_name_with_postfix(container_name)
-        startup_success = self.wait_for_startup_log(container_name, 300)
+        startup_success = self.wait_for_startup_log(container_name, 160)
         if not startup_success:
             logging.error("Cluster startup failed for %s", container_name)
             return False
