@@ -20,6 +20,11 @@ class AwsChecker:
     def __init__(self, container_communicator):
         self.container_communicator = container_communicator
 
+    @retry_check()
+    def check_kinesis_server_record_data(self, container_name, record_data):
+        (code, output) = self.container_communicator.execute_command(container_name, ["node", "/app/consumer/consumer.js", record_data])
+        return code == 0
+
     @retry_check()
     def check_s3_server_object_data(self, container_name, test_data):
         (code, output) = self.container_communicator.execute_command(container_name, ["find", "/s3mockroot/test_bucket", "-mindepth", "1", "-maxdepth", "1", "-type", "d"])
@@ -34,7 +39,11 @@ class AwsChecker:
         (code, output) = self.container_communicator.execute_command(container_name, ["find", "/s3mockroot/test_bucket", "-mindepth", "1", "-maxdepth", "1", "-type", "d"])
         if code != 0:
             return False
-        s3_mock_dir = output.strip()
+        dir_candidates = output.split("\n")
+        for candidate in dir_candidates:
+            if "multiparts" not in candidate:
+                s3_mock_dir = candidate
+                break
         (code, md5_output) = self.container_communicator.execute_command(container_name, ["md5sum", s3_mock_dir + "/binaryData"])
         if code != 0:
             return False
