@@ -28,7 +28,7 @@ class NiFiOptions:
 
 
 class NifiContainer(FlowContainer):
-    NIFI_VERSION = '2.0.0-M2'
+    NIFI_VERSION = '2.2.0'
     NIFI_ROOT = '/opt/nifi/nifi-' + NIFI_VERSION
 
     def __init__(self, feature_context, config_dir, options, name, vols, network, image_store, command=None):
@@ -55,16 +55,16 @@ class NifiContainer(FlowContainer):
                                  r"sed -i -e 's/^\(nifi.sensitive.props.key\)=.*/\1=secret_key_12345/' {nifi_root}/conf/nifi.properties && "
                                  r"sed -i -e 's/^\(nifi.remote.input.secure\)=.*/\1=false/' {nifi_root}/conf/nifi.properties && "
                                  r"sed -i -e 's/^\(nifi.web.http.port\)=.*/\1=8080/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.web.https.port\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.web.https.host\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.web.https.port\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.web.https.host\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
                                  r"sed -i -e 's/^\(nifi.web.http.host\)=.*/\1={name}/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.security.keystore\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.security.keystoreType\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.security.keystorePasswd\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.security.keyPasswd\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.security.truststore\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.security.truststoreType\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
-                                 r"sed -i -e 's/^\(nifi.security.truststorePasswd\)=.*/#\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.security.keystore\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.security.keystoreType\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.security.keystorePasswd\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.security.keyPasswd\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.security.truststore\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.security.truststoreType\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
+                                 r"sed -i -e 's/^\(nifi.security.truststorePasswd\)=.*/\1=/' {nifi_root}/conf/nifi.properties && "
                                  r"sed -i -e 's/^\(nifi.remote.input.socket.port\)=.*/\1=10000/' {nifi_root}/conf/nifi.properties && "
                                  r"cp /tmp/nifi_config/flow.json.gz {nifi_root}/conf && {nifi_root}/bin/nifi.sh run & "
                                  r"nifi_pid=$! &&"
