@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import logging
+import os
 import time
 import uuid
 
@@ -59,9 +60,11 @@ class MiNiFi_integration_test:
     def acquire_container(self, context, name, engine='minifi-cpp', command=None):
         return self.cluster.acquire_container(context=context, name=name, engine=engine, command=command)
 
+    def acquire_transient_minifi(self, context, name, engine='minifi-cpp'):
+        return self.cluster.acquire_transient_minifi(context=context, name=name, engine=engine)
+
     def start_kafka_broker(self, context):
         self.cluster.acquire_container(context=context, name='kafka-broker', engine='kafka-broker')
-        self.cluster.deploy_container(name='zookeeper')
         self.cluster.deploy_container(name='kafka-broker')
         assert self.cluster.wait_for_container_startup_to_finish('kafka-broker') or self.cluster.log_app_output()
 
@@ -177,6 +180,11 @@ class MiNiFi_integration_test:
         output_validator.set_output_dir(self.file_system_observer.get_output_dir())
         self.__check_output_after_time_period(wait_time_in_seconds, output_validator)
 
+    def check_for_no_files_generated_in_subdir(self, wait_time_in_seconds, subdir):
+        output_validator = NoFileOutPutValidator()
+        output_validator.set_output_dir(self.file_system_observer.get_output_dir() + "/" + subdir)
+        self.__check_output_after_time_period(wait_time_in_seconds, output_validator)
+
     def check_for_single_file_with_content_generated(self, content, timeout_seconds):
         output_validator = SingleFileOutputValidator(decode_escaped_str(content))
         output_validator.set_output_dir(self.file_system_observer.get_output_dir())
@@ -192,6 +200,34 @@ class MiNiFi_integration_test:
         output_validator.set_output_dir(self.file_system_observer.get_output_dir())
         self.__check_output(timeout_seconds, output_validator, file_count)
 
+    def check_subdirectory(self, sub_directory: str, expected_contents: list, timeout: int, interval: float = 1.0) -> bool:
+        logging.info("check_directory")
+        start_time = time.time()
+        expected_contents.sort()
+        while time.time() - start_time < timeout:
+            try:
+                current_contents = []
+                directory = self.file_system_observer.get_output_dir() + "/" + sub_directory
+                current_files = os.listdir(directory)
+                for file in current_files:
+                    file_path = os.path.join(directory, file)
+                    with open(file_path, 'r', encoding='utf-8', errors='ignore') as f:
+                        content = f.read()
+                        current_contents.append(content)
+                current_contents.sort()
+
+                if current_contents == expected_contents:
+                    logging.info("subdir checks out")
+                    return True
+                logging.info(f"expected: {expected_contents} vs actual {current_contents}")
+
+            except Exception as e:
+                print(f"Error checking directory: {e}")
+
+            time.sleep(interval)
+
+        return False
+
     def check_for_at_least_one_file_with_matching_content(self, regex, timeout_seconds):
         output_validator = SingleOrMultiFileOutputRegexValidator(regex)
         output_validator.set_output_dir(self.file_system_observer.get_output_dir())
@@ -251,6 +287,9 @@ class MiNiFi_integration_test:
         assert not self.cluster.segfault_happened() or self.cluster.log_app_output()
         assert validator.validate() or self.cluster.log_app_output()
 
+    def check_kinesis_server_record_data(self, kinesis_container_name, record_data):
+        assert self.cluster.check_kinesis_server_record_data(kinesis_container_name, record_data) or self.cluster.log_app_output()
+
     def check_s3_server_object_data(self, s3_container_name, object_data):
         assert self.cluster.check_s3_server_object_data(s3_container_name, object_data) or self.cluster.log_app_output()
 
@@ -269,8 +308,8 @@ class MiNiFi_integration_test:
     def check_azure_storage_server_data(self, azure_container_name, object_data):
         assert self.cluster.check_azure_storage_server_data(azure_container_name, object_data) or self.cluster.log_app_output()
 
-    def wait_for_kafka_consumer_to_be_registered(self, kafka_container_name):
-        assert self.cluster.wait_for_kafka_consumer_to_be_registered(kafka_container_name) or self.cluster.log_app_output()
+    def wait_for_kafka_consumer_to_be_registered(self, kafka_container_name, count):
+        assert self.cluster.wait_for_kafka_consumer_to_be_registered(kafka_container_name, count) or self.cluster.log_app_output()
 
     def check_splunk_event(self, splunk_container_name, query):
         assert self.cluster.check_splunk_event(splunk_container_name, query) or self.cluster.log_app_output()
@@ -392,6 +431,9 @@ class MiNiFi_integration_test:
     def remove_python_requirements_txt_in_minifi(self):
         self.cluster.remove_python_requirements_txt_in_minifi()
 
+    def use_nifi_python_processors_without_dependencies_in_minifi(self):
+        self.cluster.use_nifi_python_processors_without_dependencies_in_minifi()
+
     def set_yaml_in_minifi(self):
         self.cluster.set_yaml_in_minifi()
 
@@ -401,6 +443,9 @@ class MiNiFi_integration_test:
     def set_controller_socket_properties_in_minifi(self):
         self.cluster.set_controller_socket_properties_in_minifi()
 
+    def llama_model_is_downloaded_in_minifi(self):
+        self.cluster.llama_model_is_downloaded_in_minifi()
+
     def update_flow_config_through_controller(self, container_name: str):
         self.cluster.update_flow_config_through_controller(container_name)
 
@@ -437,6 +482,12 @@ class MiNiFi_integration_test:
     def enable_example_minifi_python_processors(self):
         self.cluster.enable_example_minifi_python_processors()
 
+    def enable_openssl_fips_mode_in_minifi(self):
+        self.cluster.enable_openssl_fips_mode_in_minifi()
+
+    def disable_openssl_fips_mode_in_minifi(self):
+        self.cluster.disable_openssl_fips_mode_in_minifi()
+
     def debug_bundle_can_be_retrieved_through_minifi_controller(self, container_name: str):
         assert self.cluster.debug_bundle_can_be_retrieved_through_minifi_controller(container_name) or self.cluster.log_app_output()
 
