@@ -22,3 +22,6 @@ class InputPort(Connectable):
         super(InputPort, self).__init__(name=name)
 
         self.remote_process_group = remote_process_group
+        self.properties = {}
+        if self.remote_process_group:
+            self.properties = self.remote_process_group.properties
