@@ -23,8 +23,9 @@ from ..core.Funnel import Funnel
 
 
 class Minifi_flow_json_serializer:
-    def serialize(self, start_nodes, controllers):
+    def serialize(self, start_nodes, controllers, parameter_context_name: str, parameter_contexts):
         res = {
+            'parameterContexts': [],
             'rootGroup': {
                 'name': 'MiNiFi Flow',
                 'processors': [],
@@ -36,6 +37,24 @@ class Minifi_flow_json_serializer:
         }
         visited = []
 
+        if parameter_context_name:
+            res['rootGroup']['parameterContextName'] = parameter_context_name
+
+        if parameter_contexts:
+            for context_name in parameter_contexts:
+                res['parameterContexts'].append({
+                    'identifier': str(uuid.uuid4()),
+                    'name': context_name,
+                    'parameters': []
+                })
+                for parameter in parameter_contexts[context_name]:
+                    res['parameterContexts'][-1]['parameters'].append({
+                        'name': parameter.name,
+                        'description': '',
+                        'sensitive': False,
+                        'value': parameter.value
+                    })
+
         for node in start_nodes:
             self.serialize_node(node, res['rootGroup'], visited)
 
@@ -75,7 +94,8 @@ class Minifi_flow_json_serializer:
 
             res_group['inputPorts'].append({
                 'identifier': str(connectable.instance_id),
-                'name': connectable.name
+                'name': connectable.name,
+                'properties': connectable.properties
             })
 
         if isinstance(connectable, Processor):
@@ -98,12 +118,7 @@ class Minifi_flow_json_serializer:
                     continue
 
                 visited.append(svc)
-                root['controllerServices'].append({
-                    'name': svc.name,
-                    'identifier': svc.id,
-                    'type': svc.service_class,
-                    'properties': svc.properties
-                })
+                self.serialize_controller(svc, root)
 
         if isinstance(connectable, Funnel):
             root['funnels'].append({
@@ -139,3 +154,9 @@ class Minifi_flow_json_serializer:
             'type': controller.service_class,
             'properties': controller.properties
         })
+
+        if controller.linked_services:
+            if len(controller.linked_services) == 1:
+                root['controllerServices'][-1]['properties']['Linked Services'] = controller.linked_services[0].name
+            else:
+                root['controllerServices'][-1]['properties']['Linked Services'] = [{"value": service.name} for service in controller.linked_services]
