@@ -18,5 +18,7 @@ from ..core.Processor import Processor
 
 
 class CountingProcessor(Processor):
-    def __init__(self):
-        super(CountingProcessor, self).__init__('CountingProcessor', class_prefix='org.apache.nifi.minifi.processors.examples.')
+    def __init__(self, context):
+        super(CountingProcessor, self).__init__(context=context,
+                                                clazz='CountingProcessor',
+                                                class_prefix='org.apache.nifi.minifi.processors.examples.')
