@@ -18,8 +18,9 @@ from ..core.Processor import Processor
 
 
 class DefragmentText(Processor):
-    def __init__(self, delimiter="<[0-9]+>", schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
-        super(DefragmentText, self).__init__('DefragmentText',
+    def __init__(self, context, delimiter="<[0-9]+>", schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
+        super(DefragmentText, self).__init__(context=context,
+                                             clazz='DefragmentText',
                                              schedule=schedule,
                                              properties={'Delimiter': delimiter},
                                              auto_terminate=['success', 'failure'])
