@@ -18,9 +18,10 @@ from ..core.Processor import Processor
 
 
 class HashContent(Processor):
-    def __init__(self, schedule={"scheduling strategy": "EVENT_DRIVEN"}):
+    def __init__(self, context, schedule={"scheduling strategy": "EVENT_DRIVEN"}):
         super(HashContent, self).__init__(
-            "HashContent",
+            context=context,
+            clazz="HashContent",
             properties={"Hash Attribute": "hash"},
             schedule=schedule,
             auto_terminate=["success", "failure"])
