@@ -16,11 +16,12 @@ from ..core.Processor import Processor
 
 
 class ListenSyslog(Processor):
-    def __init__(self, schedule=None):
+    def __init__(self, context, schedule=None):
         properties = {}
 
         super(ListenSyslog, self).__init__(
-            'ListenSyslog',
+            context=context,
+            clazz='ListenSyslog',
             properties=properties,
             auto_terminate=['success'],
             schedule=schedule)
