@@ -16,11 +16,12 @@ from ..core.Processor import Processor
 
 
 class ListenTCP(Processor):
-    def __init__(self, schedule=None):
+    def __init__(self, context, schedule=None):
         properties = {}
 
         super(ListenTCP, self).__init__(
-            'ListenTCP',
+            context=context,
+            clazz='ListenTCP',
             properties=properties,
             auto_terminate=['success'],
             schedule=schedule)
