@@ -18,8 +18,9 @@ from ..core.Processor import Processor
 
 
 class LogAttribute(Processor):
-    def __init__(self, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
+    def __init__(self, context, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
         super(LogAttribute, self).__init__(
-            'LogAttribute',
+            context=context,
+            clazz='LogAttribute',
             auto_terminate=['success'],
             schedule=schedule)
