@@ -16,7 +16,8 @@ from ..core.Processor import Processor
 
 
 class LogOnDestructionProcessor(Processor):
-    def __init__(self, schedule={'scheduling period': '2 sec'}):
+    def __init__(self, context, schedule={'scheduling period': '2 sec'}):
         super(LogOnDestructionProcessor, self).__init__(
-            'LogOnDestructionProcessor',
+            context=context,
+            clazz='LogOnDestructionProcessor',
             schedule=schedule)
