@@ -18,8 +18,9 @@ from ..core.Processor import Processor
 
 
 class PutOPCProcessor(Processor):
-    def __init__(self, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
+    def __init__(self, context, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
         super(PutOPCProcessor, self).__init__(
-            'PutOPCProcessor',
+            context=context,
+            clazz='PutOPCProcessor',
             auto_terminate=['success', 'failure'],
             schedule=schedule)
