@@ -16,16 +16,16 @@
  */
 #include "FlowConfigEncryptor.h"
 
-#include "core/extension/ExtensionManager.h"
-#include "core/FlowConfiguration.h"
-#include "core/flow/AdaptiveConfiguration.h"
-#include "core/ProcessGroup.h"
-#include "core/RepositoryFactory.h"
-#include "core/repository/VolatileContentRepository.h"
 #include "Defaults.h"
 #include "Utils.h"
-#include "utils/file/FileSystem.h"
+#include "core/FlowConfiguration.h"
+#include "core/ProcessGroup.h"
+#include "core/RepositoryFactory.h"
+#include "core/extension/ExtensionManager.h"
+#include "core/flow/AdaptiveConfiguration.h"
+#include "core/repository/VolatileContentRepository.h"
 #include "utils/Id.h"
+#include "utils/file/FileSystem.h"
 
 namespace minifi = org::apache::nifi::minifi;
 
@@ -82,7 +82,7 @@ std::vector<SensitiveItem> listSensitiveItems(const minifi::core::ProcessGroup &
   process_group.getAllProcessors(processors);
   for (const auto* processor : processors) {
     gsl_Expects(processor);
-    for (const auto& [_, property] : processor->getProperties()) {
+    for (const auto& [_, property] : processor->getSupportedProperties()) {
       if (property.isSensitive()) {
         sensitive_items.push_back(SensitiveItem{
             .component_type = ComponentType::Processor,
@@ -90,7 +90,7 @@ std::vector<SensitiveItem> listSensitiveItems(const minifi::core::ProcessGroup &
             .component_name = processor->getName(),
             .item_name = property.getName(),
             .item_display_name = property.getDisplayName(),
-            .item_value = property.getValue().to_string()});
+            .item_value = std::string{property.getValue().value_or("")}});
       }
     }
   }
@@ -104,7 +104,7 @@ std::vector<SensitiveItem> listSensitiveItems(const minifi::core::ProcessGroup &
       continue;
     }
     processed_controller_services.insert(controller_service->getUUID());
-    for (const auto& [_, property] : controller_service->getProperties()) {
+    for (const auto& [_, property] : controller_service->getSupportedProperties()) {
       if (property.isSensitive()) {
         sensitive_items.push_back(SensitiveItem{
             .component_type = ComponentType::ControllerService,
@@ -112,7 +112,7 @@ std::vector<SensitiveItem> listSensitiveItems(const minifi::core::ProcessGroup &
             .component_name = controller_service->getName(),
             .item_name = property.getName(),
             .item_display_name = property.getDisplayName(),
-            .item_value = property.getValue().to_string()});
+            .item_value = std::string{property.getValue().value_or("")}});
       }
     }
   }
@@ -179,9 +179,8 @@ void encryptSensitiveValuesInFlowConfig(const EncryptionKeys& keys, const std::f
     throw std::runtime_error("Error: cannot re-encrypt without an .old key!");
   }
 
-  const auto configure = std::make_shared<Configure>();
-  configure->setHome(minifi_home);
-  configure->loadConfigureFile(DEFAULT_NIFI_PROPERTIES_FILE);
+  const auto configure = std::make_shared<ConfigureImpl>();
+  configure->loadConfigureFile(minifi_home / DEFAULT_NIFI_PROPERTIES_FILE);
 
   bool encrypt_whole_flow_config_file = (configure->get(Configure::nifi_flow_configuration_encrypt) | utils::andThen(utils::string::toBool)).value_or(false);
   auto whole_file_encryptor = encrypt_whole_flow_config_file ? utils::crypto::EncryptionProvider::create(minifi_home) : std::nullopt;
@@ -191,7 +190,7 @@ void encryptSensitiveValuesInFlowConfig(const EncryptionKeys& keys, const std::f
       utils::crypto::EncryptionProvider{utils::crypto::XSalsa20Cipher{*keys.old_key}} :
       utils::crypto::EncryptionProvider{utils::crypto::XSalsa20Cipher{keys.encryption_key}};
 
-  core::extension::ExtensionManager::get().initialize(configure);
+  core::extension::ExtensionManagerImpl::get().initialize(configure);
 
   core::flow::AdaptiveConfiguration adaptive_configuration{core::ConfigurationContext{
       .flow_file_repo = nullptr,
