@@ -26,7 +26,7 @@
 
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "io/StreamPipe.h"
 #include "S3Processor.h"
 #include "utils/ArrayUtils.h"
@@ -37,7 +37,7 @@ class FlowProcessorS3TestsFixture;
 
 namespace org::apache::nifi::minifi::aws::processors {
 
-class FetchS3Object : public S3Processor {
+class FetchS3Object : public S3Processor {  // NOLINT(cppcoreguidelines-special-member-functions)
  public:
   EXTENSIONAPI static constexpr const char* Description = "This Processor retrieves the contents of an S3 Object and writes it to the content of a FlowFile.";
 
@@ -51,7 +51,7 @@ class FetchS3Object : public S3Processor {
       .build();
   EXTENSIONAPI static constexpr auto RequesterPays = core::PropertyDefinitionBuilder<>::createProperty("Requester Pays")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .withDescription("If true, indicates that the requester consents to pay any charges associated with retrieving "
           "objects from the S3 bucket. This sets the 'x-amz-request-payer' header to 'requester'.")
@@ -74,9 +74,7 @@ class FetchS3Object : public S3Processor {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit FetchS3Object(std::string_view name, const minifi::utils::Identifier& uuid = minifi::utils::Identifier())
-    : S3Processor(name, uuid, core::logging::LoggerFactory<FetchS3Object>::getLogger(uuid)) {
-  }
+  using S3Processor::S3Processor;
 
   ~FetchS3Object() override = default;
 
@@ -87,14 +85,15 @@ class FetchS3Object : public S3Processor {
  private:
   friend class ::FlowProcessorS3TestsFixture<FetchS3Object>;
 
-  explicit FetchS3Object(const std::string& name, const minifi::utils::Identifier& uuid, std::unique_ptr<aws::s3::S3RequestSender> s3_request_sender)
-    : S3Processor(name, uuid, core::logging::LoggerFactory<FetchS3Object>::getLogger(uuid), std::move(s3_request_sender)) {
+  explicit FetchS3Object(core::ProcessorMetadata metadata, std::unique_ptr<aws::s3::S3RequestSender> s3_request_sender)
+    : S3Processor(metadata, std::move(s3_request_sender)) {
   }
 
   std::optional<aws::s3::GetObjectRequestParameters> buildFetchS3RequestParams(
-    core::ProcessContext& context,
+    const core::ProcessContext& context,
     const core::FlowFile& flow_file,
-    const CommonProperties &common_properties) const;
+    const CommonProperties &common_properties,
+    std::string_view bucket) const;
 
   bool requester_pays_ = false;
 };
