@@ -41,15 +41,14 @@ void PutS3Object::fillUserMetadata(core::ProcessContext& context) {
   const auto &dynamic_prop_keys = context.getDynamicPropertyKeys();
   bool first_property = true;
   for (const auto &prop_key : dynamic_prop_keys) {
-    std::string prop_value;
-    if (context.getDynamicProperty(prop_key, prop_value) && !prop_value.empty()) {
-      logger_->log_debug("PutS3Object: DynamicProperty: [{}] -> [{}]", prop_key, prop_value);
-      user_metadata_map_.emplace(prop_key, prop_value);
+    if (const auto prop_value = context.getDynamicProperty(prop_key); prop_value && !prop_value->empty()) {
+      logger_->log_debug("PutS3Object: DynamicProperty: [{}] -> [{}]", prop_key, *prop_value);
+      user_metadata_map_.emplace(prop_key, *prop_value);
       if (first_property) {
-        user_metadata_ = minifi::utils::string::join_pack(prop_key, "=", prop_value);
+        user_metadata_ = minifi::utils::string::join_pack(prop_key, "=", *prop_value);
         first_property = false;
       } else {
-        user_metadata_ += minifi::utils::string::join_pack(",", prop_key, "=", prop_value);
+        user_metadata_ += minifi::utils::string::join_pack(",", prop_key, "=", *prop_value);
       }
     }
   }
@@ -59,40 +58,44 @@ void PutS3Object::fillUserMetadata(core::ProcessContext& context) {
 void PutS3Object::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) {
   S3Processor::onSchedule(context, session_factory);
 
-  if (!context.getProperty(StorageClass, storage_class_)
-      || storage_class_.empty()
-      || !ranges::contains(STORAGE_CLASSES, storage_class_)) {
-    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Storage Class property missing or invalid");
-  }
+  storage_class_ = minifi::utils::parseProperty(context, StorageClass);
   logger_->log_debug("PutS3Object: Storage Class [{}]", storage_class_);
 
-  if (!context.getProperty(ServerSideEncryption, server_side_encryption_)
-      || server_side_encryption_.empty()
-      || !ranges::contains(SERVER_SIDE_ENCRYPTIONS, server_side_encryption_)) {
-    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Server Side Encryption property missing or invalid");
-  }
+  server_side_encryption_ = minifi::utils::parseProperty(context, ServerSideEncryption);
   logger_->log_debug("PutS3Object: Server Side Encryption [{}]", server_side_encryption_);
 
-  if (auto use_path_style_access = context.getProperty<bool>(UsePathStyleAccess)) {
+  if (const auto use_path_style_access = minifi::utils::parseOptionalBoolProperty(context, UsePathStyleAccess)) {
     use_virtual_addressing_ = !*use_path_style_access;
   }
 
-  if (!context.getProperty(MultipartThreshold, multipart_threshold_) || multipart_threshold_ > getMaxUploadSize() || multipart_threshold_ < getMinPartSize()) {
-    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Multipart Threshold is not between the valid 5MB and 5GB range!");
-  }
+  multipart_threshold_ = context.getProperty(MultipartThreshold)
+      | minifi::utils::andThen([&](const auto str) { return parsing::parseDataSizeMinMax(str, getMinPartSize(), getMaxUploadSize()); })
+      | minifi::utils::orThrow("Multipart Part Size is not between the valid 5MB and 5GB range!");
+
   logger_->log_debug("PutS3Object: Multipart Threshold {}", multipart_threshold_);
-  if (!context.getProperty(MultipartPartSize, multipart_size_) || multipart_size_ > getMaxUploadSize() || multipart_size_ < getMinPartSize()) {
-    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Multipart Part Size is not between the valid 5MB and 5GB range!");
-  }
+
+  multipart_size_ = context.getProperty(MultipartPartSize)
+    | minifi::utils::andThen([&](const auto str) { return parsing::parseDataSizeMinMax(str, getMinPartSize(), getMaxUploadSize()); })
+    | minifi::utils::orThrow("Multipart Part Size is not between the valid 5MB and 5GB range!");
+
+
   logger_->log_debug("PutS3Object: Multipart Size {}", multipart_size_);
 
 
-  multipart_upload_ageoff_interval_ = minifi::utils::getRequiredPropertyOrThrow<core::TimePeriodValue>(context, MultipartUploadAgeOffInterval.name).getMilliseconds();
+  multipart_upload_ageoff_interval_ = minifi::utils::parseDurationProperty(context, MultipartUploadAgeOffInterval);
   logger_->log_debug("PutS3Object: Multipart Upload Ageoff Interval {}", multipart_upload_ageoff_interval_);
 
-  multipart_upload_max_age_threshold_ = minifi::utils::getRequiredPropertyOrThrow<core::TimePeriodValue>(context, MultipartUploadMaxAgeThreshold.name).getMilliseconds();
+  multipart_upload_max_age_threshold_ = minifi::utils::parseDurationProperty(context, MultipartUploadMaxAgeThreshold);
   logger_->log_debug("PutS3Object: Multipart Upload Max Age Threshold {}", multipart_upload_max_age_threshold_);
 
+  const auto checksum_algorithm_str = parseProperty(context, ChecksumAlgorithm);
+  if (!ranges::contains(CHECKSUM_ALGORITHMS, checksum_algorithm_str)) {
+    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Checksum Algorithm property missing or invalid");
+  }
+
+  checksum_algorithm_ = minifi::utils::at(aws::s3::CHECKSUM_ALGORITHM_MAP, checksum_algorithm_str);
+  logger_->log_debug("PutS3Object: Checksum Algorithm {}", magic_enum::enum_name(checksum_algorithm_));
+
   fillUserMetadata(context);
 
   auto state_manager = context.getStateManager();
@@ -116,10 +119,13 @@ std::string PutS3Object::parseAccessControlList(const std::string &comma_separat
 }
 
 bool PutS3Object::setCannedAcl(
-    core::ProcessContext& context,
+    const core::ProcessContext& context,
     const core::FlowFile& flow_file,
     aws::s3::PutObjectRequestParameters &put_s3_request_params) const {
-  context.getProperty(CannedACL, put_s3_request_params.canned_acl, &flow_file);
+  if (const auto canned_acl = context.getProperty(CannedACL, &flow_file)) {
+    put_s3_request_params.canned_acl = *canned_acl;
+  }
+
   if (!put_s3_request_params.canned_acl.empty() && !ranges::contains(CANNED_ACLS, put_s3_request_params.canned_acl)) {
     logger_->log_error("Canned ACL is invalid!");
     return false;
@@ -129,50 +135,50 @@ bool PutS3Object::setCannedAcl(
 }
 
 bool PutS3Object::setAccessControl(
-      core::ProcessContext& context,
+      const core::ProcessContext& context,
       const core::FlowFile& flow_file,
       aws::s3::PutObjectRequestParameters &put_s3_request_params) const {
-  std::string value;
-  if (context.getProperty(FullControlUserList, value, &flow_file) && !value.empty()) {
-    put_s3_request_params.fullcontrol_user_list = parseAccessControlList(value);
-    logger_->log_debug("PutS3Object: Full Control User List [{}]", value);
+  if (const auto full_control_user_list = context.getProperty(FullControlUserList, &flow_file)) {
+    put_s3_request_params.fullcontrol_user_list = parseAccessControlList(*full_control_user_list);
+    logger_->log_debug("PutS3Object: Full Control User List [{}]", *full_control_user_list);
   }
-  if (context.getProperty(ReadPermissionUserList, value, &flow_file) && !value.empty()) {
-    put_s3_request_params.read_permission_user_list = parseAccessControlList(value);
-    logger_->log_debug("PutS3Object: Read Permission User List [{}]", value);
+  if (const auto read_permission_user_list = context.getProperty(ReadPermissionUserList, &flow_file)) {
+    put_s3_request_params.read_permission_user_list = parseAccessControlList(*read_permission_user_list);
+    logger_->log_debug("PutS3Object: Read Permission User List [{}]", *read_permission_user_list);
   }
-  if (context.getProperty(ReadACLUserList, value, &flow_file) && !value.empty()) {
-    put_s3_request_params.read_acl_user_list = parseAccessControlList(value);
-    logger_->log_debug("PutS3Object: Read ACL User List [{}]", value);
+  if (const auto read_acl_user_list = context.getProperty(ReadACLUserList, &flow_file)) {
+    put_s3_request_params.read_acl_user_list = parseAccessControlList(*read_acl_user_list);
+    logger_->log_debug("PutS3Object: Read ACL User List [{}]", *read_acl_user_list);
   }
-  if (context.getProperty(WriteACLUserList, value, &flow_file) && !value.empty()) {
-    put_s3_request_params.write_acl_user_list = parseAccessControlList(value);
-    logger_->log_debug("PutS3Object: Write ACL User List [{}]", value);
+  if (const auto write_acl_user_list = context.getProperty(WriteACLUserList, &flow_file)) {
+    put_s3_request_params.write_acl_user_list = parseAccessControlList(*write_acl_user_list);
+    logger_->log_debug("PutS3Object: Write ACL User List [{}]", *write_acl_user_list);
   }
 
   return setCannedAcl(context, flow_file, put_s3_request_params);
 }
 
 std::optional<aws::s3::PutObjectRequestParameters> PutS3Object::buildPutS3RequestParams(
-    core::ProcessContext& context,
+    const core::ProcessContext& context,
     const core::FlowFile& flow_file,
-    const CommonProperties &common_properties) const {
+    const CommonProperties &common_properties,
+    const std::string_view bucket) const {
   gsl_Expects(client_config_);
   aws::s3::PutObjectRequestParameters params(common_properties.credentials, *client_config_);
   params.setClientConfig(common_properties.proxy, common_properties.endpoint_override_url);
-  params.bucket = common_properties.bucket;
+  params.bucket = bucket;
   params.user_metadata_map = user_metadata_map_;
   params.server_side_encryption = server_side_encryption_;
   params.storage_class = storage_class_;
 
-  context.getProperty(ObjectKey, params.object_key, &flow_file);
+  params.object_key = context.getProperty(ObjectKey, &flow_file).value_or("");
   if (params.object_key.empty() && (!flow_file.getAttribute("filename", params.object_key) || params.object_key.empty())) {
     logger_->log_error("No Object Key is set and default object key 'filename' attribute could not be found!");
     return std::nullopt;
   }
   logger_->log_debug("PutS3Object: Object Key [{}]", params.object_key);
 
-  context.getProperty(ContentType, params.content_type, &flow_file);
+  params.content_type = context.getProperty(ContentType, &flow_file).value_or("");
   logger_->log_debug("PutS3Object: Content Type [{}]", params.content_type);
 
   if (!setAccessControl(context, flow_file, params)) {
@@ -180,6 +186,7 @@ std::optional<aws::s3::PutObjectRequestParameters> PutS3Object::buildPutS3Reques
   }
 
   params.use_virtual_addressing = use_virtual_addressing_;
+  params.checksum_algorithm = checksum_algorithm_;
   return params;
 }
 
@@ -209,7 +216,7 @@ void PutS3Object::setAttributes(
   }
 }
 
-void PutS3Object::ageOffMultipartUploads(const CommonProperties &common_properties) {
+void PutS3Object::ageOffMultipartUploads(const CommonProperties &common_properties, const std::string_view bucket) {
   {
     std::lock_guard<std::mutex> lock(last_ageoff_mutex_);
     const auto now = std::chrono::system_clock::now();
@@ -223,7 +230,7 @@ void PutS3Object::ageOffMultipartUploads(const CommonProperties &common_properti
   logger_->log_trace("Listing aged off multipart uploads still in progress.");
   aws::s3::ListMultipartUploadsRequestParameters list_params(common_properties.credentials, *client_config_);
   list_params.setClientConfig(common_properties.proxy, common_properties.endpoint_override_url);
-  list_params.bucket = common_properties.bucket;
+  list_params.bucket = bucket;
   list_params.age_off_limit = multipart_upload_max_age_threshold_;
   list_params.use_virtual_addressing = use_virtual_addressing_;
   auto aged_off_uploads_in_progress = s3_wrapper_.listMultipartUploads(list_params);
@@ -232,14 +239,14 @@ void PutS3Object::ageOffMultipartUploads(const CommonProperties &common_properti
     return;
   }
 
-  logger_->log_info("Found {} aged off pending multipart upload jobs in bucket '{}'", aged_off_uploads_in_progress->size(), common_properties.bucket);
+  logger_->log_info("Found {} aged off pending multipart upload jobs in bucket '{}'", aged_off_uploads_in_progress->size(), bucket);
   size_t aborted = 0;
   for (const auto& upload : *aged_off_uploads_in_progress) {
     logger_->log_info("Aborting multipart upload with key '{}' and upload id '{}' in bucket '{}' due to reaching maximum upload age threshold.",
-      upload.key, upload.upload_id, common_properties.bucket);
+      upload.key, upload.upload_id, bucket);
     aws::s3::AbortMultipartUploadRequestParameters abort_params(common_properties.credentials, *client_config_);
     abort_params.setClientConfig(common_properties.proxy, common_properties.endpoint_override_url);
-    abort_params.bucket = common_properties.bucket;
+    abort_params.bucket = bucket;
     abort_params.key = upload.key;
     abort_params.upload_id = upload.upload_id;
     abort_params.use_virtual_addressing = use_virtual_addressing_;
@@ -250,7 +257,7 @@ void PutS3Object::ageOffMultipartUploads(const CommonProperties &common_properti
     ++aborted;
   }
   if (aborted > 0) {
-    logger_->log_info("Aborted {} pending multipart upload jobs in bucket '{}'", aborted, common_properties.bucket);
+    logger_->log_info("Aborted {} pending multipart upload jobs in bucket '{}'", aborted, bucket);
   }
   s3_wrapper_.ageOffLocalS3MultipartUploadStates(multipart_upload_max_age_threshold_);
 }
@@ -269,9 +276,17 @@ void PutS3Object::onTrigger(core::ProcessContext& context, core::ProcessSession&
     return;
   }
 
-  ageOffMultipartUploads(*common_properties);
+  auto bucket = context.getProperty(Bucket.name, flow_file.get());
+  if (!bucket) {
+    logger_->log_error("Bucket is invalid due to {}", bucket.error().message());
+    session.transfer(flow_file, Failure);
+    return;
+  }
+  logger_->log_debug("S3Processor: Bucket [{}]", *bucket);
 
-  auto put_s3_request_params = buildPutS3RequestParams(context, *flow_file, *common_properties);
+  ageOffMultipartUploads(*common_properties, *bucket);
+
+  auto put_s3_request_params = buildPutS3RequestParams(context, *flow_file, *common_properties, *bucket);
   if (!put_s3_request_params) {
     session.transfer(flow_file, Failure);
     return;
