@@ -30,23 +30,25 @@
 
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "io/StreamPipe.h"
 #include "S3Processor.h"
 #include "utils/ArrayUtils.h"
 #include "utils/gsl.h"
 #include "utils/Id.h"
+#include "utils/Enum.h"
 
 template<typename T>
 class FlowProcessorS3TestsFixture;
 
 namespace org::apache::nifi::minifi::aws::processors {
 
-class PutS3Object : public S3Processor {
+class PutS3Object : public S3Processor {  // NOLINT(cppcoreguidelines-special-member-functions)
  public:
   static constexpr auto CANNED_ACLS = minifi::utils::getKeys(minifi::aws::s3::CANNED_ACL_MAP);
   static constexpr auto STORAGE_CLASSES = minifi::utils::getKeys(minifi::aws::s3::STORAGE_CLASS_MAP);
   static constexpr auto SERVER_SIDE_ENCRYPTIONS = minifi::utils::getKeys(minifi::aws::s3::SERVER_SIDE_ENCRYPTION_MAP);
+  static constexpr auto CHECKSUM_ALGORITHMS = minifi::utils::getKeys(minifi::aws::s3::CHECKSUM_ALGORITHM_MAP);
 
   EXTENSIONAPI static constexpr const char* Description = "Puts FlowFiles to an Amazon S3 Bucket. The upload uses either the PutS3Object method or the PutS3MultipartUpload method. "
       "The PutS3Object method sends the file in a single synchronous call, but it has a 5GB size limit. Larger files are sent using the PutS3MultipartUpload method. "
@@ -84,20 +86,24 @@ class PutS3Object : public S3Processor {
   EXTENSIONAPI static constexpr auto FullControlUserList = core::PropertyDefinitionBuilder<>::createProperty("FullControl User List")
       .withDescription("A comma-separated list of Amazon User ID's or E-mail addresses that specifies who should have Full Control for an object.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto ReadPermissionUserList = core::PropertyDefinitionBuilder<>::createProperty("Read Permission User List")
       .withDescription("A comma-separated list of Amazon User ID's or E-mail addresses that specifies who should have Read Access for an object.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto ReadACLUserList = core::PropertyDefinitionBuilder<>::createProperty("Read ACL User List")
       .withDescription("A comma-separated list of Amazon User ID's or E-mail addresses that specifies who should have permissions to read "
           "the Access Control List for an object.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto WriteACLUserList = core::PropertyDefinitionBuilder<>::createProperty("Write ACL User List")
       .withDescription("A comma-separated list of Amazon User ID's or E-mail addresses that specifies who should have permissions to change "
           "the Access Control List for an object.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto CannedACL = core::PropertyDefinitionBuilder<>::createProperty("Canned ACL")
       .withDescription("Amazon Canned ACL for an object. Allowed values: BucketOwnerFullControl, BucketOwnerRead, AuthenticatedRead, "
@@ -107,37 +113,43 @@ class PutS3Object : public S3Processor {
   EXTENSIONAPI static constexpr auto UsePathStyleAccess = core::PropertyDefinitionBuilder<>::createProperty("Use Path Style Access")
       .withDescription("Path-style access can be enforced by setting this property to true. Set it to true if your endpoint does not support "
           "virtual-hosted-style requests, only path-style requests.")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MultipartThreshold = core::PropertyDefinitionBuilder<>::createProperty("Multipart Threshold")
       .withDescription("Specifies the file size threshold for switch from the PutS3Object API to the PutS3MultipartUpload API. "
                         "Flow files bigger than this limit will be sent using the multipart process. The valid range is 5MB to 5GB.")
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .withDefaultValue("5 GB")
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MultipartPartSize = core::PropertyDefinitionBuilder<>::createProperty("Multipart Part Size")
       .withDescription("Specifies the part size for use when the PutS3Multipart Upload API is used. "
                         "Flow files will be broken into chunks of this size for the upload process, but the last part sent can be smaller since it is not padded. The valid range is 5MB to 5GB.")
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .withDefaultValue("5 GB")
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MultipartUploadAgeOffInterval = core::PropertyDefinitionBuilder<>::createProperty("Multipart Upload AgeOff Interval")
       .withDescription("Specifies the interval at which existing multipart uploads in AWS S3 will be evaluated for ageoff. "
                         "When processor is triggered it will initiate the ageoff evaluation if this interval has been exceeded.")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("60 min")
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MultipartUploadMaxAgeThreshold = core::PropertyDefinitionBuilder<>::createProperty("Multipart Upload Max Age Threshold")
       .withDescription("Specifies the maximum age for existing multipart uploads in AWS S3. When the ageoff process occurs, any upload older than this threshold will be aborted.")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("7 days")
       .isRequired(true)
       .build();
+  EXTENSIONAPI static constexpr auto ChecksumAlgorithm = core::PropertyDefinitionBuilder<CHECKSUM_ALGORITHMS.size()>::createProperty("Checksum Algorithm")
+      .withDescription("Checksum algorithm used to verify the uploaded object.")
+      .withAllowedValues(CHECKSUM_ALGORITHMS)
+      .withDefaultValue("CRC64NVME")
+      .isRequired(true)
+      .build();
   EXTENSIONAPI static constexpr auto Properties = minifi::utils::array_cat(S3Processor::Properties, std::to_array<core::PropertyReference>({
       ObjectKey,
       ContentType,
@@ -152,7 +164,8 @@ class PutS3Object : public S3Processor {
       MultipartThreshold,
       MultipartPartSize,
       MultipartUploadAgeOffInterval,
-      MultipartUploadMaxAgeThreshold
+      MultipartUploadMaxAgeThreshold,
+      ChecksumAlgorithm
   }));
 
 
@@ -167,9 +180,7 @@ class PutS3Object : public S3Processor {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit PutS3Object(std::string_view name, const minifi::utils::Identifier& uuid = minifi::utils::Identifier())
-    : S3Processor(name, uuid, core::logging::LoggerFactory<PutS3Object>::getLogger(uuid)) {
-  }
+  using S3Processor::S3Processor;
 
   ~PutS3Object() override = default;
 
@@ -183,8 +194,8 @@ class PutS3Object : public S3Processor {
 
   friend class ::FlowProcessorS3TestsFixture<PutS3Object>;
 
-  explicit PutS3Object(const std::string& name, const minifi::utils::Identifier& uuid, std::unique_ptr<aws::s3::S3RequestSender> s3_request_sender)
-    : S3Processor(name, uuid, core::logging::LoggerFactory<PutS3Object>::getLogger(uuid), std::move(s3_request_sender)) {
+  explicit PutS3Object(core::ProcessorMetadata metadata, std::unique_ptr<aws::s3::S3RequestSender> s3_request_sender)
+    : S3Processor(metadata, std::move(s3_request_sender)) {
   }
 
   virtual uint64_t getMinPartSize() const {
@@ -197,18 +208,19 @@ class PutS3Object : public S3Processor {
 
   void fillUserMetadata(core::ProcessContext& context);
   static std::string parseAccessControlList(const std::string &comma_separated_list);
-  bool setCannedAcl(core::ProcessContext& context, const core::FlowFile& flow_file, aws::s3::PutObjectRequestParameters &put_s3_request_params) const;
-  bool setAccessControl(core::ProcessContext& context, const core::FlowFile& flow_file, aws::s3::PutObjectRequestParameters &put_s3_request_params) const;
+  bool setCannedAcl(const core::ProcessContext& context, const core::FlowFile& flow_file, aws::s3::PutObjectRequestParameters &put_s3_request_params) const;
+  bool setAccessControl(const core::ProcessContext& context, const core::FlowFile& flow_file, aws::s3::PutObjectRequestParameters &put_s3_request_params) const;
   void setAttributes(
     core::ProcessSession& session,
     core::FlowFile& flow_file,
     const aws::s3::PutObjectRequestParameters &put_s3_request_params,
     const minifi::aws::s3::PutObjectResult &put_object_result) const;
   std::optional<aws::s3::PutObjectRequestParameters> buildPutS3RequestParams(
-    core::ProcessContext& context,
+    const core::ProcessContext& context,
     const core::FlowFile& flow_file,
-    const CommonProperties &common_properties) const;
-  void ageOffMultipartUploads(const CommonProperties &common_properties);
+    const CommonProperties &common_properties,
+    std::string_view bucket) const;
+  void ageOffMultipartUploads(const CommonProperties &common_properties, const std::string_view bucket);
 
   std::string user_metadata_;
   std::map<std::string, std::string> user_metadata_map_;
@@ -221,6 +233,7 @@ class PutS3Object : public S3Processor {
   std::chrono::milliseconds multipart_upload_max_age_threshold_;
   std::mutex last_ageoff_mutex_;
   std::chrono::time_point<std::chrono::system_clock> last_ageoff_time_;
+  Aws::S3::Model::ChecksumAlgorithm checksum_algorithm_{Aws::S3::Model::ChecksumAlgorithm::CRC64NVME};
 };
 
 }  // namespace org::apache::nifi::minifi::aws::processors
