@@ -1,6 +1,4 @@
 /**
- * @file S3Wrapper.cpp
- * S3Wrapper class implementation
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -74,7 +72,7 @@ std::shared_ptr<Aws::StringStream> S3Wrapper::readFlowFileStream(const std::shar
   auto data_stream = std::make_shared<Aws::StringStream>();
   uint64_t read_size = 0;
   while (read_size < read_limit) {
-    const auto next_read_size = (std::min)(read_limit - read_size, BUFFER_SIZE);
+    const auto next_read_size = (std::min)(read_limit - read_size, uint64_t{BUFFER_SIZE});
     const auto read_ret = stream->read(std::span(buffer).subspan(0, next_read_size));
     if (io::isError(read_ret)) {
       throw StreamReadException("Reading flow file inputstream failed!");
@@ -130,7 +128,8 @@ std::optional<S3Wrapper::UploadPartsResult> S3Wrapper::uploadParts(const PutObje
       .WithBucket(put_object_params.bucket)
       .WithKey(put_object_params.object_key)
       .WithPartNumber(gsl::narrow<int>(part_number))
-      .WithUploadId(upload_state.upload_id);
+      .WithUploadId(upload_state.upload_id)
+      .WithChecksumAlgorithm(put_object_params.checksum_algorithm);
     upload_part_request.SetBody(stream_ptr);
 
     Aws::Utils::ByteBuffer part_md5(Aws::Utils::HashingUtils::CalculateMD5(*stream_ptr));
@@ -228,11 +227,11 @@ bool S3Wrapper::deleteObject(const DeleteObjectRequestParameters& params) {
 }
 
 int64_t S3Wrapper::writeFetchedBody(Aws::IOStream& source, const int64_t data_size, io::OutputStream& output) {
-  std::vector<uint8_t> buffer(4096);
+  std::vector<uint8_t> buffer(BUFFER_SIZE);
   size_t write_size = 0;
   if (data_size < 0) return 0;
   while (write_size < gsl::narrow<uint64_t>(data_size)) {
-    const auto next_write_size = (std::min)(gsl::narrow<size_t>(data_size) - write_size, size_t{4096});
+    const auto next_write_size = (std::min)(gsl::narrow<size_t>(data_size) - write_size, BUFFER_SIZE);
     if (!source.read(reinterpret_cast<char*>(buffer.data()), gsl::narrow<std::streamsize>(next_write_size))) {
       return -1;
     }
@@ -269,7 +268,12 @@ void S3Wrapper::addListResults(const Aws::Vector<Aws::S3::Model::ObjectVersion>&
     attributes.is_latest = version.GetIsLatest();
     attributes.last_modified = version.GetLastModified().UnderlyingTimestamp();
     attributes.length = version.GetSize();
-    attributes.store_class = minifi::utils::at(VERSION_STORAGE_CLASS_MAP, version.GetStorageClass());
+    try {
+      attributes.store_class = minifi::utils::at(VERSION_STORAGE_CLASS_MAP, version.GetStorageClass());
+    } catch (const std::out_of_range&) {
+      logger_->log_warn("Unknown storage class '{}' for object version with key '{}'", magic_enum::enum_name(version.GetStorageClass()), version.GetKey());
+      attributes.store_class = "Unknown";
+    }
     attributes.version = version.GetVersionId();
     listed_objects.push_back(attributes);
   }
@@ -288,7 +292,12 @@ void S3Wrapper::addListResults(const Aws::Vector<Aws::S3::Model::Object>& conten
     attributes.is_latest = true;
     attributes.last_modified = object.GetLastModified().UnderlyingTimestamp();
     attributes.length = object.GetSize();
-    attributes.store_class = minifi::utils::at(OBJECT_STORAGE_CLASS_MAP, object.GetStorageClass());
+    try {
+      attributes.store_class = minifi::utils::at(OBJECT_STORAGE_CLASS_MAP, object.GetStorageClass());
+    } catch (const std::out_of_range&) {
+      logger_->log_warn("Unknown storage class '{}' for object with key '{}'", magic_enum::enum_name(object.GetStorageClass()), object.GetKey());
+      attributes.store_class = "Unknown";
+    }
     listed_objects.push_back(attributes);
   }
 }
