@@ -1,6 +1,4 @@
 /**
- * @file S3Wrapper.h
- * S3Wrapper class declaration
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -29,52 +27,66 @@
 #include <utility>
 #include <vector>
 
-#include "aws/s3/model/StorageClass.h"
-#include "aws/s3/model/ServerSideEncryption.h"
-#include "aws/s3/model/ObjectCannedACL.h"
-
-#include "core/logging/Logger.h"
-#include "core/logging/LoggerConfiguration.h"
-#include "utils/AWSInitializer.h"
-#include "utils/OptionalUtils.h"
-#include "utils/StringUtils.h"
-#include "utils/ListingStateManager.h"
-#include "utils/gsl.h"
-#include "S3RequestSender.h"
 #include "Exception.h"
 #include "MultipartUploadStateStorage.h"
+#include "S3RequestSender.h"
+#include "aws/s3/model/ObjectCannedACL.h"
+#include "aws/s3/model/ServerSideEncryption.h"
+#include "aws/s3/model/StorageClass.h"
+#include "aws/s3/model/ChecksumAlgorithm.h"
+
+#include "core/logging/Logger.h"
+#include "core/logging/LoggerFactory.h"
+#include "io/InputStream.h"
+#include "io/OutputStream.h"
 #include "range/v3/algorithm/find.hpp"
+#include "utils/AWSInitializer.h"
+#include "utils/ConfigurationUtils.h"
+#include "utils/ListingStateManager.h"
+#include "utils/OptionalUtils.h"
+#include "utils/StringUtils.h"
+#include "utils/gsl.h"
+#include "utils/ProxyOptions.h"
 
 namespace org::apache::nifi::minifi::aws::s3 {
 
-inline constexpr std::array<std::pair<std::string_view, Aws::S3::Model::StorageClass>, 7> STORAGE_CLASS_MAP {{
+inline constexpr std::array<std::pair<std::string_view, Aws::S3::Model::StorageClass>, 11> STORAGE_CLASS_MAP {{
   {"Standard", Aws::S3::Model::StorageClass::STANDARD},
   {"ReducedRedundancy", Aws::S3::Model::StorageClass::REDUCED_REDUNDANCY},
   {"StandardIA", Aws::S3::Model::StorageClass::STANDARD_IA},
   {"OnezoneIA", Aws::S3::Model::StorageClass::ONEZONE_IA},
   {"IntelligentTiering", Aws::S3::Model::StorageClass::INTELLIGENT_TIERING},
   {"Glacier", Aws::S3::Model::StorageClass::GLACIER},
-  {"DeepArchive", Aws::S3::Model::StorageClass::DEEP_ARCHIVE}
+  {"DeepArchive", Aws::S3::Model::StorageClass::DEEP_ARCHIVE},
+  {"Outposts", Aws::S3::Model::StorageClass::OUTPOSTS},
+  {"GlacierIR", Aws::S3::Model::StorageClass::GLACIER_IR},
+  {"Snow", Aws::S3::Model::StorageClass::SNOW},
+  {"ExpressOneZone", Aws::S3::Model::StorageClass::EXPRESS_ONEZONE}
 }};
 
-inline constexpr std::array<std::pair<Aws::S3::Model::ObjectStorageClass, std::string_view>, 7> OBJECT_STORAGE_CLASS_MAP {{
+inline constexpr std::array<std::pair<Aws::S3::Model::ObjectStorageClass, std::string_view>, 11> OBJECT_STORAGE_CLASS_MAP {{
   {Aws::S3::Model::ObjectStorageClass::STANDARD, "Standard"},
   {Aws::S3::Model::ObjectStorageClass::REDUCED_REDUNDANCY, "ReducedRedundancy"},
+  {Aws::S3::Model::ObjectStorageClass::GLACIER, "Glacier"},
   {Aws::S3::Model::ObjectStorageClass::STANDARD_IA, "StandardIA"},
   {Aws::S3::Model::ObjectStorageClass::ONEZONE_IA, "OnezoneIA"},
   {Aws::S3::Model::ObjectStorageClass::INTELLIGENT_TIERING, "IntelligentTiering"},
-  {Aws::S3::Model::ObjectStorageClass::GLACIER, "Glacier"},
-  {Aws::S3::Model::ObjectStorageClass::DEEP_ARCHIVE, "DeepArchive"}
+  {Aws::S3::Model::ObjectStorageClass::DEEP_ARCHIVE, "DeepArchive"},
+  {Aws::S3::Model::ObjectStorageClass::OUTPOSTS, "Outposts"},
+  {Aws::S3::Model::ObjectStorageClass::GLACIER_IR, "GlacierIR"},
+  {Aws::S3::Model::ObjectStorageClass::SNOW, "Snow"},
+  {Aws::S3::Model::ObjectStorageClass::EXPRESS_ONEZONE, "ExpressOneZone"}
 }};
 
 inline constexpr std::array<std::pair<Aws::S3::Model::ObjectVersionStorageClass, std::string_view>, 1> VERSION_STORAGE_CLASS_MAP {{
   {Aws::S3::Model::ObjectVersionStorageClass::STANDARD, "Standard"}
 }};
 
-inline constexpr std::array<std::pair<std::string_view, Aws::S3::Model::ServerSideEncryption>, 3> SERVER_SIDE_ENCRYPTION_MAP {{
+inline constexpr std::array<std::pair<std::string_view, Aws::S3::Model::ServerSideEncryption>, 4> SERVER_SIDE_ENCRYPTION_MAP {{
   {"None", Aws::S3::Model::ServerSideEncryption::NOT_SET},
   {"AES256", Aws::S3::Model::ServerSideEncryption::AES256},
   {"aws_kms", Aws::S3::Model::ServerSideEncryption::aws_kms},
+  {"aws_kms_dsse", Aws::S3::Model::ServerSideEncryption::aws_kms_dsse}
 }};
 
 inline constexpr std::array<std::pair<std::string_view, Aws::S3::Model::ObjectCannedACL>, 7> CANNED_ACL_MAP {{
@@ -87,6 +99,14 @@ inline constexpr std::array<std::pair<std::string_view, Aws::S3::Model::ObjectCa
   {"AwsExecRead", Aws::S3::Model::ObjectCannedACL::aws_exec_read},
 }};
 
+inline constexpr std::array<std::pair<std::string_view, Aws::S3::Model::ChecksumAlgorithm>, 5> CHECKSUM_ALGORITHM_MAP {{
+  {"CRC32", Aws::S3::Model::ChecksumAlgorithm::CRC32},
+  {"CRC32C", Aws::S3::Model::ChecksumAlgorithm::CRC32C},
+  {"SHA1", Aws::S3::Model::ChecksumAlgorithm::SHA1},
+  {"SHA256", Aws::S3::Model::ChecksumAlgorithm::SHA256},
+  {"CRC64NVME", Aws::S3::Model::ChecksumAlgorithm::CRC64NVME}
+}};
+
 struct Expiration {
   std::string expiration_time;
   std::string expiration_time_rule_id;
@@ -106,7 +126,7 @@ struct RequestParameters {
   Aws::Auth::AWSCredentials credentials;
   Aws::Client::ClientConfiguration client_config;
 
-  void setClientConfig(const aws::s3::ProxyOptions& proxy, const std::string& endpoint_override_url) {
+  void setClientConfig(const aws::ProxyOptions& proxy, const std::string& endpoint_override_url) {
     client_config.proxyHost = proxy.host;
     client_config.proxyPort = proxy.port;
     client_config.proxyUserName = proxy.username;
@@ -129,6 +149,7 @@ struct PutObjectRequestParameters : public RequestParameters {
   std::string read_acl_user_list;
   std::string write_acl_user_list;
   std::string canned_acl;
+  Aws::S3::Model::ChecksumAlgorithm checksum_algorithm;
   bool use_virtual_addressing = true;
 };
 
@@ -227,7 +248,7 @@ class StreamReadException : public Exception {
 
 class S3Wrapper {
  public:
-  static constexpr uint64_t BUFFER_SIZE = 4_KiB;
+  static constexpr auto BUFFER_SIZE = minifi::utils::configuration::DEFAULT_BUFFER_SIZE;
 
   S3Wrapper();
   explicit S3Wrapper(std::unique_ptr<S3RequestSender>&& request_sender);
@@ -270,7 +291,8 @@ class S3Wrapper {
     auto request = RequestType{}
       .WithBucket(put_object_params.bucket)
       .WithKey(put_object_params.object_key)
-      .WithStorageClass(minifi::utils::at(STORAGE_CLASS_MAP, put_object_params.storage_class));
+      .WithStorageClass(minifi::utils::at(STORAGE_CLASS_MAP, put_object_params.storage_class))
+      .WithChecksumAlgorithm(put_object_params.checksum_algorithm);
     if (!put_object_params.server_side_encryption.empty() && put_object_params.server_side_encryption != "None") {
       request.SetServerSideEncryption(minifi::utils::at(SERVER_SIDE_ENCRYPTION_MAP, put_object_params.server_side_encryption));
     }
