@@ -45,9 +45,7 @@ class PutS3ObjectLimitChanged : public minifi::aws::processors::PutS3Object {
  protected:
   friend class ::FlowProcessorS3TestsFixture<PutS3ObjectLimitChanged>;
 
-  explicit PutS3ObjectLimitChanged(const std::string& name, const minifi::utils::Identifier& uuid, std::unique_ptr<minifi::aws::s3::S3RequestSender> s3_request_sender)
-    : PutS3Object(name, uuid, std::move(s3_request_sender)) {
-  }
+  using PutS3Object::PutS3Object;
 
   uint64_t getMinPartSize() const override {
     return 1;
@@ -102,27 +100,18 @@ TEST_CASE_METHOD(PutS3ObjectTestsFixture, "Test required property not set", "[aw
 
   SECTION("Test no object key is set") {
     setRequiredProperties();
-    plan->setDynamicProperty(update_attribute, "filename", "");
-  }
-
-  SECTION("Test storage class is empty") {
-    setRequiredProperties();
-    plan->setProperty(s3_processor, "Storage Class", "");
-  }
-
-  SECTION("Test region is empty") {
-    setRequiredProperties();
-    plan->setProperty(s3_processor, "Region", "");
-  }
-
-  SECTION("Test no server side encryption is set") {
-    setRequiredProperties();
-    plan->setProperty(s3_processor, "Server Side Encryption", "");
+    CHECK(plan->setDynamicProperty(update_attribute, "filename", ""));
   }
 
   REQUIRE_THROWS_AS(test_controller.runSession(plan), minifi::Exception);
 }
 
+TEST_CASE_METHOD(PutS3ObjectTestsFixture, "Non blank properties", "[awsS3Config]") {
+  setRequiredProperties();
+  CHECK_FALSE(plan->setProperty(s3_processor, "Server Side Encryption", ""));
+  CHECK_FALSE(plan->setProperty(s3_processor, "Storage Class", ""));
+}
+
 TEST_CASE_METHOD(PutS3ObjectTestsFixture, "Test incomplete credentials in credentials service", "[awsS3Config]") {
   setBucket();
   plan->setProperty(aws_credentials_service, "Secret Key", "secret");
@@ -261,7 +250,7 @@ TEST_CASE_METHOD(PutS3ObjectTestsFixture, "Test multipart upload limits", "[awsS
     plan->setProperty(s3_processor, "Multipart Part Size", "51 GB");
   }
 
-  REQUIRE_THROWS_AS(test_controller.runSession(plan), minifi::Exception);
+  REQUIRE_THROWS_AS(test_controller.runSession(plan), std::runtime_error);
 }
 
 TEST_CASE_METHOD(PutS3ObjectUploadLimitChangedTestsFixture, "Test multipart upload", "[awsS3MultipartUpload]") {
@@ -443,4 +432,11 @@ TEST_CASE_METHOD(PutS3ObjectUploadLimitChangedTestsFixture, "Do not continue mul
   }
 }
 
+TEST_CASE_METHOD(PutS3ObjectTestsFixture, "Test checksum algorithm property", "[awsS3checksum]") {
+  setRequiredProperties();
+  plan->setProperty(s3_processor, "Checksum Algorithm", "SHA256");
+  test_controller.runSession(plan);
+  CHECK(mock_s3_request_sender_ptr->put_object_request.GetChecksumAlgorithm() == Aws::S3::Model::ChecksumAlgorithm::SHA256);
+}
+
 }  // namespace
