@@ -1,6 +1,4 @@
 /**
- * @file AWSSdkLogger.cpp
- * AWSSdkLogger class implementation
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -20,6 +18,7 @@
 #include "AWSSdkLogger.h"
 
 #include <cstdio>
+#include <cstdarg>
 
 #include "aws/core/utils/logging/LogLevel.h"
 #include "utils/gsl.h"
