@@ -27,7 +27,7 @@
 
 #include "core/Property.h"
 #include "core/PropertyDefinition.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/logging/Logger.h"
 #include "storage/AzureBlobStorage.h"
 #include "AzureStorageProcessorBase.h"
@@ -41,6 +41,7 @@ class AzureBlobStorageProcessorBase : public AzureStorageProcessorBase {
   EXTENSIONAPI static constexpr auto ContainerName = core::PropertyDefinitionBuilder<>::createProperty("Container Name")
       .withDescription("Name of the Azure Storage container. In case of PutAzureBlobStorage processor, container can be created if it does not exist.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto StorageAccountName = core::PropertyDefinitionBuilder<>::createProperty("Storage Account Name")
@@ -70,7 +71,7 @@ class AzureBlobStorageProcessorBase : public AzureStorageProcessorBase {
   EXTENSIONAPI static constexpr auto UseManagedIdentityCredentials = core::PropertyDefinitionBuilder<>::createProperty("Use Managed Identity Credentials")
       .withDescription("If true Managed Identity credentials will be used together with the Storage Account Name for authentication.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto Properties = utils::array_cat(AzureStorageProcessorBase::Properties, std::to_array<core::PropertyReference>({
@@ -88,11 +89,9 @@ class AzureBlobStorageProcessorBase : public AzureStorageProcessorBase {
 
  protected:
   explicit AzureBlobStorageProcessorBase(
-    std::string_view name,
-    const minifi::utils::Identifier& uuid,
-    const std::shared_ptr<core::logging::Logger>& logger,
+    core::ProcessorMetadata metadata,
     std::unique_ptr<storage::BlobStorageClient> blob_storage_client)
-    : AzureStorageProcessorBase(name, uuid, logger),
+    : AzureStorageProcessorBase(metadata),
       azure_blob_storage_(std::move(blob_storage_client)) {
   }
 
