@@ -26,7 +26,7 @@
 #include <utility>
 
 #include "AzureBlobStorageProcessorBase.h"
-#include "PropertyDefinition.h"
+#include "core/PropertyDefinition.h"
 #include "utils/ArrayUtils.h"
 
 namespace org::apache::nifi::minifi::azure::processors {
@@ -41,11 +41,9 @@ class AzureBlobStorageSingleBlobProcessorBase : public AzureBlobStorageProcessor
 
  protected:
   explicit AzureBlobStorageSingleBlobProcessorBase(
-    std::string_view name,
-    const minifi::utils::Identifier& uuid,
-    const std::shared_ptr<core::logging::Logger>& logger,
+    core::ProcessorMetadata metadata,
     std::unique_ptr<storage::BlobStorageClient> blob_storage_client)
-    : AzureBlobStorageProcessorBase(name, uuid, logger, std::move(blob_storage_client)) {
+    : AzureBlobStorageProcessorBase(metadata, std::move(blob_storage_client)) {
   }
 
   bool setBlobOperationParameters(
