@@ -36,16 +36,13 @@ class AzureDataLakeStorageFileProcessorBase : public AzureDataLakeStorageProcess
       .build();
   EXTENSIONAPI static constexpr auto Properties = utils::array_cat(AzureDataLakeStorageProcessorBase::Properties, std::to_array<core::PropertyReference>({FileName}));
 
-  explicit AzureDataLakeStorageFileProcessorBase(std::string_view name, const minifi::utils::Identifier& uuid, const std::shared_ptr<core::logging::Logger> &logger)
-    : AzureDataLakeStorageProcessorBase(name, uuid, logger) {
-  }
+  using AzureDataLakeStorageProcessorBase::AzureDataLakeStorageProcessorBase;
 
   ~AzureDataLakeStorageFileProcessorBase() override = default;
 
  protected:
-  explicit AzureDataLakeStorageFileProcessorBase(std::string_view name, const minifi::utils::Identifier& uuid, const std::shared_ptr<core::logging::Logger> &logger,
-      std::unique_ptr<storage::DataLakeStorageClient> data_lake_storage_client)
-    : AzureDataLakeStorageProcessorBase(name, uuid, logger, std::move(data_lake_storage_client)) {
+  explicit AzureDataLakeStorageFileProcessorBase(core::ProcessorMetadata metadata, std::unique_ptr<storage::DataLakeStorageClient> data_lake_storage_client)
+    : AzureDataLakeStorageProcessorBase(metadata, std::move(data_lake_storage_client)) {
   }
 
   bool setFileOperationCommonParameters(
