@@ -26,26 +26,23 @@
 #include <utility>
 #include <tuple>
 
-#include "PropertyDefinition.h"
+#include "core/PropertyDefinition.h"
 #include "core/Property.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/logging/Logger.h"
 #include "storage/AzureStorageCredentials.h"
 
 namespace org::apache::nifi::minifi::azure::processors {
 
-class AzureStorageProcessorBase : public core::Processor {
+class AzureStorageProcessorBase : public core::ProcessorImpl {
  public:
   EXTENSIONAPI static constexpr auto AzureStorageCredentialsService = core::PropertyDefinitionBuilder<>::createProperty("Azure Storage Credentials Service")
       .withDescription("Name of the Azure Storage Credentials Service used to retrieve the connection string from.")
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({AzureStorageCredentialsService});
 
-  AzureStorageProcessorBase(std::string_view name, const minifi::utils::Identifier& uuid, const std::shared_ptr<core::logging::Logger>& logger)
-    : core::Processor(name, uuid),
-      logger_(logger) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
  protected:
   enum class GetCredentialsFromControllerResult {
@@ -55,8 +52,6 @@ class AzureStorageProcessorBase : public core::Processor {
   };
 
   std::tuple<GetCredentialsFromControllerResult, std::optional<storage::AzureStorageCredentials>> getCredentialsFromControllerService(core::ProcessContext &context) const;
-
-  std::shared_ptr<core::logging::Logger> logger_;
 };
 
 }  // namespace org::apache::nifi::minifi::azure::processors
