@@ -40,13 +40,13 @@ std::optional<storage::FetchAzureBlobStorageParameters> FetchAzureBlobStorage::b
   }
 
   std::string value;
-  if (context.getProperty(RangeStart, value, &flow_file)) {
-    params.range_start = std::stoull(value);
+  if (auto range_start = utils::parseOptionalU64Property(context, RangeStart, &flow_file)) {
+    params.range_start = *range_start;
     logger_->log_debug("Range Start property set to {}", *params.range_start);
   }
 
-  if (context.getProperty(RangeLength, value, &flow_file)) {
-    params.range_length = std::stoull(value);
+  if (auto range_length = utils::parseOptionalU64Property(context, RangeLength, &flow_file)) {
+    params.range_length = *range_length;
     logger_->log_debug("Range Length property set to {}", *params.range_length);
   }
 
