@@ -29,7 +29,7 @@
 #include "core/Property.h"
 #include "core/PropertyDefinition.h"
 #include "AzureBlobStorageProcessorBase.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/AzureEnums.h"
 
 namespace org::apache::nifi::minifi::azure::processors {
@@ -64,12 +64,12 @@ class ListAzureBlobStorage final : public AzureBlobStorageProcessorBase {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit ListAzureBlobStorage(std::string_view name, const minifi::utils::Identifier& uuid = minifi::utils::Identifier())
-    : ListAzureBlobStorage(name, nullptr, uuid) {
+  explicit ListAzureBlobStorage(core::ProcessorMetadata metadata)
+    : ListAzureBlobStorage(metadata, nullptr) {
   }
 
-  explicit ListAzureBlobStorage(std::string_view name, std::unique_ptr<storage::BlobStorageClient> blob_storage_client, const minifi::utils::Identifier& uuid = minifi::utils::Identifier())
-    : AzureBlobStorageProcessorBase(name, uuid, core::logging::LoggerFactory<ListAzureBlobStorage>::getLogger(uuid), std::move(blob_storage_client)) {
+  explicit ListAzureBlobStorage(core::ProcessorMetadata metadata, std::unique_ptr<storage::BlobStorageClient> blob_storage_client)
+    : AzureBlobStorageProcessorBase(metadata, std::move(blob_storage_client)) {
   }
 
   void initialize() override;
