@@ -26,11 +26,11 @@
 #include <utility>
 #include <vector>
 
-#include "ProcessContext.h"
-#include "PropertyDefinition.h"
-#include "PropertyType.h"
+#include "core/ProcessContext.h"
+#include "core/PropertyDefinition.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/Property.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "AzureBlobStorageSingleBlobProcessorBase.h"
 #include "io/StreamPipe.h"
 #include "utils/ArrayUtils.h"
@@ -49,7 +49,7 @@ class PutAzureBlobStorage final : public AzureBlobStorageSingleBlobProcessorBase
         "Permission to list containers is required. If false, this check is not made, but the Put operation will "
         "fail if the container does not exist.")
     .isRequired(true)
-    .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+    .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
     .withDefaultValue("false")
     .build();
   EXTENSIONAPI static constexpr auto Properties = utils::array_cat(AzureBlobStorageSingleBlobProcessorBase::Properties, std::to_array<core::PropertyReference>({CreateContainer}));
@@ -65,8 +65,8 @@ class PutAzureBlobStorage final : public AzureBlobStorageSingleBlobProcessorBase
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit PutAzureBlobStorage(std::string_view name, const minifi::utils::Identifier& uuid = minifi::utils::Identifier())
-    : PutAzureBlobStorage(name, uuid, nullptr) {
+  explicit PutAzureBlobStorage(core::ProcessorMetadata metadata)
+    : PutAzureBlobStorage(metadata, nullptr) {
   }
 
   void initialize() override;
@@ -107,8 +107,8 @@ class PutAzureBlobStorage final : public AzureBlobStorageSingleBlobProcessorBase
  private:
   friend class ::AzureBlobStorageTestsFixture<PutAzureBlobStorage>;
 
-  explicit PutAzureBlobStorage(std::string_view name, const minifi::utils::Identifier& uuid, std::unique_ptr<storage::BlobStorageClient> blob_storage_client)
-    : AzureBlobStorageSingleBlobProcessorBase(name, uuid, core::logging::LoggerFactory<PutAzureBlobStorage>::getLogger(), std::move(blob_storage_client)) {
+  explicit PutAzureBlobStorage(core::ProcessorMetadata metadata, std::unique_ptr<storage::BlobStorageClient> blob_storage_client)
+    : AzureBlobStorageSingleBlobProcessorBase(metadata, std::move(blob_storage_client)) {
   }
 
   std::optional<storage::PutAzureBlobStorageParameters> buildPutAzureBlobStorageParameters(core::ProcessContext &context, const core::FlowFile& flow_file);
