@@ -27,9 +27,10 @@
 #include "BlobStorageClient.h"
 #include "azure/storage/blobs.hpp"
 #include "core/logging/Logger.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/gsl.h"
 #include "utils/ListingStateManager.h"
+#include "io/OutputStream.h"
 
 namespace org::apache::nifi::minifi::azure::storage {
 
