@@ -42,8 +42,12 @@ class ListAzureDataLakeStorageTestsFixture {
     plan_ = test_controller_.createPlan();
     auto mock_data_lake_storage_client = std::make_unique<MockDataLakeStorageClient>();
     mock_data_lake_storage_client_ptr_ = mock_data_lake_storage_client.get();
-    auto list_azure_data_lake_storage_unique_ptr = std::unique_ptr<minifi::azure::processors::ListAzureDataLakeStorage>(
-      new minifi::azure::processors::ListAzureDataLakeStorage("ListAzureDataLakeStorage", utils::Identifier(), std::move(mock_data_lake_storage_client)));
+    auto uuid = utils::IdGenerator::getIdGenerator()->generate();
+    auto impl = std::unique_ptr<minifi::azure::processors::ListAzureDataLakeStorage>(
+      new minifi::azure::processors::ListAzureDataLakeStorage({
+        .uuid = uuid, .name = "ListAzureDataLakeStorage",
+        .logger = logging::LoggerFactory<minifi::azure::processors::ListAzureDataLakeStorage>::getLogger(uuid)}, std::move(mock_data_lake_storage_client)));
+    auto list_azure_data_lake_storage_unique_ptr = std::make_unique<core::Processor>(impl->getName(), impl->getUUID(), std::move(impl));
     list_azure_data_lake_storage_ = list_azure_data_lake_storage_unique_ptr.get();
 
     plan_->addProcessor(std::move(list_azure_data_lake_storage_unique_ptr), "ListAzureDataLakeStorage", { {"success", "d"} });
