@@ -23,21 +23,18 @@
 #include <string>
 #include <utility>
 
-#include "PropertyDefinition.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/FlowFile.h"
 
 namespace org::apache::nifi::minifi::processors {
 
 /**
  * Applies a mustache template using incoming attributes as template parameters.
  */
-class ApplyTemplate : public core::Processor {
+class ApplyTemplate final : public core::ProcessorImpl {
  public:
-  explicit ApplyTemplate(std::string name, const utils::Identifier& uuid = {})
-      : Processor(std::move(name), uuid) {}
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Applies the mustache template specified by the \"Template\" property and writes the output to the flow file content. "
     "FlowFile attributes are used as template parameters.";
@@ -59,9 +56,6 @@ class ApplyTemplate : public core::Processor {
 
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
-
- private:
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ApplyTemplate>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
