@@ -27,19 +27,19 @@
 #include <CivetServer.h>
 
 #include "FlowFileRecord.h"
-#include "core/Processor.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "core/Core.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/MinifiConcurrentQueue.h"
 #include "utils/gsl.h"
 #include "utils/Export.h"
 #include "utils/RegexUtils.h"
 #include "core/FlowFileStore.h"
+#include "core/ProcessorImpl.h"
 
 namespace org::apache::nifi::minifi::test {
 struct ListenHTTPTestAccessor;
@@ -47,7 +47,7 @@ struct ListenHTTPTestAccessor;
 
 namespace org::apache::nifi::minifi::processors {
 
-class ListenHTTP : public core::Processor {
+class ListenHTTP : public core::ProcessorImpl {
  private:
   static constexpr std::string_view DEFAULT_BUFFER_SIZE_STR = "5";
   static constexpr core::RelationshipDefinition Self{"__self__", "Marks the FlowFile to be owned by this processor"};
@@ -55,8 +55,8 @@ class ListenHTTP : public core::Processor {
  public:
   friend struct ::org::apache::nifi::minifi::test::ListenHTTPTestAccessor;
 
-  explicit ListenHTTP(std::string_view name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
+  explicit ListenHTTP(core::ProcessorMetadata metadata)
+      : ProcessorImpl(metadata) {
     callbacks_.log_message = &logMessage;
     callbacks_.log_access = &logAccess;
   }
@@ -72,13 +72,14 @@ class ListenHTTP : public core::Processor {
 
   EXTENSIONAPI static constexpr auto BasePath = core::PropertyDefinitionBuilder<>::createProperty("Base Path")
       .withDescription("Base path for incoming connections")
-      .isRequired(false)
+      .isRequired(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .withDefaultValue("contentListener")
       .build();
   EXTENSIONAPI static constexpr auto Port = core::PropertyDefinitionBuilder<>::createProperty("Listening Port")
       .withDescription("The Port to listen on for incoming connections. 0 means port is going to be selected randomly.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::LISTEN_PORT_TYPE)
+      .withValidator(core::StandardPropertyValidators::PORT_VALIDATOR)
       .withDefaultValue("80")
       .build();
   EXTENSIONAPI static constexpr auto AuthorizedDNPattern = core::PropertyDefinitionBuilder<>::createProperty("Authorized DN Pattern")
@@ -109,13 +110,13 @@ class ListenHTTP : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto BatchSize = core::PropertyDefinitionBuilder<>::createProperty("Batch Size")
         .withDescription("Maximum number of buffered requests to be processed in a single batch. If set to zero all buffered requests are processed.")
-        .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+        .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
         .withDefaultValue(ListenHTTP::DEFAULT_BUFFER_SIZE_STR)
         .build();
   EXTENSIONAPI static constexpr auto BufferSize = core::PropertyDefinitionBuilder<>::createProperty("Buffer Size")
         .withDescription("Maximum number of HTTP Requests allowed to be buffered before processing them when the processor is triggered. "
             "If the buffer full, the request is refused. If set to zero the buffer is unlimited.")
-        .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+        .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
         .withDefaultValue(ListenHTTP::DEFAULT_BUFFER_SIZE_STR)
         .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
@@ -153,8 +154,6 @@ class ListenHTTP : public core::Processor {
     return handler_ ? !handler_->empty() : false;
   }
 
-  std::set<core::Connectable*> getOutGoingConnections(const std::string &relationship) override;
-
   struct ResponseBody {
     std::string uri;
     std::string mime_type;
@@ -284,7 +283,6 @@ class ListenHTTP : public core::Processor {
     return handler_ ? handler_->requestCount() : 0;
   }
 
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ListenHTTP>::getLogger(uuid_);
   CivetCallbacks callbacks_;
   std::unique_ptr<CivetServer> server_;
   std::unique_ptr<Handler> handler_;
