@@ -69,7 +69,7 @@ class ListenHTTPTestsFixture {
     LogTestController::getInstance().setTrace<minifi::processors::ListenHTTP::Handler>();
     LogTestController::getInstance().setDebug<minifi::processors::LogAttribute>();
     LogTestController::getInstance().setDebug<minifi::http::HTTPClient>();
-    LogTestController::getInstance().setDebug<minifi::controllers::SSLContextService>();
+    LogTestController::getInstance().setDebug<minifi::controllers::SSLContextServiceInterface>();
 
     // Create temporary directories
     tmp_dir = testController.createTempDirectory();
@@ -125,7 +125,7 @@ class ListenHTTPTestsFixture {
   }
 
   void create_ssl_context_service(const char* ca, const char* client_cert) {
-    auto config = std::make_shared<minifi::Configure>();
+    auto config = std::make_shared<minifi::ConfigureImpl>();
     auto executable_dir = minifi::utils::file::FileUtils::get_executable_dir();
     if (ca != nullptr) {
       config->set(minifi::Configure::nifi_security_client_ca_certificate, (executable_dir / "resources" / ca).string());
@@ -147,9 +147,8 @@ class ListenHTTPTestsFixture {
     plan->runNextProcessor();  // UpdateAttribute
     plan->runNextProcessor();  // ListenHTTP
 
-    auto raw_ptr = dynamic_cast<org::apache::nifi::minifi::processors::ListenHTTP*>(listen_http);
-    std::string protocol = std::string("http") + (raw_ptr->isSecure() ? "s" : "");
-    std::string portstr = raw_ptr->getPort();
+    std::string protocol = std::string("http") + (listen_http.get().isSecure() ? "s" : "");
+    std::string portstr = listen_http.get().getPort();
     REQUIRE(LogTestController::getInstance().contains("Listening on port " + portstr));
 
     url = protocol + "://localhost:" + portstr + "/contentListener/" + endpoint;
@@ -157,10 +156,7 @@ class ListenHTTPTestsFixture {
 
   void check_content_type(minifi::http::HTTPClient& client) {
     if (endpoint == "test") {
-      std::string content_type;
-      if (!update_attribute->getDynamicProperty("mime.type", content_type)) {
-        content_type = "application/octet-stream";
-      }
+      const auto content_type = update_attribute->getDynamicProperty("mime.type").value_or("application/octet-stream");
       REQUIRE(content_type == minifi::utils::string::trim(client.getResponseHeaderMap().at("Content-type")));
       REQUIRE("19" == minifi::utils::string::trim(client.getResponseHeaderMap().at("Content-length")));
     } else {
@@ -201,18 +197,18 @@ class ListenHTTPTestsFixture {
 
   void test_connect(
       const std::vector<HttpResponseExpectations>& response_expectations = {HttpResponseExpectations{}},
-      std::size_t expected_commited_requests = 1,
+      std::size_t expected_committed_requests = 1,
       std::unique_ptr<minifi::http::HTTPClient> client_to_use = {}) {
     if (client_to_use) {
       REQUIRE(response_expectations.size() == 1);
     }
-    auto* proc = dynamic_cast<minifi::processors::ListenHTTP*>(plan->getCurrentContext()->getProcessorNode()->getProcessor());
+    TypedProcessorWrapper<minifi::processors::ListenHTTP> proc = &plan->getCurrentContext()->getProcessor();
     REQUIRE(proc);
 
     std::vector<std::thread> client_threads;
 
     for (auto& expect : response_expectations) {
-      size_t prev_req_count = ListenHTTPTestAccessor::call_pendingRequestCount(*proc);
+      size_t prev_req_count = ListenHTTPTestAccessor::call_pendingRequestCount(proc.get());
       auto thread_done_flag = std::make_shared<std::atomic_bool>(false);
       client_threads.emplace_back([&, thread_done_flag] {
         auto client = client_to_use ? std::move(client_to_use) : initialize_client();
@@ -220,7 +216,7 @@ class ListenHTTPTestsFixture {
         check_response(client->submit(), expect, *client);
         thread_done_flag->store(true);
       });
-      while (!thread_done_flag->load() && ListenHTTPTestAccessor::call_pendingRequestCount(*proc) != prev_req_count + 1) {
+      while (!thread_done_flag->load() && ListenHTTPTestAccessor::call_pendingRequestCount(proc.get()) != prev_req_count + 1) {
         std::this_thread::sleep_for(1ms);
       }
     }
@@ -234,10 +230,10 @@ class ListenHTTPTestsFixture {
       thread.join();
     }
 
-    if (expected_commited_requests > 0 && (method == HttpRequestMethod::GET || method == HttpRequestMethod::POST)) {
+    if (expected_committed_requests > 0 && (method == HttpRequestMethod::GET || method == HttpRequestMethod::POST)) {
       REQUIRE(LogTestController::getInstance().contains("Size:" + std::to_string(payload.size()) + " Offset:0"));
     }
-    REQUIRE(LogTestController::getInstance().contains("Logged " + std::to_string(expected_commited_requests) + " flow files"));
+    REQUIRE(LogTestController::getInstance().contains("Logged " + std::to_string(expected_committed_requests) + " flow files"));
   }
 
   std::unique_ptr<minifi::http::HTTPClient> initialize_client() {
@@ -259,10 +255,10 @@ class ListenHTTPTestsFixture {
   std::shared_ptr<TestPlan> plan;
   core::Processor* get_file = nullptr;
   core::Processor* update_attribute = nullptr;
-  core::Processor* listen_http = nullptr;
+  TypedProcessorWrapper<org::apache::nifi::minifi::processors::ListenHTTP> listen_http = nullptr;
   core::Processor* log_attribute = nullptr;
 
-  std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service;
+  std::shared_ptr<minifi::controllers::SSLContextServiceInterface> ssl_context_service;
   HttpRequestMethod method = HttpRequestMethod::GET;
   std::map<std::string, std::string> headers;
   std::string payload;
@@ -275,7 +271,7 @@ class ListenHTTPTestsFixture {
 TEST_CASE("ListenHTTP creation", "[basic]") {
   TestController testController;
   std::shared_ptr<core::Processor>
-      processor = std::make_shared<org::apache::nifi::minifi::processors::ListenHTTP>("processorname");
+      processor = minifi::test::utils::make_processor<org::apache::nifi::minifi::processors::ListenHTTP>("processorname");
   REQUIRE(processor->getName() == "processorname");
 }
 
@@ -333,8 +329,8 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTP no body", "[basic]") {
   }
 
   run_server();
-  const std::size_t expected_commited_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
-  test_connect({HttpResponseExpectations{}}, expected_commited_requests);
+  const std::size_t expected_committed_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
+  test_connect({HttpResponseExpectations{}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTP body with different mime type", "[basic][mime]") {
@@ -352,8 +348,8 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTP body with different mime type", "
   }
 
   run_server();
-  const std::size_t expected_commited_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
-  test_connect({HttpResponseExpectations{}}, expected_commited_requests);
+  const std::size_t expected_committed_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
+  test_connect({HttpResponseExpectations{}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTP all headers", "[basic][headers]") {
@@ -474,8 +470,8 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS without CA", "[basic][https]") {
   }
 
   run_server();
-  const std::size_t expected_commited_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
-  test_connect({HttpResponseExpectations{}}, expected_commited_requests);
+  const std::size_t expected_committed_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
+  test_connect({HttpResponseExpectations{}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS without client cert", "[basic][https]") {
@@ -497,8 +493,8 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS without client cert", "[basic][h
   }
 
   run_server();
-  const std::size_t expected_commited_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
-  test_connect({HttpResponseExpectations{}}, expected_commited_requests);
+  const std::size_t expected_committed_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
+  test_connect({HttpResponseExpectations{}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert from good CA", "[https]") {
@@ -521,8 +517,8 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert from good CA",
   }
 
   run_server();
-  const std::size_t expected_commited_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
-  test_connect({HttpResponseExpectations{}}, expected_commited_requests);
+  const std::size_t expected_committed_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
+  test_connect({HttpResponseExpectations{}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with PKCS12 client cert from good CA", "[https]") {
@@ -545,8 +541,8 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with PKCS12 client cert from goo
   }
 
   run_server();
-  const std::size_t expected_commited_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
-  test_connect({HttpResponseExpectations{}}, expected_commited_requests);
+  const std::size_t expected_committed_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
+  test_connect({HttpResponseExpectations{}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert from bad CA", "[https]") {
@@ -556,7 +552,7 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert from bad CA", "
 
   bool should_succeed = false;
   int64_t response_code = 0;
-  std::size_t expected_commited_requests = 0;
+  std::size_t expected_committed_requests = 0;
   SECTION("verify peer") {
     should_succeed = false;
     plan->setProperty(listen_http, minifi::processors::ListenHTTP::SSLVerifyPeer, "yes");
@@ -578,12 +574,12 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert from bad CA", "
 
     SECTION("GET") {
       method = HttpRequestMethod::GET;
-      expected_commited_requests = 1;
+      expected_committed_requests = 1;
     }
     SECTION("POST") {
       method = HttpRequestMethod::POST;
       payload = "Test payload";
-      expected_commited_requests = 1;
+      expected_committed_requests = 1;
     }
     SECTION("HEAD") {
       method = HttpRequestMethod::HEAD;
@@ -593,7 +589,7 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert from bad CA", "
   create_ssl_context_service("goodCA.crt", "badCA_goodClient.pem");
 
   run_server();
-  test_connect({HttpResponseExpectations{should_succeed, response_code}}, expected_commited_requests);
+  test_connect({HttpResponseExpectations{should_succeed, response_code}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert with matching DN", "[https][DN]") {
@@ -617,8 +613,8 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert with matching D
   }
 
   run_server();
-  const std::size_t expected_commited_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
-  test_connect({HttpResponseExpectations{}}, expected_commited_requests);
+  const std::size_t expected_committed_requests = (method == HttpRequestMethod::POST || method == HttpRequestMethod::GET) ? 1 : 0;
+  test_connect({HttpResponseExpectations{}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert with non-matching DN", "[https][DN]") {
@@ -628,7 +624,7 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert with non-matchi
   plan->setProperty(listen_http, minifi::processors::ListenHTTP::AuthorizedDNPattern, ".*/CN=good\\..*");
 
   int64_t response_code = 0;
-  std::size_t expected_commited_requests = 0;
+  std::size_t expected_committed_requests = 0;
   SECTION("verify peer") {
     plan->setProperty(listen_http, minifi::processors::ListenHTTP::SSLVerifyPeer, "yes");
     response_code = 403;
@@ -649,12 +645,12 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert with non-matchi
 
     SECTION("GET") {
       method = HttpRequestMethod::GET;
-      expected_commited_requests = 1;
+      expected_committed_requests = 1;
     }
     SECTION("POST") {
       method = HttpRequestMethod::POST;
       payload = "Test payload";
-      expected_commited_requests = 1;
+      expected_committed_requests = 1;
     }
     SECTION("HEAD") {
       method = HttpRequestMethod::HEAD;
@@ -664,7 +660,7 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS with client cert with non-matchi
   create_ssl_context_service("goodCA.crt", "goodCA_badClient.pem");
 
   run_server();
-  test_connect({HttpResponseExpectations{true, response_code}}, expected_commited_requests);
+  test_connect({HttpResponseExpectations{true, response_code}}, expected_committed_requests);
 }
 
 TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS minimum SSL version", "[https]") {
@@ -700,9 +696,9 @@ TEST_CASE_METHOD(ListenHTTPTestsFixture, "HTTPS minimum SSL version", "[https]")
 
 TEST_CASE("ListenHTTP bored yield", "[listenhttp][bored][yield]") {
   using processors::ListenHTTP;
-  SingleProcessorTestController controller{std::make_unique<ListenHTTP>("listenhttp")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenHTTP>("listenhttp")};
   auto listen_http = controller.getProcessor();
-  listen_http->setProperty(ListenHTTP::Port, "0");
+  REQUIRE(listen_http->setProperty(ListenHTTP::Port.name, "0"));
 
   REQUIRE(!listen_http->isYield());
   const auto output = controller.trigger();
