@@ -15,11 +15,10 @@
  * limitations under the License.
  */
 
-
 #include "PostElasticsearch.h"
 
-#include <vector>
 #include <utility>
+#include <vector>
 
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
@@ -27,8 +26,9 @@
 #include "rapidjson/document.h"
 #include "rapidjson/stream.h"
 #include "rapidjson/writer.h"
-#include "utils/expected.h"
 #include "utils/JsonCallback.h"
+#include "utils/expected.h"
+#include "utils/ProcessorConfigUtils.h"
 
 namespace org::apache::nifi::minifi::extensions::elasticsearch {
 
@@ -37,20 +37,8 @@ void PostElasticsearch::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-auto PostElasticsearch::getSSLContextService(core::ProcessContext& context) const {
-  if (auto ssl_context = context.getProperty(PostElasticsearch::SSLContext))
-    return std::dynamic_pointer_cast<minifi::controllers::SSLContextService>(context.getControllerService(*ssl_context, getUUID()));
-  return std::shared_ptr<minifi::controllers::SSLContextService>{};
-}
-
-auto PostElasticsearch::getCredentialsService(core::ProcessContext& context) const {
-  if (auto credentials = context.getProperty(PostElasticsearch::ElasticCredentials))
-    return std::dynamic_pointer_cast<ElasticsearchCredentialsControllerService>(context.getControllerService(*credentials, getUUID()));
-  return std::shared_ptr<ElasticsearchCredentialsControllerService>{};
-}
-
 void PostElasticsearch::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
-  context.getProperty(MaxBatchSize, max_batch_size_);
+  max_batch_size_ = utils::parseU64Property(context, MaxBatchSize);
   if (max_batch_size_ < 1)
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Max Batch Size property is invalid");
 
@@ -63,11 +51,12 @@ void PostElasticsearch::onSchedule(core::ProcessContext& context, core::ProcessS
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Missing or invalid hosts");
   }
 
-  credentials_service_ = getCredentialsService(context);
+  credentials_service_ = utils::parseOptionalControllerService<ElasticsearchCredentialsControllerService>(context, PostElasticsearch::ElasticCredentials, getUUID());
   if (!credentials_service_)
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Missing Elasticsearch credentials service");
 
-  client_.initialize(http::HttpRequestMethod::POST, host_url_ + "/_bulk", getSSLContextService(context));
+  auto ssl_context_service = utils::parseOptionalControllerService<minifi::controllers::SSLContextServiceInterface>(context, PostElasticsearch::SSLContext, getUUID());
+  client_.initialize(http::HttpRequestMethod::POST, host_url_ + "/_bulk", ssl_context_service);
   client_.setContentType("application/json");
   credentials_service_->authenticateClient(client_);
 }
@@ -96,7 +85,7 @@ class ElasticPayload {
     if (!index)
       return nonstd::make_unexpected("Missing index");
 
-    auto id = context.getProperty(PostElasticsearch::Identifier, flow_file.get());
+    auto id = context.getProperty(PostElasticsearch::Identifier, flow_file.get()) | utils::toOptional();
     if (!id && (action == "delete" || action == "update" || action == "upsert"))
       return nonstd::make_unexpected("Identifier is required for DELETE,UPDATE and UPSERT actions");
 
