@@ -22,25 +22,23 @@
 #include <memory>
 #include <vector>
 
-#include "controllers/SSLContextService.h"
+#include "controllers/SSLContextServiceInterface.h"
 #include "ElasticsearchCredentialsControllerService.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "utils/Enum.h"
 #include "http/HTTPClient.h"
 
 namespace org::apache::nifi::minifi::extensions::elasticsearch {
 
-class PostElasticsearch : public core::Processor {
+class PostElasticsearch : public core::ProcessorImpl {
  public:
   EXTENSIONAPI static constexpr const char* Description = "An Elasticsearch/Opensearch post processor that uses the Elasticsearch/Opensearch _bulk REST API.";
 
-  explicit PostElasticsearch(const std::string& name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~PostElasticsearch() override = default;
 
   EXTENSIONAPI static constexpr auto Action = core::PropertyDefinitionBuilder<>::createProperty("Action")
@@ -50,7 +48,7 @@ class PostElasticsearch : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto MaxBatchSize = core::PropertyDefinitionBuilder<>::createProperty("Max Batch Size")
       .withDescription("The maximum number of flow files to process at a time.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("100")
       .build();
   EXTENSIONAPI static constexpr auto ElasticCredentials = core::PropertyDefinitionBuilder<>::createProperty("Elasticsearch Credentials Provider Service")
@@ -62,16 +60,18 @@ class PostElasticsearch : public core::Processor {
       .withDescription("The SSL Context Service used to provide client certificate "
           "information for TLS/SSL (https) connections.")
       .isRequired(false)
-      .withAllowedTypes<minifi::controllers::SSLContextService>()
+      .withAllowedTypes<minifi::controllers::SSLContextServiceInterface>()
       .build();
   EXTENSIONAPI static constexpr auto Hosts = core::PropertyDefinitionBuilder<>::createProperty("Hosts")
       .withDescription("A comma-separated list of HTTP hosts that host Elasticsearch query nodes. Currently only supports a single host.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto Index = core::PropertyDefinitionBuilder<>::createProperty("Index")
       .withDescription("The name of the index to use.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto Identifier = core::PropertyDefinitionBuilder<>::createProperty("Identifier")
@@ -79,6 +79,7 @@ class PostElasticsearch : public core::Processor {
                       "in which case the document's identifier will be auto-generated by Elasticsearch. "
                       "For all other Actions, the attribute must evaluate to a non-empty value.")
       .supportsExpressionLanguage(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       Action,
@@ -108,14 +109,11 @@ class PostElasticsearch : public core::Processor {
 
  private:
   std::string collectPayload(core::ProcessContext&, core::ProcessSession&, std::vector<std::shared_ptr<core::FlowFile>>&) const;
-  auto getSSLContextService(core::ProcessContext& context) const;
-  auto getCredentialsService(core::ProcessContext& context) const;
 
   uint64_t max_batch_size_ = 100;
   std::string host_url_;
   std::shared_ptr<ElasticsearchCredentialsControllerService> credentials_service_;
   http::HTTPClient client_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<PostElasticsearch>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::extensions::elasticsearch
