@@ -34,6 +34,7 @@
 #include "utils/OsUtils.h"
 #include "expression/Expression.h"
 #include "utils/RegexUtils.h"
+#include "utils/TimeUtil.h"
 
 #ifdef WIN32
 #pragma comment(lib, "wldap32.lib" )
@@ -96,7 +97,7 @@ Expression make_dynamic_attr(const std::string &attribute_id) {
     if (cur_flow_file && cur_flow_file->getAttribute(attribute_id, result)) {
       return Value(result);
     } else {
-      auto registry = params.registry_.lock();
+      auto registry = params.registry_;
       if (registry && registry->getConfigurationProperty(attribute_id , result)) {
         return Value(result);
       }
@@ -1634,6 +1635,7 @@ Expression Expression::make_aggregate(const std::function<Value(const Parameters
 
 #ifdef WIN32
 void dateSetInstall(const std::string& install) {
+  utils::timeutils::dateSetInstall(install);
   date::set_install(install);
 }
 #endif
