@@ -26,16 +26,16 @@
 namespace org::apache::nifi::minifi::core::expressions {
 
 ExpressionContextBuilder::ExpressionContextBuilder(std::string_view name, const minifi::utils::Identifier &uuid)
-    : core::ProcessContextBuilder(name, uuid) {
+    : core::ProcessContextBuilderImpl(name, uuid) {
 }
 
 ExpressionContextBuilder::ExpressionContextBuilder(std::string_view name)
-    : core::ProcessContextBuilder(name) {
+    : core::ProcessContextBuilderImpl(name) {
 }
 
 ExpressionContextBuilder::~ExpressionContextBuilder() = default;
 
-std::shared_ptr<core::ProcessContext> ExpressionContextBuilder::build(const std::shared_ptr<ProcessorNode> &processor) {
+std::shared_ptr<core::ProcessContext> ExpressionContextBuilder::build(Processor& processor) {
   return std::make_shared<core::ProcessContextExpr>(processor, controller_service_provider_, prov_repo_, flow_repo_, configuration_, content_repo_);
 }
 
