@@ -48,7 +48,7 @@ class FetchFromGCSCallback {
     if (!reader)
       return 0;
     std::string contents{std::istreambuf_iterator<char>{reader}, {}};
-    auto write_ret = stream->write(gsl::make_span(contents).as_span<std::byte>());
+    const auto write_ret = gsl::narrow<int64_t>(stream->write(gsl::make_span(contents).as_span<std::byte>()));
     reader.Close();
     return write_ret;
   }
@@ -124,18 +124,19 @@ void FetchGCSObject::onTrigger(core::ProcessContext& context, core::ProcessSessi
   FetchFromGCSCallback callback(client, *bucket, *object_name);
   callback.setEncryptionKey(encryption_key_);
 
-  if (auto gen_str = context.getProperty(ObjectGeneration, flow_file.get()); gen_str && !gen_str->empty()) {
-    try {
-      int64_t gen = 0;
-      utils::internal::ValueParser(*gen_str).parse(gen).parseEnd();
-      callback.setGeneration(gcs::Generation(gen));
-    } catch (const utils::internal::ValueException&) {
-      logger_->log_error("Invalid generation: {}", *gen_str);
+  if (const auto object_generation_str =  context.getProperty(ObjectGeneration, flow_file.get()); object_generation_str && !object_generation_str->empty()) {
+    if (const auto geni64 = parsing::parseIntegral<int64_t>(*object_generation_str)) {
+      gcs::Generation generation = gcs::Generation{*geni64};
+      callback.setGeneration(generation);
+
+    } else {
+      logger_->log_error("Invalid generation: {}", *object_generation_str);
       session.transfer(flow_file, Failure);
       return;
     }
   }
 
+
   session.write(flow_file, std::ref(callback));
   if (!callback.getStatus().ok()) {
     flow_file->setAttribute(GCS_STATUS_MESSAGE, callback.getStatus().message());
