@@ -23,11 +23,11 @@
 
 #include "../GCPAttributes.h"
 #include "GCSProcessor.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "core/OutputAttributeDefinition.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "utils/ArrayUtils.h"
 
@@ -43,9 +43,7 @@ inline constexpr auto FILENAME_OUTPUT_ATTRIBUTE_DESCRIPTION = utils::array_to_st
 
 class ListGCSBucket : public GCSProcessor {
  public:
-  explicit ListGCSBucket(std::string_view name, const utils::Identifier& uuid = {})
-      : GCSProcessor(name, uuid, core::logging::LoggerFactory<ListGCSBucket>::getLogger(uuid)) {
-  }
+  using GCSProcessor::GCSProcessor;
   ~ListGCSBucket() override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "Retrieves a listing of objects from an GCS bucket. "
@@ -58,7 +56,7 @@ class ListGCSBucket : public GCSProcessor {
       .build();
   EXTENSIONAPI static constexpr auto ListAllVersions = core::PropertyDefinitionBuilder<>::createProperty("List all versions")
       .withDescription("Set this option to `true` to get all the previous versions separately.")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto Properties = utils::array_cat(GCSProcessor::Properties, std::to_array<core::PropertyReference>({
