@@ -23,11 +23,10 @@
 
 #include "../GCPAttributes.h"
 #include "GCSProcessor.h"
-#include "PropertyDefinition.h"
-#include "PropertyType.h"
-#include "RelationshipDefinition.h"
-#include "core/logging/LoggerConfiguration.h"
-#include "RelationshipDefinition.h"
+#include "core/PropertyDefinition.h"
+#include "minifi-cpp/core/PropertyValidator.h"
+#include "core/RelationshipDefinition.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/ArrayUtils.h"
 #include "utils/Enum.h"
 #include "google/cloud/storage/well_known_headers.h"
@@ -73,9 +72,7 @@ namespace org::apache::nifi::minifi::extensions::gcp {
 
 class PutGCSObject : public GCSProcessor {
  public:
-  explicit PutGCSObject(std::string_view name, const utils::Identifier& uuid = {})
-      : GCSProcessor(name, uuid, core::logging::LoggerFactory<PutGCSObject>::getLogger(uuid)) {
-  }
+  using GCSProcessor::GCSProcessor;
   ~PutGCSObject() override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "Puts flow files to a Google Cloud Storage Bucket.";
@@ -119,7 +116,7 @@ class PutGCSObject : public GCSProcessor {
       .build();
   EXTENSIONAPI static constexpr auto OverwriteObject = core::PropertyDefinitionBuilder<>::createProperty("Overwrite Object")
       .withDescription("If false, the upload to GCS will succeed only if the object does not exist.")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto Properties = utils::array_cat(GCSProcessor::Properties, std::to_array<core::PropertyReference>({
