@@ -77,13 +77,6 @@ void PushGrafanaLoki::LogBatch::setStartPushTime(std::chrono::system_clock::time
 
 const core::Relationship PushGrafanaLoki::Self("__self__", "Marks the FlowFile to be owned by this processor");
 
-std::shared_ptr<minifi::controllers::SSLContextService> PushGrafanaLoki::getSSLContextService(core::ProcessContext& context) const {
-  if (auto ssl_context = context.getProperty(PushGrafanaLoki::SSLContextService)) {
-    return std::dynamic_pointer_cast<minifi::controllers::SSLContextService>(context.getControllerService(*ssl_context, getUUID()));
-  }
-  return std::shared_ptr<minifi::controllers::SSLContextService>{};
-}
-
 void PushGrafanaLoki::setUpStateManager(core::ProcessContext& context) {
   auto state_manager = context.getStateManager();
   if (state_manager == nullptr) {
@@ -110,11 +103,11 @@ std::map<std::string, std::string> PushGrafanaLoki::buildStreamLabelMap(core::Pr
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Missing or invalid Stream Labels property");
     }
     for (const auto& label : stream_labels) {
-      auto stream_labels = utils::string::splitAndTrimRemovingEmpty(label, "=");
-      if (stream_labels.size() != 2) {
+      auto key_value = utils::string::splitAndTrimRemovingEmpty(label, "=");
+      if (key_value.size() != 2) {
         throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Missing or invalid Stream Labels property");
       }
-      stream_label_map[stream_labels[0]] = stream_labels[1];
+      stream_label_map[key_value[0]] = key_value[1];
     }
   } else {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Missing or invalid Stream Labels property");
@@ -130,15 +123,15 @@ void PushGrafanaLoki::onSchedule(core::ProcessContext& context, core::ProcessSes
     log_line_metadata_attributes_ = utils::string::splitAndTrimRemovingEmpty(*log_line_metadata_attributes, ",");
   }
 
-  auto log_line_batch_wait = context.getProperty<core::TimePeriodValue>(LogLineBatchWait);
-  auto log_line_batch_size = context.getProperty<uint64_t>(LogLineBatchSize);
+  auto log_line_batch_wait = utils::parseOptionalDurationProperty(context, LogLineBatchWait);
+  auto log_line_batch_size = utils::parseOptionalU64Property(context, LogLineBatchSize);
   if (log_line_batch_size && *log_line_batch_size < 1) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Log Line Batch Size property is missing or less than 1!");
   }
   log_line_batch_size_is_set_ = log_line_batch_size.has_value();
   log_line_batch_wait_is_set_ = log_line_batch_wait.has_value();
 
-  max_batch_size_ = context.getProperty<uint64_t>(MaxBatchSize);
+  max_batch_size_ = utils::parseOptionalU64Property(context, MaxBatchSize);
   if (max_batch_size_) {
     logger_->log_debug("PushGrafanaLoki Max Batch Size is set to: {}", *max_batch_size_);
   }
@@ -149,8 +142,8 @@ void PushGrafanaLoki::onSchedule(core::ProcessContext& context, core::ProcessSes
   }
 
   if (log_line_batch_wait) {
-    log_batch_.setLogLineBatchWait(log_line_batch_wait->getMilliseconds());
-    logger_->log_debug("PushGrafanaLoki Log Line Batch Wait is set to {} milliseconds", log_line_batch_wait->getMilliseconds());
+    log_batch_.setLogLineBatchWait(log_line_batch_wait);
+    logger_->log_debug("PushGrafanaLoki Log Line Batch Wait is set to {} milliseconds", *log_line_batch_wait);
   }
 }
 
@@ -232,12 +225,4 @@ void PushGrafanaLoki::restore(const std::shared_ptr<core::FlowFile>& flow_file)
   log_batch_.restore(flow_file);
 }
 
-std::set<core::Connectable*> PushGrafanaLoki::getOutGoingConnections(const std::string &relationship) {
-  auto result = core::Connectable::getOutGoingConnections(relationship);
-  if (relationship == Self.getName()) {
-    result.insert(this);
-  }
-  return result;
-}
-
 }  // namespace org::apache::nifi::minifi::extensions::grafana::loki
