@@ -21,23 +21,22 @@
 #include <vector>
 #include <map>
 
-#include "controllers/SSLContextService.h"
-#include "core/Processor.h"
+#include "controllers/SSLContextServiceInterface.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "core/StateManager.h"
 #include "utils/ArrayUtils.h"
 
 namespace org::apache::nifi::minifi::extensions::grafana::loki {
 
-class PushGrafanaLoki : public core::Processor {
+class PushGrafanaLoki : public core::ProcessorImpl {
  public:
-  PushGrafanaLoki(const std::string& name, const utils::Identifier& uuid, const std::shared_ptr<core::logging::Logger>& logger)
-      : Processor(name, uuid),
-        logger_(logger),
-        log_batch_(logger_) {
+  explicit PushGrafanaLoki(core::ProcessorMetadata metadata)
+      : ProcessorImpl(metadata),
+        log_batch_(metadata.logger) {
   }
   ~PushGrafanaLoki() override = default;
 
@@ -54,31 +53,32 @@ class PushGrafanaLoki : public core::Processor {
     .build();
   EXTENSIONAPI static constexpr auto TenantID = core::PropertyDefinitionBuilder<>::createProperty("Tenant ID")
     .withDescription("The tenant ID used by default to push logs to Grafana Loki. If omitted or empty it assumes Grafana Loki is running in single-tenant mode and no X-Scope-OrgID header is sent.")
+    .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
     .build();
   EXTENSIONAPI static constexpr auto MaxBatchSize = core::PropertyDefinitionBuilder<>::createProperty("Max Batch Size")
     .withDescription("The maximum number of flow files to process at a time. If it is set to 0, all FlowFiles will be processed at once.")
-    .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+    .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
     .withDefaultValue("100")
     .build();
   EXTENSIONAPI static constexpr auto LogLineBatchWait = core::PropertyDefinitionBuilder<>::createProperty("Log Line Batch Wait")
     .withDescription("Time to wait before sending a log line batch to Grafana Loki, full or not. If this property and Log Line Batch Size are both unset, "
                      "the log batch of the current trigger will be sent immediately.")
-    .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+    .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
     .build();
   EXTENSIONAPI static constexpr auto LogLineBatchSize = core::PropertyDefinitionBuilder<>::createProperty("Log Line Batch Size")
     .withDescription("Number of log lines to send in a batch to Loki. If this property and Log Line Batch Wait are both unset, "
                      "the log batch of the current trigger will be sent immediately.")
-    .withPropertyType(core::StandardPropertyTypes::UNSIGNED_INT_TYPE)
+    .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
     .build();
   EXTENSIONAPI static constexpr auto ConnectTimeout = core::PropertyDefinitionBuilder<>::createProperty("Connection Timeout")
     .withDescription("Max wait time for connection to the Grafana Loki service.")
-    .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+    .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
     .withDefaultValue("5 s")
     .isRequired(true)
     .build();
   EXTENSIONAPI static constexpr auto SSLContextService = core::PropertyDefinitionBuilder<>::createProperty("SSL Context Service")
     .withDescription("The SSL Context Service used to provide client certificate information for TLS/SSL (https) connections.")
-    .withAllowedTypes<minifi::controllers::SSLContextService>()
+    .withAllowedTypes<minifi::controllers::SSLContextServiceInterface>()
     .build();
   EXTENSIONAPI static constexpr auto Properties = utils::array_cat(std::to_array<core::PropertyReference>({
       Url,
@@ -106,7 +106,6 @@ class PushGrafanaLoki : public core::Processor {
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& sessionFactory) override;
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void restore(const std::shared_ptr<core::FlowFile>& flow_file) override;
-  std::set<core::Connectable*> getOutGoingConnections(const std::string &relationship) override;
 
  protected:
   static const core::Relationship Self;
@@ -134,14 +133,12 @@ class PushGrafanaLoki : public core::Processor {
 
   static std::map<std::string, std::string> buildStreamLabelMap(core::ProcessContext& context);
 
-  std::shared_ptr<minifi::controllers::SSLContextService> getSSLContextService(core::ProcessContext& context) const;
   void processBatch(const std::vector<std::shared_ptr<core::FlowFile>>& batched_flow_files, core::ProcessSession& session);
   virtual nonstd::expected<void, std::string> submitRequest(const std::vector<std::shared_ptr<core::FlowFile>>& batched_flow_files, core::ProcessSession& session) = 0;
   void initializeHttpClient(core::ProcessContext& context);
   void setUpStateManager(core::ProcessContext& context);
   virtual void setUpStreamLabels(core::ProcessContext& context) = 0;
 
-  std::shared_ptr<core::logging::Logger> logger_;
   std::optional<uint64_t> max_batch_size_;
   std::vector<std::string> log_line_metadata_attributes_;
   bool log_line_batch_size_is_set_ = false;
