@@ -56,33 +56,35 @@ void PushGrafanaLokiGrpc::setUpStreamLabels(core::ProcessContext& context) {
 void PushGrafanaLokiGrpc::setUpGrpcChannel(const std::string& url, core::ProcessContext& context) {
   ::grpc::ChannelArguments args;
 
-  if (auto keep_alive_time = context.getProperty<core::TimePeriodValue>(PushGrafanaLokiGrpc::KeepAliveTime)) {
-    logger_->log_debug("PushGrafanaLokiGrpc Keep Alive Time is set to {} ms", keep_alive_time->getMilliseconds().count());
-    args.SetInt(GRPC_ARG_KEEPALIVE_TIME_MS, gsl::narrow<int>(keep_alive_time->getMilliseconds().count()));
+  if (auto keep_alive_time = utils::parseOptionalDurationProperty(context, PushGrafanaLokiGrpc::KeepAliveTime)) {
+    logger_->log_debug("PushGrafanaLokiGrpc Keep Alive Time is set to {} ms", keep_alive_time->count());
+    args.SetInt(GRPC_ARG_KEEPALIVE_TIME_MS, gsl::narrow<int>(keep_alive_time->count()));
   }
 
-  if (auto keep_alive_timeout = context.getProperty<core::TimePeriodValue>(PushGrafanaLokiGrpc::KeepAliveTimeout)) {
-    logger_->log_debug("PushGrafanaLokiGrpc Keep Alive Timeout is set to {} ms", keep_alive_timeout->getMilliseconds().count());
-    args.SetInt(GRPC_ARG_KEEPALIVE_TIMEOUT_MS, gsl::narrow<int>(keep_alive_timeout->getMilliseconds().count()));
+  if (auto keep_alive_timeout = utils::parseOptionalDurationProperty(context, PushGrafanaLokiGrpc::KeepAliveTimeout)) {
+    logger_->log_debug("PushGrafanaLokiGrpc Keep Alive Timeout is set to {} ms", keep_alive_timeout->count());
+    args.SetInt(GRPC_ARG_KEEPALIVE_TIMEOUT_MS, gsl::narrow<int>(keep_alive_timeout->count()));
   }
 
-  if (auto max_pings_without_data = context.getProperty<uint64_t>(PushGrafanaLokiGrpc::MaxPingsWithoutData)) {
+  if (auto max_pings_without_data = utils::parseOptionalU64Property(context, PushGrafanaLokiGrpc::MaxPingsWithoutData)) {
     logger_->log_debug("PushGrafanaLokiGrpc Max Pings Without Data is set to {}", *max_pings_without_data);
     args.SetInt(GRPC_ARG_HTTP2_MAX_PINGS_WITHOUT_DATA, gsl::narrow<int>(*max_pings_without_data));
   }
 
   args.SetInt(GRPC_ARG_KEEPALIVE_PERMIT_WITHOUT_CALLS, 1);
 
-  std::shared_ptr<::grpc::ChannelCredentials> creds;
-  if (auto ssl_context_service = getSSLContextService(context)) {
-    ::grpc::SslCredentialsOptions ssl_credentials_options;
-    ssl_credentials_options.pem_cert_chain = utils::file::FileUtils::get_content(ssl_context_service->getCertificateFile());
-    ssl_credentials_options.pem_private_key = utils::file::FileUtils::get_content(ssl_context_service->getPrivateKeyFile());
-    ssl_credentials_options.pem_root_certs = utils::file::FileUtils::get_content(ssl_context_service->getCACertificate());
-    creds = ::grpc::SslCredentials(ssl_credentials_options);
-  } else {
-    creds = ::grpc::InsecureChannelCredentials();
-  }
+  std::shared_ptr<::grpc::ChannelCredentials> creds = [&]() {
+    auto ssl_context_service = utils::parseOptionalControllerService<minifi::controllers::SSLContextServiceInterface>(context, PushGrafanaLoki::SSLContextService, getUUID());
+    if (ssl_context_service) {
+      ::grpc::SslCredentialsOptions ssl_credentials_options;
+      ssl_credentials_options.pem_cert_chain = utils::file::FileUtils::get_content(ssl_context_service->getCertificateFile());
+      ssl_credentials_options.pem_private_key = utils::file::FileUtils::get_content(ssl_context_service->getPrivateKeyFile());
+      ssl_credentials_options.pem_root_certs = utils::file::FileUtils::get_content(ssl_context_service->getCACertificate());
+      return ::grpc::SslCredentials(ssl_credentials_options);
+    } else {
+      return ::grpc::InsecureChannelCredentials();
+    }
+  }();
 
   push_channel_ = ::grpc::CreateCustomChannel(url, creds, args);
   if (!push_channel_) {
@@ -94,13 +96,13 @@ void PushGrafanaLokiGrpc::setUpGrpcChannel(const std::string& url, core::Process
 
 void PushGrafanaLokiGrpc::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) {
   PushGrafanaLoki::onSchedule(context, session_factory);
-  auto url = utils::getRequiredPropertyOrThrow<std::string>(context, Url.name);
+  auto url = utils::parseProperty(context, Url);
   if (url.empty()) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Url property cannot be empty!");
   }
-  tenant_id_ = context.getProperty(TenantID);
-  if (auto connection_timeout = context.getProperty<core::TimePeriodValue>(PushGrafanaLokiGrpc::ConnectTimeout)) {
-    connection_timeout_ms_ = connection_timeout->getMilliseconds();
+  tenant_id_ = context.getProperty(TenantID) | utils::toOptional();
+  if (auto connection_timeout = utils::parseOptionalDurationProperty(context, PushGrafanaLokiGrpc::ConnectTimeout)) {
+    connection_timeout_ms_ = *connection_timeout;
   } else {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Invalid connection timeout is set.");
   }
