@@ -18,36 +18,35 @@
 
 #include "PushGrafanaLoki.h"
 
+#include "core/logging/LoggerFactory.h"
 #include "core/StateManager.h"
-#include "grafana-loki-push.pb.h"
 #include "grafana-loki-push.grpc.pb.h"
+#include "grafana-loki-push.pb.h"
 #include "grpc/grpc.h"
 
 namespace org::apache::nifi::minifi::extensions::grafana::loki {
 
-class PushGrafanaLokiGrpc : public PushGrafanaLoki {
+class PushGrafanaLokiGrpc final : public PushGrafanaLoki {
  public:
   EXTENSIONAPI static constexpr const char* Description = "A Grafana Loki push processor that uses the Grafana Loki Grpc port. The processor expects each flow file to contain a single log line to be "
                                                           "pushed to Grafana Loki, therefore it is usually used together with the TailFile processor.";
 
-  explicit PushGrafanaLokiGrpc(const std::string& name, const utils::Identifier& uuid = {})
-      : PushGrafanaLoki(name, uuid, core::logging::LoggerFactory<PushGrafanaLokiGrpc>::getLogger(uuid)) {
-  }
+  using PushGrafanaLoki::PushGrafanaLoki;
   ~PushGrafanaLokiGrpc() override = default;
 
   EXTENSIONAPI static constexpr auto KeepAliveTime = core::PropertyDefinitionBuilder<>::createProperty("Keep Alive Time")
     .withDescription("The period after which a keepalive ping is sent on the transport. If not set, then the keep alive is disabled.")
-    .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+    .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
     .build();
   EXTENSIONAPI static constexpr auto KeepAliveTimeout = core::PropertyDefinitionBuilder<>::createProperty("Keep Alive Timeout")
     .withDescription("The amount of time the sender of the keepalive ping waits for an acknowledgement. If it does not receive an acknowledgment within this time, "
                      "it will close the connection. If not set, then the default value 20 seconds is used.")
-    .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+    .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
     .build();
   EXTENSIONAPI static constexpr auto MaxPingsWithoutData = core::PropertyDefinitionBuilder<>::createProperty("Max Pings Without Data")
     .withDescription("The maximum number of pings that can be sent when there is no data/header frame to be sent. gRPC Core will not continue sending pings "
                      "if we run over the limit. Setting it to 0 allows sending pings without such a restriction. If not set, then the default value 2 is used.")
-    .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+    .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
     .build();
   EXTENSIONAPI static constexpr auto Properties = utils::array_cat(PushGrafanaLoki::Properties, std::to_array<core::PropertyReference>({
       KeepAliveTime,
@@ -64,7 +63,7 @@ class PushGrafanaLokiGrpc : public PushGrafanaLoki {
   void setUpGrpcChannel(const std::string& url, core::ProcessContext& context);
 
   std::string stream_labels_;
-  std::chrono::milliseconds connection_timeout_ms_;
+  std::chrono::milliseconds connection_timeout_ms_{};
   std::optional<std::string> tenant_id_;
   std::shared_ptr<::grpc::Channel> push_channel_;
   std::unique_ptr<logproto::Pusher::Stub> push_stub_;
