@@ -19,6 +19,7 @@
 #include "PushGrafanaLoki.h"
 
 #include "http/HTTPClient.h"
+#include "rapidjson/document.h"
 
 namespace org::apache::nifi::minifi::extensions::grafana::loki {
 
@@ -27,14 +28,12 @@ class PushGrafanaLokiREST : public PushGrafanaLoki {
   EXTENSIONAPI static constexpr const char* Description = "A Grafana Loki push processor that uses the Grafana Loki REST API. The processor expects each flow file to contain a single log line to be "
                                                           "pushed to Grafana Loki, therefore it is usually used together with the TailFile processor.";
 
-  explicit PushGrafanaLokiREST(const std::string& name, const utils::Identifier& uuid = {})
-      : PushGrafanaLoki(name, uuid, core::logging::LoggerFactory<PushGrafanaLokiREST>::getLogger(uuid)) {
-  }
+  using PushGrafanaLoki::PushGrafanaLoki;
   ~PushGrafanaLokiREST() override = default;
 
   EXTENSIONAPI static constexpr auto ReadTimeout = core::PropertyDefinitionBuilder<>::createProperty("Read Timeout")
     .withDescription("Max wait time for response from remote service.")
-    .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+    .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
     .withDefaultValue("15 s")
     .isRequired(true)
     .build();
