@@ -25,7 +25,7 @@
 namespace org::apache::nifi::minifi::extensions::grafana::loki::test {
 
 TEST_CASE("Url property is required", "[PushGrafanaLokiGrpc]") {
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc"));
   auto push_grafana_loki_grpc = test_controller.getProcessor();
   test_controller.plan->setProperty(push_grafana_loki_grpc, PushGrafanaLokiGrpc::Url, "");
   test_controller.plan->setProperty(push_grafana_loki_grpc, PushGrafanaLokiGrpc::StreamLabels, "job=minifi,directory=/opt/minifi/logs/");
@@ -34,7 +34,7 @@ TEST_CASE("Url property is required", "[PushGrafanaLokiGrpc]") {
 }
 
 TEST_CASE("Valid stream labels need to be set", "[PushGrafanaLokiGrpc]") {
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc"));
   auto push_grafana_loki_grpc = test_controller.getProcessor();
   test_controller.plan->setProperty(push_grafana_loki_grpc, PushGrafanaLokiGrpc::Url, "localhost:10991");
   test_controller.plan->setProperty(push_grafana_loki_grpc, PushGrafanaLokiGrpc::LogLineBatchSize, "1");
@@ -48,7 +48,7 @@ TEST_CASE("Valid stream labels need to be set", "[PushGrafanaLokiGrpc]") {
 }
 
 TEST_CASE("Log Line Batch Size cannot be 0", "[PushGrafanaLokiGrpc]") {
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc"));
   auto push_grafana_loki_grpc = test_controller.getProcessor();
   CHECK(test_controller.plan->setProperty(push_grafana_loki_grpc, PushGrafanaLokiGrpc::Url, "localhost:10991"));
   CHECK(test_controller.plan->setProperty(push_grafana_loki_grpc, PushGrafanaLokiGrpc::StreamLabels, "job=minifi,directory=/opt/minifi/logs/"));
@@ -60,8 +60,8 @@ class PushGrafanaLokiGrpcTestFixture {
  public:
   PushGrafanaLokiGrpcTestFixture()
       : mock_loki_("10991"),
-        test_controller_(std::make_unique<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc")),
-        push_grafana_loki_grpc_(test_controller_.getProcessor<PushGrafanaLokiGrpc>()) {
+        test_controller_(minifi::test::utils::make_processor<PushGrafanaLokiGrpc>("PushGrafanaLokiGrpc")),
+        push_grafana_loki_grpc_(test_controller_.getProcessor()) {
     LogTestController::getInstance().setDebug<TestPlan>();
     LogTestController::getInstance().setDebug<minifi::core::Processor>();
     LogTestController::getInstance().setTrace<minifi::core::ProcessSession>();
@@ -111,7 +111,7 @@ class PushGrafanaLokiGrpcTestFixture {
  protected:
   MockGrafanaLokiGrpc mock_loki_;
   minifi::test::SingleProcessorTestController test_controller_;
-  PushGrafanaLokiGrpc* push_grafana_loki_grpc_;
+  TypedProcessorWrapper<PushGrafanaLokiGrpc> push_grafana_loki_grpc_;
 };
 
 TEST_CASE_METHOD(PushGrafanaLokiGrpcTestFixture, "PushGrafanaLokiGrpc should send 1 log line to Grafana Loki in a trigger", "[PushGrafanaLokiGrpc]") {
