@@ -24,19 +24,19 @@ extern "C" {
 }
 
 #include "core/Resource.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "Exception.h"
 #include "utils/gsl.h"
 #include "utils/StringUtils.h"
 
 namespace org::apache::nifi::minifi::controllers {
 
-KubernetesControllerService::KubernetesControllerService(const std::string& name, const utils::Identifier& uuid)
-  : AttributeProviderService(name, uuid),
+KubernetesControllerService::KubernetesControllerService(const std::string_view name, const utils::Identifier& uuid)
+  : AttributeProviderServiceImpl(name, uuid),
     logger_{core::logging::LoggerFactory<KubernetesControllerService>::getLogger(uuid)} {
 }
 
-KubernetesControllerService::KubernetesControllerService(const std::string& name, const std::shared_ptr<Configure>& configuration)
+KubernetesControllerService::KubernetesControllerService(const std::string_view name, const std::shared_ptr<Configure>& configuration)
   : KubernetesControllerService{name} {
     setConfiguration(configuration);
     initialize();
@@ -46,7 +46,7 @@ void KubernetesControllerService::initialize() {
   std::lock_guard<std::mutex> lock(initialization_mutex_);
   if (initialized_) { return; }
 
-  ControllerService::initialize();
+  ControllerServiceImpl::initialize();
   setSupportedProperties(Properties);
   initialized_ = true;
 }
@@ -58,19 +58,16 @@ void KubernetesControllerService::onEnable() {
     logger_->log_error("Could not create the API client in the Kubernetes Controller Service: {}", ex.what());
   }
 
-  std::string namespace_filter;
-  if (getProperty(NamespaceFilter, namespace_filter) && !namespace_filter.empty()) {
-    namespace_filter_ = utils::Regex{namespace_filter};
+  if (std::string namespace_filter = getProperty(NamespaceFilter.name).value_or(""); !namespace_filter.empty()) {
+    namespace_filter_ = utils::Regex{std::move(namespace_filter)};
   }
 
-  std::string pod_name_filter;
-  if (getProperty(PodNameFilter, pod_name_filter) && !pod_name_filter.empty()) {
-    pod_name_filter_ = utils::Regex{pod_name_filter};
+  if (std::string pod_name_filter = getProperty(PodNameFilter.name).value_or(""); !pod_name_filter.empty()) {
+    pod_name_filter_ = utils::Regex{std::move(pod_name_filter)};
   }
 
-  std::string container_name_filter;
-  if (getProperty(ContainerNameFilter, container_name_filter) && !container_name_filter.empty()) {
-    container_name_filter_ = utils::Regex{container_name_filter};
+  if (std::string container_name_filter = getProperty(ContainerNameFilter.name).value_or(""); !container_name_filter.empty()) {
+    container_name_filter_ = utils::Regex{std::move(container_name_filter)};
   }
 }
 
