@@ -20,18 +20,16 @@
 #include <string>
 
 #include "../controllerservice/KubernetesControllerService.h"
-#include "core/logging/LoggerConfiguration.h"
-#include "core/Processor.h"
+#include "core/logging/LoggerFactory.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class CollectKubernetesPodMetrics : public core::Processor {
+class CollectKubernetesPodMetrics : public core::ProcessorImpl {
  public:
-  explicit CollectKubernetesPodMetrics(const std::string& name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "A processor which collects pod metrics when MiNiFi is run inside Kubernetes.";
 
@@ -55,7 +53,6 @@ class CollectKubernetesPodMetrics : public core::Processor {
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
 
  private:
-  gsl::not_null<std::shared_ptr<core::logging::Logger>> logger_ = gsl::make_not_null(core::logging::LoggerFactory<CollectKubernetesPodMetrics>::getLogger(uuid_));
   std::shared_ptr<controllers::KubernetesControllerService> kubernetes_controller_service_;
 };
 
