@@ -26,17 +26,17 @@
 #include <map>
 #include <string>
 
-#include "PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "archive_entry.h"
 #include "archive.h"
 
 #include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/Core.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "io/ZlibStream.h"
 #include "utils/Enum.h"
 #include "utils/gsl.h"
@@ -83,11 +83,9 @@ constexpr customize_t enum_name<ExtendedCompressionFormat>(ExtendedCompressionFo
 
 namespace org::apache::nifi::minifi::processors {
 
-class CompressContent : public core::Processor {
+class CompressContent : public core::ProcessorImpl {
  public:
-  explicit CompressContent(std::string_view name, const utils::Identifier& uuid = {})
-    : core::Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~CompressContent() override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "Compresses or decompresses the contents of FlowFiles using a user-specified compression algorithm "
@@ -102,7 +100,7 @@ class CompressContent : public core::Processor {
   EXTENSIONAPI static constexpr auto CompressLevel = core::PropertyDefinitionBuilder<>::createProperty("Compression Level")
       .withDescription("The compression level to use; this is valid only when using GZIP compression.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::INTEGER_TYPE)
+      .withValidator(core::StandardPropertyValidators::INTEGER_VALIDATOR)
       .withDefaultValue("1")
       .build();
   EXTENSIONAPI static constexpr auto CompressFormat = core::PropertyDefinitionBuilder<magic_enum::enum_count<compress_content::ExtendedCompressionFormat>()>::createProperty("Compression Format")
@@ -114,7 +112,7 @@ class CompressContent : public core::Processor {
   EXTENSIONAPI static constexpr auto UpdateFileName = core::PropertyDefinitionBuilder<>::createProperty("Update Filename")
       .withDescription("Determines if filename extension need to be updated")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto EncapsulateInTar = core::PropertyDefinitionBuilder<>::createProperty("Encapsulate in TAR")
@@ -123,12 +121,12 @@ class CompressContent : public core::Processor {
           "If false, on compression the content of the FlowFile simply gets compressed, and on decompression a simple compressed content is expected.\n"
           "true is the behaviour compatible with older MiNiFi C++ versions, false is the behaviour compatible with NiFi.")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto BatchSize = core::PropertyDefinitionBuilder<>::createProperty("Batch Size")
       .withDescription("Maximum number of FlowFiles processed in a single session")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_INT_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("1")
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
@@ -214,13 +212,12 @@ class CompressContent : public core::Processor {
 
   void processFlowFile(const std::shared_ptr<core::FlowFile>& flowFile, core::ProcessSession& session);
 
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<CompressContent>::getLogger(uuid_);
   int compressLevel_{};
   compress_content::CompressionMode compressMode_;
   compress_content::ExtendedCompressionFormat compressFormat_;
   bool updateFileName_ = false;
   bool encapsulateInTar_ = false;
-  uint32_t batchSize_{1};
+  uint64_t batchSize_{1};
   static const std::map<std::string, io::CompressionFormat> compressionFormatMimeTypeMap_;
   static const std::map<io::CompressionFormat, std::string> fileExtension_;
 };
