@@ -24,23 +24,21 @@
 
 #include "ArchiveMetadata.h"
 #include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/RelationshipDefinition.h"
 #include "core/Core.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/file/FileManager.h"
 #include "utils/Export.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class FocusArchiveEntry : public core::Processor {
+class FocusArchiveEntry : public core::ProcessorImpl {
  public:
-  explicit FocusArchiveEntry(std::string_view name, const utils::Identifier& uuid = {})
-  : core::Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~FocusArchiveEntry()   override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "Allows manipulation of entries within an archive (e.g. TAR) by focusing on one entry within the archive at a time. "
@@ -67,12 +65,12 @@ class FocusArchiveEntry : public core::Processor {
 
   class ReadCallback {
    public:
-    explicit ReadCallback(core::Processor*, utils::file::FileManager *file_man, ArchiveMetadata *archiveMetadata);
+    explicit ReadCallback(core::ProcessContext* context, utils::file::FileManager *file_man, ArchiveMetadata *archiveMetadata);
     int64_t operator()(const std::shared_ptr<io::InputStream>& stream) const;
 
    private:
     utils::file::FileManager *file_man_;
-    core::Processor * const proc_;
+    core::ProcessContext* const context_;
     std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<FocusArchiveEntry>::getLogger();
     ArchiveMetadata *_archiveMetadata;
     static int ok_cb(struct archive *, void* /*d*/) { return ARCHIVE_OK; }
@@ -80,7 +78,6 @@ class FocusArchiveEntry : public core::Processor {
   };
 
  private:
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<FocusArchiveEntry>::getLogger(uuid_);
   static std::shared_ptr<utils::IdGenerator> id_generator_;
 };
 
