@@ -28,13 +28,14 @@
 #include "archive_entry.h"
 #include "archive.h"
 #include "SmartArchivePtrs.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "serialization/FlowFileSerializer.h"
 #include "utils/ArrayUtils.h"
 #include "utils/gsl.h"
 #include "utils/Export.h"
+#include "io/Stream.h"
 
 namespace org::apache::nifi::minifi::processors {
 
@@ -122,7 +123,7 @@ class BinaryConcatenationMerge : public MergeBin {
 
 class ArchiveMerge {
  public:
-  class ArchiveWriter : public io::OutputStream {
+  class ArchiveWriter : public io::StreamImpl, public io::OutputStream {
    public:
     ArchiveWriter(archive& arch, archive_entry& entry) : arch_(arch), entry_(entry) {}
     size_t write(const uint8_t* data, const size_t size) override {
@@ -293,8 +294,8 @@ class KeepAllUniqueAttributesMerger: public AttributeMerger {
  */
 class MergeContent : public processors::BinFiles {
  public:
-  explicit MergeContent(const std::string& name, const utils::Identifier& uuid = {})
-      : processors::BinFiles(name, uuid) {
+  explicit MergeContent(core::ProcessorMetadata metadata)
+      : processors::BinFiles(metadata) {
     mergeStrategy_ = merge_content_options::MERGE_STRATEGY_DEFRAGMENT;
     mergeFormat_ = merge_content_options::MERGE_FORMAT_CONCAT_VALUE;
     delimiterStrategy_ = merge_content_options::DELIMITER_STRATEGY_FILENAME;
@@ -340,7 +341,7 @@ class MergeContent : public processors::BinFiles {
       .build();
   EXTENSIONAPI static constexpr auto KeepPath = core::PropertyDefinitionBuilder<>::createProperty("Keep Path")
       .withDescription("If using the Zip or Tar Merge Format, specifies whether or not the FlowFiles' paths should be included in their entry")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto AttributeStrategy = core::PropertyDefinitionBuilder<2>::createProperty("Attribute Strategy")
@@ -388,7 +389,6 @@ class MergeContent : public processors::BinFiles {
  private:
   void validatePropertyOptions();
 
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<MergeContent>::getLogger(uuid_);
   std::string mergeStrategy_;
   std::string mergeFormat_;
   std::string correlationAttributeName_;
