@@ -25,11 +25,10 @@
 #include <sstream>
 #include <string>
 
-#include "Relationship.h"
+#include "core/Relationship.h"
 #include "core/Core.h"
 #include "core/Processor.h"
 #include "core/ProcessContext.h"
-#include "core/ProcessorNode.h"
 #include "core/ProcessSession.h"
 #include "FlowController.h"
 #include "../../include/core/FlowFile.h"
@@ -162,18 +161,18 @@ class MergeTestController : public TestController {
 
     std::shared_ptr<TestRepository> repo = std::make_shared<TestRepository>();
     auto content_repo = std::make_shared<core::repository::VolatileContentRepository>();
-    content_repo->initialize(std::make_shared<minifi::Configure>());
+    content_repo->initialize(std::make_shared<minifi::ConfigureImpl>());
 
-    merge_content_processor_ = std::make_unique<minifi::processors::MergeContent>("mergecontent");
+    merge_content_processor_ = minifi::test::utils::make_processor<minifi::processors::MergeContent>("mergecontent");
     merge_content_processor_->initialize();
     utils::Identifier processoruuid = merge_content_processor_->getUUID();
     REQUIRE(processoruuid);
-    log_attribute_processor_ = std::make_unique<minifi::processors::LogAttribute>("logattribute");
+    log_attribute_processor_ = minifi::test::utils::make_processor<minifi::processors::LogAttribute>("logattribute");
     utils::Identifier logAttributeuuid = log_attribute_processor_->getUUID();
     REQUIRE(logAttributeuuid);
 
     // output from merge processor to log attribute
-    output_ = std::make_unique<minifi::Connection>(repo, content_repo, "logattributeconnection");
+    output_ = std::make_unique<minifi::ConnectionImpl>(repo, content_repo, "logattributeconnection");
     output_->addRelationship(minifi::processors::MergeContent::Merge);
     output_->setSource(merge_content_processor_.get());
     output_->setDestination(log_attribute_processor_.get());
@@ -181,7 +180,7 @@ class MergeTestController : public TestController {
     output_->setDestinationUUID(logAttributeuuid);
     merge_content_processor_->addConnection(output_.get());
     // input to merge processor
-    input_ = std::make_unique<minifi::Connection>(repo, content_repo, "mergeinput");
+    input_ = std::make_unique<minifi::ConnectionImpl>(repo, content_repo, "mergeinput");
     input_->setDestination(merge_content_processor_.get());
     input_->setDestinationUUID(processoruuid);
     merge_content_processor_->addConnection(input_.get());
@@ -193,7 +192,7 @@ class MergeTestController : public TestController {
     log_attribute_processor_->incrementActiveTasks();
     log_attribute_processor_->setScheduledState(core::ScheduledState::RUNNING);
 
-    context_ = std::make_shared<core::ProcessContext>(std::make_shared<core::ProcessorNode>(merge_content_processor_.get()), nullptr, repo, repo, content_repo);
+    context_ = std::make_shared<core::ProcessContextImpl>(*merge_content_processor_, nullptr, repo, repo, content_repo);
 
     for (size_t i = 0; i < 6; ++i) {
       flowFileContents_[i] = utils::string::repeat(std::to_string(i), 32);
@@ -223,11 +222,11 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileDefragment", "[mergefiletest1]")
     flowFileContents_[3] + flowFileContents_[4] + flowFileContents_[5]
   };
 
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 6 flowfiles, first three merged to one, second three merged to one
   for (const int i : {0, 2, 5, 4, 1, 3}) {
     const auto flow = sessionGenFlowFile.create();
@@ -246,10 +245,10 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileDefragment", "[mergefiletest1]")
     input_->put(flow);
   }
 
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 6; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -281,14 +280,14 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileDefragmentDelimiter", "[mergefil
   std::ofstream(FOOTER_FILE, std::ios::binary) << "footer";
   std::ofstream(DEMARCATOR_FILE, std::ios::binary) << "demarcator";
 
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_FILENAME);
-  context_->setProperty(minifi::processors::MergeContent::Header, HEADER_FILE);
-  context_->setProperty(minifi::processors::MergeContent::Footer, FOOTER_FILE);
-  context_->setProperty(minifi::processors::MergeContent::Demarcator, DEMARCATOR_FILE);
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_FILENAME}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::Header, HEADER_FILE));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::Footer, FOOTER_FILE));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::Demarcator, DEMARCATOR_FILE));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 6 flowfiles, first three merged to one, second three merged to one
   for (const int i : {0, 2, 5, 4, 1, 3}) {
     const auto flow = sessionGenFlowFile.create();
@@ -308,10 +307,10 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileDefragmentDelimiter", "[mergefil
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 6; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -340,12 +339,12 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileDefragmentDropFlow", "[mergefile
     flowFileContents_[3] + flowFileContents_[5]
   };
 
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::MergeContent::MaxBinAge, "1 sec");
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MaxBinAge, "1 sec"));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 5 flowfiles, first threes merged to one, the other two merged to one
   for (const int i : {0, 2, 5, 1, 3}) {
     const auto flow = sessionGenFlowFile.create();
@@ -365,16 +364,16 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileDefragmentDropFlow", "[mergefile
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 5; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
   std::this_thread::sleep_for(std::chrono::milliseconds(2000));
   {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -402,13 +401,13 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileBinPack", "[mergefiletest4]") {
     flowFileContents_[3] + flowFileContents_[4] + flowFileContents_[5]
   };
 
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::MergeContent::MinSize, "96");
-  context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag");
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MinSize, "96"));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag"));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 6 flowfiles, first threes merged to one, second thress merged to one
   for (const int i : {0, 1, 2, 3, 4, 5}) {
     const auto flow = sessionGenFlowFile.create();
@@ -419,10 +418,10 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileBinPack", "[mergefiletest4]") {
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 6; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -446,13 +445,13 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileBinPack", "[mergefiletest4]") {
 
 
 TEST_CASE_METHOD(MergeTestController, "MergeFileTar", "[mergefiletest4]") {
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_TAR_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::MergeContent::MinSize, "96");
-  context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag");
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_TAR_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MinSize, "96"));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag"));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 6 flowfiles, first threes merged to one, second thress merged to one
   for (const int i : {0, 1, 2, 3, 4, 5}) {
     const auto flow = sessionGenFlowFile.create();
@@ -463,10 +462,10 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileTar", "[mergefiletest4]") {
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 6; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -497,13 +496,13 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileTar", "[mergefiletest4]") {
 }
 
 TEST_CASE_METHOD(MergeTestController, "MergeFileZip", "[mergefiletest5]") {
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_ZIP_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::MergeContent::MinSize, "96");
-  context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag");
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_ZIP_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MinSize, "96"));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag"));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 6 flowfiles, first threes merged to one, second thress merged to one
   for (const int i : {0, 1, 2, 3, 4, 5}) {
     const auto flow = sessionGenFlowFile.create();
@@ -514,10 +513,10 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileZip", "[mergefiletest5]") {
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 6; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -553,13 +552,13 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileOnAttribute", "[mergefiletest5]"
     flowFileContents_[1] + flowFileContents_[3] + flowFileContents_[5]
   };
 
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::MergeContent::MinEntries, "3");
-  context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag");
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MinEntries, "3"));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::CorrelationAttributeName, "tag"));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 6 flowfiles, even files are merged to one, odd files are merged to an other
   for (const int i : {0, 1, 2, 3, 4, 5}) {
     const auto flow = sessionGenFlowFile.create();
@@ -573,10 +572,10 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileOnAttribute", "[mergefiletest5]"
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 6; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -597,11 +596,11 @@ TEST_CASE_METHOD(MergeTestController, "MergeFileOnAttribute", "[mergefiletest5]"
 }
 
 TEST_CASE_METHOD(MergeTestController, "Test Merge File Attributes Keeping Only Common Attributes", "[testMergeFileKeepOnlyCommonAttributes]") {
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_TAR_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_TAR_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
 
   // Generate 3 flowfiles merging all into one
   for (const int i : {1, 2, 0}) {
@@ -626,10 +625,10 @@ TEST_CASE_METHOD(MergeTestController, "Test Merge File Attributes Keeping Only C
     input_->put(flow);
   }
 
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 3; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -646,12 +645,12 @@ TEST_CASE_METHOD(MergeTestController, "Test Merge File Attributes Keeping Only C
 }
 
 TEST_CASE_METHOD(MergeTestController, "Test Merge File Attributes Keeping All Unique Attributes", "[testMergeFileKeepAllUniqueAttributes]") {
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_TAR_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::MergeContent::AttributeStrategy, minifi::processors::merge_content_options::ATTRIBUTE_STRATEGY_KEEP_ALL_UNIQUE);
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_TAR_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_DEFRAGMENT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::AttributeStrategy, std::string{minifi::processors::merge_content_options::ATTRIBUTE_STRATEGY_KEEP_ALL_UNIQUE}));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // Generate 3 flowfiles merging all into one
   for (const int i : {1, 2, 0}) {
     const auto flow = sessionGenFlowFile.create();
@@ -675,10 +674,10 @@ TEST_CASE_METHOD(MergeTestController, "Test Merge File Attributes Keeping All Un
     input_->put(flow);
   }
 
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   for (int i = 0; i < 3; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -709,7 +708,7 @@ TEST_CASE("FlowFile serialization", "[testFlowFileSerialization]") {
   std::string footer = "}END";
   std::string demarcator = "_";
 
-  core::ProcessSession session(context);
+  core::ProcessSessionImpl session(context);
 
   minifi::PayloadSerializer payloadSerializer([&] (const std::shared_ptr<core::FlowFile>& ff, const minifi::io::InputStreamCallback& cb) {
     return session.read(ff, cb);
@@ -734,19 +733,19 @@ TEST_CASE("FlowFile serialization", "[testFlowFileSerialization]") {
     input->put(ff);
   }
 
-  context->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  context->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context->setProperty(minifi::processors::MergeContent::Header, header);
-  context->setProperty(minifi::processors::MergeContent::Footer, footer);
-  context->setProperty(minifi::processors::MergeContent::Demarcator, demarcator);
-  context->setProperty(minifi::processors::BinFiles::MinEntries, "3");
+  REQUIRE(context->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(context->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context->setProperty(minifi::processors::MergeContent::Header, header));
+  REQUIRE(context->setProperty(minifi::processors::MergeContent::Footer, footer));
+  REQUIRE(context->setProperty(minifi::processors::MergeContent::Demarcator, demarcator));
+  REQUIRE(context->setProperty(minifi::processors::BinFiles::MinEntries, "3"));
 
   SECTION("Payload Serializer") {
-    context->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
+    REQUIRE(context->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
     usedSerializer = &payloadSerializer;
   }
   SECTION("FlowFileV3 Serializer") {
-    context->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_FLOWFILE_STREAM_V3_VALUE);
+    REQUIRE(context->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_FLOWFILE_STREAM_V3_VALUE}));
     usedSerializer = &ffV3Serializer;
     // only Binary Concatenation take these into account
     header = "";
@@ -768,10 +767,10 @@ TEST_CASE("FlowFile serialization", "[testFlowFileSerialization]") {
 
   const auto expected = utils::span_to<std::string>(utils::as_span<const char>(result->getBuffer()));
 
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context);
   merge_content_processor->onSchedule(*context, *factory);
   for (int i = 0; i < 3; i++) {
-    auto mergeSession = std::make_shared<core::ProcessSession>(context);
+    auto mergeSession = std::make_shared<core::ProcessSessionImpl>(context);
     merge_content_processor->onTrigger(*context, *mergeSession);
     mergeSession->commit();
   }
@@ -795,12 +794,12 @@ TEST_CASE_METHOD(MergeTestController, "Batch Size", "[testMergeFileBatchSize]")
     flowFileContents_[3] + flowFileContents_[4]
   };
 
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::BinFiles::BatchSize, "3");
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::BinFiles::BatchSize, "3"));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // enqueue 5 (five) flowFiles
   for (const int i : {0, 1, 2, 3, 4}) {
     const auto flow = sessionGenFlowFile.create();
@@ -810,11 +809,11 @@ TEST_CASE_METHOD(MergeTestController, "Batch Size", "[testMergeFileBatchSize]")
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   // two trigger is enough to process all five flowFiles
   for (int i = 0; i < 2; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -847,19 +846,19 @@ TEST_CASE_METHOD(MergeTestController, "Maximum Group Size is respected", "[testM
     flowFileContents_[2] + flowFileContents_[3]
   };
 
-  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  context_->setProperty(minifi::processors::BinFiles::BatchSize, "1000");
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeFormat, std::string{minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::MergeStrategy, std::string{minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, std::string{minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(context_->setProperty(minifi::processors::BinFiles::BatchSize, "1000"));
 
   // we want a bit more than 2 flowfiles
-  context_->setProperty(minifi::processors::BinFiles::MinSize, "65");
-  context_->setProperty(minifi::processors::BinFiles::MaxSize, "65");
+  REQUIRE(context_->setProperty(minifi::processors::BinFiles::MinSize, "65"));
+  REQUIRE(context_->setProperty(minifi::processors::BinFiles::MaxSize, "65"));
 
-  context_->setProperty(minifi::processors::BinFiles::MinEntries, "3");
-  context_->setProperty(minifi::processors::BinFiles::MaxEntries, "3");
+  REQUIRE(context_->setProperty(minifi::processors::BinFiles::MinEntries, "3"));
+  REQUIRE(context_->setProperty(minifi::processors::BinFiles::MaxEntries, "3"));
 
-  core::ProcessSession sessionGenFlowFile(context_);
+  core::ProcessSessionImpl sessionGenFlowFile(context_);
   // enqueue 6 (six) flowFiles
   for (const int i : {0, 1, 2, 3, 4, 5}) {
     const auto flow = sessionGenFlowFile.create();
@@ -869,11 +868,11 @@ TEST_CASE_METHOD(MergeTestController, "Maximum Group Size is respected", "[testM
   }
 
   REQUIRE(merge_content_processor_->getName() == "mergecontent");
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context_);
   merge_content_processor_->onSchedule(*context_, *factory);
   // a single trigger is enough to process all five flowFiles
   {
-    auto session = std::make_shared<core::ProcessSession>(context_);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context_);
     merge_content_processor_->onTrigger(*context_, *session);
     session->commit();
   }
@@ -904,7 +903,7 @@ TEST_CASE_METHOD(MergeTestController, "Maximum Group Size is respected", "[testM
 }
 
 TEST_CASE("Empty MergeContent yields") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<minifi::processors::MergeContent>("mergeContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::MergeContent>("mergeContent")};
   controller.trigger();
 
   auto merge_content = controller.getProcessor();
@@ -912,10 +911,10 @@ TEST_CASE("Empty MergeContent yields") {
 }
 
 TEST_CASE("Empty MergeContent doesnt yield when processing readybins") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<minifi::processors::MergeContent>("mergeContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::MergeContent>("mergeContent")};
   const auto merge_content = controller.getProcessor();
-  controller.plan->setProperty(merge_content, minifi::processors::MergeContent::MaxBinAge, "100ms");
-  controller.plan->setProperty(merge_content, minifi::processors::MergeContent::MinEntries, "2");
+  REQUIRE(controller.plan->setProperty(merge_content, minifi::processors::MergeContent::MaxBinAge, "100ms"));
+  REQUIRE(controller.plan->setProperty(merge_content, minifi::processors::MergeContent::MinEntries, "2"));
 
   auto first_trigger_results = controller.trigger("foo");
   CHECK_FALSE(merge_content->isYield());
