@@ -23,12 +23,12 @@
 #include <vector>
 #include <shared_mutex>
 
-#include "PropertyDefinition.h"
-#include "core/Processor.h"
+#include "core/PropertyDefinition.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/Core.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Enum.h"
 #include "MQTTAsync.h"
 
@@ -84,11 +84,9 @@ namespace org::apache::nifi::minifi::processors {
 
 static constexpr const char* const MQTT_SECURITY_PROTOCOL_SSL = "ssl";
 
-class AbstractMQTTProcessor : public core::Processor {
+class AbstractMQTTProcessor : public core::ProcessorImpl {
  public:
-  explicit AbstractMQTTProcessor(std::string_view name, const utils::Identifier& uuid = {}, std::shared_ptr<core::ProcessorMetrics> metrics = {})
-      : core::Processor(name, uuid, std::move(metrics)) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   ~AbstractMQTTProcessor() override {
     freeResources();
@@ -115,12 +113,12 @@ class AbstractMQTTProcessor : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto ConnectionTimeout = core::PropertyDefinitionBuilder<>::createProperty("Connection Timeout")
       .withDescription("Maximum time interval the client will wait for the network connection to the MQTT broker")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("10 sec")
       .build();
   EXTENSIONAPI static constexpr auto KeepAliveInterval = core::PropertyDefinitionBuilder<>::createProperty("Keep Alive Interval")
       .withDescription("Defines the maximum time interval between messages sent or received")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("60 sec")
       .build();
   EXTENSIONAPI static constexpr auto LastWillTopic = core::PropertyDefinitionBuilder<>::createProperty("Last Will Topic")
@@ -137,7 +135,7 @@ class AbstractMQTTProcessor : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto LastWillRetain = core::PropertyDefinitionBuilder<>::createProperty("Last Will Retain")
       .withDescription("Whether to retain the client's Last Will")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto LastWillContentType = core::PropertyDefinitionBuilder<>::createProperty("Last Will Content Type")
@@ -221,7 +219,7 @@ class AbstractMQTTProcessor : public core::Processor {
   /**
    * Checks property consistency before connecting to broker
    */
-  virtual void checkProperties() {
+  virtual void checkProperties(core::ProcessContext& /*context*/) {
   }
 
   /**
@@ -323,8 +321,6 @@ class AbstractMQTTProcessor : public core::Processor {
   mqtt::MqttQoS last_will_qos_{mqtt::MqttQoS::LEVEL_0};
   bool last_will_retain_ = false;
   std::string last_will_content_type_;
-
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<AbstractMQTTProcessor>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
