@@ -23,9 +23,11 @@
 #include <vector>
 
 #include "utils/StringUtils.h"
+#include "utils/ProcessorConfigUtils.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/Resource.h"
+#include "core/state/Value.h"
 
 namespace {
 class RetriableError : public std::runtime_error {
@@ -46,16 +48,9 @@ void PublishMQTT::readProperties(core::ProcessContext& context) {
   if (!context.getProperty(Topic).has_value()) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "PublishMQTT: Topic is required");
   }
-
-  if (const auto retain_opt = context.getProperty(Retain) | utils::andThen(&utils::string::toBool)) {
-    retain_ = *retain_opt;
-  }
-  logger_->log_debug("PublishMQTT: Retain [{}]", retain_);
-
-  if (const auto message_expiry_interval = context.getProperty(MessageExpiryInterval) | utils::andThen(&core::TimePeriodValue::fromString)) {
-    message_expiry_interval_ = std::chrono::duration_cast<std::chrono::seconds>(message_expiry_interval->getMilliseconds());
-    logger_->log_debug("PublishMQTT: MessageExpiryInterval [{}] s", int64_t{message_expiry_interval_->count()});
-  }
+  retain_ = utils::parseBoolProperty(context, Retain);
+  message_expiry_interval_ = utils::parseOptionalDurationProperty(context, MessageExpiryInterval)
+      | utils::transform([](const auto&& ms) { return std::chrono::duration_cast<std::chrono::seconds>(ms); });
 
   in_flight_message_counter_.setEnabled(mqtt_version_ == mqtt::MqttVersions::V_5_0 && qos_ != mqtt::MqttQoS::LEVEL_0);
 }
@@ -64,7 +59,7 @@ void PublishMQTT::onTriggerImpl(core::ProcessContext& context, core::ProcessSess
   std::shared_ptr<core::FlowFile> flow_file = session.get();
 
   if (!flow_file) {
-    yield();
+    context.yield();
     return;
   }
 
@@ -137,12 +132,16 @@ bool PublishMQTT::sendMessage(const std::vector<std::byte>& buffer, const std::s
   return send_finished_task.get_future().get();
 }
 
-void PublishMQTT::checkProperties() {
+void PublishMQTT::checkProperties(core::ProcessContext& context) {
+  auto is_property_explicitly_set = [&context](const std::string_view property_name) -> bool {
+    const auto property_values = context.getAllPropertyValues(property_name) | utils::orThrow("It should only be called on valid property");
+    return !property_values.empty();
+  };
   if ((mqtt_version_ == mqtt::MqttVersions::V_3_1_0 || mqtt_version_ == mqtt::MqttVersions::V_3_1_1 || mqtt_version_ == mqtt::MqttVersions::V_3X_AUTO)) {
-    if (isPropertyExplicitlySet(MessageExpiryInterval)) {
+    if (is_property_explicitly_set(MessageExpiryInterval.name)) {
       logger_->log_warn("MQTT 3.x specification does not support Message Expiry Intervals. Property is not used.");
     }
-    if (isPropertyExplicitlySet(ContentType)) {
+    if (is_property_explicitly_set(ContentType.name)) {
       logger_->log_warn("MQTT 3.x specification does not support Content Types. Property is not used.");
     }
   }
@@ -294,13 +293,13 @@ uint16_t PublishMQTT::InFlightMessageCounter::getCounter() const {
   return counter_;
 }
 
-PublishMQTT::PublishMQTTMetrics::PublishMQTTMetrics(const core::Processor& source_processor, const InFlightMessageCounter& in_flight_message_counter)
-  : core::ProcessorMetrics(source_processor),
+PublishMQTT::PublishMQTTMetrics::PublishMQTTMetrics(const core::ProcessorImpl& source_processor, const InFlightMessageCounter& in_flight_message_counter)
+  : core::ProcessorMetricsImpl(source_processor),
     in_flight_message_counter_(&in_flight_message_counter) {
 }
 
 std::vector<state::response::SerializedResponseNode> PublishMQTT::PublishMQTTMetrics::serialize() {
-  auto metrics_vector = core::ProcessorMetrics::serialize();
+  auto metrics_vector = core::ProcessorMetricsImpl::serialize();
   gsl_Expects(!metrics_vector.empty());
   auto& metrics = metrics_vector[0];
 
@@ -311,7 +310,7 @@ std::vector<state::response::SerializedResponseNode> PublishMQTT::PublishMQTTMet
 }
 
 std::vector<state::PublishedMetric> PublishMQTT::PublishMQTTMetrics::calculateMetrics() {
-  auto metrics = core::ProcessorMetrics::calculateMetrics();
+  auto metrics = core::ProcessorMetricsImpl::calculateMetrics();
   metrics.push_back({"in_flight_message_count", static_cast<double>(in_flight_message_counter_->getCounter()), getCommonLabels()});
   return metrics;
 }
