@@ -23,25 +23,25 @@
 #include <utility>
 #include <vector>
 
-#include "FlowFileRecord.h"
-#include "RelationshipDefinition.h"
-#include "core/Processor.h"
-#include "RelationshipDefinition.h"
+#include "core/RelationshipDefinition.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/Core.h"
 #include "core/Property.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "AbstractMQTTProcessor.h"
 #include "utils/ArrayUtils.h"
 #include "utils/gsl.h"
+#include "core/ProcessorMetrics.h"
 
 namespace org::apache::nifi::minifi::processors {
 
 class PublishMQTT : public processors::AbstractMQTTProcessor {
  public:
-  explicit PublishMQTT(std::string_view name, const utils::Identifier& uuid = {})
-      : processors::AbstractMQTTProcessor(name, uuid, std::make_shared<PublishMQTTMetrics>(*this, in_flight_message_counter_)) {
+  explicit PublishMQTT(core::ProcessorMetadata metadata)
+      : processors::AbstractMQTTProcessor(metadata) {
+    metrics_ = gsl::make_not_null(std::make_shared<PublishMQTTMetrics>(*this, in_flight_message_counter_));
   }
 
   EXTENSIONAPI static constexpr const char* Description = "PublishMQTT serializes FlowFile content as an MQTT payload, sending the message to the configured topic and broker.";
@@ -53,12 +53,12 @@ class PublishMQTT : public processors::AbstractMQTTProcessor {
       .build();
   EXTENSIONAPI static constexpr auto Retain = core::PropertyDefinitionBuilder<>::createProperty("Retain")
       .withDescription("Retain published message in broker")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto MessageExpiryInterval = core::PropertyDefinitionBuilder<>::createProperty("Message Expiry Interval")
       .withDescription("Time while message is valid and will be forwarded by broker. MQTT 5.x only.")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto ContentType = core::PropertyDefinitionBuilder<>::createProperty("Content Type")
       .withDescription("Content type of the message. MQTT 5.x only.")
@@ -108,9 +108,9 @@ class PublishMQTT : public processors::AbstractMQTTProcessor {
     uint16_t limit_{MQTT_MAX_RECEIVE_MAXIMUM};
   };
 
-  class PublishMQTTMetrics : public core::ProcessorMetrics {
+  class PublishMQTTMetrics : public core::ProcessorMetricsImpl {
    public:
-    PublishMQTTMetrics(const core::Processor& source_processor, const InFlightMessageCounter& in_flight_message_counter);
+    PublishMQTTMetrics(const core::ProcessorImpl& source_processor, const InFlightMessageCounter& in_flight_message_counter);
     std::vector<state::response::SerializedResponseNode> serialize() override;
     std::vector<state::PublishedMetric> calculateMetrics() override;
 
@@ -185,13 +185,12 @@ class PublishMQTT : public processors::AbstractMQTTProcessor {
     // there is no need to do anything like subscribe in the beginning
   }
 
-  void checkProperties() override;
+  void checkProperties(core::ProcessContext& context) override;
   void checkBrokerLimitsImpl() override;
 
   bool retain_ = false;
   std::optional<std::chrono::seconds> message_expiry_interval_;
   InFlightMessageCounter in_flight_message_counter_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<PublishMQTT>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
