@@ -20,14 +20,13 @@
 #include <atomic>
 #include <iomanip>
 #include <ctime>
-#include <utility>
 #include <vector>
 #include <memory>
 #include <string>
 #include <opencv2/opencv.hpp>
 
-#include "core/logging/LoggerConfiguration.h"
-#include "core/Processor.h"
+#include "core/logging/LoggerFactory.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "io/StreamPipe.h"
 #include "utils/gsl.h"
@@ -35,11 +34,9 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-class CaptureRTSPFrame : public core::Processor {
+class CaptureRTSPFrame final : public core::ProcessorImpl {
  public:
-  explicit CaptureRTSPFrame(std::string name, const utils::Identifier &uuid = {})
-      : Processor(std::move(name), uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Captures a frame from the RTSP stream at specified intervals.";
 
@@ -91,7 +88,6 @@ class CaptureRTSPFrame : public core::Processor {
   void notifyStop() override;
 
  private:
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<CaptureRTSPFrame>::getLogger(uuid_);
   std::mutex mutex_;
   std::string rtsp_username_;
   std::string rtsp_password_;
