@@ -22,22 +22,20 @@
 #include <string>
 #include <utility>
 
-#include "core/logging/LoggerConfiguration.h"
-#include "core/Processor.h"
+#include "core/logging/LoggerFactory.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "opencv2/opencv.hpp"
 #include "opencv2/imgproc.hpp"
 
 namespace org::apache::nifi::minifi::processors {
 
-class MotionDetector : public core::Processor {
+class MotionDetector final : public core::ProcessorImpl {
  public:
-  explicit MotionDetector(std::string name, const utils::Identifier &uuid = {})
-      : Processor(std::move(name), uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Detect motion from captured images.";
 
@@ -50,24 +48,25 @@ class MotionDetector : public core::Processor {
   EXTENSIONAPI static constexpr auto MinInterestArea = core::PropertyDefinitionBuilder<>::createProperty("Minimum Area")
       .withDescription("We only consider the movement regions with area greater than this.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_INT_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("100")
       .build();
   EXTENSIONAPI static constexpr auto Threshold = core::PropertyDefinitionBuilder<>::createProperty("Threshold for segmentation")
       .withDescription("Pixel greater than this will be white, otherwise black.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_INT_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("42")
       .build();
   EXTENSIONAPI static constexpr auto DilateIter = core::PropertyDefinitionBuilder<>::createProperty("Dilate iteration")
       .withDescription("For image processing, if an object is detected as 2 separate objects, increase this value")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_INT_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("10")
       .build();
   EXTENSIONAPI static constexpr auto BackgroundFrame = core::PropertyDefinitionBuilder<>::createProperty("Path to background frame")
       .withDescription("If not provided then the processor will take the first input frame as background")
       .isRequired(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       ImageEncoding,
@@ -98,14 +97,13 @@ class MotionDetector : public core::Processor {
  private:
   bool detectAndDraw(cv::Mat &frame);
 
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<MotionDetector>::getLogger(uuid_);
   std::mutex mutex_;
   cv::Mat background_;
   cv::Mat bg_img_;
   std::string image_encoding_;
-  int min_area_{};
-  int threshold_{};
-  int dil_iter_{};
+  uint64_t min_area_{};
+  uint64_t threshold_{};
+  uint64_t dil_iter_{};
 
   // hardcoded width to 500
   const double IMG_WIDTH = 500.0;
