@@ -15,17 +15,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include "OpenCVLoader.h"
+#include "core/extension/Extension.h"
+#include "utils/Environment.h"
 
-#include "core/FlowConfiguration.h"
-
-bool OpenCVObjectFactory::added = core::FlowConfiguration::add_static_func("createOpenCVFactory");
-extern "C" {
-
-
-
-void *createOpenCVFactory(void) {
-  return new OpenCVObjectFactory();
+static bool init(const std::shared_ptr<org::apache::nifi::minifi::Configure>& /*config*/) {
+  // By default in OpenCV, ffmpeg capture is hardcoded to use TCP and this is a workaround
+  // also if UDP timeout, ffmpeg will retry with TCP
+  // Note:
+  // 1. OpenCV community are trying to find a better approach than setenv.
+  // 2. The command will not overwrite value if "OPENCV_FFMPEG_CAPTURE_OPTIONS" already exists.
+  return org::apache::nifi::minifi::utils::Environment::setEnvironmentVariable("OPENCV_FFMPEG_CAPTURE_OPTIONS", "rtsp_transport;udp", false /*overwrite*/);
 }
 
-}
+static void deinit() {}
+
+REGISTER_EXTENSION("OpenCVExtension", init, deinit);
