@@ -30,7 +30,7 @@ DWORD PDHCounter::getDWFormat() const {
 }
 
 std::unique_ptr<PDHCounter> PDHCounter::createPDHCounter(const std::string& query_name, bool is_double) {
-  auto groups = utils::StringUtils::splitRemovingEmpty(query_name, "\\");
+  auto groups = utils::string::splitRemovingEmpty(query_name, "\\");
   if (groups.size() != 2 || query_name.substr(0, 1) != "\\")
     return nullptr;
   if (query_name.find("(*)") != std::string::npos) {
@@ -45,17 +45,17 @@ const std::string& PDHCounter::getName() const {
 }
 
 std::string PDHCounter::getObjectName() const {
-  auto groups = utils::StringUtils::splitRemovingEmpty(pdh_english_counter_name_, "\\");
+  auto groups = utils::string::splitRemovingEmpty(pdh_english_counter_name_, "\\");
   return groups[0];
 }
 
 std::string PDHCounter::getCounterName() const {
-  auto groups = utils::StringUtils::splitRemovingEmpty(pdh_english_counter_name_, "\\");
+  auto groups = utils::string::splitRemovingEmpty(pdh_english_counter_name_, "\\");
   return groups[1];
 }
 
 void SinglePDHCounter::addToJson(rapidjson::Value& body, rapidjson::Document::AllocatorType& alloc) const {
-  rapidjson::Value key(getCounterName().c_str(), getCounterName().length(), alloc);
+  rapidjson::Value key(getCounterName().c_str(), gsl::narrow<rapidjson::SizeType>(getCounterName().length()), alloc);
   rapidjson::Value& group_node = acquireNode(getObjectName(), body, alloc);
   group_node.AddMember(key, getValue(), alloc);
 }
@@ -91,7 +91,7 @@ void PDHCounterArray::addToJson(rapidjson::Value& body, rapidjson::Document::All
     rapidjson::Value& counter_node = acquireNode(node_name, group_node, alloc);
     rapidjson::Value value = getValue(i);
     rapidjson::Value key;
-    key.SetString(getCounterName().c_str(), getCounterName().length(), alloc);
+    key.SetString(getCounterName().c_str(), gsl::narrow<rapidjson::SizeType>(getCounterName().length()), alloc);
     counter_node.AddMember(key, value, alloc);
   }
 }
