@@ -23,6 +23,7 @@
 #include "utils/StringUtils.h"
 #include "utils/JsonCallback.h"
 #include "utils/OpenTelemetryLogDataModelUtils.h"
+#include "utils/ProcessorConfigUtils.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/Resource.h"
@@ -64,21 +65,21 @@ void PerformanceDataMonitor::onSchedule(core::ProcessContext& context, core::Pro
 void PerformanceDataMonitor::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   if (resource_consumption_counters_.empty()) {
     logger_->log_error("No valid counters for PerformanceDataMonitor");
-    yield();
+    context.yield();
     return;
   }
 
   std::shared_ptr<core::FlowFile> flowFile = session.create();
   if (!flowFile) {
     logger_->log_error("Failed to create flowfile!");
-    yield();
+    context.yield();
     return;
   }
 
   PDH_STATUS collect_query_data_result = PdhCollectQueryData(pdh_query_);
   if (ERROR_SUCCESS != collect_query_data_result) {
     logger_->log_error("Error during PdhCollectQueryData, error code: {:#x}", collect_query_data_result);
-    yield();
+    context.yield();
     return;
   }
 
@@ -242,41 +243,37 @@ void PerformanceDataMonitor::addCustomPDHCountersFromProperty(const std::string&
 }
 
 void PerformanceDataMonitor::setupCountersFromProperties(core::ProcessContext& context) {
-  std::string custom_pdh_counters;
-  if (context.getProperty(CustomPDHCounters, custom_pdh_counters)) {
-    logger_->log_trace("Custom PDH counters configured to be {}", custom_pdh_counters);
-    addCustomPDHCountersFromProperty(custom_pdh_counters);
+  if (const auto custom_pdh_counters = context.getProperty(CustomPDHCounters)) {
+    logger_->log_trace("Custom PDH counters configured to be {}", *custom_pdh_counters);
+    addCustomPDHCountersFromProperty(*custom_pdh_counters);
   }
 }
 
 void PerformanceDataMonitor::setupPredefinedGroupsFromProperties(core::ProcessContext& context) {
-  std::string predefined_groups;
-  if (context.getProperty(PredefinedGroups, predefined_groups)) {
-    logger_->log_trace("Predefined group configured to be {}", predefined_groups);
-    addCountersFromPredefinedGroupsProperty(predefined_groups);
+  if (const auto predefined_groups = context.getProperty(PredefinedGroups)) {
+    logger_->log_trace("Predefined group configured to be {}", *predefined_groups);
+    addCountersFromPredefinedGroupsProperty(*predefined_groups);
   }
 }
 
 void PerformanceDataMonitor::setupOutputFormatFromProperties(core::ProcessContext& context) {
-  std::string output_format_string;
-  if (context.getProperty(OutputFormatProperty, output_format_string)) {
-    if (output_format_string == OPEN_TELEMETRY_FORMAT_STR) {
+  if (const auto output_format_string = context.getProperty(OutputFormatProperty)) {
+    if (*output_format_string == OPEN_TELEMETRY_FORMAT_STR) {
       output_format_ = OutputFormat::OPENTELEMETRY;
-    } else if (output_format_string == JSON_FORMAT_STR) {
+    } else if (*output_format_string == JSON_FORMAT_STR) {
       output_format_ = OutputFormat::JSON;
     } else {
-      throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Invalid PerformanceDataMonitor Output Format: " + output_format_string);
+      throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Invalid PerformanceDataMonitor Output Format: " + *output_format_string);
     }
   }
 
-  std::string output_compactness_string;
-  if (context.getProperty(OutputCompactness, output_compactness_string)) {
-    if (output_compactness_string == PRETTY_FORMAT_STR) {
+  if (const auto output_compactness_string = context.getProperty(OutputCompactness)) {
+    if (*output_compactness_string == PRETTY_FORMAT_STR) {
       pretty_output_ = true;
-    } else if (output_compactness_string == COMPACT_FORMAT_STR) {
+    } else if (*output_compactness_string == COMPACT_FORMAT_STR) {
       pretty_output_ = false;
     } else {
-      throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Invalid PerformanceDataMonitor Output Compactness: " + output_compactness_string);
+      throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Invalid PerformanceDataMonitor Output Compactness: " + *output_compactness_string);
     }
   }
 
@@ -284,20 +281,11 @@ void PerformanceDataMonitor::setupOutputFormatFromProperties(core::ProcessContex
 }
 
 void PerformanceDataMonitor::setupDecimalPlacesFromProperties(core::ProcessContext& context) {
-  std::string decimal_places_str;
-  if (!context.getProperty(DecimalPlaces, decimal_places_str) || decimal_places_str == "") {
-    decimal_places_ = std::nullopt;
-    return;
-  }
+  decimal_places_ = context.getProperty(DecimalPlaces.name) | utils::andThen(parsing::parseIntegral<uint8_t>) | utils::toOptional();
 
-  int64_t decimal_places;
-  if (context.getProperty(DecimalPlaces, decimal_places)) {
-    if (decimal_places > std::numeric_limits<uint8_t>::max() || decimal_places < 1)
-      throw Exception(PROCESS_SCHEDULE_EXCEPTION, "PerformanceDataMonitor Decimal Places is out of range");
-    decimal_places_ = static_cast<uint8_t>(decimal_places);
-  }
-  if (decimal_places_.has_value())
+  if (decimal_places_.has_value()) {
     logger_->log_trace("Rounding is enabled with {} decimal places", decimal_places_.value());
+  }
 }
 
 void PerformanceDataMonitor::setupMembersFromProperties(core::ProcessContext& context) {
