@@ -24,8 +24,8 @@
 #include <utility>
 #include <vector>
 
-#include "core/logging/LoggerConfiguration.h"
-#include "core/Processor.h"
+#include "core/logging/LoggerFactory.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/RelationshipDefinition.h"
@@ -42,16 +42,16 @@ namespace nifi {
 namespace minifi {
 namespace processors {
 
-class PerformanceDataMonitor : public core::Processor {
+class PerformanceDataMonitor final : public core::ProcessorImpl {
  public:
   static constexpr const char* JSON_FORMAT_STR = "JSON";
   static constexpr const char* OPEN_TELEMETRY_FORMAT_STR = "OpenTelemetry";
   static constexpr const char* PRETTY_FORMAT_STR = "Pretty";
   static constexpr const char* COMPACT_FORMAT_STR = "Compact";
 
-  explicit PerformanceDataMonitor(const std::string& name, utils::Identifier uuid = utils::Identifier())
-      : Processor(name, uuid), output_format_(OutputFormat::JSON), pretty_output_(false),
-        decimal_places_(std::nullopt), logger_(core::logging::LoggerFactory<PerformanceDataMonitor>::getLogger()),
+  explicit PerformanceDataMonitor(core::ProcessorMetadata metadata)
+      : ProcessorImpl(metadata), output_format_(OutputFormat::JSON), pretty_output_(false),
+        decimal_places_(std::nullopt),
         pdh_query_(nullptr), resource_consumption_counters_() {}
 
   ~PerformanceDataMonitor() override;
@@ -124,7 +124,6 @@ class PerformanceDataMonitor : public core::Processor {
   bool pretty_output_;
 
   std::optional<uint8_t> decimal_places_;
-  std::shared_ptr<core::logging::Logger> logger_;
   PDH_HQUERY pdh_query_;
   std::vector<std::unique_ptr<PerformanceDataCounter>> resource_consumption_counters_;
 };
