@@ -25,11 +25,11 @@
 #include <optional>
 
 #include "../ProcFs.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/RelationshipDefinition.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "core/logging/Logger.h"
 #include "utils/Enum.h"
 
@@ -53,11 +53,9 @@ enum class ResultRelativeness {
   Absolute
 };
 
-class ProcFsMonitor : public core::Processor {
+class ProcFsMonitor final : public core::ProcessorImpl {
  public:
-  explicit ProcFsMonitor(std::string name, utils::Identifier uuid = utils::Identifier())
-      : Processor(std::move(name), uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~ProcFsMonitor() override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "This processor can create FlowFiles with various performance data through the proc pseudo-filesystem. (Linux only)";
@@ -76,6 +74,7 @@ class ProcFsMonitor : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto DecimalPlaces = core::PropertyDefinitionBuilder<>::createProperty("Round to decimal places")
       .withDescription("The number of decimal places to round the values to (blank for no rounding)")
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto ResultRelativenessProperty = core::PropertyDefinitionBuilder<magic_enum::enum_count<ResultRelativeness>()>::createProperty("Result Type")
       .withDescription("Absolute returns the current procfs values, relative calculates the usage between triggers")
@@ -109,8 +108,6 @@ class ProcFsMonitor : public core::Processor {
  private:
   rapidjson::Value& prepareJSONBody(rapidjson::Document& root);
 
-  void setupDecimalPlacesFromProperties(const core::ProcessContext& context);
-
   void processCPUInformation(const std::vector<std::pair<std::string, CpuStatData>>& current_cpu_stats,
                              rapidjson::Value& body,
                              rapidjson::Document::AllocatorType& alloc);
@@ -141,7 +138,6 @@ class ProcFsMonitor : public core::Processor {
   ResultRelativeness result_relativeness_ = ResultRelativeness::Absolute;
 
   std::optional<uint8_t> decimal_places_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ProcFsMonitor>::getLogger(uuid_);
 
   ProcFs proc_fs_;
 
