@@ -21,10 +21,10 @@
 #include <vector>
 
 #include "MetricsExposer.h"
-#include "prometheus/exposer.h"
+#include "controllers/SSLContextServiceInterface.h"
 #include "core/logging/Logger.h"
-#include "core/logging/LoggerConfiguration.h"
-#include "controllers/SSLContextService.h"
+#include "core/logging/LoggerFactory.h"
+#include "prometheus/exposer.h"
 
 namespace org::apache::nifi::minifi::extensions::prometheus {
 
