@@ -49,11 +49,11 @@ class DummyMetricsExposer : public MetricsExposer {
 class PrometheusPublisherTestFixture {
  public:
   explicit PrometheusPublisherTestFixture(bool user_dummy_exposer)
-    : configuration_(std::make_shared<Configure>()),
+    : configuration_(std::make_shared<ConfigureImpl>()),
       provenance_repo_(core::createRepository("provenancerepository")),
       flow_file_repo_(core::createRepository("flowfilerepository")),
       content_repo_(core::createContentRepository("volatilecontentrepository")),
-      response_node_loader_(std::make_shared<state::response::ResponseNodeLoader>(configuration_,
+      response_node_loader_(std::make_shared<state::response::ResponseNodeLoaderImpl>(configuration_,
         std::vector<std::shared_ptr<core::RepositoryMetricsSource>>{provenance_repo_, flow_file_repo_, content_repo_}, nullptr)) {
     std::unique_ptr<DummyMetricsExposer> dummy_exposer;
     if (user_dummy_exposer) {
