@@ -15,31 +15,28 @@
  * limitations under the License.
  */
 
+#include "ExecutePythonProcessor.h"
+
 #include <set>
 #include <stdexcept>
 #include <utility>
 
-#include "ExecutePythonProcessor.h"
 #include "PythonConfigState.h"
-#include "types/PyRelationship.h"
+#include "controllers/SSLContextServiceInterface.h"
+#include "core/Resource.h"
+#include "range/v3/algorithm/find_if.hpp"
+#include "range/v3/range/conversion.hpp"
 #include "types/PyLogger.h"
-#include "controllers/SSLContextService.h"
-
+#include "types/PyRelationship.h"
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
-#include "core/Resource.h"
-#include "range/v3/range/conversion.hpp"
-#include "range/v3/algorithm/find_if.hpp"
+#include "utils/ProcessorConfigUtils.h"
+#include "utils/PropertyErrors.h"
+#include "minifi-cpp/core/ProcessorDescriptor.h"
 
 namespace org::apache::nifi::minifi::extensions::python::processors {
 
-void ExecutePythonProcessor::initialize() {
-  if (getProperties().empty()) {
-    setSupportedProperties(Properties);
-    setAcceptAllProperties();
-    setSupportedRelationships(Relationships);
-  }
-
+void ExecutePythonProcessor::initializeScript() {
   if (processor_initialized_) {
     logger_->log_debug("Processor has already been initialized, returning...");
     return;
@@ -57,6 +54,15 @@ void ExecutePythonProcessor::initialize() {
   initalizeThroughScriptEngine();
 }
 
+void ExecutePythonProcessor::initialize() {
+  initializeScript();
+  std::vector<core::PropertyReference> all_properties{Properties.begin(), Properties.end()};
+  ranges::transform(python_properties_, std::back_inserter(all_properties), &core::Property::getReference);
+  setSupportedProperties(all_properties);
+  setSupportedRelationships(Relationships);
+  logger_->log_debug("Processor has been initialized.");
+}
+
 void ExecutePythonProcessor::initalizeThroughScriptEngine() {
   try {
     appendPathForImportModules();
@@ -79,8 +85,11 @@ void ExecutePythonProcessor::initalizeThroughScriptEngine() {
 }
 
 void ExecutePythonProcessor::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& /*sessionFactory*/) {
-  addAutoTerminatedRelationship(Original);
+  context.addAutoTerminatedRelationship(Original);
   if (!processor_initialized_) {
+    script_file_path_ = context.getProperty(ScriptFile.name).value_or("");
+    script_to_exec_ = context.getProperty(ScriptBody.name).value_or("");
+    module_directory_ = context.getProperty(ModuleDirectory.name).value_or("");
     loadScript();
     python_script_engine_ = createScriptEngine();
     initalizeThroughScriptEngine();
@@ -95,7 +104,7 @@ void ExecutePythonProcessor::onSchedule(core::ProcessContext& context, core::Pro
   python_script_engine_->eval(script_to_exec_);
   python_script_engine_->onSchedule(context);
 
-  getProperty(ReloadOnScriptChange, reload_on_script_change_);
+  reload_on_script_change_ = utils::parseBoolProperty(context, ReloadOnScriptChange);
 }
 
 void ExecutePythonProcessor::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
@@ -107,11 +116,9 @@ void ExecutePythonProcessor::onTrigger(core::ProcessContext& context, core::Proc
   python_script_engine_->onTrigger(context, session);
 }
 
-void ExecutePythonProcessor::appendPathForImportModules() {
-  std::string module_directory;
-  getProperty(ModuleDirectory, module_directory);
-  if (!module_directory.empty()) {
-    python_script_engine_->appendModulePaths(utils::string::splitAndTrimRemovingEmpty(module_directory, ",") | ranges::to<std::vector<std::filesystem::path>>());
+void ExecutePythonProcessor::appendPathForImportModules() const {
+  if (!module_directory_.empty()) {
+    python_script_engine_->appendModulePaths(utils::string::splitAndTrimRemovingEmpty(module_directory_, ",") | ranges::to<std::vector<std::filesystem::path>>());
   }
 }
 
@@ -125,24 +132,17 @@ void ExecutePythonProcessor::loadScriptFromFile() {
 }
 
 void ExecutePythonProcessor::loadScript() {
-  std::string script_file;
-  std::string script_body;
-  getProperty(ScriptFile, script_file);
-  getProperty(ScriptBody, script_body);
-  if (script_file.empty() && script_body.empty()) {
+  if (script_file_path_.empty() && script_to_exec_.empty()) {
     throw std::runtime_error("Neither Script Body nor Script File is available to execute");
   }
 
-  if (!script_file.empty()) {
-    if (!script_body.empty()) {
+  if (!script_file_path_.empty()) {
+    if (!script_to_exec_.empty()) {
       throw std::runtime_error("Only one of Script File or Script Body may be used");
     }
-    script_file_path_ = script_file;
     loadScriptFromFile();
     last_script_write_time_ = utils::file::last_write_time(script_file_path_);
-    return;
   }
-  script_to_exec_ = script_body;
 }
 
 void ExecutePythonProcessor::reloadScriptIfUsingScriptFileProperty() {
@@ -160,13 +160,43 @@ void ExecutePythonProcessor::reloadScriptIfUsingScriptFileProperty() {
 
 std::unique_ptr<PythonScriptEngine> ExecutePythonProcessor::createScriptEngine() {
   auto engine = std::make_unique<PythonScriptEngine>();
-
-  python_logger_ = core::logging::LoggerFactory<ExecutePythonProcessor>::getAliasedLogger(getName());
   engine->initialize(Success, Failure, Original, python_logger_);
-
   return engine;
 }
 
+namespace {
+enum class PropertyValidatorCode : int64_t {
+  INTEGER = 0,
+  LONG = 1,
+  BOOLEAN = 2,
+  DATA_SIZE = 3,
+  TIME_PERIOD = 4,
+  NON_BLANK = 5,
+  PORT = 6
+};
+
+const core::PropertyValidator& translateCodeToPropertyValidator(const PropertyValidatorCode& code) {
+  switch (code) {
+    case PropertyValidatorCode::INTEGER:  // NOLINT(*-branch-clone)
+      return core::StandardPropertyValidators::INTEGER_VALIDATOR;
+    case PropertyValidatorCode::LONG:
+      return core::StandardPropertyValidators::INTEGER_VALIDATOR;
+    case PropertyValidatorCode::BOOLEAN:
+      return core::StandardPropertyValidators::BOOLEAN_VALIDATOR;
+    case PropertyValidatorCode::DATA_SIZE:
+      return core::StandardPropertyValidators::DATA_SIZE_VALIDATOR;
+    case PropertyValidatorCode::TIME_PERIOD:
+      return core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR;
+    case PropertyValidatorCode::NON_BLANK:
+      return core::StandardPropertyValidators::NON_BLANK_VALIDATOR;
+    case PropertyValidatorCode::PORT:
+      return core::StandardPropertyValidators::PORT_VALIDATOR;
+    default:
+      throw std::invalid_argument("Unknown PropertyValidatorCode");
+  }
+}
+}  // namespace
+
 void ExecutePythonProcessor::addProperty(const std::string &name, const std::string &description, const std::optional<std::string> &defaultvalue, bool required, bool el, bool sensitive,
     const std::optional<int64_t>& property_type_code, gsl::span<const std::string_view> allowable_values, const std::optional<std::string>& controller_service_type_name) {
   auto builder = core::PropertyDefinitionBuilder<>::createProperty(name).withDescription(description).isRequired(required).supportsExpressionLanguage(el).isSensitive(sensitive);
@@ -174,57 +204,35 @@ void ExecutePythonProcessor::addProperty(const std::string &name, const std::str
     builder.withDefaultValue(*defaultvalue);
   }
   if (property_type_code) {
-    builder.withPropertyType(core::StandardPropertyTypes::translateCodeToPropertyType(static_cast<core::StandardPropertyTypes::PropertyTypeCode>(*property_type_code)));
+    builder.withValidator(translateCodeToPropertyValidator(static_cast<PropertyValidatorCode>(*property_type_code)));
   }
   if (controller_service_type_name && *controller_service_type_name == "SSLContextService") {
-    builder.withAllowedTypes<controllers::SSLContextService>();
+    builder.withAllowedTypes<controllers::SSLContextServiceInterface>();
   }
   const auto property_definition = builder.build();
 
   core::Property property{property_definition};
-  property.setAllowedValues(allowable_values, *property_definition.type);
+  std::vector<std::string> allowed_values{allowable_values.begin(), allowable_values.end()};
+  property.setAllowedValues(std::move(allowed_values));
 
   std::lock_guard<std::mutex> lock(python_properties_mutex_);
   python_properties_.emplace_back(property);
 }
 
-const core::Property* ExecutePythonProcessor::findProperty(const std::string& name) const {
-  if (auto prop_ptr = core::ConfigurableComponent::findProperty(name)) {
-    return prop_ptr;
-  }
-
-  std::lock_guard<std::mutex> lock(python_properties_mutex_);
-
-  auto it = ranges::find_if(python_properties_, [&name](const auto& item){
-    return item.getName() == name;
-  });
-  if (it != python_properties_.end()) {
-    return &*it;
-  }
-
-  return nullptr;
-}
-
-std::map<std::string, core::Property> ExecutePythonProcessor::getProperties() const {
-  auto result = ConfigurableComponent::getProperties();
-
-  std::lock_guard<std::mutex> lock(python_properties_mutex_);
-
-  for (const auto &property : python_properties_) {
-    result.insert({ property.getName(), property });
-  }
-
-  return result;
-}
-
-std::vector<core::Relationship> ExecutePythonProcessor::getPythonRelationships() {
-  auto relationships = getSupportedRelationships();
+std::vector<core::Relationship> ExecutePythonProcessor::getPythonRelationships() const {
+  std::vector<core::Relationship> relationships{Relationships.begin(), Relationships.end()};
   auto custom_relationships = python_script_engine_->getCustomPythonRelationships();
   relationships.reserve(relationships.size() + std::distance(custom_relationships.begin(), custom_relationships.end()));
   relationships.insert(relationships.end(), custom_relationships.begin(), custom_relationships.end());
   return relationships;
 }
 
+void ExecutePythonProcessor::setLoggerCallback(const std::function<void(core::logging::LOG_LEVEL level, const std::string& message)>& callback) {
+  gsl_Expects(logger_ && python_logger_);
+  logger_->setLogCallback(callback);
+  python_logger_->setLogCallback(callback);
+}
+
 REGISTER_RESOURCE(ExecutePythonProcessor, Processor);
 
 }  // namespace org::apache::nifi::minifi::extensions::python::processors
