@@ -28,31 +28,34 @@
 #include <filesystem>
 
 #include "concurrentqueue.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "PythonScriptEngine.h"
 #include "utils/gsl.h"
 
 namespace org::apache::nifi::minifi::extensions::python::processors {
 
-class ExecutePythonProcessor : public core::Processor {
+class ExecutePythonProcessor : public core::ProcessorImpl {
  public:
-  explicit ExecutePythonProcessor(std::string_view name, const utils::Identifier &uuid = {})
-      : Processor(name, uuid),
+  explicit ExecutePythonProcessor(core::ProcessorMetadata metadata)
+      : ProcessorImpl(metadata),
         processor_initialized_(false),
         python_dynamic_(false),
         reload_on_script_change_(true) {
+    python_logger_ = core::logging::LoggerFactory<ExecutePythonProcessor>::getAliasedLogger(getName(), metadata.uuid);
   }
 
-  EXTENSIONAPI static constexpr const char* Description = "Executes a script given the flow file and a process session. "
+  EXTENSIONAPI static constexpr const char* Description = "DEPRECATED. This processor should only be used internally for running NiFi and MiNiFi C++ style python processors. "
+      "Do not use this processor in your own flows, move your python processors to the minifi-python directory instead, where they will be parsed, "
+      "and then they can be used with their filename as the processor class in the flow configuration.\n\n"
+      "This processor executes a script given the flow file and a process session. "
       "The script is responsible for handling the incoming flow file (transfer to SUCCESS or remove, e.g.) as well as "
-      "any flow files created by the script. If the handling is incomplete or incorrect, the session will be rolled back.Scripts must define an onTrigger function which accepts NiFi Context "
-      "and Property objects. For efficiency, scripts are executed once when the processor is run, then the onTrigger method is called for each incoming flowfile. This enables scripts to keep state "
-      "if they wish, although there will be a script context per concurrent task of the processor. In order to, e.g., compute an arithmetic sum based on incoming flow file information, set the "
-      "concurrent tasks to 1. The python script files are expected to contain `describe(procesor)` and `onTrigger(context, session)`.";
+      "any flow files created by the script. If the handling is incomplete or incorrect, the session will be rolled back. Scripts must define an onTrigger function which accepts NiFi Context "
+      "and ProcessSession objects. Scripts are executed once when the processor is run, then the onTrigger method is called for each incoming flowfile. This enables scripts to keep state "
+      "if they wish. The python script files are expected to contain `describe(processor)` and `onTrigger(context, session)`.";
 
   EXTENSIONAPI static constexpr auto ScriptFile = core::PropertyDefinitionBuilder<>::createProperty("Script File")
       .withDescription("Path to script file to execute. Only one of Script File or Script Body may be used")
@@ -66,7 +69,7 @@ class ExecutePythonProcessor : public core::Processor {
   EXTENSIONAPI static constexpr auto ReloadOnScriptChange = core::PropertyDefinitionBuilder<>::createProperty("Reload on Script Change")
       .withDescription("If true and Script File property is used, then script file will be reloaded if it has changed, otherwise the first loaded version will be used at all times.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
@@ -86,8 +89,14 @@ class ExecutePythonProcessor : public core::Processor {
   EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
   EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
   EXTENSIONAPI static constexpr bool IsSingleThreaded = true;
-  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
+  bool supportsDynamicProperties() const override { return python_dynamic_; }
+  bool supportsDynamicRelationships() const override { return SupportsDynamicRelationships; }
+  minifi::core::annotation::Input getInputRequirement() const override { return InputRequirement; }
+  bool isSingleThreaded() const override { return IsSingleThreaded; }
+  ADD_GET_PROCESSOR_NAME
+
+  void initializeScript();
   void initialize() override;
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) override;
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
@@ -104,10 +113,6 @@ class ExecutePythonProcessor : public core::Processor {
     return python_properties_;
   }
 
-  bool getPythonSupportDynamicProperties() {
-    return python_dynamic_;
-  }
-
   void setDescription(const std::string &description) {
     description_ = description;
   }
@@ -136,12 +141,12 @@ class ExecutePythonProcessor : public core::Processor {
     qualified_module_name_ = qualified_module_name;
   }
 
-  std::map<std::string, core::Property> getProperties() const override;
+  void setScriptFilePath(std::string script_file_path) {
+    script_file_path_ = script_file_path;
+  }
 
-  std::vector<core::Relationship> getPythonRelationships();
-
- protected:
-  const core::Property* findProperty(const std::string& name) const override;
+  std::vector<core::Relationship> getPythonRelationships() const;
+  void setLoggerCallback(const std::function<void(core::logging::LOG_LEVEL level, const std::string& message)>& callback) override;
 
  private:
   mutable std::mutex python_properties_mutex_;
@@ -153,8 +158,6 @@ class ExecutePythonProcessor : public core::Processor {
   bool processor_initialized_;
   bool python_dynamic_;
 
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ExecutePythonProcessor>::getLogger(uuid_);
-
   std::string script_to_exec_;
   bool reload_on_script_change_;
   std::optional<std::chrono::file_clock::time_point> last_script_write_time_;
@@ -164,8 +167,9 @@ class ExecutePythonProcessor : public core::Processor {
   std::optional<std::string> python_class_name_;
   std::vector<std::filesystem::path> python_paths_;
   std::string qualified_module_name_;
+  std::string module_directory_;
 
-  void appendPathForImportModules();
+  void appendPathForImportModules() const;
   void loadScriptFromFile();
   void loadScript();
   void reloadScriptIfUsingScriptFileProperty();
