@@ -21,7 +21,7 @@ a * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 
 #include "PyStateManager.h"
 #include "PyScriptFlowFile.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "controllers/RecordSetReader.h"
 #include "controllers/RecordSetWriter.h"
 
@@ -30,11 +30,13 @@ namespace org::apache::nifi::minifi::extensions::python {
 
 static PyMethodDef PyProcessContext_methods[] = {  // NOLINT(cppcoreguidelines-avoid-c-arrays)
     {"getProperty", (PyCFunction) PyProcessContext::getProperty, METH_VARARGS, nullptr},
+    {"getDynamicProperty", (PyCFunction) PyProcessContext::getDynamicProperty, METH_VARARGS, nullptr},
+    {"getDynamicPropertyKeys", (PyCFunction) PyProcessContext::getDynamicPropertyKeys, METH_VARARGS, nullptr},
     {"getStateManager", (PyCFunction) PyProcessContext::getStateManager, METH_VARARGS, nullptr},
     {"getControllerService", (PyCFunction) PyProcessContext::getControllerService, METH_VARARGS, nullptr},
     {"getName", (PyCFunction) PyProcessContext::getName, METH_VARARGS, nullptr},
     {"getProperties", (PyCFunction) PyProcessContext::getProperties, METH_VARARGS, nullptr},
-    {"yieldResources", (PyCFunction) PyProcessContext::getProperties, METH_VARARGS, nullptr},
+    {"yieldResources", (PyCFunction) PyProcessContext::yieldResources, METH_VARARGS, nullptr},
     {}  /* Sentinel */
 };
 
@@ -80,26 +82,72 @@ PyObject* PyProcessContext::getProperty(PyProcessContext* self, PyObject* args)
     return nullptr;
   }
 
-  std::string value;
   if (!script_flow_file) {
-    if (!context->getProperty(property_name, value)) {
-      Py_RETURN_NONE;
-    }
-  } else {
-    auto py_flow = reinterpret_cast<PyScriptFlowFile*>(script_flow_file);
-    const auto flow_file = py_flow->script_flow_file_.lock();
-    if (!flow_file) {
-      PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
-      return nullptr;
-    }
-    core::Property property{property_name, ""};
-    property.setSupportsExpressionLanguage(true);
-    if (!context->getProperty(property, value, flow_file.get())) {
-      Py_RETURN_NONE;
+    if (const auto property_value = context->getProperty(property_name)) {
+      return object::returnReference(*property_value);
     }
+    Py_RETURN_NONE;
+  }
+  auto py_flow = reinterpret_cast<PyScriptFlowFile*>(script_flow_file);
+  const auto flow_file = py_flow->script_flow_file_.lock();
+  if (!flow_file) {
+    PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
+    return nullptr;
+  }
+  core::Property property{property_name, ""};
+  property.setSupportsExpressionLanguage(true);
+  if (const auto property_value = context->getProperty(property, flow_file.get())) {
+    return object::returnReference(*property_value);
+  }
+  Py_RETURN_NONE;
+}
+
+PyObject* PyProcessContext::getDynamicProperty(PyProcessContext* self, PyObject* args) {
+  auto context = self->process_context_;
+  if (!context) {
+    PyErr_SetString(PyExc_AttributeError, "tried reading process context outside 'on_trigger'");
+    return nullptr;
   }
 
-  return object::returnReference(value);
+  const char* property_name = nullptr;
+  PyObject* script_flow_file = nullptr;
+  if (!PyArg_ParseTuple(args, "s|O", &property_name, &script_flow_file)) {
+    return nullptr;
+  }
+
+  if (!script_flow_file) {
+    if (const auto property_value = context->getDynamicProperty(property_name, nullptr)) {
+      return object::returnReference(*property_value);
+    }
+    Py_RETURN_NONE;
+  }
+  auto py_flow = reinterpret_cast<PyScriptFlowFile*>(script_flow_file);
+  const auto flow_file = py_flow->script_flow_file_.lock();
+  if (!flow_file) {
+    PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
+    return nullptr;
+  }
+
+  if (const auto property_value = context->getDynamicProperty(property_name, flow_file.get())) {
+    return object::returnReference(*property_value);
+  }
+  Py_RETURN_NONE;
+}
+
+PyObject* PyProcessContext::getDynamicPropertyKeys(PyProcessContext* self, PyObject*) {
+  auto context = self->process_context_;
+  if (!context) {
+    PyErr_SetString(PyExc_AttributeError, "tried reading process context outside 'on_trigger'");
+    return nullptr;
+  }
+
+  auto property_keys = context->getDynamicPropertyKeys();
+  auto py_properties = OwnedList::create();
+  for (const auto& property_name : property_keys) {
+    py_properties.append(property_name);
+  }
+
+  return object::returnReference(py_properties);
 }
 
 PyObject* PyProcessContext::getStateManager(PyProcessContext* self, PyObject*) {
@@ -125,10 +173,10 @@ PyObject* PyProcessContext::getControllerService(PyProcessContext* self, PyObjec
     return nullptr;
   }
 
-  if (auto controller_service = context->getControllerService(controller_service_name, context->getProcessorNode()->getUUID())) {
+  if (auto controller_service = context->getControllerService(controller_service_name, context->getProcessorInfo().getUUID())) {
     std::string controller_service_type_str = controller_service_type;
     if (controller_service_type_str == "SSLContextService") {
-      auto ssl_ctx_service = std::dynamic_pointer_cast<controllers::SSLContextService>(controller_service);
+      auto ssl_ctx_service = std::dynamic_pointer_cast<controllers::SSLContextServiceInterface>(controller_service);
       return object::returnReference(std::weak_ptr(ssl_ctx_service));
     } else if (controller_service_type_str == "RecordSetReader") {
       auto record_set_reader = std::dynamic_pointer_cast<core::RecordSetReader>(controller_service);
@@ -149,7 +197,7 @@ PyObject* PyProcessContext::getName(PyProcessContext* self, PyObject*) {
     return nullptr;
   }
 
-  return object::returnReference(context->getProcessorNode()->getName());
+  return object::returnReference(context->getProcessorInfo().getName());
 }
 
 PyObject* PyProcessContext::getProperties(PyProcessContext* self, PyObject*) {
@@ -159,19 +207,12 @@ PyObject* PyProcessContext::getProperties(PyProcessContext* self, PyObject*) {
     return nullptr;
   }
 
-  auto processor = dynamic_cast<core::Processor*>(context->getProcessorNode()->getProcessor());
-  if (!processor) {
-    PyErr_SetString(PyExc_AttributeError, "Processor not available in getProperties");
-    return nullptr;
-  }
-  auto properties = processor->getProperties();
+  auto properties = context->getProcessorInfo().getSupportedProperties();
   auto py_properties = OwnedDict::create();
   for (const auto& [property_name, property] : properties) {
-    std::string value;
-    if (!context->getProperty(property_name, value)) {
-      continue;
+    if (const auto value = context->getProperty(property_name)) {
+      py_properties.put(property_name, *value);
     }
-    py_properties.put(property_name, value);
   }
 
   return object::returnReference(py_properties);
