@@ -37,6 +37,8 @@ struct PyProcessContext {
   static int init(PyProcessContext* self, PyObject* args, PyObject* kwds);
 
   static PyObject* getProperty(PyProcessContext* self, PyObject* args);
+  static PyObject* getDynamicProperty(PyProcessContext* self, PyObject* args);
+  static PyObject* getDynamicPropertyKeys(PyProcessContext* self, PyObject* args);
   static PyObject* getStateManager(PyProcessContext* self, PyObject* args);
   static PyObject* getControllerService(PyProcessContext* self, PyObject* args);
   static PyObject* getName(PyProcessContext* self, PyObject* args);
