@@ -27,7 +27,7 @@ namespace org::apache::nifi::minifi::extensions::python {
 
 class PyProcessSession {
  public:
-  explicit PyProcessSession(std::shared_ptr<core::ProcessSession> session);
+  explicit PyProcessSession(core::ProcessSession& session);
 
   std::shared_ptr<core::FlowFile> get();
   std::shared_ptr<core::FlowFile> create(const std::shared_ptr<core::FlowFile>& flow_file = nullptr);
@@ -38,10 +38,12 @@ class PyProcessSession {
   void write(const std::shared_ptr<core::FlowFile>& flow_file, BorrowedObject output_stream_callback);
   void remove(const std::shared_ptr<core::FlowFile>& flow_file);
   std::string getContentsAsString(const std::shared_ptr<core::FlowFile>& flow_file);
+  void putAttribute(const std::shared_ptr<core::FlowFile>& flow_file, std::string_view key, const std::string& value);
+  core::ProcessSession& getSession() const { return session_; }
 
  private:
   std::vector<std::shared_ptr<core::FlowFile>> flow_files_;
-  std::shared_ptr<core::ProcessSession> session_;
+  core::ProcessSession& session_;
 };
 
 struct PyProcessSessionObject {
@@ -63,6 +65,7 @@ struct PyProcessSessionObject {
   static PyObject* transferToCustomRelationship(PyProcessSessionObject* self, PyObject* args);
   static PyObject* remove(PyProcessSessionObject* self, PyObject* args);
   static PyObject* getContentsAsBytes(PyProcessSessionObject* self, PyObject* args);
+  static PyObject* putAttribute(PyProcessSessionObject* self, PyObject* args);
 
   static PyTypeObject* typeObject();
 };
