@@ -24,12 +24,14 @@
 #include <utility>
 #include <vector>
 
+#include "FlowFileRecord.h"
+#include "core/Resource.h"
+#include "core/TypedValues.h"
 #include "rocksdb/options.h"
 #include "rocksdb/slice.h"
-#include "FlowFileRecord.h"
-#include "utils/gsl.h"
-#include "core/Resource.h"
+#include "utils/Locations.h"
 #include "utils/OptionalUtils.h"
+#include "utils/gsl.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -120,7 +122,7 @@ void FlowFileRepository::run() {
   flush();
 }
 
-bool FlowFileRepository::contentSizeIsAmpleForFlowFile(const FlowFileRecord& flow_file_record, const std::shared_ptr<ResourceClaim>& resource_claim) const {
+bool FlowFileRepository::contentSizeIsAmpleForFlowFile(const FlowFile& flow_file_record, const std::shared_ptr<ResourceClaim>& resource_claim) const {
   const auto stream_size = resource_claim ? content_repo_->size(*resource_claim) : 0;
   const auto required_size = flow_file_record.getOffset() + flow_file_record.getSize();
   return stream_size >= required_size;
@@ -209,7 +211,9 @@ bool FlowFileRepository::initialize(const std::shared_ptr<Configure> &configure)
 
   setCompactionPeriod(configure);
 
-  const auto encrypted_env = createEncryptingEnv(utils::crypto::EncryptionManager{configure->getHome()}, DbEncryptionOptions{directory_, ENCRYPTION_KEY_NAME});
+  const auto working_dir = utils::getMinifiDir();
+
+  const auto encrypted_env = createEncryptingEnv(utils::crypto::EncryptionManager{working_dir}, DbEncryptionOptions{directory_, ENCRYPTION_KEY_NAME});
   logger_->log_info("Using {} FlowFileRepository", encrypted_env ? "encrypted" : "plaintext");
 
   verify_checksums_in_rocksdb_reads_ = (configure->get(Configure::nifi_flowfile_repository_rocksdb_read_verify_checksums) | utils::andThen(&utils::string::toBool)).value_or(false);
@@ -283,7 +287,7 @@ void FlowFileRepository::runCompaction() {
 }
 
 bool FlowFileRepository::start() {
-  const bool ret = ThreadedRepository::start();
+  const bool ret = ThreadedRepositoryImpl::start();
   if (swap_loader_) {
     swap_loader_->start();
   }
@@ -300,7 +304,7 @@ bool FlowFileRepository::stop() {
   if (swap_loader_) {
     swap_loader_->stop();
   }
-  return ThreadedRepository::stop();
+  return ThreadedRepositoryImpl::stop();
 }
 
 void FlowFileRepository::store(std::vector<std::shared_ptr<core::FlowFile>> flow_files) {
