@@ -30,7 +30,7 @@ bool ProvenanceRepository::initialize(const std::shared_ptr<org::apache::nifi::m
   }
   logger_->log_debug("MiNiFi Provenance Repository Directory {}", directory_);
   if (config->get(Configure::nifi_provenance_repository_max_storage_size, value)) {
-    core::Property::StringToInt(value, max_partition_bytes_);
+    max_partition_bytes_ = gsl::narrow<int64_t>(parsing::parseDataSize(value) | utils::orThrow("expected parsable data size"));
   }
   logger_->log_debug("MiNiFi Provenance Max Partition Bytes {}", max_partition_bytes_);
   if (config->get(Configure::nifi_provenance_repository_max_storage_time, value)) {
@@ -86,7 +86,7 @@ bool ProvenanceRepository::getElements(std::vector<std::shared_ptr<core::Seriali
   for (it->SeekToFirst(); it->Valid(); it->Next()) {
     if (max_size >= requested_batch)
       break;
-    auto eventRead = std::make_shared<ProvenanceEventRecord>();
+    auto eventRead = ProvenanceEventRecord::create();
     std::string key = it->key().ToString();
     io::BufferStream stream(gsl::make_span(it->value()).as_span<const std::byte>());
     if (eventRead->deserialize(stream)) {
