@@ -15,14 +15,16 @@
  * limitations under the License.
  */
 
+#include "RocksDbStateStorage.h"
+
 #include <cinttypes>
 #include <fstream>
 #include <utility>
 
-#include "RocksDbStateStorage.h"
 #include "../encryption/RocksDbEncryptionProvider.h"
-#include "utils/StringUtils.h"
 #include "core/Resource.h"
+#include "utils/Locations.h"
+#include "utils/StringUtils.h"
 
 namespace org::apache::nifi::minifi::controllers {
 
@@ -35,7 +37,7 @@ RocksDbStateStorage::~RocksDbStateStorage() {
 }
 
 void RocksDbStateStorage::initialize() {
-  ControllerService::initialize();
+  ControllerServiceImpl::initialize();
   setSupportedProperties(Properties);
 }
 
@@ -45,24 +47,27 @@ void RocksDbStateStorage::onEnable() {
     return;
   }
 
-  const auto always_persist = getProperty<bool>(AlwaysPersist).value_or(false);
+  const auto always_persist = getProperty(AlwaysPersist.name)
+      | utils::andThen(parsing::parseBool)
+      | utils::orThrow("RocksDbStateStorage::AlwaysPersist is a required Property");
   logger_->log_info("Always Persist property: {}", always_persist);
 
-  const auto auto_persistence_interval = getProperty<core::TimePeriodValue>(AutoPersistenceInterval).value_or(core::TimePeriodValue{}).getMilliseconds();
+  const auto auto_persistence_interval = getProperty(AutoPersistenceInterval.name)
+      | utils::andThen(parsing::parseDuration<std::chrono::milliseconds>)
+      | utils::orThrow("RocksDbStateStorage::AutoPersistenceInterval is a required Property");
   logger_->log_info("Auto Persistence Interval property: {}", auto_persistence_interval);
 
-  if (!getProperty(Directory, directory_)) {
-    logger_->log_error("Invalid or missing property: Directory");
-    return;
-  }
+  directory_ = getProperty(Directory.name) | utils::orThrow("RocksDbStateStorage::Directory is required property");
 
   auto_persistor_.start(always_persist, auto_persistence_interval, [this] { return persistNonVirtual(); });
-
   db_.reset();
 
-  auto encrypted_env = createEncryptingEnv(utils::crypto::EncryptionManager{configuration_->getHome()}, core::repository::DbEncryptionOptions{directory_, ENCRYPTION_KEY_NAME});
+
+  const auto working_dir = utils::getMinifiDir();
+
+  auto encrypted_env = createEncryptingEnv(utils::crypto::EncryptionManager{working_dir}, core::repository::DbEncryptionOptions{directory_, ENCRYPTION_KEY_NAME});
   if (!encrypted_env) {
-    encrypted_env = createEncryptingEnv(utils::crypto::EncryptionManager{configuration_->getHome()}, core::repository::DbEncryptionOptions{directory_, ENCRYPTION_KEY_NAME_OLD});
+    encrypted_env = createEncryptingEnv(utils::crypto::EncryptionManager{working_dir}, core::repository::DbEncryptionOptions{directory_, ENCRYPTION_KEY_NAME_OLD});
   }
   logger_->log_info("Using {} RocksDbStateStorage", encrypted_env ? "encrypted" : "plaintext");
 
