@@ -24,11 +24,11 @@
 #include "FileSystemRepository.h"
 #include "VolatileContentRepository.h"
 #include "DatabaseContentRepository.h"
-#include "BufferedContentSession.h"
+#include "core/BufferedContentSession.h"
 #include "FlowFileRecord.h"
 #include "unit/TestBase.h"
 #include "unit/Catch.h"
-#include "utils/gsl.h"
+#include "utils/ConfigurationUtils.h"
 
 template<typename ContentRepositoryClass>
 class ContentSessionController : public TestController {
@@ -36,8 +36,7 @@ class ContentSessionController : public TestController {
   ContentSessionController()
       : contentRepository(std::make_shared<ContentRepositoryClass>()) {
     auto contentRepoPath = createTempDirectory();
-    auto config = std::make_shared<minifi::Configure>();
-    config->setHome(contentRepoPath);
+    auto config = std::make_shared<minifi::ConfigureImpl>();
     config->set(minifi::Configure::nifi_dbcontent_repository_directory_default, contentRepoPath.string());
     contentRepository->initialize(config);
   }
@@ -54,14 +53,14 @@ class ContentSessionController : public TestController {
   std::shared_ptr<core::ContentRepository> contentRepository;
 };
 
-const std::shared_ptr<minifi::io::OutputStream>& operator<<(const std::shared_ptr<minifi::io::OutputStream>& stream, const std::string& str) {
+std::shared_ptr<minifi::io::OutputStream> operator<<(std::shared_ptr<minifi::io::OutputStream> stream, const std::string& str) {
   REQUIRE(stream->write(reinterpret_cast<const uint8_t*>(str.data()), str.length()) == str.length());
   return stream;
 }
 
-const std::shared_ptr<minifi::io::InputStream>& operator>>(const std::shared_ptr<minifi::io::InputStream>& stream, std::string& str) {
+std::shared_ptr<minifi::io::InputStream> operator>>(std::shared_ptr<minifi::io::InputStream> stream, std::string& str) {
   str = "";
-  std::array<std::byte, 4096> buffer{};
+  std::array<std::byte, utils::configuration::DEFAULT_BUFFER_SIZE> buffer{};
   while (true) {
     const auto ret = stream->read(buffer);
     REQUIRE_FALSE(minifi::io::isError(ret));
@@ -104,7 +103,7 @@ void test_template() {
   {
     auto other_session = contentRepository->createSession();
     other_session->append(oldClaim, 4, [&] (auto new_claim) {
-      copied_claim = new_claim;
+      copied_claim = std::move(new_claim);
     }) << "-some extra content";
     other_session->commit();
   }
