@@ -53,11 +53,10 @@ void ExecuteScript::onSchedule(core::ProcessContext& context, core::ProcessSessi
   }
 
 
-  std::string script_file;
-  std::string script_body;
-  context.getProperty(ScriptFile, script_file);
-  context.getProperty(ScriptBody, script_body);
-  auto module_directory = context.getProperty(ModuleDirectory);
+  std::string script_file = context.getProperty(ScriptFile).value_or("");
+  std::string script_body = context.getProperty(ScriptBody).value_or("");
+
+  auto module_directory = context.getProperty(ModuleDirectory) | utils::toOptional();
 
   if (script_file.empty() && script_body.empty()) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Either Script Body or Script File must be defined");
@@ -71,7 +70,7 @@ void ExecuteScript::onSchedule(core::ProcessContext& context, core::ProcessSessi
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Script File set is not a regular file or does not exist: " + script_file);
   }
 
-  script_executor_->initialize(std::move(script_file), std::move(script_body), std::move(module_directory), getMaxConcurrentTasks(), Success, Failure, Original, logger_);
+  script_executor_->initialize(std::move(script_file), std::move(script_body), std::move(module_directory), context.getMaxConcurrentTasks(), Success, Failure, Original, logger_);
 }
 
 void ExecuteScript::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
