@@ -25,7 +25,7 @@
 #include <optional>
 
 #include "concurrentqueue.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/RelationshipDefinition.h"
@@ -33,7 +33,7 @@
 #include "ScriptExecutor.h"
 #include "utils/Enum.h"
 #include "utils/ResourceQueue.h"
-#include "logging/LoggerFactory.h"
+#include "core/logging/LoggerFactory.h"
 
 namespace org::apache::nifi::minifi::processors {
 
@@ -44,11 +44,9 @@ enum class ScriptEngineOption {
 };
 }  // namespace execute_script
 
-class ExecuteScript : public core::Processor {
+class ExecuteScript : public core::ProcessorImpl {
  public:
-  explicit ExecuteScript(std::string_view name, const utils::Identifier &uuid = {})
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Executes a script given the flow file and a process session. "
       "The script is responsible for handling the incoming flow file (transfer to SUCCESS or remove, e.g.) as well as "
@@ -99,8 +97,6 @@ class ExecuteScript : public core::Processor {
   }
 
  private:
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ExecuteScript>::getLogger(uuid_);
-
   std::unique_ptr<extensions::script::ScriptExecutor> script_executor_;
 };
 
