@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -24,11 +23,13 @@
 #include <sstream>
 #include <string>
 #include <tuple>
-#include <utility>
 #include <vector>
 
+#include "utils/ConfigurationUtils.h"
 #include "utils/StringUtils.h"
 #include "utils/gsl.h"
+#include "minifi-cpp/io/OutputStream.h"
+#include "minifi-cpp/io/InputStream.h"
 
 namespace org::apache::nifi::minifi::utils {
 
@@ -152,11 +153,12 @@ LastSFTPError::operator SFTPError() const {
 }
 
 
-SFTPClient::SFTPClient(std::string hostname, uint16_t port, std::string username)
+SFTPClient::SFTPClient(std::string hostname, uint16_t port, std::string username, const size_t buffer_size)
     : logger_(core::logging::LoggerFactory<SFTPClient>::getLogger()),
       hostname_(std::move(hostname)),
       port_(port),
       username_(std::move(username)),
+      buffer_size_(buffer_size),
       curl_errorbuffer_(CURL_ERROR_SIZE, '\0'),
       easy_(curl_easy_init()) {
   if (easy_ == nullptr) {
@@ -717,8 +719,8 @@ bool SFTPClient::listDirectory(const std::string& path, bool follow_symlinks,
   });
 
   LIBSSH2_SFTP_ATTRIBUTES attrs;
-  std::vector<char> filename(4096U);
-  std::vector<char> longentry(4096U);
+  std::vector<char> filename(buffer_size_);
+  std::vector<char> longentry(buffer_size_);
   do {
     int ret = libssh2_sftp_readdir_ex(dir_handle,
                                       filename.data(),
