@@ -17,9 +17,9 @@
 
 #include "FetchSFTP.h"
 
-#include <memory>
 #include <algorithm>
 #include <cstdint>
+#include <memory>
 #include <utility>
 
 #include "core/FlowFile.h"
@@ -27,8 +27,10 @@
 #include "core/Relationship.h"
 #include "core/Resource.h"
 #include "io/BufferStream.h"
+#include "utils/ConfigurationUtils.h"
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
+#include "utils/ProcessorConfigUtils.h"
 
 namespace org::apache::nifi::minifi::processors {
 
@@ -39,33 +41,15 @@ void FetchSFTP::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-FetchSFTP::FetchSFTP(std::string_view name, const utils::Identifier& uuid /*= utils::Identifier()*/)
-    : SFTPProcessorBase(name, uuid) {
-  logger_ = core::logging::LoggerFactory<FetchSFTP>::getLogger(uuid_);
-}
-
 FetchSFTP::~FetchSFTP() = default;
 
 void FetchSFTP::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
   parseCommonPropertiesOnSchedule(context);
 
-  std::string value;
-  context.getProperty(CompletionStrategy, completion_strategy_);
-  if (!context.getProperty(CreateDirectory, value)) {
-    logger_->log_error("Create Directory attribute is missing or invalid");
-  } else {
-    create_directory_ = utils::string::toBool(value).value_or(false);
-  }
-  if (!context.getProperty(DisableDirectoryListing, value)) {
-    logger_->log_error("Disable Directory Listing attribute is missing or invalid");
-  } else {
-    disable_directory_listing_ = utils::string::toBool(value).value_or(false);
-  }
-  if (!context.getProperty(UseCompression, value)) {
-    logger_->log_error("Use Compression attribute is missing or invalid");
-  } else {
-    use_compression_ = utils::string::toBool(value).value_or(false);
-  }
+  completion_strategy_ = utils::parseProperty(context, CompletionStrategy);
+  create_directory_ = utils::parseBoolProperty(context, CreateDirectory);
+  disable_directory_listing_ = utils::parseBoolProperty(context, DisableDirectoryListing);
+  use_compression_ =  utils::parseBoolProperty(context, UseCompression);
 
   startKeepaliveThreadIfNeeded();
 }
@@ -101,11 +85,13 @@ void FetchSFTP::onTrigger(core::ProcessContext& context, core::ProcessSession& s
                                                                       common_properties.proxy_host,
                                                                       common_properties.proxy_port,
                                                                       common_properties.proxy_username};
+  const auto buffer_size = utils::configuration::getBufferSize(*context.getConfiguration());
   auto client = getOrCreateConnection(connection_cache_key,
                                       common_properties.password,
                                       common_properties.private_key_path,
                                       common_properties.private_key_passphrase,
-                                      common_properties.proxy_password);
+                                      common_properties.proxy_password,
+                                      buffer_size);
   if (client == nullptr) {
     context.yield();
     return;
