@@ -23,13 +23,13 @@
 #include "SFTPProcessorBase.h"
 #include "utils/ByteArrayCallback.h"
 #include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/Core.h"
 #include "core/Property.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "minifi-cpp/core/PropertyValidator.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/ArrayUtils.h"
 #include "utils/Id.h"
 #include "../client/SFTPClient.h"
@@ -42,7 +42,7 @@ class FetchSFTP : public SFTPProcessorBase {
   static constexpr char const *COMPLETION_STRATEGY_MOVE_FILE = "Move File";
   static constexpr char const *COMPLETION_STRATEGY_DELETE_FILE = "Delete File";
 
-  explicit FetchSFTP(std::string_view name, const utils::Identifier& uuid = {});
+  using SFTPProcessorBase::SFTPProcessorBase;
   ~FetchSFTP() override;
 
   EXTENSIONAPI static constexpr const char* Description = "Fetches the content of a file from a remote SFTP server "
@@ -70,7 +70,7 @@ class FetchSFTP : public SFTPProcessorBase {
   EXTENSIONAPI static constexpr auto CreateDirectory = core::PropertyDefinitionBuilder<>::createProperty("Create Directory")
       .withDescription("Specifies whether or not the remote directory should be created if it does not exist.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto DisableDirectoryListing = core::PropertyDefinitionBuilder<>::createProperty("Disable Directory Listing")
@@ -82,13 +82,13 @@ class FetchSFTP : public SFTPProcessorBase {
           "Also, if any other SFTP client created the directory after this processor performed a listing and before a directory creation request by this processor is finished, "
           "then an error is returned because the directory already exists.")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto UseCompression = core::PropertyDefinitionBuilder<>::createProperty("Use Compression")
       .withDescription("Indicates whether or not ZLIB compression should be used when transferring files")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
 
