@@ -17,28 +17,30 @@
 
 #include "ListSFTP.h"
 
-#include <memory>
 #include <algorithm>
 #include <cstdint>
 #include <cstring>
+#include <deque>
 #include <iterator>
 #include <limits>
-#include <map>
-#include <set>
 #include <list>
+#include <map>
+#include <memory>
+#include <set>
+#include <tuple>
 #include <utility>
 #include <vector>
-#include <tuple>
-#include <deque>
 
-#include "utils/TimeUtil.h"
-#include "utils/StringUtils.h"
-#include "utils/file/FileUtils.h"
 #include "core/FlowFile.h"
 #include "core/ProcessContext.h"
 #include "core/Resource.h"
 #include "io/BufferStream.h"
 #include "rapidjson/ostreamwrapper.h"
+#include "utils/ConfigurationUtils.h"
+#include "utils/StringUtils.h"
+#include "utils/TimeUtil.h"
+#include "utils/file/FileUtils.h"
+#include "utils/ProcessorConfigUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -66,11 +68,6 @@ void ListSFTP::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-ListSFTP::ListSFTP(std::string_view name, const utils::Identifier& uuid /*= utils::Identifier()*/)
-    : SFTPProcessorBase(name, uuid) {
-  logger_ = core::logging::LoggerFactory<ListSFTP>::getLogger(uuid_);
-}
-
 ListSFTP::~ListSFTP() = default;
 
 void ListSFTP::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
@@ -81,64 +78,43 @@ void ListSFTP::onSchedule(core::ProcessContext& context, core::ProcessSessionFac
     throw Exception(PROCESSOR_EXCEPTION, "Failed to get StateManager");
   }
 
-  std::string value;
-  context.getProperty(ListingStrategy, listing_strategy_);
+  listing_strategy_ = utils::parseProperty(context, ListingStrategy);
   if (!last_listing_strategy_.empty() && last_listing_strategy_ != listing_strategy_) {
     invalidateCache();
   }
   last_listing_strategy_ = listing_strategy_;
-  if (!context.getProperty(SearchRecursively, value)) {
-    logger_->log_error("Search Recursively attribute is missing or invalid");
-  } else {
-    search_recursively_ = utils::string::toBool(value).value_or(false);
-  }
-  if (!context.getProperty(FollowSymlink, value)) {
-    logger_->log_error("Follow symlink attribute is missing or invalid");
-  } else {
-    follow_symlink_ = utils::string::toBool(value).value_or(false);
-  }
-  if (context.getProperty(FileFilterRegex, file_filter_regex_) && !file_filter_regex_.empty()) {
+
+  search_recursively_ = utils::parseBoolProperty(context, SearchRecursively);
+  follow_symlink_ = utils::parseBoolProperty(context, FollowSymlink);
+  ignore_dotted_files_ = utils::parseBoolProperty(context, IgnoreDottedFiles);
+
+  file_filter_regex_ = context.getProperty(FileFilterRegex).value_or("");
+  if (!file_filter_regex_.empty()) {
     try {
       compiled_file_filter_regex_ = utils::Regex(file_filter_regex_);
     } catch (const Exception&) {
       logger_->log_error("Failed to compile File Filter Regex \"{}\"", file_filter_regex_.c_str());
     }
   }
-  if (context.getProperty(PathFilterRegex, path_filter_regex_) && !path_filter_regex_.empty()) {
+
+  path_filter_regex_ = context.getProperty(PathFilterRegex).value_or("");
+  if (!path_filter_regex_.empty()) {
     try {
       compiled_path_filter_regex_ = utils::Regex(path_filter_regex_);
     } catch (const Exception&) {
       logger_->log_error("Failed to compile Path Filter Regex \"{}\"", path_filter_regex_.c_str());
     }
   }
-  if (!context.getProperty(IgnoreDottedFiles, value)) {
-    logger_->log_error("Ignore Dotted Files attribute is missing or invalid");
-  } else {
-    ignore_dotted_files_ = utils::string::toBool(value).value_or(true);
-  }
-  context.getProperty(TargetSystemTimestampPrecision, target_system_timestamp_precision_);
-  context.getProperty(EntityTrackingInitialListingTarget, entity_tracking_initial_listing_target_);
 
-  if (auto minimum_file_age = context.getProperty<core::TimePeriodValue>(MinimumFileAge)) {
-    minimum_file_age_ = minimum_file_age->getMilliseconds();
-  } else {
-    logger_->log_error("Minimum File Age attribute is missing or invalid");
-  }
 
-  if (auto maximum_file_age = context.getProperty(MaximumFileAge) | utils::andThen(&core::TimePeriodValue::fromString)) {
-    maximum_file_age_ = maximum_file_age->getMilliseconds();
-  } else {
-    logger_->log_error("Maximum File Age attribute is missing or invalid");
-  }
+  target_system_timestamp_precision_ = utils::parseProperty(context, TargetSystemTimestampPrecision);
+  entity_tracking_initial_listing_target_ = utils::parseProperty(context, EntityTrackingInitialListingTarget);
 
-  if (!context.getProperty(MinimumFileSize, minimum_file_size_)) {
-    logger_->log_error("Minimum File Size attribute is invalid");
-  }
-  if (context.getProperty(MaximumFileSize, value)) {
-    if (!core::DataSizeValue::StringToInt(value, maximum_file_size_)) {
-      logger_->log_error("Maximum File Size attribute is invalid");
-    }
-  }
+  minimum_file_age_ = utils::parseDurationProperty(context, MinimumFileAge);
+  maximum_file_age_ = utils::parseOptionalDurationProperty(context, MaximumFileAge);
+
+  minimum_file_size_ = utils::parseDataSizeProperty(context, MinimumFileSize);
+  maximum_file_size_ = utils::parseOptionalDataSizeProperty(context, MaximumFileSize);
 
   startKeepaliveThreadIfNeeded();
 }
@@ -218,12 +194,12 @@ bool ListSFTP::filterFile(const std::string& parent_path, const std::string& fil
         minimum_file_age_);
     return false;
   }
-  if (maximum_file_age_ != 0ms && file_age > maximum_file_age_) {
+  if (maximum_file_age_ && file_age > *maximum_file_age_) {
     logger_->log_debug("Ignoring \"{}/{}\" because it is older than the Maximum File Age: {} > {}",
                        parent_path.c_str(),
                        filename.c_str(),
                        file_age,
-                       maximum_file_age_);
+                       *maximum_file_age_);
     return false;
   }
 
@@ -236,12 +212,12 @@ bool ListSFTP::filterFile(const std::string& parent_path, const std::string& fil
                        minimum_file_size_);
     return false;
   }
-  if (maximum_file_size_ != 0U && attrs.filesize > maximum_file_size_) {
+  if (maximum_file_size_ && attrs.filesize > *maximum_file_size_) {
     logger_->log_debug("Ignoring \"{}/{}\" because it is larger than the Maximum File Size: {} B > {} B",
                        parent_path.c_str(),
                        filename.c_str(),
                        attrs.filesize,
-                       maximum_file_size_);
+                       *maximum_file_size_);
     return false;
   }
 
@@ -807,18 +783,16 @@ void ListSFTP::onTrigger(core::ProcessContext& context, core::ProcessSession& se
     return;
   }
 
-  std::string remote_path_str;
-  context.getProperty(RemotePath, remote_path_str);
+  std::string remote_path_str = context.getProperty(RemotePath).value_or("");
   /* Remove trailing slashes */
   while (remote_path_str.size() > 1 && remote_path_str.ends_with('/')) {
     remote_path_str.pop_back();
   }
   std::filesystem::path remote_path{remote_path_str, std::filesystem::path::format::generic_format};
 
-  std::string value;
   std::chrono::milliseconds entity_tracking_time_window = 3h;  /* The default is 3 hours */
-  if (context.getProperty(EntityTrackingTimeWindow, value)) {
-    if (auto parsed_entity_time_window = utils::timeutils::StringToDuration<std::chrono::milliseconds>(value)) {
+  if (const auto entity_tracking_time_window_str = context.getProperty(EntityTrackingTimeWindow)) {
+    if (auto parsed_entity_time_window = utils::timeutils::StringToDuration<std::chrono::milliseconds>(*entity_tracking_time_window_str)) {
       entity_tracking_time_window = parsed_entity_time_window.value();
     } else {
       logger_->log_error("Entity Tracking Time Window attribute is invalid");
@@ -843,11 +817,13 @@ void ListSFTP::onTrigger(core::ProcessContext& context, core::ProcessSession& se
                                                                       common_properties.proxy_host,
                                                                       common_properties.proxy_port,
                                                                       common_properties.proxy_username};
+  const auto buffer_size = utils::configuration::getBufferSize(*context.getConfiguration());
   auto client = getOrCreateConnection(connection_cache_key,
                                       common_properties.password,
                                       common_properties.private_key_path,
                                       common_properties.private_key_passphrase,
-                                      common_properties.proxy_password);
+                                      common_properties.proxy_password,
+                                      buffer_size);
   if (client == nullptr) {
     context.yield();
     return;
