@@ -30,11 +30,11 @@
 #include <string_view>
 
 #include "SFTPProcessorBase.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/Property.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "utils/ArrayUtils.h"
 #include "utils/Id.h"
 #include "controllers/keyvalue/KeyValueStateStorage.h"
@@ -55,7 +55,7 @@ class ListSFTP : public SFTPProcessorBase {
   static constexpr std::string_view ENTITY_TRACKING_INITIAL_LISTING_TARGET_TRACKING_TIME_WINDOW = "Tracking Time Window";
   static constexpr std::string_view ENTITY_TRACKING_INITIAL_LISTING_TARGET_ALL_AVAILABLE = "All Available";
 
-  explicit ListSFTP(std::string_view name, const utils::Identifier& uuid = {});
+  using SFTPProcessorBase::SFTPProcessorBase;
   ~ListSFTP() override;
 
   EXTENSIONAPI static constexpr const char* Description = "Performs a listing of the files residing on an SFTP server. "
@@ -78,14 +78,14 @@ class ListSFTP : public SFTPProcessorBase {
       .withDescription("If true, will pull files from arbitrarily nested subdirectories; "
                       "otherwise, will not traverse subdirectories")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto FollowSymlink = core::PropertyDefinitionBuilder<>::createProperty("Follow symlink")
       .withDescription("If true, will pull even symbolic files and also nested symbolic subdirectories; "
           "otherwise, will not read symbolic files and will not traverse symbolic link subdirectories")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto FileFilterRegex = core::PropertyDefinitionBuilder<>::createProperty("File Filter Regex")
@@ -100,7 +100,7 @@ class ListSFTP : public SFTPProcessorBase {
   EXTENSIONAPI static constexpr auto IgnoreDottedFiles = core::PropertyDefinitionBuilder<>::createProperty("Ignore Dotted Files")
       .withDescription("If true, files whose names begin with a dot (\".\") will be ignored")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto TargetSystemTimestampPrecision = core::PropertyDefinitionBuilder<4>::createProperty("Target System Timestamp Precision")
@@ -138,18 +138,18 @@ class ListSFTP : public SFTPProcessorBase {
   EXTENSIONAPI static constexpr auto MinimumFileAge = core::PropertyDefinitionBuilder<>::createProperty("Minimum File Age")
       .withDescription("The minimum age that a file must be in order to be pulled; any file younger than this amount of time (according to last modification date) will be ignored")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("0 sec")
       .build();
   EXTENSIONAPI static constexpr auto MaximumFileAge = core::PropertyDefinitionBuilder<>::createProperty("Maximum File Age")
       .withDescription("The maximum age that a file must be in order to be pulled; any file older than this amount of time (according to last modification date) will be ignored")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto MinimumFileSize = core::PropertyDefinitionBuilder<>::createProperty("Minimum File Size")
       .withDescription("The minimum size that a file must be in order to be pulled")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .withDefaultValue("0 B")
       .build();
   EXTENSIONAPI static constexpr auto MaximumFileSize = core::PropertyDefinitionBuilder<>::createProperty("Maximum File Size")
@@ -216,9 +216,9 @@ class ListSFTP : public SFTPProcessorBase {
   std::string target_system_timestamp_precision_;
   std::string entity_tracking_initial_listing_target_;
   std::chrono::milliseconds minimum_file_age_{};
-  std::chrono::milliseconds maximum_file_age_{};
+  std::optional<std::chrono::milliseconds> maximum_file_age_{};
   uint64_t minimum_file_size_{};
-  uint64_t maximum_file_size_{};
+  std::optional<uint64_t> maximum_file_size_{};
 
   std::string last_listing_strategy_;
   std::string last_hostname_;
