@@ -27,20 +27,20 @@
 #include <vector>
 
 #include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
-#include "controllers/SSLContextService.h"
+#include "minifi-cpp/core/PropertyValidator.h"
+#include "controllers/SSLContextServiceInterface.h"
 #include "utils/Id.h"
 #include "../client/SFTPClient.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class SFTPProcessorBase : public core::Processor {
+class SFTPProcessorBase : public core::ProcessorImpl {
  public:
-  SFTPProcessorBase(std::string_view name, const utils::Identifier& uuid);
+  explicit SFTPProcessorBase(core::ProcessorMetadata metadata);
   ~SFTPProcessorBase() override;
 
   static constexpr std::string_view PROXY_TYPE_DIRECT = "DIRECT";
@@ -82,7 +82,7 @@ class SFTPProcessorBase : public core::Processor {
   EXTENSIONAPI static constexpr auto StrictHostKeyChecking = core::PropertyDefinitionBuilder<>::createProperty("Strict Host Key Checking")
       .withDescription("Indicates whether or not strict enforcement of hosts keys should be applied")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
           .build();
   EXTENSIONAPI static constexpr auto HostKeyFile = core::PropertyDefinitionBuilder<>::createProperty("Host Key File")
@@ -92,19 +92,19 @@ class SFTPProcessorBase : public core::Processor {
   EXTENSIONAPI static constexpr auto ConnectionTimeout = core::PropertyDefinitionBuilder<>::createProperty("Connection Timeout")
       .withDescription("Amount of time to wait before timing out while creating a connection")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("30 sec")
       .build();
   EXTENSIONAPI static constexpr auto DataTimeout = core::PropertyDefinitionBuilder<>::createProperty("Data Timeout")
       .withDescription("When transferring a file between the local and remote system, this value specifies how long is allowed to elapse without any data being transferred between systems")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("30 sec")
       .build();
   EXTENSIONAPI static constexpr auto SendKeepaliveOnTimeout = core::PropertyDefinitionBuilder<>::createProperty("Send Keep Alive On Timeout")
       .withDescription("Indicates whether or not to send a single Keep Alive message when SSH socket times out")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto ProxyType = core::PropertyDefinitionBuilder<3>::createProperty("Proxy Type")
@@ -158,8 +158,6 @@ class SFTPProcessorBase : public core::Processor {
   void notifyStop() override;
 
  protected:
-  std::shared_ptr<core::logging::Logger> logger_;
-
   std::chrono::milliseconds connection_timeout_;
   std::chrono::milliseconds data_timeout_;
   std::string host_key_file_;
@@ -217,7 +215,8 @@ class SFTPProcessorBase : public core::Processor {
       const std::string& password,
       const std::string& private_key_path,
       const std::string& private_key_passphrase,
-      const std::string& proxy_password);
+      const std::string& proxy_password,
+      size_t buffer_size);
 
   enum class CreateDirectoryHierarchyError : uint8_t {
     CREATE_DIRECTORY_HIERARCHY_ERROR_OK = 0,
