@@ -24,8 +24,8 @@
 #include <iostream>
 #include <iterator>
 
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "utils/file/FileUtils.h"
 #include "core/ProcessGroup.h"
 #include "FlowController.h"
@@ -156,10 +156,10 @@ class FetchSFTPTestsFixture {
   std::filesystem::path dst_dir{testController.createTempDirectory()};
   std::shared_ptr<TestPlan> plan = testController.createPlan();
   std::unique_ptr<SFTPTestServer> sftp_server;
-  std::shared_ptr<core::Processor> generate_flow_file;
-  std::shared_ptr<core::Processor> update_attribute;
-  std::shared_ptr<core::Processor> fetch_sftp;
-  std::shared_ptr<core::Processor> put_file;
+  core::Processor* generate_flow_file;
+  core::Processor* update_attribute;
+  core::Processor* fetch_sftp;
+  core::Processor* put_file;
 };
 
 TEST_CASE_METHOD(FetchSFTPTestsFixture, "FetchSFTP fetch one file", "[FetchSFTP][basic]") {
