@@ -74,9 +74,6 @@ class ListSFTPTestsFixture {
     sftp_server = std::make_unique<SFTPTestServer>(working_directory);
     REQUIRE(true == sftp_server->start());
 
-    if (configuration) {
-      configuration->setHome(working_directory);
-    }
     // Build MiNiFi processing graph
     createPlan(nullptr, configuration);
   }
@@ -95,9 +92,6 @@ class ListSFTPTestsFixture {
     list_sftp = nullptr;
     plan.reset();
 
-    if (configuration) {
-      configuration->setHome(working_directory);
-    }
     plan = testController.createPlan(configuration, state_dir);
     if (list_sftp_uuid == nullptr) {
       list_sftp = plan->addProcessor(
@@ -152,7 +146,7 @@ class ListSFTPTestsFixture {
   }
 
   void createFileWithModificationTimeDiff(const std::filesystem::path& relative_path, const std::string& content, std::chrono::seconds modification_timediff = -5min) const {
-    return createFile(relative_path, content, std::chrono::file_clock::now() + modification_timediff);
+    createFile(relative_path, content, std::chrono::file_clock::now() + modification_timediff);
   }
 
  protected:
@@ -167,7 +161,7 @@ class ListSFTPTestsFixture {
 class PersistentListSFTPTestsFixture : public ListSFTPTestsFixture {
  public:
   PersistentListSFTPTestsFixture() :
-    ListSFTPTestsFixture(std::make_shared<minifi::Configure>()) {
+    ListSFTPTestsFixture(std::make_shared<minifi::ConfigureImpl>()) {
   }
 };
 
@@ -555,7 +549,7 @@ TEST_CASE_METHOD(PersistentListSFTPTestsFixture, "ListSFTP Tracking Timestamps r
 
   utils::Identifier list_sftp_uuid = list_sftp->getUUID();
   REQUIRE(list_sftp_uuid);
-  createPlan(&list_sftp_uuid, std::make_shared<minifi::Configure>());
+  createPlan(&list_sftp_uuid, std::make_shared<minifi::ConfigureImpl>());
   plan->setProperty(list_sftp, "Listing Strategy", "Tracking Timestamps");
   LogTestController::getInstance().clear();
 
@@ -597,7 +591,7 @@ TEST_CASE_METHOD(PersistentListSFTPTestsFixture, "ListSFTP Tracking Timestamps r
 
   utils::Identifier list_sftp_uuid = list_sftp->getUUID();
   REQUIRE(list_sftp_uuid);
-  createPlan(&list_sftp_uuid, std::make_shared<minifi::Configure>());
+  createPlan(&list_sftp_uuid, std::make_shared<minifi::ConfigureImpl>());
   plan->setProperty(list_sftp, "Listing Strategy", "Tracking Timestamps");
   plan->setProperty(list_sftp, "Remote Path", "/nifi_test");
   LogTestController::getInstance().clear();
@@ -836,7 +830,7 @@ TEST_CASE_METHOD(PersistentListSFTPTestsFixture, "ListSFTP Tracking Entities res
 
   utils::Identifier list_sftp_uuid = list_sftp->getUUID();
   REQUIRE(list_sftp_uuid);
-  createPlan(&list_sftp_uuid, std::make_shared<minifi::Configure>());
+  createPlan(&list_sftp_uuid, std::make_shared<minifi::ConfigureImpl>());
   plan->setProperty(list_sftp, "Listing Strategy", "Tracking Entities");
   LogTestController::getInstance().clear();
 
@@ -896,7 +890,7 @@ TEST_CASE_METHOD(PersistentListSFTPTestsFixture, "ListSFTP Tracking Entities res
 
   utils::Identifier list_sftp_uuid = list_sftp->getUUID();
   REQUIRE(list_sftp_uuid);
-  createPlan(&list_sftp_uuid, std::make_shared<minifi::Configure>());
+  createPlan(&list_sftp_uuid, std::make_shared<minifi::ConfigureImpl>());
   plan->setProperty(list_sftp, "Listing Strategy", "Tracking Entities");
   plan->setProperty(list_sftp, "Remote Path", "/nifi_test");
   LogTestController::getInstance().clear();
