@@ -17,8 +17,6 @@
  */
 
 #include <sys/stat.h>
-#undef NDEBUG
-#include <cassert>
 #include <cstring>
 #include <utility>
 #include <chrono>
@@ -34,8 +32,8 @@
 #include <iterator>
 #include <random>
 
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "utils/file/FileUtils.h"
 #include "core/logging/Logger.h"
 #include "core/ProcessGroup.h"
@@ -190,10 +188,10 @@ class ListThenFetchSFTPTestsFixture {
   std::filesystem::path dst_dir = testController.createTempDirectory();
   std::shared_ptr<TestPlan> plan = testController.createPlan();
   std::unique_ptr<SFTPTestServer> sftp_server;
-  std::shared_ptr<core::Processor> list_sftp;
-  std::shared_ptr<core::Processor> fetch_sftp;
-  std::shared_ptr<core::Processor> log_attribute;
-  std::shared_ptr<core::Processor> put_file;
+  core::Processor* list_sftp;
+  core::Processor* fetch_sftp;
+  core::Processor* log_attribute;
+  core::Processor* put_file;
 };
 
 TEST_CASE_METHOD(ListThenFetchSFTPTestsFixture, "ListSFTP then FetchSFTP one file", "[ListThenFetchSFTP][basic]") {
