@@ -17,7 +17,6 @@
  */
 
 #include <sys/stat.h>
-#undef NDEBUG
 #include <cstring>
 #include <utility>
 #include <chrono>
@@ -37,8 +36,8 @@
 #include <unistd.h>
 #endif
 
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "Exception.h"
 #include "date/date.h"
 #include "utils/file/FileUtils.h"
@@ -191,8 +190,8 @@ class PutSFTPTestsFixture {
   std::filesystem::path dst_dir = testController.createTempDirectory();
   std::shared_ptr<TestPlan> plan = testController.createPlan();
   std::unique_ptr<SFTPTestServer> sftp_server;
-  std::shared_ptr<core::Processor> get_file;
-  std::shared_ptr<core::Processor> put;
+  core::Processor* get_file;
+  core::Processor* put;
 };
 
 namespace {
