@@ -23,13 +23,13 @@
 #include <utility>
 
 #include "SmbConnectionControllerService.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/Property.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/OutputAttributeDefinition.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Enum.h"
 #include "utils/ListingStateManager.h"
 #include "utils/file/ListedFile.h"
@@ -37,11 +37,9 @@
 
 namespace org::apache::nifi::minifi::extensions::smb {
 
-class FetchSmb : public core::Processor {
+class FetchSmb final : public core::ProcessorImpl {
  public:
-  explicit FetchSmb(std::string name, const utils::Identifier& uuid = {})
-      : core::Processor(std::move(name), uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Fetches files from a SMB Share. Designed to be used in tandem with ListSmb.";
 
@@ -83,7 +81,7 @@ class FetchSmb : public core::Processor {
 
  private:
   std::shared_ptr<SmbConnectionControllerService> smb_connection_controller_service_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<FetchSmb>::getLogger(uuid_);
+  size_t buffer_size_{};
 };
 
 }  // namespace org::apache::nifi::minifi::extensions::smb
