@@ -21,19 +21,17 @@
 #include <string>
 #include <utility>
 
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "utils/Enum.h"
 #include "SmbConnectionControllerService.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 
 namespace org::apache::nifi::minifi::extensions::smb {
 
-class PutSmb : public core::Processor {
+class PutSmb final : public core::ProcessorImpl {
  public:
-  explicit PutSmb(std::string name,  const utils::Identifier& uuid = {})
-      : core::Processor(std::move(name), uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   enum class FileExistsResolutionStrategy {
     fail,
@@ -88,7 +86,6 @@ class PutSmb : public core::Processor {
   bool create_missing_dirs_ = true;
   FileExistsResolutionStrategy conflict_resolution_strategy_ = FileExistsResolutionStrategy::fail;
   std::shared_ptr<SmbConnectionControllerService> smb_connection_controller_service_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<PutSmb>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::extensions::smb
