@@ -20,18 +20,21 @@
 #include <string>
 #include <memory>
 
-#include "ProcessContext.h"
+#include "Windows.h"
+#include "winnetwk.h"
+
+#include "core/ProcessContext.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/controller/ControllerService.h"
 #include "core/logging/Logger.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Enum.h"
 #include "utils/expected.h"
 
 namespace org::apache::nifi::minifi::extensions::smb {
 
-class SmbConnectionControllerService : public core::controller::ControllerService {
+class SmbConnectionControllerService : public core::controller::ControllerServiceImpl {
  public:
   EXTENSIONAPI static constexpr const char* Description = "SMB Connection Controller Service";
 
@@ -70,7 +73,7 @@ class SmbConnectionControllerService : public core::controller::ControllerServic
   EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
 
-  using ControllerService::ControllerService;
+  using ControllerServiceImpl::ControllerServiceImpl;
 
   void initialize() override;
 
@@ -84,8 +87,6 @@ class SmbConnectionControllerService : public core::controller::ControllerServic
   virtual std::error_code validateConnection();
   virtual std::filesystem::path getPath() const { return server_path_; }
 
-  static gsl::not_null<std::shared_ptr<SmbConnectionControllerService>> getFromProperty(const core::ProcessContext& context, const core::PropertyReference& property);
-
  private:
   nonstd::expected<void, std::error_code> connect();
   nonstd::expected<void, std::error_code> disconnect();
