@@ -33,10 +33,10 @@ using minifi::processors::ReadFromFlowFileTestProcessor;
 TEST_CASE("ListSmb and FetchSmb work together") {
   TestController controller;
   auto plan = controller.createPlan();
-  auto list_smb = dynamic_cast<ListSmb*>(plan->addProcessor("ListSmb", "list_smb"));
-  auto fetch_smb = dynamic_cast<FetchSmb*>(plan->addProcessor("FetchSmb", "fetch_smb"));
-  auto read_from_success_relationship = dynamic_cast<ReadFromFlowFileTestProcessor*>(plan->addProcessor("ReadFromFlowFileTestProcessor", "read_from_success_relationship"));
-  auto read_from_failure_relationship = dynamic_cast<ReadFromFlowFileTestProcessor*>(plan->addProcessor("ReadFromFlowFileTestProcessor", "read_from_failure_relationship"));
+  auto list_smb = plan->addProcessor<ListSmb>("list_smb");
+  auto fetch_smb = plan->addProcessor<ListSmb>("fetch_smb");
+  auto read_from_success_relationship = plan->addProcessor<ReadFromFlowFileTestProcessor>("read_from_success_relationship");
+  auto read_from_failure_relationship = plan->addProcessor<ReadFromFlowFileTestProcessor>("read_from_failure_relationship");
 
   plan->addConnection(list_smb, ListSmb::Success, fetch_smb);
 
@@ -55,7 +55,7 @@ TEST_CASE("ListSmb and FetchSmb work together") {
 
   mock_smb_connection_controller_service->setPath(controller.createTempDirectory());
   constexpr std::string_view content = "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus malesuada elit odio, sit amet viverra ante venenatis eget.";
-  mock_smb_connection_controller_service->addFile("input_dir/sub_dir/b.foo", content, 5min);
+  REQUIRE(mock_smb_connection_controller_service->addFile("input_dir/sub_dir/b.foo", content, 5min));
 
   SECTION("With Input Directory") {
     plan->setProperty(list_smb, ListSmb::InputDirectory, "input_dir");
@@ -65,8 +65,8 @@ TEST_CASE("ListSmb and FetchSmb work together") {
   }
 
   controller.runSession(plan);
-  CHECK(read_from_success_relationship->numberOfFlowFilesRead() == 1);
-  CHECK(read_from_failure_relationship->numberOfFlowFilesRead() == 0);
+  CHECK(read_from_success_relationship.get().numberOfFlowFilesRead() == 1);
+  CHECK(read_from_failure_relationship.get().numberOfFlowFilesRead() == 0);
 }
 
 }  // namespace org::apache::nifi::minifi::extensions::smb::test
