@@ -34,9 +34,7 @@ namespace org::apache::nifi::minifi::extensions::splunk {
 
 class PutSplunkHTTP final : public SplunkHECProcessor {
  public:
-  explicit PutSplunkHTTP(std::string_view name, const utils::Identifier& uuid = {})
-      : SplunkHECProcessor(name, uuid) {
-  }
+  using SplunkHECProcessor::SplunkHECProcessor;
   PutSplunkHTTP(const PutSplunkHTTP&) = delete;
   PutSplunkHTTP(PutSplunkHTTP&&) = delete;
   PutSplunkHTTP& operator=(const PutSplunkHTTP&) = delete;
@@ -109,12 +107,11 @@ class PutSplunkHTTP final : public SplunkHECProcessor {
  private:
   std::string getEndpoint(http::HTTPClient& client);
 
-  std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service_;
+  std::shared_ptr<minifi::controllers::SSLContextServiceInterface> ssl_context_service_;
   std::optional<std::string> source_type_;
   std::optional<std::string> source_;
   std::optional<std::string> host_;
   std::optional<std::string> index_;
-  std::shared_ptr<core::logging::Logger> logger_{core::logging::LoggerFactory<PutSplunkHTTP>::getLogger(uuid_)};
   std::shared_ptr<utils::ResourceQueue<http::HTTPClient>> client_queue_;
 };
 
