@@ -24,7 +24,7 @@
 #include "SplunkHECProcessor.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "utils/ArrayUtils.h"
 #include "utils/gsl.h"
@@ -35,9 +35,7 @@ namespace org::apache::nifi::minifi::extensions::splunk {
 
 class QuerySplunkIndexingStatus final : public SplunkHECProcessor {
  public:
-  explicit QuerySplunkIndexingStatus(std::string_view name, const utils::Identifier& uuid = {})
-      : SplunkHECProcessor(name, uuid) {
-  }
+  using SplunkHECProcessor::SplunkHECProcessor;
   QuerySplunkIndexingStatus(const QuerySplunkIndexingStatus&) = delete;
   QuerySplunkIndexingStatus(QuerySplunkIndexingStatus&&) = delete;
   QuerySplunkIndexingStatus& operator=(const QuerySplunkIndexingStatus&) = delete;
@@ -72,14 +70,14 @@ class QuerySplunkIndexingStatus final : public SplunkHECProcessor {
   EXTENSIONAPI static constexpr auto MaximumWaitingTime = core::PropertyDefinitionBuilder<>::createProperty("Maximum Waiting Time")
       .withDescription("The maximum time the processor tries to acquire acknowledgement confirmation for an index, from the point of registration. "
           "After the given amount of time, the processor considers the index as not acknowledged and transfers the FlowFile to the \"unacknowledged\" relationship.")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("1 hour")
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MaxQuerySize = core::PropertyDefinitionBuilder<>::createProperty("Maximum Query Size")
       .withDescription("The maximum number of acknowledgement identifiers the outgoing query contains in one batch. "
           "It is recommended not to set it too low in order to reduce network communication.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("1000")
       .isRequired(true)
       .build();
@@ -121,7 +119,7 @@ class QuerySplunkIndexingStatus final : public SplunkHECProcessor {
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
 
  protected:
-  uint32_t batch_size_ = 1000;
+  uint64_t batch_size_ = 1000;
   std::chrono::milliseconds max_age_ = std::chrono::hours(1);
   http::HTTPClient client_;
 };
