@@ -20,13 +20,13 @@
 #include <string>
 #include <utility>
 
-#include "controllers/SSLContextService.h"
+#include "controllers/SSLContextServiceInterface.h"
 #include "core/Core.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
 #include "http/HTTPClient.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 
 namespace org::apache::nifi::minifi::extensions::curl {
 class HTTPClient;
@@ -34,7 +34,7 @@ class HTTPClient;
 
 namespace org::apache::nifi::minifi::extensions::splunk {
 
-class SplunkHECProcessor : public core::Processor {
+class SplunkHECProcessor : public core::ProcessorImpl {
  public:
   EXTENSIONAPI static constexpr auto Hostname = core::PropertyDefinitionBuilder<>::createProperty("Hostname")
       .withDescription("The ip address or hostname of the Splunk server.")
@@ -42,7 +42,7 @@ class SplunkHECProcessor : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto Port = core::PropertyDefinitionBuilder<>::createProperty("Port")
       .withDescription("The HTTP Event Collector HTTP Port Number.")
-      .withPropertyType(core::StandardPropertyTypes::PORT_TYPE)
+      .withValidator(core::StandardPropertyValidators::PORT_VALIDATOR)
       .withDefaultValue("8088")
       .isRequired(true)
       .build();
@@ -59,7 +59,7 @@ class SplunkHECProcessor : public core::Processor {
       .withDescription("The SSL Context Service used to provide client certificate information for TLS/SSL (https) connections.")
       .isRequired(false)
       .withExclusiveOfProperties({{{"Hostname", "^http:.*$"}}})
-      .withAllowedTypes<minifi::controllers::SSLContextService>()
+      .withAllowedTypes<minifi::controllers::SSLContextServiceInterface>()
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       Hostname,
@@ -69,10 +69,7 @@ class SplunkHECProcessor : public core::Processor {
       SSLContext
   });
 
-
-  explicit SplunkHECProcessor(std::string_view name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~SplunkHECProcessor() override = default;
 
   void initialize() override;
@@ -80,8 +77,7 @@ class SplunkHECProcessor : public core::Processor {
 
  protected:
   std::string getNetworkLocation() const;
-  std::shared_ptr<minifi::controllers::SSLContextService> getSSLContextService(core::ProcessContext& context) const;
-  void initializeClient(http::HTTPClient& client, const std::string &url, std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service) const;
+  void initializeClient(http::HTTPClient& client, const std::string &url, std::shared_ptr<minifi::controllers::SSLContextServiceInterface> ssl_context_service) const;
 
   std::string token_;
   std::string hostname_;
