@@ -29,10 +29,6 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-PutSQL::PutSQL(std::string_view name, const utils::Identifier& uuid)
-  : SQLProcessor(name, uuid, core::logging::LoggerFactory<PutSQL>::getLogger(uuid)) {
-}
-
 void PutSQL::initialize() {
   setSupportedProperties(Properties);
   setSupportedRelationships(Relationships);
@@ -51,8 +47,8 @@ void PutSQL::processOnTrigger(core::ProcessContext& context, core::ProcessSessio
     return;
   }
 
-  std::string sql_statement;
-  if (!context.getProperty(SQLStatement, sql_statement, flow_file.get())) {
+  std::string sql_statement = context.getProperty(SQLStatement).value_or("");
+  if (sql_statement.empty()) {
     logger_->log_debug("Using the contents of the flow file as the SQL statement");
     sql_statement = to_string(session.readBuffer(flow_file));
   }
