@@ -20,17 +20,19 @@
 
 #pragma once
 
+
+#include <memory>
 #include <string>
-#include <vector>
 #include <unordered_map>
 #include <unordered_set>
-#include <memory>
+#include <vector>
 
+#include "FlowFileSource.h"
+#include "SQLProcessor.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "SQLProcessor.h"
-#include "FlowFileSource.h"
+#include "core/StateManager.h"
 #include "data/SQLColumnIdentifier.h"
 #include "utils/ArrayUtils.h"
 
@@ -38,7 +40,7 @@ namespace org::apache::nifi::minifi::processors {
 
 class QueryDatabaseTable: public SQLProcessor, public FlowFileSource {
  public:
-  explicit QueryDatabaseTable(std::string_view name, const utils::Identifier& uuid = {});
+  using SQLProcessor::SQLProcessor;
 
   EXTENSIONAPI static const std::string RESULT_TABLE_NAME;
   EXTENSIONAPI static const std::string RESULT_ROW_COUNT;
@@ -69,7 +71,8 @@ class QueryDatabaseTable: public SQLProcessor, public FlowFileSource {
         "Using multiple columns implies an order to the column list, and each column's values are expected to increase more slowly than the previous columns' values. "
         "Thus, using multiple columns implies a hierarchical structure of columns, which is usually used for partitioning tables. "
         "This processor can be used to retrieve only those rows that have been added/updated since the last retrieval. "
-        "Note that some ODBC types such as bit/boolean are not conducive to maintaining maximum value, so columns of these types should not be listed in this property, and will result in error(s) during processing. "
+        "Note that some ODBC types such as bit/boolean are not conducive to maintaining maximum value, so columns of these types should not be listed in this property, "
+        "and will result in error(s) during processing. "
         "If no columns are provided, all rows from the table will be considered, which could have a performance impact. "
         "NOTE: It is important to use consistent max-value column names for a given table for incremental fetch to work properly. "
         "NOTE: Because of a limitation of database access library 'soci', which doesn't support milliseconds in it's 'dt_date', "
