@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
-#include "core/logging/LoggerConfiguration.h"
-#include "core/controller/ControllerService.h"
 #include <string>
 #include <memory>
 #include <set>
+
+#include "core/logging/LoggerFactory.h"
+#include "core/controller/ControllerService.h"
 #include "DatabaseService.h"
 #include "io/validation.h"
 #include "properties/Configure.h"
@@ -33,7 +33,7 @@ void DatabaseService::initialize() {
     return;
   }
 
-  ControllerService::initialize();
+  ControllerServiceImpl::initialize();
 
   initializeProperties();
 
@@ -41,7 +41,7 @@ void DatabaseService::initialize() {
 }
 
 void DatabaseService::onEnable() {
-  getProperty(ConnectionString, connection_string_);
+  connection_string_ = getProperty(ConnectionString.name).value_or("");
 }
 
 void DatabaseService::initializeProperties() {
