@@ -16,6 +16,7 @@
  * limitations under the License.
  */
 #include "unit/TestBase.h"
+#include "unit/TestUtils.h"
 #include "unit/Catch.h"
 #include "SQLTestController.h"
 
@@ -28,7 +29,7 @@
 TEST_CASE("Test Creation of PutSQL", "[PutSQLCreate]") {
   TestController testController;
   std::shared_ptr<core::Processor>
-      processor = std::make_shared<org::apache::nifi::minifi::processors::PutSQL>("processorname");
+      processor = minifi::test::utils::make_processor<org::apache::nifi::minifi::processors::PutSQL>("processorname");
   REQUIRE(processor->getName() == "processorname");
 }
 
@@ -42,9 +43,9 @@ TEST_CASE("Statement from processor property") {
     {"sql.args.1.value", "42"},
   });
 
-  sql_proc->setProperty(
+  REQUIRE(sql_proc->setProperty(
       "SQL Statement",
-      "INSERT INTO test_table (int_col, text_col) VALUES (?, 'asdf')");
+      "INSERT INTO test_table (int_col, text_col) VALUES (?, 'asdf')"));
 
   plan->run();
 
@@ -98,9 +99,9 @@ TEST_CASE("PutSQL routes to failure on malformed statement") {
 //    });
 //  }
 
-  sql_proc->setProperty(
+  REQUIRE(sql_proc->setProperty(
       "SQL Statement",
-      "INSERT INTO test_table (int_col, text_col) VALUES (?, 'asdf')");
+      "INSERT INTO test_table (int_col, text_col) VALUES (?, 'asdf')"));
 
   plan->run();
 
