@@ -27,24 +27,22 @@
 #include <utility>
 
 #include "core/Property.h"
-#include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
+#include "core/ProcessContext.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/Core.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Export.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class AppendHostInfo : public core::Processor {
+class AppendHostInfo : public core::ProcessorImpl {
  public:
   static constexpr const char* REFRESH_POLICY_ON_TRIGGER = "On every trigger";
   static constexpr const char* REFRESH_POLICY_ON_SCHEDULE = "On schedule";
 
-  explicit AppendHostInfo(std::string_view name, const utils::Identifier& uuid = {})
-      : core::Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~AppendHostInfo() override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "Appends host information such as IP address and hostname as an attribute to incoming flowfiles.";
@@ -55,10 +53,12 @@ class AppendHostInfo : public core::Processor {
   EXTENSIONAPI static constexpr auto HostAttribute = core::PropertyDefinitionBuilder<>::createProperty("Hostname Attribute")
       .withDescription("Flowfile attribute used to record the agent's hostname")
       .withDefaultValue("source.hostname")
+      .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto IPAttribute = core::PropertyDefinitionBuilder<>::createProperty("IP Attribute")
       .withDescription("Flowfile attribute used to record the agent's IP addresses in a comma separated list")
       .withDefaultValue("source.ipv4")
+      .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto RefreshPolicy = core::PropertyDefinitionBuilder<2>::createProperty("Refresh Policy")
       .withDescription("When to recalculate the host info")
@@ -92,7 +92,6 @@ class AppendHostInfo : public core::Processor {
 
  private:
   std::shared_mutex shared_mutex_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<AppendHostInfo>::getLogger(uuid_);
   std::string hostname_attribute_name_;
   std::string ipaddress_attribute_name_;
   std::optional<std::regex> interface_name_filter_;
