@@ -29,11 +29,11 @@
 
 #include "rapidjson/document.h"
 #include "core/FlowFile.h"
-#include "core/logging/LoggerConfiguration.h"
-#include "core/Processor.h"
+#include "core/logging/LoggerFactory.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "io/StreamPipe.h"
 #include "utils/Enum.h"
@@ -64,7 +64,7 @@ constexpr customize_t enum_name<WriteDestination>(WriteDestination value) noexce
 
 namespace org::apache::nifi::minifi::processors {
 
-class AttributesToJSON : public core::Processor {
+class AttributesToJSON : public core::ProcessorImpl {
  public:
   EXTENSIONAPI static constexpr const char* Description = "Generates a JSON representation of the input FlowFile Attributes. "
       "The resulting JSON can be written to either a new Attribute 'JSONAttributes' or written to the FlowFile as content.";
@@ -73,10 +73,12 @@ class AttributesToJSON : public core::Processor {
       .withDescription("Comma separated list of attributes to be included in the resulting JSON. "
           "If this value is left empty then all existing Attributes will be included. This list of attributes is case sensitive. "
           "If an attribute specified in the list is not found it will be be emitted to the resulting JSON with an empty string or NULL value.")
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto AttributesRegularExpression = core::PropertyDefinitionBuilder<>::createProperty("Attributes Regular Expression")
       .withDescription("Regular expression that will be evaluated against the flow file attributes to select the matching attributes. "
           "Both the matching attributes and the selected attributes from the Attributes List property will be written in the resulting JSON.")
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto Destination = core::PropertyDefinitionBuilder<2>::createProperty("Destination")
       .withDescription("Control if JSON value is written as a new flowfile attribute 'JSONAttributes' or written in the flowfile content. "
@@ -88,13 +90,13 @@ class AttributesToJSON : public core::Processor {
   EXTENSIONAPI static constexpr auto IncludeCoreAttributes = core::PropertyDefinitionBuilder<>::createProperty("Include Core Attributes")
       .withDescription("Determines if the FlowFile core attributes which are contained in every FlowFile should be included in the final JSON value generated.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto NullValue = core::PropertyDefinitionBuilder<>::createProperty("Null Value")
       .withDescription("If true a non existing selected attribute will be NULL in the resulting JSON. If false an empty string will be placed in the JSON.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
@@ -116,9 +118,7 @@ class AttributesToJSON : public core::Processor {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit AttributesToJSON(std::string_view name, const utils::Identifier& uuid = {})
-      : core::Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   void initialize() override;
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
@@ -130,7 +130,6 @@ class AttributesToJSON : public core::Processor {
   void addAttributeToJson(rapidjson::Document& document, const std::string& key, const std::optional<std::string>& value) const;
   std::string buildAttributeJsonData(const core::FlowFile::AttributeMap& flowfile_attributes);
 
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<AttributesToJSON>::getLogger(uuid_);
   std::vector<std::string> attribute_list_;
   std::optional<utils::Regex> attributes_regular_expression_;
   attributes_to_json::WriteDestination write_destination_;
