@@ -23,10 +23,10 @@
 #include <unordered_map>
 #include <utility>
 
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/FlowFileStore.h"
 #include "core/logging/Logger.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "utils/Enum.h"
@@ -57,11 +57,9 @@ constexpr customize_t enum_name<PatternLocation>(PatternLocation value) noexcept
 
 namespace org::apache::nifi::minifi::processors {
 
-class DefragmentText : public core::Processor {
+class DefragmentText : public core::ProcessorImpl {
  public:
-  explicit DefragmentText(std::string_view name,  const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "DefragmentText splits and merges incoming flowfiles so cohesive messages are not split between them. "
       "It can handle multiple inputs differentiated by the absolute.path flow file attribute.";
@@ -69,6 +67,7 @@ class DefragmentText : public core::Processor {
   EXTENSIONAPI static constexpr auto Pattern = core::PropertyDefinitionBuilder<>::createProperty("Pattern")
       .withDescription("A regular expression to match at the start or end of messages.")
       .isRequired(true)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto PatternLoc = core::PropertyDefinitionBuilder<magic_enum::enum_count<defragment_text::PatternLocation>()>::createProperty("Pattern Location")
       .withDescription("Whether the pattern is located at the start or at the end of the messages.")
@@ -79,12 +78,12 @@ class DefragmentText : public core::Processor {
   EXTENSIONAPI static constexpr auto MaxBufferAge = core::PropertyDefinitionBuilder<>::createProperty("Max Buffer Age")
       .withDescription("The maximum age of the buffer after which it will be transferred to success when matching Start of Message patterns or to failure when matching End of Message patterns. "
           "Expected format is <duration> <time unit>")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("10 min")
       .build();
   EXTENSIONAPI static constexpr auto MaxBufferSize = core::PropertyDefinitionBuilder<>::createProperty("Max Buffer Size")
       .withDescription("The maximum buffer size, if the buffer exceeds this, it will be transferred to failure. Expected format is <size> <data unit>")
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       Pattern,
@@ -114,7 +113,6 @@ class DefragmentText : public core::Processor {
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void restore(const std::shared_ptr<core::FlowFile>& flowFile) override;
-  std::set<core::Connectable*> getOutGoingConnections(const std::string &relationship) override;
 
  protected:
   class Buffer {
@@ -156,7 +154,6 @@ class DefragmentText : public core::Processor {
   std::optional<std::chrono::milliseconds> max_age_;
   std::optional<size_t> max_size_;
 
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<DefragmentText>::getLogger(uuid_);
   core::FlowFileStore flow_file_store_;
   std::unordered_map<FragmentSource::Id, FragmentSource, FragmentSource::Id::hash> fragment_sources_;
 
