@@ -20,6 +20,7 @@
 #include <filesystem>
 #include <utility>
 
+#include "utils/ConfigurationUtils.h"
 #include "utils/ProcessorConfigUtils.h"
 #include "utils/file/FileReaderCallback.h"
 #include "utils/file/FileUtils.h"
@@ -34,19 +35,18 @@ void FetchFile::initialize() {
 
 void FetchFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory &) {
   completion_strategy_ = utils::parseEnumProperty<fetch_file::CompletionStrategyOption>(context, CompletionStrategy);
-  std::string move_destination_dir;
-  context.getProperty(MoveDestinationDirectory, move_destination_dir);
+  const std::string move_destination_dir = context.getProperty(MoveDestinationDirectory).value_or("");
   if (completion_strategy_ == fetch_file::CompletionStrategyOption::MOVE_FILE && move_destination_dir.empty()) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Move Destination Directory is required when Completion Strategy is set to Move File");
   }
   move_conflict_strategy_ = utils::parseEnumProperty<fetch_file::MoveConflictStrategyOption>(context, MoveConflictStrategy);
   log_level_when_file_not_found_ = utils::parseEnumProperty<utils::LogUtils::LogLevelOption>(context, LogLevelWhenFileNotFound);
   log_level_when_permission_denied_ = utils::parseEnumProperty<utils::LogUtils::LogLevelOption>(context, LogLevelWhenPermissionDenied);
+  buffer_size_ = utils::configuration::getBufferSize(*context.getConfiguration());
 }
 
 std::filesystem::path FetchFile::getFileToFetch(core::ProcessContext& context, const std::shared_ptr<core::FlowFile>& flow_file) {
-  std::string file_to_fetch_path;
-  context.getProperty(FileToFetch, file_to_fetch_path, flow_file.get());
+  std::string file_to_fetch_path = context.getProperty(FileToFetch, flow_file.get()).value_or("");
   if (!file_to_fetch_path.empty()) {
     return file_to_fetch_path;
   }
@@ -132,8 +132,7 @@ void FetchFile::onTrigger(core::ProcessContext& context, core::ProcessSession& s
 
   auto file_name = file_to_fetch_path.filename();
 
-  std::string move_destination_directory_str;
-  context.getProperty(MoveDestinationDirectory, move_destination_directory_str, flow_file.get());
+  std::string move_destination_directory_str = context.getProperty(MoveDestinationDirectory, flow_file.get()).value_or("");
   std::filesystem::path move_destination_directory = move_destination_directory_str;
   if (moveWouldFailWithDestinationConflict(move_destination_directory, file_name)) {
     logger_->log_error("Move destination ({}) conflicts with an already existing file!", move_destination_directory);
@@ -142,7 +141,7 @@ void FetchFile::onTrigger(core::ProcessContext& context, core::ProcessSession& s
   }
 
   try {
-    utils::FileReaderCallback callback(file_to_fetch_path);
+    utils::FileReaderCallback callback(file_to_fetch_path, buffer_size_);
     session.write(flow_file, std::move(callback));
     logger_->log_debug("Fetching file '{}' successful!", file_to_fetch_path);
     session.transfer(flow_file, Success);
