@@ -20,13 +20,13 @@
 #include <string>
 #include <utility>
 
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/RelationshipDefinition.h"
 #include "utils/Enum.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/LogUtils.h"
 
 namespace org::apache::nifi::minifi::processors::fetch_file {
@@ -82,11 +82,9 @@ constexpr customize_t enum_name<MoveConflictStrategyOption>(MoveConflictStrategy
 
 namespace org::apache::nifi::minifi::processors {
 
-class FetchFile final : public core::Processor {
+class FetchFile final : public core::ProcessorImpl {
  public:
-  explicit FetchFile(const std::string_view name, const utils::Identifier& uuid = {})
-    : core::Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Reads the contents of a file from disk and streams it into the contents of an incoming FlowFile. "
       "Once this is done, the file is optionally moved elsewhere or deleted to help keep the file system organized.";
@@ -176,7 +174,7 @@ class FetchFile final : public core::Processor {
   fetch_file::MoveConflictStrategyOption move_conflict_strategy_{};
   utils::LogUtils::LogLevelOption log_level_when_file_not_found_{};
   utils::LogUtils::LogLevelOption log_level_when_permission_denied_{};
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<FetchFile>::getLogger(uuid_);
+  size_t buffer_size_{};
 };
 
 }  // namespace org::apache::nifi::minifi::processors
