@@ -24,12 +24,12 @@
 #include <utility>
 #include <vector>
 
-#include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
+#include "core/ProcessContext.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "core/Core.h"
 #include "utils/gsl.h"
@@ -37,11 +37,9 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-class GenerateFlowFile : public core::Processor {
+class GenerateFlowFile : public core::ProcessorImpl {
  public:
-  explicit GenerateFlowFile(const std::string_view name, const utils::Identifier& uuid = {}) // NOLINT
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~GenerateFlowFile() override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "This processor creates FlowFiles with random data or custom content. "
@@ -50,13 +48,13 @@ class GenerateFlowFile : public core::Processor {
   EXTENSIONAPI static constexpr auto FileSize = core::PropertyDefinitionBuilder<>::createProperty("File Size")
       .withDescription("The size of the file that will be used")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .withDefaultValue("1 kB")
       .build();
   EXTENSIONAPI static constexpr auto BatchSize = core::PropertyDefinitionBuilder<>::createProperty("Batch Size")
       .withDescription("The number of FlowFiles to be transferred in each invocation")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::INTEGER_TYPE)
+      .withValidator(core::StandardPropertyValidators::INTEGER_VALIDATOR)
       .withDefaultValue("1")
       .build();
   EXTENSIONAPI static constexpr auto DataFormat = core::PropertyDefinitionBuilder<2>::createProperty("Data Format")
@@ -70,7 +68,7 @@ class GenerateFlowFile : public core::Processor {
           "If false, a random value will be generated and all FlowFiles will get the same content but this offers much higher throughput "
           "(but see the description of Custom Text for special non-random use cases)")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto CustomText = core::PropertyDefinitionBuilder<>::createProperty("Custom Text")
@@ -124,8 +122,6 @@ class GenerateFlowFile : public core::Processor {
   static Mode getMode(bool is_unique, bool is_text, bool has_custom_text, uint64_t file_size);
   static bool isUnique(Mode mode) { return mode == Mode::UniqueText || mode == Mode::UniqueByte; }
   static bool isText(Mode mode) { return mode == Mode::UniqueText || mode == Mode::CustomText || mode == Mode::NotUniqueText; }
-
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<GenerateFlowFile>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
