@@ -17,19 +17,23 @@
  */
 #include "GetFile.h"
 
-#include <queue>
+
 #include <memory>
+#include <queue>
 #include <string>
 
-#include "utils/StringUtils.h"
-#include "utils/file/FileUtils.h"
-#include "utils/TimeUtil.h"
+#include "ListFile.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/Resource.h"
 #include "core/TypedValues.h"
-#include "utils/file/FileReaderCallback.h"
 #include "utils/RegexUtils.h"
+#include "utils/StringUtils.h"
+#include "utils/TimeUtil.h"
+#include "utils/ConfigurationUtils.h"
+#include "utils/file/FileReaderCallback.h"
+#include "utils/file/FileUtils.h"
+#include "utils/ProcessorConfigUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -41,40 +45,18 @@ void GetFile::initialize() {
 }
 
 void GetFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
-  std::string value;
-  if (context.getProperty(BatchSize, value)) {
-    core::Property::StringToInt(value, request_.batchSize);
-  }
-  if (context.getProperty(IgnoreHiddenFile, value)) {
-    request_.ignoreHiddenFile = org::apache::nifi::minifi::utils::string::toBool(value).value_or(true);
-  }
-  if (context.getProperty(KeepSourceFile, value)) {
-    request_.keepSourceFile = org::apache::nifi::minifi::utils::string::toBool(value).value_or(false);
-  }
+  buffer_size_ = utils::configuration::getBufferSize(*context.getConfiguration());
 
-  if (auto max_age = context.getProperty<core::TimePeriodValue>(MaxAge))
-    request_.maxAge = max_age->getMilliseconds();
-  if (auto min_age = context.getProperty<core::TimePeriodValue>(MinAge))
-    request_.minAge = min_age->getMilliseconds();
-
-  if (context.getProperty(MaxSize, value)) {
-    core::Property::StringToInt(value, request_.maxSize);
-  }
-  if (context.getProperty(MinSize, value)) {
-    core::Property::StringToInt(value, request_.minSize);
-  }
-
-  if (const auto poll_interval = context.getProperty<core::TimePeriodValue>(PollInterval)) {
-    request_.pollInterval = poll_interval->getMilliseconds();
-  }
-
-  if (context.getProperty(Recurse, value)) {
-    request_.recursive = org::apache::nifi::minifi::utils::string::toBool(value).value_or(true);
-  }
-
-  if (context.getProperty(FileFilter, value)) {
-    request_.fileFilter = value;
-  }
+  request_.batchSize = utils::parseU64Property(context, BatchSize);
+  request_.ignoreHiddenFile = utils::parseBoolProperty(context, IgnoreHiddenFile);
+  request_.keepSourceFile = utils::parseBoolProperty(context, KeepSourceFile);
+  request_.maxAge = utils::parseDurationProperty(context, MaxAge);
+  request_.minAge = utils::parseDurationProperty(context, MinAge);
+  request_.maxSize = utils::parseDataSizeProperty(context, MaxSize);
+  request_.minSize = utils::parseDataSizeProperty(context, MinSize);
+  request_.pollInterval = utils::parseDurationProperty(context, PollInterval);
+  request_.recursive = utils::parseBoolProperty(context, Recurse);
+  request_.fileFilter = utils::parseProperty(context, FileFilter);
 
   if (auto directory_str = context.getProperty(Directory, nullptr)) {
     if (!utils::file::is_directory(*directory_str)) {
@@ -86,7 +68,7 @@ void GetFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFact
   }
 }
 
-void GetFile::onTrigger(core::ProcessContext&, core::ProcessSession& session) {
+void GetFile::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   const bool is_dir_empty_before_poll = isListingEmpty();
   logger_->log_debug("Listing is {} before polling directory", is_dir_empty_before_poll ? "empty" : "not empty");
   if (is_dir_empty_before_poll) {
@@ -99,7 +81,7 @@ void GetFile::onTrigger(core::ProcessContext&, core::ProcessSession& session) {
   const bool is_dir_empty_after_poll = isListingEmpty();
   logger_->log_debug("Listing is {} after polling directory", is_dir_empty_after_poll ? "empty" : "not empty");
   if (is_dir_empty_after_poll) {
-    yield();
+    context.yield();
     return;
   }
 
@@ -122,7 +104,7 @@ void GetFile::getSingleFile(core::ProcessSession& session, const std::filesystem
   flow_file->setAttribute(core::SpecialFlowAttribute::PATH, (relative_path / "").string());
 
   try {
-    session.write(flow_file, utils::FileReaderCallback{file_path});
+    session.write(flow_file, utils::FileReaderCallback{file_path, buffer_size_});
     session.transfer(flow_file, Success);
     if (!request_.keepSourceFile) {
       std::error_code remove_error;
@@ -196,7 +178,8 @@ bool GetFile::fileMatchesRequestCriteria(const std::filesystem::path& full_name,
     return false;
   }
 
-  auto* const getfile_metrics = static_cast<GetFileMetrics*>(metrics_.get());
+  auto* const getfile_metrics = dynamic_cast<GetFileMetrics*>(metrics_.get());
+  gsl_Assert(getfile_metrics);
   getfile_metrics->input_bytes += file_size;
   ++getfile_metrics->accepted_files;
   return true;
@@ -208,7 +191,7 @@ void GetFile::performListing(const GetFileRequest &request) {
     if (fileMatchesRequestCriteria(fullpath, filename, request)) {
       putListing(fullpath);
     }
-    return isRunning();
+    return true;
   };
   utils::file::list_dir(request.inputDirectory, callback, logger_, request.recursive);
 }
