@@ -17,19 +17,20 @@
  */
 #include "GetTCP.h"
 
-#include <memory>
-#include <thread>
-#include <string>
 
-#include <asio/read_until.hpp>
-#include <asio/detached.hpp>
-#include "utils/net/AsioCoro.h"
-#include "utils/gsl.h"
-#include "utils/StringUtils.h"
+#include <memory>
+#include <string>
+#include <thread>
+
+#include "asio/detached.hpp"
+#include "asio/read_until.hpp"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
-#include "core/ProcessSessionFactory.h"
 #include "core/Resource.h"
+#include "utils/StringUtils.h"
+#include "utils/gsl.h"
+#include "utils/net/AsioCoro.h"
+#include "utils/ProcessorConfigUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -70,50 +71,35 @@ char GetTCP::parseDelimiter(core::ProcessContext& context) {
   return delimiter;
 }
 
-std::optional<asio::ssl::context> GetTCP::parseSSLContext(core::ProcessContext& context) const {
-  std::optional<asio::ssl::context> ssl_context;
-  if (auto context_name = context.getProperty(SSLContextService)) {
-    if (auto controller_service = context.getControllerService(*context_name, getUUID())) {
-      if (auto ssl_context_service = std::dynamic_pointer_cast<minifi::controllers::SSLContextService>(context.getControllerService(*context_name, getUUID()))) {
-        ssl_context = utils::net::getSslContext(*ssl_context_service);
-      } else {
-        throw Exception(PROCESS_SCHEDULE_EXCEPTION, *context_name + " is not an SSL Context Service");
-      }
-    } else {
-      throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Invalid controller service: " + *context_name);
-    }
-  }
-  return ssl_context;
-}
-
 uint64_t GetTCP::parseMaxBatchSize(core::ProcessContext& context) {
-  if (auto max_batch_size = context.getProperty<uint64_t>(MaxBatchSize)) {
-    if (*max_batch_size == 0) {
-      throw Exception(PROCESS_SCHEDULE_EXCEPTION, fmt::format("{} should be non-zero.", MaxBatchSize.name));
-    }
-    return *max_batch_size;
+  const auto max_batch_size = utils::parseU64Property(context, MaxBatchSize);
+  if (max_batch_size == 0) {
+    throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Max batch size must be greater than zero");
   }
-  static_assert(MaxBatchSize.default_value);
-  return MaxBatchSize.type->parse(*MaxBatchSize.default_value);
+  return max_batch_size;
 }
 
 void GetTCP::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
   auto connections_to_make = parseEndpointList(context);
   auto delimiter = parseDelimiter(context);
-  auto ssl_context = parseSSLContext(context);
-
-  std::optional<size_t> max_queue_size = context.getProperty<uint64_t>(MaxQueueSize);
-  std::optional<size_t> max_message_size = context.getProperty<uint64_t>(MaxMessageSize);
+  auto ssl_context = [&]() -> std::optional<asio::ssl::context> {
+    if (auto ssl_context_service = utils::parseOptionalControllerService<minifi::controllers::SSLContextServiceInterface>(context, SSLContextService, getUUID())) {
+      return {utils::net::getSslContext(*ssl_context_service)};
+    }
+    return std::nullopt;
+  }();
 
+  std::optional<size_t> max_queue_size = utils::parseOptionalU64Property(context, MaxQueueSize);
+  std::optional<size_t> max_message_size = utils::parseOptionalU64Property(context, MaxMessageSize);
 
   asio::steady_timer::duration timeout_duration = 1s;
-  if (auto timeout_value = context.getProperty<core::TimePeriodValue>(Timeout)) {
-    timeout_duration = timeout_value->getMilliseconds();
+  if (auto timeout_value = utils::parseOptionalDurationProperty(context, Timeout)) {
+    timeout_duration = *timeout_value;
   }
 
   asio::steady_timer::duration reconnection_interval = 1min;
-  if (auto reconnect_interval_value = context.getProperty<core::TimePeriodValue>(ReconnectInterval)) {
-    reconnection_interval = reconnect_interval_value->getMilliseconds();
+  if (auto reconnect_interval_value = utils::parseOptionalDurationProperty(context, ReconnectInterval)) {
+    reconnection_interval = *reconnect_interval_value;;
   }
 
 
