@@ -26,19 +26,17 @@
 #include <asio/io_context.hpp>
 #include "utils/Literals.h"
 
-#include "../core/state/nodes/MetricsBase.h"
-#include "FlowFileRecord.h"
-#include "core/OutputAttributeDefinition.h"
-#include "core/Processor.h"
+#include "minifi-cpp/core/OutputAttributeDefinition.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/Core.h"
 #include "concurrentqueue.h"
 #include "utils/ThreadPool.h"
-#include "core/logging/LoggerConfiguration.h"
-#include "controllers/SSLContextService.h"
+#include "core/logging/LoggerFactory.h"
+#include "controllers/SSLContextServiceInterface.h"
 #include "utils/gsl.h"
 #include "utils/Export.h"
 #include "utils/net/AsioSocketUtils.h"
@@ -46,11 +44,9 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-class GetTCP : public core::Processor {
+class GetTCP : public core::ProcessorImpl {
  public:
-  explicit GetTCP(std::string_view name, const utils::Identifier& uuid = {})
-    : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   ~GetTCP() override {
     if (client_) {
@@ -70,7 +66,7 @@ class GetTCP : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto SSLContextService = core::PropertyDefinitionBuilder<>::createProperty("SSL Context Service")
       .withDescription("SSL Context Service Name")
-      .withAllowedTypes<minifi::controllers::SSLContextService>()
+      .withAllowedTypes<minifi::controllers::SSLContextServiceInterface>()
       .build();
   EXTENSIONAPI static constexpr auto MessageDelimiter = core::PropertyDefinitionBuilder<>::createProperty("Message Delimiter")
       .withDescription("Character that denotes the end of the message.")
@@ -79,13 +75,13 @@ class GetTCP : public core::Processor {
   EXTENSIONAPI static constexpr auto MaxQueueSize = core::PropertyDefinitionBuilder<>::createProperty("Max Size of Message Queue")
       .withDescription("Maximum number of messages allowed to be buffered before processing them when the processor is triggered. "
           "If the buffer is full, the message is ignored. If set to zero the buffer is unlimited.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("10000")
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MaxBatchSize = core::PropertyDefinitionBuilder<>::createProperty("Max Batch Size")
       .withDescription("The maximum number of messages to process at a time.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("500")
       .isRequired(true)
       .build();
@@ -94,17 +90,15 @@ class GetTCP : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto Timeout = core::PropertyDefinitionBuilder<>::createProperty("Timeout")
       .withDescription("The timeout for connecting to and communicating with the destination.")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("1s")
       .isRequired(true)
-      .supportsExpressionLanguage(true)
       .build();
   EXTENSIONAPI static constexpr auto ReconnectInterval = core::PropertyDefinitionBuilder<>::createProperty("Reconnection Interval")
       .withDescription("The duration to wait before attempting to reconnect to the endpoints.")
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("1 min")
       .isRequired(true)
-      .supportsExpressionLanguage(true)
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       EndpointList,
@@ -141,7 +135,6 @@ class GetTCP : public core::Processor {
 
   std::vector<utils::net::ConnectionId> parseEndpointList(core::ProcessContext& context);
   static char parseDelimiter(core::ProcessContext& context);
-  std::optional<asio::ssl::context> parseSSLContext(core::ProcessContext& context) const;
   static uint64_t parseMaxBatchSize(core::ProcessContext& context);
 
   class TcpClient {
@@ -187,7 +180,6 @@ class GetTCP : public core::Processor {
   std::optional<TcpClient> client_;
   size_t max_batch_size_{500};
   std::thread client_thread_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<GetTCP>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
