@@ -19,7 +19,8 @@
 
 #include <string>
 
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
+#include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
@@ -35,11 +36,9 @@ enum class JoltTransform {
 
 namespace org::apache::nifi::minifi::processors {
 
-class JoltTransformJSON : public core::Processor {
+class JoltTransformJSON : public core::ProcessorImpl {
  public:
-  explicit JoltTransformJSON(std::string_view name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {}
-
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Applies a list of Jolt specifications to the flowfile JSON payload. A new FlowFile is created "
       "with transformed content and is routed to the 'success' relationship. If the JSON transform "
@@ -84,7 +83,6 @@ class JoltTransformJSON : public core::Processor {
  private:
   jolt_transform_json::JoltTransform transform_;
   std::optional<utils::jolt::Spec> spec_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<JoltTransformJSON>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
