@@ -23,12 +23,13 @@
 #include <memory>
 #include <regex>
 
+#include "controllers/SSLContextServiceInterface.h"
 #include "NetworkListenerProcessor.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "core/OutputAttributeDefinition.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "utils/net/Ssl.h"
 
@@ -36,9 +37,7 @@ namespace org::apache::nifi::minifi::processors {
 
 class ListenSyslog : public NetworkListenerProcessor {
  public:
-  explicit ListenSyslog(std::string_view name, const utils::Identifier& uuid = {})
-      : NetworkListenerProcessor(name, uuid, core::logging::LoggerFactory<ListenSyslog>::getLogger(uuid)) {
-  }
+  using NetworkListenerProcessor::NetworkListenerProcessor;
 
   EXTENSIONAPI static constexpr const char* Description = "Listens for Syslog messages being sent to a given port over TCP or UDP. "
       "Incoming messages are optionally checked against regular expressions for RFC5424 and RFC3164 formatted messages. "
@@ -49,7 +48,7 @@ class ListenSyslog : public NetworkListenerProcessor {
   EXTENSIONAPI static constexpr auto Port = core::PropertyDefinitionBuilder<>::createProperty("Listening Port")
       .withDescription("The port for Syslog communication. (Well-known ports (0-1023) require root access)")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::LISTEN_PORT_TYPE)
+      .withValidator(core::StandardPropertyValidators::PORT_VALIDATOR)
       .withDefaultValue("514")
       .build();
   EXTENSIONAPI static constexpr auto ProtocolProperty = core::PropertyDefinitionBuilder<magic_enum::enum_count<utils::net::IpProtocol>()>::createProperty("Protocol")
@@ -60,25 +59,25 @@ class ListenSyslog : public NetworkListenerProcessor {
       .build();
   EXTENSIONAPI static constexpr auto MaxBatchSize = core::PropertyDefinitionBuilder<>::createProperty("Max Batch Size")
       .withDescription("The maximum number of Syslog events to process at a time.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("500")
       .build();
   EXTENSIONAPI static constexpr auto ParseMessages = core::PropertyDefinitionBuilder<>::createProperty("Parse Messages")
       .withDescription("Indicates if the processor should parse the Syslog messages. "
           "If set to false, each outgoing FlowFile will only contain the sender, protocol, and port, and no additional attributes.")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto MaxQueueSize = core::PropertyDefinitionBuilder<>::createProperty("Max Size of Message Queue")
       .withDescription("Maximum number of Syslog messages allowed to be buffered before processing them when the processor is triggered. "
           "If the buffer is full, the message is ignored. If set to zero the buffer is unlimited.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("10000")
       .build();
   EXTENSIONAPI static constexpr auto SSLContextService = core::PropertyDefinitionBuilder<>::createProperty("SSL Context Service")
       .withDescription("The Controller Service to use in order to obtain an SSL Context. If this property is set, messages will be received over a secure connection. "
           "This Property is only considered if the <Protocol> Property has a value of \"TCP\".")
-      .withAllowedTypes<minifi::controllers::SSLContextService>()
+      .withAllowedTypes<minifi::controllers::SSLContextServiceInterface>()
       .build();
   EXTENSIONAPI static constexpr auto ClientAuth = core::PropertyDefinitionBuilder<magic_enum::enum_count<utils::net::ClientAuthOption>()>::createProperty("Client Auth")
       .withDescription("The client authentication policy to use for the SSL Context. Only used if an SSL Context Service is provided.")
