@@ -24,25 +24,26 @@
 #include <utility>
 #include <vector>
 
-#include "FlowFileRecord.h"
 #include "core/Core.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
+#include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Export.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class LogAttribute : public core::Processor {
+class LogAttribute : public core::ProcessorImpl {
  public:
-  explicit LogAttribute(const std::string_view name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
+  explicit LogAttribute(core::ProcessorMetadata metadata)
+      : ProcessorImpl(metadata) {
     logger_->set_max_log_size(-1);
   }
+
   ~LogAttribute() override = default;
 
   EXTENSIONAPI static constexpr const char* Description = "Logs attributes of flow files in the MiNiFi application log.";
@@ -53,31 +54,34 @@ class LogAttribute : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto AttributesToLog = core::PropertyDefinitionBuilder<>::createProperty("Attributes to Log")
       .withDescription("A comma-separated list of Attributes to Log. If not specified, all attributes will be logged.")
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto AttributesToIgnore = core::PropertyDefinitionBuilder<>::createProperty("Attributes to Ignore")
       .withDescription("A comma-separated list of Attributes to ignore. If not specified, no attributes will be ignored.")
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto LogPayload = core::PropertyDefinitionBuilder<>::createProperty("Log Payload")
       .withDescription("If true, the FlowFile's payload will be logged, in addition to its attributes. Otherwise, just the Attributes will be logged.")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto HexencodePayload = core::PropertyDefinitionBuilder<>::createProperty("Hexencode Payload")
       .withDescription("If true, the FlowFile's payload will be logged in a hexencoded format")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto MaxPayloadLineLength = core::PropertyDefinitionBuilder<>::createProperty("Maximum Payload Line Length")
       .withDescription("The logged payload will be broken into lines this long. 0 means no newlines will be added.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_INT_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("0")
       .build();
   EXTENSIONAPI static constexpr auto LogPrefix = core::PropertyDefinitionBuilder<>::createProperty("Log Prefix")
       .withDescription("Log prefix appended to the log lines. It helps to distinguish the output of multiple LogAttribute processors.")
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto FlowFilesToLog = core::PropertyDefinitionBuilder<>::createProperty("FlowFiles To Log")
       .withDescription("Number of flow files to log. If set to zero all flow files will be logged. Please note that this may block other threads from running if not used judiciously.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("1")
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
@@ -111,8 +115,7 @@ class LogAttribute : public core::Processor {
 
   uint64_t flowfiles_to_log_{1};
   bool hexencode_{false};
-  uint32_t max_line_length_{80};
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<LogAttribute>::getLogger(uuid_);
+  uint64_t max_line_length_{80};
   core::logging::LOG_LEVEL log_level_{core::logging::LOG_LEVEL::info};
   std::string dash_line_ = "--------------------------------------------------";
   bool log_payload_ = false;
