@@ -20,7 +20,7 @@
 #include <string>
 #include <utility>
 
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/logging/Logger.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
@@ -29,12 +29,9 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-class NetworkListenerProcessor : public core::Processor {
+class NetworkListenerProcessor : public core::ProcessorImpl {
  public:
-  NetworkListenerProcessor(std::string_view name, const utils::Identifier& uuid, std::shared_ptr<core::logging::Logger> logger)
-    : core::Processor(name, uuid),
-      logger_(std::move(logger)) {
-  }
+  using ProcessorImpl::ProcessorImpl;
   ~NetworkListenerProcessor() override;
 
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
@@ -50,7 +47,7 @@ class NetworkListenerProcessor : public core::Processor {
     stopServer();
   }
 
-  uint16_t getPort() {
+  uint16_t getPort() const {
     if (server_)
       return server_->getPort();
     return 0;
@@ -64,13 +61,10 @@ class NetworkListenerProcessor : public core::Processor {
       std::string delimiter);
   void startUdpServer(const core::ProcessContext& context);
 
- protected:
-  std::shared_ptr<core::logging::Logger> logger_;
-
  private:
   struct ServerOptions {
     std::optional<uint64_t> max_queue_size;
-    int port = 0;
+    uint16_t port = 0;
   };
 
   void stopServer();
