@@ -20,26 +20,24 @@
 #include <string>
 #include <utility>
 
-#include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
+#include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "core/Core.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Id.h"
 #include "utils/Export.h"
 #include "utils/Enum.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class PutFile : public core::Processor {
+class PutFile : public core::ProcessorImpl {
  public:
-  explicit PutFile(std::string_view name,  const utils::Identifier& uuid = {})
-      : core::Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   ~PutFile() override = default;
 
@@ -74,12 +72,13 @@ class PutFile : public core::Processor {
   EXTENSIONAPI static constexpr auto CreateDirs = core::PropertyDefinitionBuilder<0, 1>::createProperty("Create Missing Directories")
       .withDescription("If true, then missing destination directories will be created. If false, flowfiles are penalized and sent to failure.")
       .withDefaultValue("true")
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .isRequired(true)
       .withDependentProperties({Directory.name})
       .build();
   EXTENSIONAPI static constexpr auto MaxDestFiles = core::PropertyDefinitionBuilder<>::createProperty("Maximum File Count")
       .withDescription("Specifies the maximum number of files that can exist in the output directory")
-      .withPropertyType(core::StandardPropertyTypes::INTEGER_TYPE)
+      .withValidator(core::StandardPropertyValidators::INTEGER_VALIDATOR)
       .withDefaultValue("-1")
       .build();
   EXTENSIONAPI static constexpr auto Properties =
@@ -120,7 +119,6 @@ class PutFile : public core::Processor {
   bool directoryIsFull(const std::filesystem::path& directory) const;
   std::optional<std::filesystem::path> getDestinationPath(core::ProcessContext& context, const std::shared_ptr<core::FlowFile>& flow_file);
   void putFile(core::ProcessSession& session, const std::shared_ptr<core::FlowFile>& flow_file, const std::filesystem::path& dest_file);
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<PutFile>::getLogger(uuid_);
   static std::shared_ptr<utils::IdGenerator> id_generator_;
 
 #ifndef WIN32
