@@ -21,7 +21,7 @@
 #include <utility>
 #include <vector>
 
-#include "Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/RelationshipDefinition.h"
@@ -30,7 +30,7 @@
 namespace org::apache::nifi::minifi::core::logging { class Logger; }
 
 namespace org::apache::nifi::minifi::processors {
-class PutUDP final : public core::Processor {
+class PutUDP final : public core::ProcessorImpl {
  public:
   EXTENSIONAPI static constexpr const char* Description = "The PutUDP processor receives a FlowFile and packages the FlowFile content into a single UDP datagram packet "
       "which is then transmitted to the configured UDP server. "
@@ -39,11 +39,13 @@ class PutUDP final : public core::Processor {
   EXTENSIONAPI static constexpr auto Hostname = core::PropertyDefinitionBuilder<>::createProperty("Hostname")
     .withDescription("The ip address or hostname of the destination.")
     .withDefaultValue("localhost")
+    .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
     .isRequired(true)
     .supportsExpressionLanguage(true)
     .build();
   EXTENSIONAPI static constexpr auto Port = core::PropertyDefinitionBuilder<>::createProperty("Port")
     .withDescription("The port on the destination. Can be a service name like ssh or http, as defined in /etc/services.")
+    .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
     .isRequired(true)
     .supportsExpressionLanguage(true)
     .build();
@@ -60,7 +62,7 @@ class PutUDP final : public core::Processor {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit PutUDP(std::string_view name, const utils::Identifier& uuid = {});
+  using ProcessorImpl::ProcessorImpl;
   PutUDP(const PutUDP&) = delete;
   PutUDP& operator=(const PutUDP&) = delete;
   ~PutUDP() final;
@@ -69,8 +71,5 @@ class PutUDP final : public core::Processor {
   void notifyStop() final;
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) final;
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) final;
-
- private:
-  std::shared_ptr<core::logging::Logger> logger_;
 };
 }  // namespace org::apache::nifi::minifi::processors
