@@ -25,26 +25,24 @@
 #include <utility>
 #include <vector>
 
-#include "core/state/nodes/MetricsBase.h"
-#include "FlowFileRecord.h"
 #include "core/Core.h"
 #include "core/OutputAttributeDefinition.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
+#include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/OptionalUtils.h"
 #include "utils/Export.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class RetryFlowFile : public core::Processor {
+class RetryFlowFile : public core::ProcessorImpl {
  public:
-  explicit RetryFlowFile(std::string_view name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {}
+  using ProcessorImpl::ProcessorImpl;
   ~RetryFlowFile() override = default;
 
   // ReuseMode allowed values
@@ -65,27 +63,26 @@ class RetryFlowFile : public core::Processor {
         "The name of the attribute that contains the current retry count for the FlowFile."
         "WARNING: If the name matches an attribute already on the FlowFile that does not contain a numerical value, "
         "the processor will either overwrite that attribute with '1' or fail based on configuration.")
-      .withPropertyType(core::StandardPropertyTypes::NON_BLANK_TYPE)
+      .withValidator(core::StandardPropertyValidators::NON_BLANK_VALIDATOR)
       .withDefaultValue("flowfile.retries")
       .supportsExpressionLanguage(true)
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MaximumRetries = core::PropertyDefinitionBuilder<>::createProperty("Maximum Retries")
       .withDescription("The maximum number of times a FlowFile can be retried before being passed to the 'retries_exceeded' relationship.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("3")
-      .supportsExpressionLanguage(true)
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto PenalizeRetries = core::PropertyDefinitionBuilder<>::createProperty("Penalize Retries")
       .withDescription("If set to 'true', this Processor will penalize input FlowFiles before passing them to the 'retry' relationship. This does not apply to the 'retries_exceeded' relationship.")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto FailOnNonNumericalOverwrite = core::PropertyDefinitionBuilder<>::createProperty("Fail on Non-numerical Overwrite")
       .withDescription("If the FlowFile already has the attribute defined in 'Retry Attribute' that is *not* a number, fail the FlowFile instead of resetting that value to '1'")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .isRequired(true)
       .build();
@@ -150,7 +147,7 @@ class RetryFlowFile : public core::Processor {
  private:
   void readDynamicPropertyKeys(const core::ProcessContext& context);
   std::optional<uint64_t> getRetryPropertyValue(const std::shared_ptr<core::FlowFile>& flow_file) const;
-  void setRetriesExceededAttributesOnFlowFile(core::ProcessContext& context, const std::shared_ptr<core::FlowFile>& flow_file) const;
+  void setRetriesExceededAttributesOnFlowFile(const core::ProcessContext& context, const std::shared_ptr<core::FlowFile>& flow_file) const;
 
   std::string retry_attribute_;
   uint64_t maximum_retries_ = 3;  // The real default value is set by the default on the MaximumRetries property
@@ -158,8 +155,6 @@ class RetryFlowFile : public core::Processor {
   bool fail_on_non_numerical_overwrite_ = false;  // The real default value is set by the default on the FailOnNonNumericalOverwrite property
   std::string reuse_mode_;
   std::vector<core::Property> exceeded_flowfile_attribute_keys_;
-
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<RetryFlowFile>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
