@@ -33,21 +33,18 @@ void RouteOnAttribute::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void RouteOnAttribute::onDynamicPropertyModified(const core::Property& /*orig_property*/, const core::Property &new_property) {
-  // Update the routing table when routes are added via dynamic properties.
-  route_properties_[new_property.getName()] = new_property;
+void RouteOnAttribute::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  route_properties_ = context.getDynamicProperties();
 
   const auto static_relationships = RouteOnAttribute::Relationships;
   std::vector<core::RelationshipDefinition> relationships(static_relationships.begin(), static_relationships.end());
 
-  for (const auto &route : route_properties_) {
+  for (const auto& route : route_properties_) {
     core::RelationshipDefinition route_rel{ route.first, "Dynamic route" };
     route_rels_[route.first] = route_rel;
     relationships.push_back(route_rel);
-    logger_->log_info("RouteOnAttribute registered route '{}' with expression '{}'", route.first, route.second.getValue().to_string());
+    logger_->log_info("RouteOnAttribute registered route '{}' with expression '{}'", route.first, route.second);
   }
-
-  setSupportedRelationships(relationships);
 }
 
 void RouteOnAttribute::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
@@ -63,8 +60,7 @@ void RouteOnAttribute::onTrigger(core::ProcessContext& context, core::ProcessSes
 
     // Perform dynamic routing logic
     for (const auto &route : route_properties_) {
-      std::string do_route;
-      context.getDynamicProperty(route.second, do_route, flow_file.get());
+      std::string do_route = context.getDynamicProperty(route.first, flow_file.get()).value_or("");
 
       if (do_route == "true") {
         did_match = true;
@@ -81,7 +77,7 @@ void RouteOnAttribute::onTrigger(core::ProcessContext& context, core::ProcessSes
   } catch (const std::exception &e) {
     logger_->log_error("Caught exception while updating attributes: type: {}, what: {}", typeid(e).name(), e.what());
     session.transfer(flow_file, Failure);
-    yield();
+    context.yield();
   }
 }
 
