@@ -24,20 +24,18 @@
 #include <string>
 #include <utility>
 
-#include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
+#include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/RelationshipDefinition.h"
 #include "core/Core.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 
 namespace org::apache::nifi::minifi::processors {
 
-class RouteOnAttribute : public core::Processor {
+class RouteOnAttribute : public core::ProcessorImpl {
  public:
-  explicit RouteOnAttribute(std::string_view name, const utils::Identifier& uuid = {})
-      : core::Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Routes FlowFiles based on their Attributes using the Attribute Expression Language.\n\n"
       "Any number of user-defined dynamic properties can be added, which all support the Attribute Expression Language. Relationships matching the name of the properties will be added.\n"
@@ -57,13 +55,12 @@ class RouteOnAttribute : public core::Processor {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  void onDynamicPropertyModified(const core::Property &orig_property, const core::Property &new_property) override;
+  void onSchedule(core::ProcessContext &, core::ProcessSessionFactory&) override;
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
   void initialize() override;
 
  private:
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<RouteOnAttribute>::getLogger(uuid_);
-  std::map<std::string, core::Property> route_properties_;
+  std::map<std::string, std::string> route_properties_;
   std::map<std::string, core::Relationship> route_rels_;
 };
 
