@@ -24,10 +24,10 @@
 #include <memory>
 
 #include "core/OutputAttributeDefinition.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "utils/Enum.h"
 #include "utils/Export.h"
@@ -114,7 +114,7 @@ constexpr customize_t enum_name<Segmentation>(Segmentation value) noexcept {
 
 namespace org::apache::nifi::minifi::processors {
 
-class RouteText : public core::Processor {
+class RouteText : public core::ProcessorImpl {
  public:
   EXTENSIONAPI static constexpr const char* Description = "Routes textual data based on a set of user-defined rules. Each segment in an incoming FlowFile is "
       "compared against the values specified by user-defined Properties. The mechanism by which the text is compared "
@@ -140,14 +140,14 @@ class RouteText : public core::Processor {
   EXTENSIONAPI static constexpr auto TrimWhitespace = core::PropertyDefinitionBuilder<>::createProperty("Ignore Leading/Trailing Whitespace")
       .withDescription("Indicates whether or not the whitespace at the beginning and end should be ignored when evaluating a segment.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   EXTENSIONAPI static constexpr auto IgnoreCase = core::PropertyDefinitionBuilder<>::createProperty("Ignore Case")
       .withDescription("If true, capitalization will not be taken into account when comparing values. E.g., matching against 'HELLO' or 'hello' will have the same result. "
           "This property is ignored if the 'Matching Strategy' is set to 'Satisfies Expression'.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto GroupingRegex = core::PropertyDefinitionBuilder<>::createProperty("Grouping Regular Expression")
@@ -205,14 +205,12 @@ class RouteText : public core::Processor {
 
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  explicit RouteText(std::string_view name, const utils::Identifier& uuid = {});
+  using ProcessorImpl::ProcessorImpl;
 
   void initialize() override;
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
 
-  void onDynamicPropertyModified(const core::Property& orig_property, const core::Property& new_property) override;
-
  private:
   static constexpr const char* GROUP_ATTRIBUTE_NAME = "RouteText.Group";
 
@@ -226,7 +224,7 @@ class RouteText : public core::Processor {
   };
 
   std::string_view preprocess(std::string_view str) const;
-  bool matchSegment(MatchingContext& context, const Segment& segment, const core::Property& prop) const;
+  bool matchSegment(MatchingContext& context, const Segment& segment, const std::string& property_name) const;
   std::optional<std::string> getGroup(const std::string_view& segment) const;
 
   route_text::Routing routing_ = route_text::Routing::DYNAMIC;
@@ -237,10 +235,7 @@ class RouteText : public core::Processor {
   std::optional<utils::Regex> group_regex_;
   std::string group_fallback_;
 
-  std::map<std::string, core::Property> dynamic_properties_;
   std::map<std::string, core::Relationship> dynamic_relationships_;
-
-  std::shared_ptr<core::logging::Logger> logger_;
 };
 
 }  // namespace org::apache::nifi::minifi::processors
