@@ -24,13 +24,12 @@
 #include <utility>
 #include <optional>
 
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/PropertyDefinition.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
-#include "FlowFileRecord.h"
 #include "utils/Export.h"
 #include "utils/expected.h"
 
@@ -46,8 +45,6 @@ struct SplitTextConfiguration {
 
 namespace detail {
 
-inline constexpr size_t SPLIT_TEXT_BUFFER_SIZE = 8192;
-
 enum class StreamReadState {
   Ok,
   StreamReadError,
@@ -65,9 +62,9 @@ class LineReader {
     bool operator==(const LineInfo& line_info) const = default;
   };
 
-  explicit LineReader(const std::shared_ptr<io::InputStream>& stream);
+  explicit LineReader(const std::shared_ptr<io::InputStream>& stream, size_t buffer_size);
   std::optional<LineInfo> readNextLine(const std::optional<std::string>& starts_with = std::nullopt);
-  StreamReadState getState() const { return state_; }
+  [[nodiscard]] StreamReadState getState() const { return state_; }
 
  private:
   uint8_t getEndLineSize(size_t newline_position);
@@ -79,19 +76,18 @@ class LineReader {
   uint64_t current_buffer_count_ = 0;
   size_t last_read_size_ = 0;
   uint64_t read_size_ = 0;
-  std::array<char, SPLIT_TEXT_BUFFER_SIZE> buffer_{};
   std::shared_ptr<io::InputStream> stream_;
+  size_t buffer_size_;
+  std::vector<char> buffer_ = std::vector<char>(buffer_size_);
   std::optional<LineInfo> last_line_info_;
   StreamReadState state_ = StreamReadState::Ok;
 };
 
 }  // namespace detail
 
-class SplitText : public core::Processor {
+class SplitText : public core::ProcessorImpl {
  public:
-  explicit SplitText(std::string_view name,  const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "Splits a text file into multiple smaller text files on line boundaries limited by maximum number of lines or total size of fragment. "
     "Each output split file will contain no more than the configured number of lines or bytes. If both Line Split Count and Maximum Fragment Size are specified, the split occurs at whichever "
@@ -104,17 +100,17 @@ class SplitText : public core::Processor {
   EXTENSIONAPI static constexpr auto LineSplitCount = core::PropertyDefinitionBuilder<>::createProperty("Line Split Count")
       .withDescription("The number of lines that will be added to each split file, excluding header lines. A value of zero requires Maximum Fragment Size to be set, and line count will not "
         "be considered in determining splits.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .isRequired(true)
       .build();
   EXTENSIONAPI static constexpr auto MaximumFragmentSize = core::PropertyDefinitionBuilder<>::createProperty("Maximum Fragment Size")
       .withDescription("The maximum size of each split file, including header lines. NOTE: in the case where a single line exceeds this property (including headers, if applicable), "
         "that line will be output in a split of its own which exceeds this Maximum Fragment Size setting.")
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .build();
   EXTENSIONAPI static constexpr auto HeaderLineCount = core::PropertyDefinitionBuilder<>::createProperty("Header Line Count")
       .withDescription("The number of lines that should be considered part of the header; the header lines will be duplicated to all split files.")
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("0")
       .isRequired(true)
       .build();
@@ -126,7 +122,7 @@ class SplitText : public core::Processor {
       .withDescription("Whether to remove newlines at the end of each split file. This should be false if you intend to merge the split files later. If this is set to 'true' and a FlowFile is "
         "generated that contains only 'empty lines' (i.e., consists only of \\r and \\n characters), the FlowFile will not be emitted. Note, however, that if header lines are specified, "
         "the resultant FlowFile will never be empty as it will consist of the header lines, so a FlowFile may be emitted that contains only the header lines.")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .isRequired(true)
       .build();
@@ -175,7 +171,7 @@ class SplitText : public core::Processor {
 
  private:
   SplitTextConfiguration split_text_config_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<SplitText>::getLogger(uuid_);
+  size_t buffer_size_{};
 };
 
 }  // namespace org::apache::nifi::minifi::processors
