@@ -19,7 +19,6 @@
  */
 
 #include <algorithm>
-#include <array>
 #include <iostream>
 #include <map>
 #include <unordered_map>
@@ -30,8 +29,8 @@
 
 #include "range/v3/action/sort.hpp"
 
-#include "FlowFileRecord.h"
 #include "io/CRCStream.h"
+#include "utils/ConfigurationUtils.h"
 #include "utils/file/FileUtils.h"
 #include "utils/file/PathUtils.h"
 #include "utils/StringUtils.h"
@@ -45,10 +44,10 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-const char *TailFile::CURRENT_STR = "CURRENT.";
-const char *TailFile::POSITION_STR = "POSITION.";
-
 namespace {
+inline constexpr std::string_view CURRENT_STR = "CURRENT.";
+inline constexpr std::string_view POSITION_STR = "POSITION.";
+
 template<typename Container, typename Key>
 bool containsKey(const Container &container, const Key &key) {
   return container.find(key) != container.end();
@@ -99,16 +98,16 @@ void openFile(const std::filesystem::path& file_path, uint64_t offset, std::ifst
   }
 }
 
-constexpr std::size_t BUFFER_SIZE = 4096;
-
 class FileReaderCallback {
  public:
   FileReaderCallback(const std::filesystem::path& file_path,
                      uint64_t offset,
                      char input_delimiter,
-                     uint64_t checksum)
+                     uint64_t checksum,
+                     size_t buffer_size)
     : input_delimiter_(input_delimiter),
-      checksum_(checksum) {
+      checksum_(checksum),
+      buffer_size_(buffer_size) {
     openFile(file_path, offset, input_stream_, logger_);
   }
 
@@ -120,7 +119,7 @@ class FileReaderCallback {
 
     while (hasMoreToRead() && !found_delimiter) {
       if (begin_ == end_) {
-        input_stream_.read(reinterpret_cast<char *>(buffer_.data()), gsl::narrow<std::streamsize>(buffer_.size()));
+        input_stream_.read(buffer_.data(), gsl::narrow<std::streamsize>(buffer_.size()));
 
         const auto num_bytes_read = input_stream_.gcount();
         logger_->log_trace("Read {} bytes of input", std::intmax_t{num_bytes_read});
@@ -160,12 +159,13 @@ class FileReaderCallback {
   }
 
  private:
-  char input_delimiter_;
-  uint64_t checksum_;
+  char input_delimiter_{};
+  uint64_t checksum_{};
   std::ifstream input_stream_;
+  size_t buffer_size_{};
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<TailFile>::getLogger();
 
-  std::array<char, BUFFER_SIZE> buffer_{};
+  std::vector<char> buffer_ = std::vector<char>(buffer_size_);
   char *begin_ = buffer_.data();
   char *end_ = buffer_.data();
 
@@ -176,8 +176,10 @@ class WholeFileReaderCallback {
  public:
   WholeFileReaderCallback(const std::filesystem::path& file_path,
                           uint64_t offset,
-                          uint64_t checksum)
-    : checksum_(checksum) {
+                          uint64_t checksum,
+                          size_t buffer_size)
+    : checksum_(checksum),
+      buffer_size_(buffer_size) {
     openFile(file_path, offset, input_stream_, logger_);
   }
 
@@ -186,14 +188,14 @@ class WholeFileReaderCallback {
   }
 
   int64_t operator()(const std::shared_ptr<io::OutputStream>& output_stream) {
-    std::array<char, BUFFER_SIZE> buffer{};
+    std::vector<char> buffer(buffer_size_);
 
     io::CRCStream<io::OutputStream> crc_stream{gsl::make_not_null(output_stream.get()), checksum_};
 
     uint64_t num_bytes_written = 0;
 
     while (input_stream_.good()) {
-      input_stream_.read(buffer.data(), buffer.size());
+      input_stream_.read(buffer.data(), gsl::narrow<std::streamsize>(buffer.size()));
 
       const auto num_bytes_read = input_stream_.gcount();
       logger_->log_trace("Read {} bytes of input", std::intmax_t{num_bytes_read});
@@ -212,6 +214,7 @@ class WholeFileReaderCallback {
  private:
   uint64_t checksum_;
   std::ifstream input_stream_;
+  size_t buffer_size_;
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<TailFile>::getLogger();
 };
 
@@ -235,6 +238,7 @@ void TailFile::initialize() {
 }
 
 void TailFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  buffer_size_ = utils::configuration::getBufferSize(*context.getConfiguration());
   tail_states_.clear();
 
   state_manager_ = context.getStateManager();
@@ -242,27 +246,33 @@ void TailFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFac
     throw Exception(PROCESSOR_EXCEPTION, "Failed to get StateManager");
   }
 
+  const auto result_format = utils::parseEnumProperty<TailResultFormat>(context, ResultFormat);
   if (auto delimiter_str = context.getProperty(Delimiter)) {
-    if (auto parsed_delimiter = utils::string::parseCharacter(*delimiter_str)) {
-      delimiter_ = *parsed_delimiter;
+    if (result_format == TailResultFormat::FlowFilePerBatch) {
+      logger_->log_warn("Delimiter({}) is ignored with {}", *delimiter_str, magic_enum::enum_name(TailResultFormat::FlowFilePerBatch));
     } else {
-      logger_->log_error("Invalid {}: \"{}\" (it should be a single character, whether escaped or not). Using the first character as the {}",
-          TailFile::Delimiter.name, *delimiter_str, TailFile::Delimiter.name);
-      delimiter_ = getDelimiterOld(*delimiter_str);
+      if (auto parsed_delimiter = utils::string::parseCharacter(*delimiter_str)) {
+        delimiter_ = *parsed_delimiter;
+      } else {
+        logger_->log_error("Invalid {}: \"{}\" (it should be a single character, whether escaped or not). Using the first character as the {}",
+            TailFile::Delimiter.name, *delimiter_str, TailFile::Delimiter.name);
+        delimiter_ = getDelimiterOld(*delimiter_str);
+      }
     }
   }
 
-  std::string file_name_str;
-  context.getProperty(FileName, file_name_str);
+  std::string file_name_str = context.getProperty(FileName).value_or("");
 
-  std::string mode;
-  context.getProperty(TailMode, mode);
+  std::string mode = context.getProperty(TailMode).value_or("");
 
   if (mode == "Multiple file") {
     tail_mode_ = Mode::MULTIPLE;
     pattern_regex_ = utils::Regex(file_name_str);
 
-    parseAttributeProviderServiceProperty(context);
+    if (auto service = utils::parseOptionalControllerService<minifi::controllers::AttributeProviderService>(context, AttributeProviderService, getUUID())) {
+      // we drop ownership of the service here -- in the long term, getControllerService/parseControllerService should return a non-owning pointer or optional reference
+      attribute_provider_service_ = service.get();
+    }
 
     if (auto base_dir = context.getProperty(BaseDirectory); !base_dir) {
       throw minifi::Exception(ExceptionType::PROCESSOR_EXCEPTION, "Base directory is required for multiple tail mode.");
@@ -274,11 +284,8 @@ void TailFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFac
       throw minifi::Exception(ExceptionType::PROCESSOR_EXCEPTION, "Base directory does not exist or is not a directory");
     }
 
-    context.getProperty(RecursiveLookup, recursive_lookup_);
-
-    if (auto lookup_frequency = context.getProperty<core::TimePeriodValue>(LookupFrequency)) {
-      lookup_frequency_ = lookup_frequency->getMilliseconds();
-    }
+    recursive_lookup_ = utils::parseBoolProperty(context, RecursiveLookup);
+    lookup_frequency_ = utils::parseDurationProperty(context, LookupFrequency);
 
     recoverState(context);
 
@@ -298,33 +305,11 @@ void TailFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFac
     recoverState(context);
   }
 
-  std::string rolling_filename_pattern_glob;
-  context.getProperty(RollingFilenamePattern, rolling_filename_pattern_glob);
+  std::string rolling_filename_pattern_glob = utils::parseProperty(context, RollingFilenamePattern);
   rolling_filename_pattern_ = utils::file::globToRegex(rolling_filename_pattern_glob);
   initial_start_position_ = utils::parseEnumProperty<InitialStartPositions>(context, InitialStartPosition);
-
-  uint32_t batch_size = 0;
-  if (context.getProperty(BatchSize, batch_size) && batch_size != 0) {
-    batch_size_ = batch_size;
-  }
-}
-
-void TailFile::parseAttributeProviderServiceProperty(const core::ProcessContext& context) {
-  const auto attribute_provider_service_name = context.getProperty(AttributeProviderService);
-  if (!attribute_provider_service_name || attribute_provider_service_name->empty()) {
-    return;
-  }
-
-  std::shared_ptr<core::controller::ControllerService> controller_service = context.getControllerService(*attribute_provider_service_name, getUUID());
-  if (!controller_service) {
-    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::string::join_pack("Controller service '", *attribute_provider_service_name, "' not found")};
-  }
-
-  // we drop ownership of the service here -- in the long term, getControllerService() should return a non-owning pointer or optional reference
-  attribute_provider_service_ = dynamic_cast<minifi::controllers::AttributeProviderService*>(controller_service.get());
-  if (!attribute_provider_service_) {
-    throw minifi::Exception{ExceptionType::PROCESS_SCHEDULE_EXCEPTION, utils::string::join_pack("Controller service '", *attribute_provider_service_name, "' is not an AttributeProviderService")};
-  }
+  batch_size_ = gsl::narrow<uint32_t>(utils::parseU64Property(context, BatchSize));
+  if (batch_size_ == 0) { batch_size_.reset(); }
 }
 
 void TailFile::parseStateFileLine(char *buf, std::map<std::filesystem::path, TailState> &state) const {
@@ -379,8 +364,8 @@ void TailFile::parseStateFileLine(char *buf, std::map<std::filesystem::path, Tai
     logger_->log_debug("Received position {}", position);
     state.begin()->second.position_ = gsl::narrow<uint64_t>(position);
   }
-  if (key.find(CURRENT_STR) == 0) {
-    const auto file = key.substr(strlen(CURRENT_STR));
+  if (key.starts_with(CURRENT_STR)) {
+    const auto file = key.substr(CURRENT_STR.size());
     std::filesystem::path file_path = value;
     if (file_path.has_filename() && file_path.has_parent_path()) {
       state[file].path_ = file_path.parent_path();
@@ -390,8 +375,8 @@ void TailFile::parseStateFileLine(char *buf, std::map<std::filesystem::path, Tai
     }
   }
 
-  if (key.find(POSITION_STR) == 0) {
-    const auto file = key.substr(strlen(POSITION_STR));
+  if (key.starts_with(POSITION_STR)) {
+    const auto file = key.substr(POSITION_STR.size());
     state[file].position_ = std::stoull(value);
   }
 }
@@ -464,8 +449,7 @@ bool TailFile::getStateFromStateManager(std::map<std::filesystem::path, TailStat
 
 bool TailFile::getStateFromLegacyStateFile(const core::ProcessContext& context,
                                            std::map<std::filesystem::path, TailState> &new_tail_states) const {
-  std::string state_file_name_property;
-  context.getProperty(StateFile, state_file_name_property);
+  const std::string state_file_name_property = context.getProperty(StateFile).value_or("");
   std::string state_file = state_file_name_property + "." + getUUIDStr();
 
   std::ifstream file(state_file.c_str(), std::ifstream::in);
@@ -475,9 +459,9 @@ bool TailFile::getStateFromLegacyStateFile(const core::ProcessContext& context,
   }
 
   std::map<std::filesystem::path, TailState> legacy_tail_states;
-  std::array<char, BUFFER_SIZE> buf{};
-  for (file.getline(buf.data(), BUFFER_SIZE); file.good(); file.getline(buf.data(), BUFFER_SIZE)) {
-    parseStateFileLine(buf.data(), legacy_tail_states);
+  std::vector<char> buffer(buffer_size_);
+  for (file.getline(buffer.data(), gsl::narrow<std::streamsize>(buffer_size_)); file.good(); file.getline(buffer.data(), gsl::narrow<std::streamsize>(buffer_size_))) {
+    parseStateFileLine(buffer.data(), legacy_tail_states);
   }
 
   new_tail_states = update_keys_in_legacy_states(legacy_tail_states);
@@ -485,7 +469,7 @@ bool TailFile::getStateFromLegacyStateFile(const core::ProcessContext& context,
 }
 
 void TailFile::logState() {
-  logger_->log_info("State of the TailFile processor {}:", name_);
+  logger_->log_info("State of the TailFile processor {}:", getName());
   for (const auto& [key, value] : tail_states_) {
     logger_->log_info("key => {{{}}}", value);
   }
@@ -611,7 +595,7 @@ void TailFile::onTrigger(core::ProcessContext& context, core::ProcessSession& se
   }
 
   if (!session.existsFlowFileInRelationship(Success)) {
-    yield();
+    context.yield();
   }
 
   first_trigger_ = false;
@@ -687,7 +671,7 @@ void TailFile::processSingleFile(core::ProcessSession& session,
     logger_->log_trace("Looking for delimiter 0x{:X}", *delimiter_);
 
     std::size_t num_flow_files = 0;
-    FileReaderCallback file_reader{full_file_name, state.position_, *delimiter_, state.checksum_};
+    FileReaderCallback file_reader{full_file_name, state.position_, *delimiter_, state.checksum_, buffer_size_};
     TailState state_copy{state};
 
     while (file_reader.hasMoreToRead() && (!batch_size_ || *batch_size_ > num_flow_files)) {
@@ -710,7 +694,7 @@ void TailFile::processSingleFile(core::ProcessSession& session,
     logger_->log_info("{} flowfiles were received from TailFile input", num_flow_files);
 
   } else {
-    WholeFileReaderCallback file_reader{full_file_name, state.position_, state.checksum_};
+    WholeFileReaderCallback file_reader{full_file_name, state.position_, state.checksum_, buffer_size_};
     auto flow_file = session.create();
     session.write(flow_file, std::ref(file_reader));
 
@@ -804,11 +788,11 @@ void TailFile::checkForNewFiles(core::ProcessContext& context) {
 }
 
 std::string TailFile::baseDirectoryFromAttributes(const controllers::AttributeProviderService::AttributeMap& attribute_map, core::ProcessContext& context) {
-  auto flow_file = std::make_shared<FlowFileRecord>();
+  auto flow_file = core::FlowFile::create();
   for (const auto& [key, value] : attribute_map) {
     flow_file->setAttribute(key, value);
   }
-  return context.getProperty(BaseDirectory, flow_file.get()).value();
+  return context.getProperty(BaseDirectory, flow_file.get()) | utils::orThrow("Base directory is required for multiple tail mode.");
 }
 
 std::chrono::milliseconds TailFile::getLookupFrequency() const {
