@@ -28,15 +28,14 @@
 #include <optional>
 
 #include "controllers/AttributeProviderService.h"
-#include "FlowFileRecord.h"
 #include "core/Core.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Enum.h"
 #include "utils/Export.h"
 #include "utils/RegexUtils.h"
@@ -49,10 +48,16 @@ enum class InitialStartPositions {
   CURRENT_TIME
 };
 
+enum class TailResultFormat {
+  FlowFilePerDelimiter,
+  FlowFilePerBatch
+};
+
 }  // namespace org::apache::nifi::minifi::processors
 
 namespace magic_enum::customize {
 using InitialStartPositions = org::apache::nifi::minifi::processors::InitialStartPositions;
+using TailResultFormat = org::apache::nifi::minifi::processors::TailResultFormat;
 
 template <>
 constexpr customize_t enum_name<InitialStartPositions>(InitialStartPositions value) noexcept {
@@ -66,6 +71,17 @@ constexpr customize_t enum_name<InitialStartPositions>(InitialStartPositions val
   }
   return invalid_tag;
 }
+
+template<>
+constexpr customize_t enum_name<TailResultFormat>(TailResultFormat value) noexcept {
+  switch (value) {
+    case TailResultFormat::FlowFilePerBatch:
+      return "Flow file per batch";
+    case TailResultFormat::FlowFilePerDelimiter:
+      return "Flow file per delimiter";
+  }
+  return invalid_tag;
+}
 }  // namespace magic_enum::customize
 
 namespace org::apache::nifi::minifi::processors {
@@ -103,13 +119,9 @@ enum class Mode {
   SINGLE, MULTIPLE, UNDEFINED
 };
 
-class TailFile : public core::Processor {
+class TailFile : public core::ProcessorImpl {
  public:
-  explicit TailFile(std::string_view name, const utils::Identifier& uuid = {})
-      : core::Processor(name, uuid) {
-  }
-
-  ~TailFile() override = default;
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "\"Tails\" a file, or a list of files, ingesting data from the file as it is written to the file. The file is expected to be textual."
       " Data is ingested only when a new line is encountered (carriage return or new-line character or combination). If the file to tail is periodically \"rolled over\","
@@ -150,14 +162,14 @@ class TailFile : public core::Processor {
   EXTENSIONAPI static constexpr auto RecursiveLookup = core::PropertyDefinitionBuilder<>::createProperty("Recursive lookup")
       .withDescription("When using Multiple file mode, this property determines whether files are tailed in child directories of the Base Directory or not.")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto LookupFrequency = core::PropertyDefinitionBuilder<>::createProperty("Lookup frequency")
       .withDescription("When using Multiple file mode, this property specifies the minimum duration "
           "the processor will wait between looking for new files to tail in the Base Directory.")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("10 min")
       .build();
   EXTENSIONAPI static constexpr auto RollingFilenamePattern = core::PropertyDefinitionBuilder<>::createProperty("Rolling Filename Pattern")
@@ -184,11 +196,17 @@ class TailFile : public core::Processor {
       .withAllowedTypes<minifi::controllers::AttributeProviderService>()
       .build();
   EXTENSIONAPI static constexpr auto BatchSize = core::PropertyDefinitionBuilder<>::createProperty("Batch Size")
-      .withDescription("Maximum number of flowfiles emitted in a single trigger. If set to 0 all new content will be processed.")
+      .withDescription("Maximum number of lines emitted in a single trigger. If set to 0 all new content will be processed.")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_INT_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("0")
       .build();
+  EXTENSIONAPI static constexpr auto ResultFormat = core::PropertyDefinitionBuilder<magic_enum::enum_count<TailResultFormat>()>::createProperty("Result Mode")
+      .withDescription("Specifies how the result lines are arranged into output flow files")
+      .isRequired(true)
+      .withDefaultValue(magic_enum::enum_name(TailResultFormat::FlowFilePerDelimiter))
+      .withAllowedValues(magic_enum::enum_names<TailResultFormat>())
+      .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       FileName,
       StateFile,
@@ -200,7 +218,8 @@ class TailFile : public core::Processor {
       RollingFilenamePattern,
       InitialStartPosition,
       AttributeProviderService,
-      BatchSize
+      BatchSize,
+      ResultFormat
   });
 
 
@@ -237,7 +256,6 @@ class TailFile : public core::Processor {
     TimePoint mtime_;
   };
 
-  void parseAttributeProviderServiceProperty(const core::ProcessContext& context);
   void parseStateFileLine(char *buf, std::map<std::filesystem::path, TailState> &state) const;
   void processAllRotatedFiles(core::ProcessSession& session, TailState &state);
   void processRotatedFiles(core::ProcessSession& session, TailState &state, std::vector<TailState> &rotated_file_states);
@@ -265,8 +283,6 @@ class TailFile : public core::Processor {
   static void updateStateAttributes(TailState &state, uint64_t size, uint64_t checksum);
   bool isOldFileInitiallyRead(const TailState &state) const;
 
-  static const char *CURRENT_STR;
-  static const char *POSITION_STR;
   static constexpr int BUFFER_SIZE = 512;
 
   std::optional<char> delimiter_;  // Delimiter for the data incoming from the tailed file.
@@ -284,7 +300,7 @@ class TailFile : public core::Processor {
   controllers::AttributeProviderService* attribute_provider_service_ = nullptr;
   std::unordered_map<std::string, controllers::AttributeProviderService::AttributeMap> extra_attributes_;
   std::optional<uint32_t> batch_size_;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<TailFile>::getLogger(uuid_);
+  size_t buffer_size_{};
 };
 
 }  // namespace org::apache::nifi::minifi::processors
