@@ -18,77 +18,99 @@
 #include <array>
 #include <memory>
 #include <string>
+#include <unordered_map>
 #include "unit/TestBase.h"
 #include "unit/Catch.h"
 #include "core/Core.h"
 #include "http/HTTPClient.h"
 #include "InvokeHTTP.h"
-#include "processors/ListenHTTP.h"
 #include "core/FlowFile.h"
 #include "unit/ProvenanceTestHelper.h"
 #include "core/Processor.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
-#include "core/ProcessorNode.h"
 #include "processors/LogAttribute.h"
 #include "unit/SingleProcessorTestController.h"
 #include "integration/ConnectionCountingServer.h"
 #include "unit/TestUtils.h"
+#include "integration/TestServer.h"
+#include "utils/StringUtils.h"
 
 namespace org::apache::nifi::minifi::test {
 
+class TestHandler : public CivetHandler {
+ public:
+  bool handleGet(CivetServer*, struct mg_connection* conn) override {
+    storeHeaders(conn);
+    mg_printf(conn, "HTTP/1.1 200 OK\r\n");
+    return true;
+  }
+
+  bool handlePost(CivetServer* /*server*/, struct mg_connection *conn) override {
+    storeHeaders(conn);
+    mg_printf(conn, "HTTP/1.1 200 OK\r\nContent-Type: "
+                    "text/plain\r\nContent-Length: 0\r\nConnection: close\r\n\r\n");
+    return true;
+  }
+
+  [[nodiscard]] const std::unordered_map<std::string, std::string>& getHeaders() const {
+    return headers_;
+  }
+
+ private:
+  void storeHeaders(struct mg_connection* conn) {
+    headers_.clear();
+    auto req_info = mg_get_request_info(conn);
+    for (int i = 0; i < req_info->num_headers; ++i) {
+      auto header = &req_info->http_headers[i];
+      headers_[std::string(header->name)] = std::string(header->value);
+    }
+  }
+
+  std::unordered_map<std::string, std::string> headers_;
+};
+
 class TestHTTPServer {
  public:
-  explicit TestHTTPServer(TestController& test_controller) {
-    LogTestController::getInstance().setDebug<org::apache::nifi::minifi::processors::ListenHTTP>();
-    LogTestController::getInstance().setDebug<org::apache::nifi::minifi::processors::LogAttribute>();
-
-    test_plan_ = test_controller.createPlan();
-
-    listen_http_ = dynamic_cast<processors::ListenHTTP*>(test_plan_->addProcessor("ListenHTTP", PROCESSOR_NAME));
-    log_attribute_ = dynamic_cast<processors::LogAttribute*>(test_plan_->addProcessor("LogAttribute", "LogAttribute", core::Relationship("success", "description"), true));
-    REQUIRE(listen_http_);
-    REQUIRE(log_attribute_);
-    test_plan_->setProperty(listen_http_, org::apache::nifi::minifi::processors::ListenHTTP::BasePath, "testytesttest");
-    test_plan_->setProperty(listen_http_, org::apache::nifi::minifi::processors::ListenHTTP::Port, "8681");
-    test_plan_->setProperty(listen_http_, org::apache::nifi::minifi::processors::ListenHTTP::HeadersAsAttributesRegex, ".*");
-    test_plan_->runProcessor(listen_http_);
-    test_plan_->runProcessor(log_attribute_);
-    thread_ = std::thread{[this] {
-      while (running_) {
-        if (listen_http_->isWorkAvailable()) {
-          test_plan_->runProcessor(listen_http_);
-          test_plan_->runProcessor(log_attribute_);
-        }
-      }
-    }};
+  TestHTTPServer() : server_(std::make_unique<TestServer>("8681", "/testytesttest", &handler_)) {
   }
   TestHTTPServer(const TestHTTPServer&) = delete;
   TestHTTPServer(TestHTTPServer&&) = delete;
   TestHTTPServer& operator=(const TestHTTPServer&) = delete;
   TestHTTPServer& operator=(TestHTTPServer&&) = delete;
+  ~TestHTTPServer() = default;
 
-  static constexpr const char* PROCESSOR_NAME = "my_http_server";
   static constexpr const char* URL = "http://localhost:8681/testytesttest";
 
-  ~TestHTTPServer() {
-    running_ = false;
-    thread_.join();
+  [[nodiscard]] const std::unordered_map<std::string, std::string>& getHeaders() const {
+    return handler_.getHeaders();
+  }
+
+  [[nodiscard]] std::vector<std::string> getHeaderKeys() const {
+    std::vector<std::string> keys;
+    for (const auto& [key, _] : handler_.getHeaders()) {
+      keys.push_back(key);
+    }
+    return keys;
+  }
+
+  [[nodiscard]] bool noInvalidHeaderPresent() const {
+    auto header_keys = getHeaderKeys();
+    return std::none_of(header_keys.begin(), header_keys.end(), [] (const auto& key) {
+      return minifi::utils::string::startsWith(key, "invalid");
+    });
   }
 
  private:
-  processors::ListenHTTP* listen_http_ = nullptr;
-  processors::LogAttribute* log_attribute_ = nullptr;
-  std::shared_ptr<TestPlan> test_plan_;
-  std::thread thread_;
-  std::atomic_bool running_{true};
+  TestHandler handler_;
+  std::unique_ptr<TestServer> server_;
 };
 
 TEST_CASE("HTTPTestsPenalizeNoRetry", "[httptest1]") {
   using minifi::processors::InvokeHTTP;
 
   TestController testController;
-  TestHTTPServer http_server(testController);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setInfo<minifi::core::ProcessSession>();
 
@@ -96,20 +118,20 @@ TEST_CASE("HTTPTestsPenalizeNoRetry", "[httptest1]") {
   plan->addProcessor("GenerateFlowFile", "genfile");
   auto invokehttp = plan->addProcessor("InvokeHTTP", "invokehttp", core::Relationship("success", "description"), true);
 
-  plan->setProperty(invokehttp, InvokeHTTP::Method, "GET");
-  plan->setProperty(invokehttp, InvokeHTTP::URL, "http://localhost:8681/invalid");
+  REQUIRE(plan->setProperty(invokehttp, InvokeHTTP::Method, "GET"));
+  REQUIRE(plan->setProperty(invokehttp, InvokeHTTP::URL, "http://localhost:8681/invalid"));
   invokehttp->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelFailure, InvokeHTTP::RelNoRetry, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
 
   constexpr const char* PENALIZE_LOG_PATTERN = "Penalizing [0-9a-f-]+ for [0-9]+ms at invokehttp";
 
   SECTION("with penalize on no retry set to true") {
-    plan->setProperty(invokehttp, InvokeHTTP::PenalizeOnNoRetry, "true");
+    REQUIRE(plan->setProperty(invokehttp, InvokeHTTP::PenalizeOnNoRetry, "true"));
     testController.runSession(plan);
     REQUIRE(LogTestController::getInstance().matchesRegex(PENALIZE_LOG_PATTERN));
   }
 
   SECTION("with penalize on no retry set to false") {
-    plan->setProperty(invokehttp, InvokeHTTP::PenalizeOnNoRetry, "false");
+    REQUIRE(plan->setProperty(invokehttp, InvokeHTTP::PenalizeOnNoRetry, "false"));
     testController.runSession(plan);
     REQUIRE_FALSE(LogTestController::getInstance().matchesRegex(PENALIZE_LOG_PATTERN));
   }
@@ -118,123 +140,125 @@ TEST_CASE("HTTPTestsPenalizeNoRetry", "[httptest1]") {
 TEST_CASE("InvokeHTTP fails with when flow contains invalid attribute names in HTTP headers", "[httptest1]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invokehttp = test_controller.getProcessor();
-  TestHTTPServer http_server(test_controller);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setDebug<InvokeHTTP>();
 
-  invokehttp->setProperty(InvokeHTTP::Method, "GET");
-  invokehttp->setProperty(InvokeHTTP::URL, TestHTTPServer::URL);
-  invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy, "fail");
-  invokehttp->setProperty(InvokeHTTP::AttributesToSend, ".*");
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy.name, "fail"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::AttributesToSend.name, ".*"));
   invokehttp->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelNoRetry, InvokeHTTP::Success, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
   const auto result = test_controller.trigger("data", {{"invalid header", "value"}});
   auto file_contents = result.at(InvokeHTTP::RelFailure);
   REQUIRE(file_contents.size() == 1);
   REQUIRE(test_controller.plan->getContent(file_contents[0]) == "data");
+  REQUIRE(http_server.getHeaders().empty());
 }
 
 TEST_CASE("InvokeHTTP succeeds when the flow file contains an attribute that would be invalid as an HTTP header, and the policy is FAIL, but the attribute is not matched",
     "[httptest1][invokehttp][httpheader][attribute]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invokehttp = test_controller.getProcessor();
-  TestHTTPServer http_server(test_controller);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setDebug<InvokeHTTP>();
 
-  invokehttp->setProperty(InvokeHTTP::Method, "GET");
-  invokehttp->setProperty(InvokeHTTP::URL, TestHTTPServer::URL);
-  invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy, "fail");
-  invokehttp->setProperty(InvokeHTTP::AttributesToSend, "valid.*");
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy.name, "fail"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::AttributesToSend.name, "valid.*"));
   invokehttp->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelNoRetry, InvokeHTTP::Success, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
   const auto result = test_controller.trigger("data", {{"invalid header", "value"}, {"valid-header", "value2"}});
   REQUIRE(result.at(InvokeHTTP::RelFailure).empty());
   const auto& success_contents = result.at(InvokeHTTP::Success);
   REQUIRE(success_contents.size() == 1);
-  REQUIRE(utils::verifyLogLinePresenceInPollTime(1s, "key:valid-header value:value2"));
-  REQUIRE_FALSE(LogTestController::getInstance().contains("key:invalid"));
+  REQUIRE(http_server.getHeaders().at("valid-header") == "value2");
+  REQUIRE(http_server.noInvalidHeaderPresent());
 }
 
 TEST_CASE("InvokeHTTP replaces invalid characters of attributes", "[httptest1]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invokehttp = test_controller.getProcessor();
-  TestHTTPServer http_server(test_controller);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setTrace<InvokeHTTP>();
 
-  invokehttp->setProperty(InvokeHTTP::Method, "GET");
-  invokehttp->setProperty(InvokeHTTP::URL, TestHTTPServer::URL);
-  invokehttp->setProperty(InvokeHTTP::AttributesToSend, ".*");
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::AttributesToSend.name, ".*"));
   invokehttp->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelNoRetry, InvokeHTTP::RelFailure, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
   const auto result = test_controller.trigger("data", {{"invalid header", "value"}, {"", "value2"}});
   auto file_contents = result.at(InvokeHTTP::Success);
   REQUIRE(file_contents.size() == 1);
   REQUIRE(test_controller.plan->getContent(file_contents[0]) == "data");
-  REQUIRE(utils::verifyLogLinePresenceInPollTime(1s, "key:invalid-header value:value"));
-  REQUIRE(utils::verifyLogLinePresenceInPollTime(1s, "key:X-MiNiFi-Empty-Attribute-Name value:value2"));
+  REQUIRE(http_server.getHeaders().at("invalid-header") == "value");
+  REQUIRE(http_server.getHeaders().at("X-MiNiFi-Empty-Attribute-Name") == "value2");
 }
 
 TEST_CASE("InvokeHTTP drops invalid attributes from HTTP headers", "[httptest1]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invokehttp = test_controller.getProcessor();
-  TestHTTPServer http_server(test_controller);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setTrace<InvokeHTTP>();
 
-  invokehttp->setProperty(InvokeHTTP::Method, "GET");
-  invokehttp->setProperty(InvokeHTTP::URL, TestHTTPServer::URL);
-  invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy, "drop");
-  invokehttp->setProperty(InvokeHTTP::AttributesToSend, ".*");
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy.name, "drop"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::AttributesToSend.name, ".*"));
   invokehttp->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelNoRetry, InvokeHTTP::RelFailure, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
   const auto result = test_controller.trigger("data", {{"legit-header", "value1"}, {"invalid header", "value2"}});
   auto file_contents = result.at(InvokeHTTP::Success);
   REQUIRE(file_contents.size() == 1);
   REQUIRE(test_controller.plan->getContent(file_contents[0]) == "data");
-  REQUIRE(utils::verifyLogLinePresenceInPollTime(1s, "key:legit-header value:value1"));
-  REQUIRE_FALSE(LogTestController::getInstance().contains("key:invalid", 0s));
+  REQUIRE(http_server.getHeaders().at("legit-header") == "value1");
+  REQUIRE(http_server.noInvalidHeaderPresent());
 }
 
 TEST_CASE("InvokeHTTP empty Attributes to Send means no attributes are sent", "[httptest1]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invokehttp = test_controller.getProcessor();
-  TestHTTPServer http_server(test_controller);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setTrace<InvokeHTTP>();
 
-  invokehttp->setProperty(InvokeHTTP::Method, "GET");
-  invokehttp->setProperty(InvokeHTTP::URL, TestHTTPServer::URL);
-  invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy, "drop");
-  invokehttp->setProperty(InvokeHTTP::AttributesToSend, "");
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy.name, "drop"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::AttributesToSend.name, ""));
   invokehttp->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelNoRetry, InvokeHTTP::RelFailure, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
   const auto result = test_controller.trigger("data", {{"legit-header", "value1"}, {"invalid header", "value2"}});
   auto file_contents = result.at(InvokeHTTP::Success);
   REQUIRE(file_contents.size() == 1);
   REQUIRE(test_controller.plan->getContent(file_contents[0]) == "data");
-  REQUIRE_FALSE(LogTestController::getInstance().contains("key:legit-header value:value1"));
-  REQUIRE_FALSE(LogTestController::getInstance().contains("key:invalid", 0s));
+  auto header_keys = http_server.getHeaderKeys();
+  REQUIRE_FALSE(http_server.getHeaders().contains("legit-header"));
+  REQUIRE(http_server.noInvalidHeaderPresent());
 }
 
 TEST_CASE("InvokeHTTP DateHeader", "[InvokeHTTP]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invoke_http = test_controller.getProcessor();
-  TestHTTPServer http_server(test_controller);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setTrace<InvokeHTTP>();
 
-  invoke_http->setProperty(InvokeHTTP::Method, "GET");
-  invoke_http->setProperty(InvokeHTTP::URL, TestHTTPServer::URL);
-  invoke_http->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy, "drop");
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy.name, "drop"));
   invoke_http->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelNoRetry, InvokeHTTP::RelFailure, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
 
   bool date_header{};
@@ -245,48 +269,52 @@ TEST_CASE("InvokeHTTP DateHeader", "[InvokeHTTP]") {
     date_header = true;
   };
 
-  invoke_http->setProperty(InvokeHTTP::DateHeader, date_header ? "true" : "false");
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::DateHeader.name, date_header ? "true" : "false"));
   const auto result = test_controller.trigger("data");
   auto file_contents = result.at(InvokeHTTP::Success);
   REQUIRE(file_contents.size() == 1);
   REQUIRE(test_controller.plan->getContent(file_contents[0]) == "data");
-  REQUIRE(utils::verifyEventHappenedInPollTime(1s, [&] {return LogTestController::getInstance().contains("key:Date", 0ms) == date_header;}));
+  if (date_header) {
+    REQUIRE(http_server.getHeaders().contains("Date"));
+  } else {
+    REQUIRE_FALSE(http_server.getHeaders().contains("Date"));
+  }
 }
 
 TEST_CASE("InvokeHTTP Attributes to Send uses full string matching, not substring", "[httptest1]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invokehttp = test_controller.getProcessor();
-  TestHTTPServer http_server(test_controller);
+  TestHTTPServer http_server;
 
   LogTestController::getInstance().setTrace<InvokeHTTP>();
 
-  invokehttp->setProperty(InvokeHTTP::Method, "GET");
-  invokehttp->setProperty(InvokeHTTP::URL, TestHTTPServer::URL);
-  invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy, "drop");
-  invokehttp->setProperty(InvokeHTTP::AttributesToSend, "he.*er");
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::InvalidHTTPHeaderFieldHandlingStrategy.name, "drop"));
+  REQUIRE(invokehttp->setProperty(InvokeHTTP::AttributesToSend.name, "he.*er"));
   invokehttp->setAutoTerminatedRelationships(std::array<core::Relationship, 4>{InvokeHTTP::RelNoRetry, InvokeHTTP::RelFailure, InvokeHTTP::RelResponse, InvokeHTTP::RelRetry});
   const auto result = test_controller.trigger("data", {{"header1", "value1"}, {"header", "value2"}});
   auto file_contents = result.at(InvokeHTTP::Success);
   REQUIRE(file_contents.size() == 1);
   REQUIRE(test_controller.plan->getContent(file_contents[0]) == "data");
-  REQUIRE(utils::verifyLogLinePresenceInPollTime(1s, "key:header value:value2"));
-  REQUIRE_FALSE(LogTestController::getInstance().contains("key:header1 value:value1"));
-  REQUIRE_FALSE(LogTestController::getInstance().contains("key:invalid", 0s));
+  REQUIRE(http_server.getHeaders().at("header") == "value2");
+  REQUIRE_FALSE(http_server.getHeaders().contains("header1"));
+  REQUIRE(http_server.noInvalidHeaderPresent());
 }
 
 TEST_CASE("HTTPTestsResponseBodyinAttribute", "[InvokeHTTP]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invoke_http = test_controller.getProcessor();
 
   minifi::test::ConnectionCountingServer connection_counting_server;
 
-  invoke_http->setProperty(InvokeHTTP::Method, "POST");
-  invoke_http->setProperty(InvokeHTTP::URL, "http://localhost:" + connection_counting_server.getPort()  + "/reverse");
-  invoke_http->setProperty(InvokeHTTP::PutResponseBodyInAttribute, "http.body");
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::Method.name, "POST"));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::URL.name, "http://localhost:" + connection_counting_server.getPort()  + "/reverse"));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::PutResponseBodyInAttribute.name, "http.body"));
   const auto result = test_controller.trigger("data", {{"header1", "value1"}, {"header", "value2"}});
   auto success_flow_files = result.at(InvokeHTTP::Success);
   CHECK(result.at(InvokeHTTP::RelFailure).empty());
@@ -304,14 +332,14 @@ TEST_CASE("HTTPTestsResponseBodyinAttribute", "[InvokeHTTP]") {
 TEST_CASE("HTTPTestsResponseBody", "[InvokeHTTP]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invoke_http = test_controller.getProcessor();
 
   minifi::test::ConnectionCountingServer connection_counting_server;
 
-  invoke_http->setProperty(InvokeHTTP::Method, "POST");
-  invoke_http->setProperty(InvokeHTTP::URL, "http://localhost:" + connection_counting_server.getPort()  + "/reverse");
-  invoke_http->setProperty(InvokeHTTP::SendMessageBody, "true");
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::Method.name, "POST"));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::URL.name, "http://localhost:" + connection_counting_server.getPort()  + "/reverse"));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::SendMessageBody.name, "true"));
   const auto result = test_controller.trigger("data", {{"header1", "value1"}, {"header", "value2"}});
   CHECK(result.at(InvokeHTTP::RelFailure).empty());
   CHECK(result.at(InvokeHTTP::RelNoRetry).empty());
@@ -327,13 +355,13 @@ TEST_CASE("HTTPTestsResponseBody", "[InvokeHTTP]") {
 TEST_CASE("Test Keepalive", "[InvokeHTTP]") {
   using minifi::processors::InvokeHTTP;
 
-  test::SingleProcessorTestController test_controller{std::make_unique<InvokeHTTP>("InvokeHTTP")};
+  test::SingleProcessorTestController test_controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
   auto invoke_http = test_controller.getProcessor();
 
   minifi::test::ConnectionCountingServer connection_counting_server;
 
-  invoke_http->setProperty(InvokeHTTP::Method, "GET");
-  invoke_http->setProperty(InvokeHTTP::URL, "http://localhost:" + connection_counting_server.getPort()  + "/method");
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::Method.name, "GET"));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::URL.name, "http://localhost:" + connection_counting_server.getPort()  + "/method"));
 
   for (auto i = 0; i < 4; ++i) {
     const auto result = test_controller.trigger(InputFlowFileData{"data"});
@@ -347,4 +375,58 @@ TEST_CASE("Test Keepalive", "[InvokeHTTP]") {
   CHECK(1 == connection_counting_server.getConnectionCounter());
 }
 
+TEST_CASE("Validating data transfer speed") {
+  const auto& data_transfer_speed_validator = processors::invoke_http::DATA_TRANSFER_SPEED_VALIDATOR;
+  CHECK(data_transfer_speed_validator.validate("10 kB/s"));
+  CHECK(data_transfer_speed_validator.validate("20 MB/s"));
+  CHECK(data_transfer_speed_validator.validate("20 TB/s"));
+  CHECK_FALSE(data_transfer_speed_validator.validate("1KBinvalidsuffix"));
+  CHECK_FALSE(data_transfer_speed_validator.validate("1KB"));
+}
+
+TEST_CASE("Data transfer speed parsing") {
+  CHECK(processors::invoke_http::parseDataTransferSpeed("10 kB/s") == 10_KiB);
+  CHECK(processors::invoke_http::parseDataTransferSpeed("20 MB/s") == 20_MiB);
+  CHECK(processors::invoke_http::parseDataTransferSpeed("19 TB/s") == 19_TiB);
+  CHECK(processors::invoke_http::parseDataTransferSpeed("1KBinvalidsuffix") == nonstd::make_unexpected(make_error_code(core::ParsingErrorCode::GeneralParsingError)));
+  CHECK(processors::invoke_http::parseDataTransferSpeed("1KB") == nonstd::make_unexpected(make_error_code(core::ParsingErrorCode::GeneralParsingError)));
+}
+
+TEST_CASE("InvokeHTTP: invalid characters are removed from outgoing HTTP headers", "[InvokeHTTP][http][attribute][header][sanitize]") {
+  using processors::InvokeHTTP;
+  constexpr std::string_view test_content = "flow file content";
+  std::string_view test_attr_value_in;
+  std::string_view test_attr_value_out;
+  SECTION("HTTP status message: CR and LF removed") {
+    test_attr_value_in = "400 Bad Request\r\n";
+    test_attr_value_out = "400 Bad Request";
+  };
+  SECTION("UTF-8 case 1: accented characters are kept") {
+    test_attr_value_in = "árvíztűrő tükörfúrógép";
+    test_attr_value_out = test_attr_value_in;
+  };
+  SECTION("UTF-8 case 2: chinese characters are kept") {
+    test_attr_value_in = "你知道吗？最近我开始注重健康饮了";
+    test_attr_value_out = test_attr_value_in;
+  };
+
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<InvokeHTTP>("InvokeHTTP")};
+  auto const invoke_http = controller.getProcessor<InvokeHTTP>();
+  const TestHTTPServer http_server;
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::Method.name, "POST"));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::URL.name, TestHTTPServer::URL));
+  REQUIRE(invoke_http->setProperty(InvokeHTTP::AttributesToSend.name, ".*"));
+  const auto result = controller.trigger(InputFlowFileData{.content = test_content, .attributes = {
+    {std::string{InvokeHTTP::STATUS_MESSAGE}, std::string{test_attr_value_in}},
+  }});
+  CHECK(result.at(InvokeHTTP::RelFailure).empty());
+  CHECK(result.at(InvokeHTTP::RelNoRetry).empty());
+  CHECK(result.at(InvokeHTTP::RelRetry).empty());
+  CHECK(!result.at(InvokeHTTP::Success).empty());
+  CHECK(!result.at(InvokeHTTP::RelResponse).empty());
+  CHECK(controller.plan->getContent(result.at(InvokeHTTP::Success)[0]) == test_content);
+  auto headers = http_server.getHeaders();
+  CHECK(headers.at(std::string{InvokeHTTP::STATUS_MESSAGE}) == test_attr_value_out);
+}
+
 }  // namespace org::apache::nifi::minifi::test
