@@ -21,6 +21,7 @@
 #include "AttributeRollingWindow.h"
 #include "unit/SingleProcessorTestController.h"
 #include "core/FlowFile.h"
+#include "unit/TestUtils.h"
 
 namespace org::apache::nifi::minifi::test {
 using AttributeRollingWindow = processors::AttributeRollingWindow;
@@ -36,10 +37,10 @@ bool checkAttributes(const std::map<std::string, std::string>& expected, const s
 }
 
 TEST_CASE("AttributeRollingWindow properly forwards properties to RollingWindow and sets attributes", "[attributerollingwindow]") {
-  SingleProcessorTestController controller{std::make_unique<AttributeRollingWindow>("AttributeRollingWindow")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<AttributeRollingWindow>("AttributeRollingWindow")};
   const auto proc = controller.getProcessor();
-  proc->setProperty(AttributeRollingWindow::ValueToTrack, "${value}");
-  proc->setProperty(AttributeRollingWindow::WindowLength, "3");
+  controller.plan->setProperty(proc, AttributeRollingWindow::ValueToTrack, "${value}");
+  controller.plan->setProperty(proc, AttributeRollingWindow::WindowLength, "3");
   const auto trigger_with_value_and_check_attributes = [&controller](const std::string& value, const std::map<std::string, std::string>& expected_out_attributes) {
     const auto rel = [](auto name) { return core::Relationship{std::move(name), "description"}; };
     const auto out = controller.trigger({.content = "content", .attributes = {{"value", value}}});
