@@ -46,7 +46,7 @@ class FetchFileTestFixture {
   [[nodiscard]] std::unordered_multiset<std::string> getDirContents(const std::filesystem::path& dir_path) const;
 
   std::shared_ptr<minifi::test::SingleProcessorTestController> test_controller_;
-  minifi::processors::FetchFile* fetch_file_processor_ = nullptr;
+  minifi::core::Processor* fetch_file_processor_ = nullptr;
   const std::filesystem::path input_dir_;
   const std::filesystem::path permission_denied_file_name_;
   const std::filesystem::path input_file_name_;
@@ -55,8 +55,8 @@ class FetchFileTestFixture {
 };
 
 FetchFileTestFixture::FetchFileTestFixture()
-  : test_controller_(std::make_shared<minifi::test::SingleProcessorTestController>(std::make_unique<minifi::processors::FetchFile>("FetchFile"))),
-    fetch_file_processor_(test_controller_->getProcessor<minifi::processors::FetchFile>()),
+  : test_controller_(std::make_shared<minifi::test::SingleProcessorTestController>(minifi::test::utils::make_processor<minifi::processors::FetchFile>("FetchFile"))),
+    fetch_file_processor_(test_controller_->getProcessor()),
     input_dir_(test_controller_->createTempDirectory()),
     permission_denied_file_name_("permission_denied.txt"),
     input_file_name_("test.txt"),
@@ -99,8 +99,8 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Test fetching file with default but non-
 }
 
 TEST_CASE_METHOD(FetchFileTestFixture, "FileToFetch property set to a non-existent file path", "[testFetchFile]") {
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::FileToFetch, "/tmp/non_existent.file");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::LogLevelWhenFileNotFound, "INFO");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::FileToFetch.name, "/tmp/non_existent.file"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::LogLevelWhenFileNotFound.name, "INFO"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::NotFound);
   REQUIRE(file_contents.size() == 1);
@@ -113,8 +113,8 @@ TEST_CASE_METHOD(FetchFileTestFixture, "FileToFetch property set to a non-existe
 TEST_CASE_METHOD(FetchFileTestFixture, "Permission denied to read file", "[testFetchFile]") {
   if (minifi::test::utils::runningAsUnixRoot())
     SKIP("Cannot test insufficient permissions with root user");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::FileToFetch, (input_dir_ / permission_denied_file_name_).string());
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::LogLevelWhenPermissionDenied, "WARN");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::FileToFetch.name, (input_dir_ / permission_denied_file_name_).string()));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::LogLevelWhenPermissionDenied.name, "WARN"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::PermissionDenied);
   REQUIRE(file_contents.size() == 1);
@@ -136,7 +136,7 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Test fetching file from a custom path",
   REQUIRE(0 == utils::file::FileUtils::create_dir(input_dir_ / "sub"));
   minifi::test::utils::putFileToDir(input_dir_ / "sub", input_file_name_, file_content_);
   auto file_path = input_dir_ / "sub" / input_file_name_;
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::FileToFetch, file_path.string());
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::FileToFetch.name, file_path.string()));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -145,16 +145,16 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Test fetching file from a custom path",
 }
 
 TEST_CASE_METHOD(FetchFileTestFixture, "Flow scheduling fails due to missing move destination directory when completion strategy is set to move file", "[testFetchFile]") {
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
   REQUIRE_THROWS_AS(test_controller_->trigger("", attributes_), minifi::Exception);
 }
 
 TEST_CASE_METHOD(FetchFileTestFixture, "Flow fails due to move conflict", "[testFetchFile]") {
   auto move_dir = test_controller_->createTempDirectory();
   minifi::test::utils::putFileToDir(move_dir, input_file_name_, "old content");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveConflictStrategy, "Fail");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveConflictStrategy.name, "Fail"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Failure);
   REQUIRE(file_contents.size() == 1);
@@ -168,8 +168,8 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Flow fails due to move conflict", "[test
 TEST_CASE_METHOD(FetchFileTestFixture, "Move specific properties are ignored when completion strategy is not move file", "[testFetchFile]") {
   auto move_dir = test_controller_->createTempDirectory();
   minifi::test::utils::putFileToDir(move_dir, input_file_name_, "old content");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveConflictStrategy, "Fail");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveConflictStrategy.name, "Fail"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -179,9 +179,9 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Move specific properties are ignored whe
 TEST_CASE_METHOD(FetchFileTestFixture, "Move destination conflict is resolved with replace file", "[testFetchFile]") {
   auto move_dir = test_controller_->createTempDirectory();
   minifi::test::utils::putFileToDir(move_dir, input_file_name_, "old content");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveConflictStrategy, "Replace File");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveConflictStrategy.name, "Replace File"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -195,9 +195,9 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Move destination conflict is resolved wi
 TEST_CASE_METHOD(FetchFileTestFixture, "Move destination conflict is resolved with renaming file to a new random filename", "[testFetchFile]") {
   auto move_dir = test_controller_->createTempDirectory();
   minifi::test::utils::putFileToDir(move_dir, input_file_name_, "old content");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveConflictStrategy, "Rename");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveConflictStrategy.name, "Rename"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -212,9 +212,9 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Move destination conflict is resolved wi
 TEST_CASE_METHOD(FetchFileTestFixture, "Move destination conflict is resolved with deleting the new file and keeping the old one", "[testFetchFile]") {
   auto move_dir = test_controller_->createTempDirectory();
   minifi::test::utils::putFileToDir(move_dir, input_file_name_, "old content");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveConflictStrategy, "Keep Existing");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveConflictStrategy.name, "Keep Existing"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -227,8 +227,8 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Move destination conflict is resolved wi
 
 TEST_CASE_METHOD(FetchFileTestFixture, "Fetched file is moved to a new directory after flow completion", "[testFetchFile]") {
   auto move_dir = test_controller_->createTempDirectory();
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -242,8 +242,8 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Fetched file is moved to a new directory
 TEST_CASE_METHOD(FetchFileTestFixture, "After flow completion the fetched file is moved to a non-existent directory which is created by the flow", "[testFetchFile]") {
   auto move_dir = test_controller_->createTempDirectory();
   move_dir = move_dir / "temp";
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -260,8 +260,8 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Move completion strategy failure due to
     SKIP("Cannot test insufficient permissions with root user");
   auto move_dir = test_controller_->createTempDirectory();
   utils::file::FileUtils::set_permissions(move_dir, 0);
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Move File");
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::MoveDestinationDirectory, move_dir.string());
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Move File"));
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::MoveDestinationDirectory.name, move_dir.string()));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
@@ -274,7 +274,7 @@ TEST_CASE_METHOD(FetchFileTestFixture, "Move completion strategy failure due to
 #endif
 
 TEST_CASE_METHOD(FetchFileTestFixture, "Fetched file is deleted after flow completion", "[testFetchFile]") {
-  fetch_file_processor_->setProperty(org::apache::nifi::minifi::processors::FetchFile::CompletionStrategy, "Delete File");
+  REQUIRE(fetch_file_processor_->setProperty(minifi::processors::FetchFile::CompletionStrategy.name, "Delete File"));
   const auto result = test_controller_->trigger("", attributes_);
   auto file_contents = result.at(minifi::processors::FetchFile::Success);
   REQUIRE(file_contents.size() == 1);
