@@ -21,6 +21,7 @@
 #include <chrono>
 #include "core/repository/VolatileContentRepository.h"
 #include "core/ProcessGroup.h"
+#include "core/Processor.h"
 #include "core/yaml/YamlConfiguration.h"
 #include "TailFile.h"
 #include "unit/Catch.h"
@@ -29,6 +30,10 @@
 #include "Funnel.h"
 #include "core/Resource.h"
 #include "utils/crypto/property_encryption/PropertyEncryptionUtils.h"
+#include "unit/TestUtils.h"
+#include "unit/DummyParameterProvider.h"
+#include "catch2/generators/catch_generators.hpp"
+
 
 using namespace std::literals::chrono_literals;
 
@@ -74,6 +79,7 @@ TEST_CASE("NiFi flow json format is correctly parsed") {
       "schedulingPeriod": "3 sec",
       "penaltyDuration": "12 sec",
       "yieldDuration": "4 sec",
+      "bulletinLevel": "ERROR",
       "runDurationMillis": 12,
       "autoTerminatedRelationships": ["one", "two"],
       "properties": {
@@ -137,33 +143,34 @@ TEST_CASE("NiFi flow json format is correctly parsed") {
   // verify processor
   auto* proc = flow->findProcessorByName("MyGenFF");
   REQUIRE(proc);
-  REQUIRE(proc->getUUIDStr() == "00000000-0000-0000-0000-000000000001");
-  REQUIRE(15 == proc->getMaxConcurrentTasks());
-  REQUIRE(core::SchedulingStrategy::TIMER_DRIVEN == proc->getSchedulingStrategy());
-  REQUIRE(3s == proc->getSchedulingPeriod());
-  REQUIRE(12s == proc->getPenalizationPeriod());
-  REQUIRE(4s == proc->getYieldPeriod());
-  REQUIRE(proc->isAutoTerminated({"one", ""}));
-  REQUIRE(proc->isAutoTerminated({"two", ""}));
-  REQUIRE_FALSE(proc->isAutoTerminated({"three", ""}));
-  REQUIRE(proc->getProperty("File Size") == "10 B");
-  REQUIRE(proc->getProperty("Batch Size") == "12");
+  CHECK(proc->getUUIDStr() == "00000000-0000-0000-0000-000000000001");
+  CHECK(15 == proc->getMaxConcurrentTasks());
+  CHECK(core::SchedulingStrategy::TIMER_DRIVEN == proc->getSchedulingStrategy());
+  CHECK(3s == proc->getSchedulingPeriod());
+  CHECK(12s == proc->getPenalizationPeriod());
+  CHECK(4s == proc->getYieldPeriod());
+  CHECK(proc->getLogBulletinLevel() == logging::LOG_LEVEL::err);
+  CHECK(proc->isAutoTerminated({"one", ""}));
+  CHECK(proc->isAutoTerminated({"two", ""}));
+  CHECK_FALSE(proc->isAutoTerminated({"three", ""}));
+  CHECK(proc->getProperty("File Size") == "10 B");
+  CHECK(proc->getProperty("Batch Size") == "12");
 
   // verify funnel
-  auto* funnel = dynamic_cast<minifi::Funnel*>(flow->findProcessorByName("CoolFunnel"));
+  TypedProcessorWrapper<minifi::Funnel> funnel = flow->findProcessorByName("CoolFunnel");
   REQUIRE(funnel);
-  REQUIRE(funnel->getUUIDStr() == "00000000-0000-0000-0000-000000000010");
+  CHECK(funnel->getUUIDStr() == "00000000-0000-0000-0000-000000000010");
 
   // verify RPG input port
-  auto* port = dynamic_cast<minifi::RemoteProcessorGroupPort*>(flow->findProcessorByName("AmazingInputPort"));
+  TypedProcessorWrapper<minifi::RemoteProcessorGroupPort> port = flow->findProcessorByName("AmazingInputPort");
   REQUIRE(port);
-  REQUIRE(port->getUUIDStr() == "00000000-0000-0000-0000-000000000003");
-  REQUIRE(port->getMaxConcurrentTasks() == 7);
-  REQUIRE(port->getInstances().size() == 1);
-  REQUIRE(port->getInstances().front().host_ == "localhost");
-  REQUIRE(port->getInstances().front().port_ == 8090);
-  REQUIRE(port->getInstances().front().protocol_ == "https://");
-  REQUIRE(port->getProperty("Port UUID") == "00000000-0000-0000-0000-000000000005");
+  CHECK(port->getUUIDStr() == "00000000-0000-0000-0000-000000000003");
+  CHECK(port->getMaxConcurrentTasks() == 7);
+  CHECK(port.get().getInstances().size() == 1);
+  CHECK(port.get().getInstances().front().host_ == "localhost");
+  CHECK(port.get().getInstances().front().port_ == 8090);
+  CHECK(port.get().getInstances().front().protocol_ == "https://");
+  CHECK(port->getProperty("Port UUID") == "00000000-0000-0000-0000-000000000005");
 
   // verify connection
   std::map<std::string, minifi::Connection*> connection_map;
@@ -171,20 +178,58 @@ TEST_CASE("NiFi flow json format is correctly parsed") {
   REQUIRE(4 == connection_map.size());
   auto connection1 = connection_map.at("00000000-0000-0000-0000-000000000002");
   REQUIRE(connection1);
-  REQUIRE("GenToFunnel" == connection1->getName());
-  REQUIRE(connection1->getSource() == proc);
-  REQUIRE(connection1->getDestination() == funnel);
-  REQUIRE(connection1->getRelationships() == (std::set<core::Relationship>{{"a", ""}, {"b", ""}}));
-  REQUIRE(connection1->getBackpressureThresholdCount() == 7);
-  REQUIRE(connection1->getBackpressureThresholdDataSize() == 11_KiB);
-  REQUIRE(13s == connection1->getFlowExpirationDuration());
+  CHECK("GenToFunnel" == connection1->getName());
+  CHECK(connection1->getSource() == proc);
+  CHECK(connection1->getDestination() == funnel);
+  CHECK(connection1->getRelationships() == (std::set<core::Relationship>{{"a", ""}, {"b", ""}}));
+  CHECK(connection1->getBackpressureThresholdCount() == 7);
+  CHECK(connection1->getBackpressureThresholdDataSize() == 11_KiB);
+  CHECK(13s == connection1->getFlowExpirationDuration());
 
   auto connection2 = connection_map.at("00000000-0000-0000-0000-000000000008");
   REQUIRE(connection2);
-  REQUIRE("FunnelToS2S" == connection2->getName());
-  REQUIRE(connection2->getSource() == funnel);
-  REQUIRE(connection2->getDestination() == port);
-  REQUIRE(connection2->getRelationships() == (std::set<core::Relationship>{{"success", ""}}));
+  CHECK("FunnelToS2S" == connection2->getName());
+  CHECK(connection2->getSource() == funnel);
+  CHECK(connection2->getDestination() == port);
+  CHECK(connection2->getRelationships() == (std::set<core::Relationship>{{"success", ""}}));
+}
+
+TEST_CASE("Cannot use invalid property values") {
+  ConfigurationTestController test_controller;
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+  auto [file_size_property_str, throws] = GENERATE(
+    std::make_tuple(R"("12 dogBytes")", true),
+    std::make_tuple(R"("1 kB")", false),
+    std::make_tuple(R"([{"value": "1 kB"},{"value": "2 kB"}])", false),
+    std::make_tuple(R"("foo")", true),
+    std::make_tuple(R"([{"value": "1 kB"},{"value": "bar"}])", true));
+  const std::string CONFIG_JSON = fmt::format(
+      R"(
+{{
+  "rootGroup": {{
+    "name": "MiNiFi Flow",
+    "processors": [{{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyGenFF",
+      "type": "org.apache.nifi.processors.standard.GenerateFlowFile",
+      "concurrentlySchedulableTaskCount": 15,
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "penaltyDuration": "12 sec",
+      "yieldDuration": "4 sec",
+      "runDurationMillis": 12,
+      "autoTerminatedRelationships": ["success"],
+      "properties": {{
+        "File Size": {}
+      }}
+    }}]
+  }}
+}})", file_size_property_str);
+  if (throws) {
+    REQUIRE_THROWS_WITH(config.getRootFromPayload(CONFIG_JSON), "Unable to parse configuration file for component named 'MyGenFF' because ValidationFailed");
+  } else {
+    REQUIRE_NOTHROW(config.getRootFromPayload(CONFIG_JSON));
+  }
 }
 
 TEST_CASE("Parameters from different parameter contexts should not be replaced") {
@@ -333,31 +378,6 @@ TEST_CASE("Cannot use the same parameter name within a parameter context twice")
   REQUIRE_THROWS_WITH(config.getRootFromPayload(CONFIG_JSON), "Parameter Operation: Parameter name 'file_size' already exists, parameter names must be unique within a parameter context!");
 }
 
-class DummyFlowJsonProcessor : public core::Processor {
- public:
-  using core::Processor::Processor;
-
-  static constexpr const char* Description = "A processor that does nothing.";
-  static constexpr auto SimpleProperty = core::PropertyDefinitionBuilder<>::createProperty("Simple Property")
-      .withDescription("Just a simple string property")
-      .build();
-  static constexpr auto SensitiveProperty = core::PropertyDefinitionBuilder<>::createProperty("Sensitive Property")
-      .withDescription("Sensitive property")
-      .isSensitive(true)
-      .build();
-  static constexpr auto Properties = std::to_array<core::PropertyReference>({SimpleProperty, SensitiveProperty});
-  static constexpr auto Relationships = std::array<core::RelationshipDefinition, 0>{};
-  static constexpr bool SupportsDynamicProperties = true;
-  static constexpr bool SupportsDynamicRelationships = true;
-  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
-  static constexpr bool IsSingleThreaded = false;
-  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
-
-  void initialize() override { setSupportedProperties(Properties); }
-};
-
-REGISTER_RESOURCE(DummyFlowJsonProcessor, Processor);
-
 TEST_CASE("Cannot use non-sensitive parameter in sensitive property") {
   ConfigurationTestController test_controller;
 
@@ -386,7 +406,7 @@ TEST_CASE("Cannot use non-sensitive parameter in sensitive property") {
     "processors": [{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyGenFF",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {
@@ -429,7 +449,7 @@ TEST_CASE("Cannot use non-sensitive parameter in sensitive property value sequen
     "processors": [{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyGenFF",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {
@@ -640,7 +660,7 @@ TEST_CASE("Cannot use parameters if no parameter context is defined") {
     "processors": [{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyGenFF",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {
@@ -666,7 +686,7 @@ TEST_CASE("Cannot use parameters in property value sequences if no parameter con
     "processors": [{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyGenFF",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {
@@ -716,7 +736,7 @@ TEST_CASE("Property value sequences can use parameters") {
     "processors": [{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyProcessor",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {
@@ -735,12 +755,11 @@ TEST_CASE("Property value sequences can use parameters") {
 
   auto* proc = flow->findProcessorByName("MyProcessor");
   REQUIRE(proc);
-  core::Property property("Simple Property", "");
-  proc->getProperty("Simple Property", property);
-  auto values = property.getValues();
-  REQUIRE(values.size() == 2);
-  CHECK(values[0] == "value1");
-  CHECK(values[1] == "value2");
+  auto values = proc->getAllPropertyValues("Simple Property");
+  REQUIRE(values);
+  REQUIRE(values->size() == 2);
+  CHECK((*values)[0] == "value1");
+  CHECK((*values)[1] == "value2");
 }
 
 TEST_CASE("Dynamic properties can use parameters") {
@@ -777,7 +796,7 @@ TEST_CASE("Dynamic properties can use parameters") {
     "processors": [{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyProcessor",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {
@@ -797,15 +816,13 @@ TEST_CASE("Dynamic properties can use parameters") {
 
   auto* proc = flow->findProcessorByName("MyProcessor");
   REQUIRE(proc);
-  core::Property property("My Dynamic Property Sequence", "");
-  proc->getDynamicProperty("My Dynamic Property Sequence", property);
-  auto values = property.getValues();
-  REQUIRE(values.size() == 2);
-  CHECK(values[0] == "value1");
-  CHECK(values[1] == "value2");
+  auto values = proc->getAllDynamicPropertyValues("My Dynamic Property Sequence");
+  REQUIRE(values);
+  REQUIRE(values->size() == 2);
+  CHECK((*values)[0] == "value1");
+  CHECK((*values)[1] == "value2");
   std::string value;
-  REQUIRE(proc->getDynamicProperty("My Dynamic Property", value));
-  CHECK(value == "value1");
+  REQUIRE("value1" == proc->getDynamicProperty("My Dynamic Property"));
 }
 
 TEST_CASE("Test sensitive parameters in sensitive properties") {
@@ -838,7 +855,7 @@ TEST_CASE("Test sensitive parameters in sensitive properties") {
     "processors": [{{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyProcessor",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {{
@@ -854,7 +871,7 @@ TEST_CASE("Test sensitive parameters in sensitive properties") {
 
   auto* proc = flow->findProcessorByName("MyProcessor");
   REQUIRE(proc);
-  REQUIRE(proc->getProperty("Sensitive Property") == "value1");
+  CHECK(proc->getProperty("Sensitive Property") == "value1");
 }
 
 TEST_CASE("Test sensitive parameters in sensitive property value sequence") {
@@ -895,7 +912,7 @@ TEST_CASE("Test sensitive parameters in sensitive property value sequence") {
     "processors": [{{
       "identifier": "00000000-0000-0000-0000-000000000001",
       "name": "MyProcessor",
-      "type": "org.apache.nifi.processors.DummyFlowJsonProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
       "schedulingStrategy": "TIMER_DRIVEN",
       "schedulingPeriod": "3 sec",
       "properties": {{
@@ -916,11 +933,11 @@ TEST_CASE("Test sensitive parameters in sensitive property value sequence") {
   auto* proc = flow->findProcessorByName("MyProcessor");
   REQUIRE(proc);
   core::Property property("Sensitive Property", "");
-  proc->getProperty("Sensitive Property", property);
-  auto values = property.getValues();
-  REQUIRE(values.size() == 2);
-  CHECK(values[0] == "value1");
-  CHECK(values[1] == "value2");
+  auto values = proc->getAllPropertyValues("Sensitive Property");
+  REQUIRE(values);
+  REQUIRE(values->size() == 2);
+  CHECK((*values)[0] == "value1");
+  CHECK((*values)[1] == "value2");
 }
 
 TEST_CASE("NiFi flow json can use alternative targetUris field") {
@@ -1014,22 +1031,21 @@ TEST_CASE("NiFi flow json can use alternative targetUris field") {
   REQUIRE(flow);
 
   // verify RPG input port
-  auto* port = dynamic_cast<minifi::RemoteProcessorGroupPort*>(flow->findProcessorByName("AmazingInputPort"));
+  TypedProcessorWrapper<minifi::RemoteProcessorGroupPort> port = flow->findProcessorByName("AmazingInputPort");
   REQUIRE(port);
-  REQUIRE(port->getUUIDStr() == "00000000-0000-0000-0000-000000000003");
-  REQUIRE(port->getMaxConcurrentTasks() == 7);
+  CHECK(port.get().getUUIDStr() == "00000000-0000-0000-0000-000000000003");
+  CHECK(port->getMaxConcurrentTasks() == 7);
   if (target_uri_valid) {
-    REQUIRE(port->getInstances().size() == 1);
-    REQUIRE(port->getInstances().front().host_ == "localhost");
-    REQUIRE(port->getInstances().front().port_ == 8090);
-    REQUIRE(port->getInstances().front().protocol_ == "https://");
+    CHECK(port.get().getInstances().size() == 1);
+    CHECK(port.get().getInstances().front().host_ == "localhost");
+    CHECK(port.get().getInstances().front().port_ == 8090);
+    CHECK(port.get().getInstances().front().protocol_ == "https://");
   } else {
-    REQUIRE(port->getInstances().empty());
+    CHECK(port.get().getInstances().empty());
   }
-  REQUIRE(port->getProperty("Port UUID") == "00000000-0000-0000-0000-000000000005");
+  CHECK(port->getProperty("Port UUID") == "00000000-0000-0000-0000-000000000005");
 }
 
-
 TEST_CASE("Test parameters in controller services") {
   ConfigurationTestController test_controller;
   auto context = test_controller.getContext();
@@ -1149,4 +1165,625 @@ TEST_CASE("Parameters can be used in controller services in nested process group
   CHECK(impl->getProperty("Private Key").value() == "/opt/secrets/private-key.pem");
 }
 
+TEST_CASE("Test parameter context inheritance") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_parameter_value = minifi::utils::crypto::property_encryption::encrypt("value1", *context.sensitive_values_encryptor);
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{my_new_parameter}", *context.sensitive_values_encryptor);
+  core::flow::AdaptiveConfiguration config(context);
+
+  static const std::string CONFIG_JSON =
+      fmt::format(R"(
+{{
+  "parameterContexts": [
+    {{
+      "identifier": "721e10b7-8e00-3188-9a27-476cca376978",
+      "name": "inherited-context",
+      "description": "inherited parameter context",
+      "parameters": [
+        {{
+          "name": "my_new_parameter",
+          "description": "",
+          "sensitive": true,
+          "value": "{}"
+        }}
+      ],
+      "inheritedParameterContexts": ["base-context"]
+    }},
+    {{
+      "identifier": "521e10b7-8e00-3188-9a27-476cca376351",
+      "name": "base-context",
+      "description": "my base parameter context",
+      "parameters": [
+        {{
+          "name": "my_old_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "old_value"
+        }}
+      ]
+    }}
+  ],
+  "rootGroup": {{
+    "name": "MiNiFi Flow",
+    "processors": [{{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {{
+        "Sensitive Property": "{}",
+        "Simple Property": "#{{my_old_parameter}}"
+      }}
+    }}],
+    "parameterContextName": "inherited-context"
+  }}
+}})", encrypted_parameter_value, encrypted_sensitive_property_value);
+
+  std::unique_ptr<core::ProcessGroup> flow = config.getRootFromPayload(CONFIG_JSON);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("MyProcessor");
+  REQUIRE(proc);
+  CHECK(proc->getProperty("Sensitive Property") == "value1");
+  CHECK(proc->getProperty("Simple Property") == "old_value");
+}
+
+TEST_CASE("Parameter context can not inherit from a itself") {
+  ConfigurationTestController test_controller;
+
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+
+  static const std::string CONFIG_JSON =
+      R"(
+{
+  "parameterContexts": [
+    {
+      "identifier": "521e10b7-8e00-3188-9a27-476cca376351",
+      "name": "base-context",
+      "description": "my base parameter context",
+      "parameters": [
+        {
+          "name": "my_old_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "old_value"
+        }
+      ],
+      "inheritedParameterContexts": ["base-context"]
+    }
+  ],
+  "rootGroup": {
+    "name": "MiNiFi Flow",
+    "processors": [{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {
+        "Simple Property": "#{my_old_parameter}"
+      }
+    }],
+    "parameterContextName": "base-context"
+  }
+})";
+
+  REQUIRE_THROWS_WITH(config.getRootFromPayload(CONFIG_JSON), "Inherited parameter context 'base-context' cannot be the same as the parameter context!");
+}
+
+TEST_CASE("Parameter context can not inherit from non-existing parameter context") {
+  ConfigurationTestController test_controller;
+
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+
+  static const std::string CONFIG_JSON =
+      R"(
+{
+  "parameterContexts": [
+    {
+      "identifier": "521e10b7-8e00-3188-9a27-476cca376351",
+      "name": "base-context",
+      "description": "my base parameter context",
+      "parameters": [
+        {
+          "name": "my_old_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "old_value"
+        }
+      ],
+      "inheritedParameterContexts": ["unknown"]
+    }
+  ],
+  "rootGroup": {
+    "name": "MiNiFi Flow",
+    "processors": [{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {
+        "Simple Property": "#{my_old_parameter}"
+      }
+    }],
+    "parameterContextName": "base-context"
+  }
+})";
+
+  REQUIRE_THROWS_WITH(config.getRootFromPayload(CONFIG_JSON), "Inherited parameter context 'unknown' does not exist!");
+}
+
+TEST_CASE("Cycles are not allowed in parameter context inheritance") {
+  ConfigurationTestController test_controller;
+
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+
+  static const std::string CONFIG_JSON =
+      R"(
+{
+  "parameterContexts": [
+    {
+      "identifier": "123e10b7-8e00-3188-9a27-476cca376351",
+      "name": "a-context",
+      "description": "",
+      "parameters": [
+        {
+          "name": "a_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "a_value"
+        }
+      ],
+      "inheritedParameterContexts": ["c-context"]
+    },
+    {
+      "identifier": "456e10b7-8e00-3188-9a27-476cca376351",
+      "name": "b-context",
+      "description": "",
+      "parameters": [
+        {
+          "name": "b_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "b_value"
+        }
+      ],
+      "inheritedParameterContexts": ["a-context"]
+    },
+    {
+      "identifier": "789e10b7-8e00-3188-9a27-476cca376351",
+      "name": "c-context",
+      "description": "",
+      "parameters": [
+        {
+          "name": "c_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "c_value"
+        }
+      ],
+      "inheritedParameterContexts": ["d-context", "b-context"]
+    },
+    {
+      "identifier": "101e10b7-8e00-3188-9a27-476cca376351",
+      "name": "d-context",
+      "description": "",
+      "parameters": [
+        {
+          "name": "d_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "d_value"
+        }
+      ],
+      "inheritedParameterContexts": []
+    }
+  ],
+  "rootGroup": {
+    "name": "MiNiFi Flow",
+    "processors": [{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {
+        "Simple Property": "#{my_old_parameter}"
+      }
+    }],
+    "parameterContextName": "c-context"
+  }
+})";
+
+  REQUIRE_THROWS_AS(config.getRootFromPayload(CONFIG_JSON), std::invalid_argument);
+  CHECK(minifi::test::utils::verifyLogLinePresenceInPollTime(0s, "Circular references in Parameter Context inheritance are not allowed. Inheritance cycle was detected in parameter context"));
+}
+
+TEST_CASE("Parameter context inheritance order is respected") {
+  ConfigurationTestController test_controller;
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+
+  static const std::string CONFIG_JSON =
+      R"(
+{
+  "parameterContexts": [
+    {
+      "identifier": "721e10b7-8e00-3188-9a27-476cca376978",
+      "name": "a-context",
+      "description": "",
+      "parameters": [
+        {
+          "name": "a_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "1"
+        },
+        {
+          "name": "b_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "2"
+        }
+      ]
+    },
+    {
+      "identifier": "521e10b7-8e00-3188-9a27-476cca376351",
+      "name": "b-context",
+      "description": "",
+      "parameters": [
+        {
+          "name": "b_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "3"
+        },
+        {
+          "name": "c_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "4"
+        }
+      ]
+    },
+    {
+      "identifier": "123e10b7-8e00-3188-9a27-476cca376351",
+      "name": "c-context",
+      "description": "",
+      "parameters": [
+        {
+          "name": "c_parameter",
+          "description": "",
+          "sensitive": false,
+          "value": "5"
+        }
+      ],
+      "inheritedParameterContexts": ["b-context", "a-context"]
+    }
+  ],
+  "rootGroup": {
+    "name": "MiNiFi Flow",
+    "processors": [{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {
+        "My A Property": "#{a_parameter}",
+        "My B Property": "#{b_parameter}",
+        "My C Property": "#{c_parameter}"
+      }
+    }],
+    "parameterContextName": "c-context"
+  }
+})";
+
+  std::unique_ptr<core::ProcessGroup> flow = config.getRootFromPayload(CONFIG_JSON);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("MyProcessor");
+  CHECK("1" == proc->getDynamicProperty("My A Property"));
+  CHECK("3" == proc->getDynamicProperty("My B Property"));
+  CHECK("5" == proc->getDynamicProperty("My C Property"));
+}
+
+TEST_CASE("Parameter providers can be used for parameter values") {
+  ConfigurationTestController test_controller;
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+
+  static const std::string CONFIG_JSON =
+      R"(
+{
+  "parameterProviders": [
+    {
+        "identifier": "d26ee5f5-0192-1000-0482-4e333725e089",
+        "name": "DummyParameterProvider",
+        "type": "DummyParameterProvider",
+        "properties": {
+          "Dummy1 Value": "value1",
+          "Dummy2 Value": "value2",
+          "Dummy3 Value": "value3"
+        }
+    }
+  ],
+  "rootGroup": {
+    "name": "MiNiFi Flow",
+    "processors": [{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {
+        "Simple Property": "#{dummy1}",
+        "My Dynamic Property Sequence": [
+          {"value": "#{dummy2}"},
+          {"value": "#{dummy3}"}
+        ]
+      }
+    }],
+    "parameterContextName": "dummycontext"
+  }
+})";
+
+  std::unique_ptr<core::ProcessGroup> flow = config.getRootFromPayload(CONFIG_JSON);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("MyProcessor");
+  REQUIRE(proc);
+  auto values = proc->getAllDynamicPropertyValues("My Dynamic Property Sequence");
+  CHECK((*values)[0] == "value2");
+  CHECK((*values)[1] == "value3");
+}
+
+TEST_CASE("Parameter providers can be configured to select which parameters to be sensitive") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{dummy1}", *context.sensitive_values_encryptor);
+  core::flow::AdaptiveConfiguration config(context);
+
+  static const std::string CONFIG_JSON =
+      fmt::format(R"(
+{{
+  "parameterProviders": [
+    {{
+        "identifier": "d26ee5f5-0192-1000-0482-4e333725e089",
+        "name": "DummyParameterProvider",
+        "type": "DummyParameterProvider",
+        "properties": {{
+          "Sensitive Parameter Scope": "selected",
+          "Sensitive Parameter List": "dummy1",
+          "Dummy1 Value": "value1",
+          "Dummy3 Value": "value3"
+        }}
+    }}
+  ],
+  "rootGroup": {{
+    "name": "MiNiFi Flow",
+    "processors": [{{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {{
+        "Simple Property": "#{{dummy3}}",
+        "Sensitive Property": "{}"
+      }}
+    }}],
+    "parameterContextName": "dummycontext"
+  }}
+}})", encrypted_sensitive_property_value);
+
+  std::unique_ptr<core::ProcessGroup> flow = config.getRootFromPayload(CONFIG_JSON);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("MyProcessor");
+  REQUIRE(proc);
+  CHECK(proc->getProperty("Sensitive Property") == "value1");
+  CHECK(proc->getProperty("Simple Property") == "value3");
+}
+
+TEST_CASE("If sensitive parameter scope is set to selected sensitive parameter list is required") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{dummy1}", *context.sensitive_values_encryptor);
+  core::flow::AdaptiveConfiguration config(context);
+
+  static const std::string CONFIG_JSON =
+      fmt::format(R"(
+{{
+  "parameterProviders": [
+    {{
+        "identifier": "d26ee5f5-0192-1000-0482-4e333725e089",
+        "name": "DummyParameterProvider",
+        "type": "DummyParameterProvider",
+        "properties": {{
+          "Sensitive Parameter Scope": "selected",
+          "Dummy1 Value": "value1",
+          "Dummy3 Value": "value3"
+        }}
+    }}
+  ],
+  "rootGroup": {{
+    "name": "MiNiFi Flow",
+    "processors": [{{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {{
+        "Simple Property": "#{{dummy3}}",
+        "Sensitive Property": "{}"
+      }}
+    }}],
+    "parameterContextName": "dummycontext"
+  }}
+}})", encrypted_sensitive_property_value);
+
+  REQUIRE_THROWS_WITH(config.getRootFromPayload(CONFIG_JSON), "Parameter Operation: Sensitive Parameter Scope is set to 'selected' but Sensitive Parameter List is empty");
+}
+
+TEST_CASE("Parameter providers can be configured to make all parameters sensitive") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{dummy1}", *context.sensitive_values_encryptor);
+  core::flow::AdaptiveConfiguration config(context);
+
+  static const std::string CONFIG_JSON =
+      fmt::format(R"(
+{{
+  "parameterProviders": [
+    {{
+        "identifier": "d26ee5f5-0192-1000-0482-4e333725e089",
+        "name": "DummyParameterProvider",
+        "type": "DummyParameterProvider",
+        "properties": {{
+          "Sensitive Parameter Scope": "all",
+          "Dummy1 Value": "value1",
+          "Dummy3 Value": "value3"
+        }}
+    }}
+  ],
+  "rootGroup": {{
+    "name": "MiNiFi Flow",
+    "processors": [{{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {{
+        "Sensitive Property": "{}"
+      }}
+    }}],
+    "parameterContextName": "dummycontext"
+  }}
+}})", encrypted_sensitive_property_value);
+
+  std::unique_ptr<core::ProcessGroup> flow = config.getRootFromPayload(CONFIG_JSON);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("MyProcessor");
+  REQUIRE(proc);
+  CHECK(proc->getProperty("Sensitive Property") == "value1");
+}
+
+TEST_CASE("Parameter context can be inherited from parameter provider generated parameter context") {
+  ConfigurationTestController test_controller;
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+
+  static const std::string CONFIG_JSON =
+      R"(
+{
+  "parameterProviders": [
+    {
+        "identifier": "d26ee5f5-0192-1000-0482-4e333725e089",
+        "name": "DummyParameterProvider",
+        "type": "DummyParameterProvider",
+        "properties": {
+          "Dummy1 Value": "value1",
+          "Dummy2 Value": "value2",
+          "Dummy3 Value": "value3"
+        }
+    }
+  ],
+  "parameterContexts": [
+    {
+      "identifier": "721e10b7-8e00-3188-9a27-476cca376978",
+      "name": "my-context",
+      "description": "my parameter context",
+      "parameters": [
+        {
+          "name": "file_size",
+          "description": "",
+          "sensitive": false,
+          "value": "10 B"
+        }
+      ],
+      "inheritedParameterContexts": ["dummycontext"]
+    }
+  ],
+  "rootGroup": {
+    "name": "MiNiFi Flow",
+    "processors": [{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {
+        "Simple Property": "#{dummy1}"
+      }
+    }],
+    "parameterContextName": "my-context"
+  }
+})";
+
+  std::unique_ptr<core::ProcessGroup> flow = config.getRootFromPayload(CONFIG_JSON);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("MyProcessor");
+  REQUIRE(proc);
+  CHECK(proc->getProperty("Simple Property") == "value1");
+}
+
+TEST_CASE("Parameter context names cannot conflict with parameter provider generated parameter context names") {
+  ConfigurationTestController test_controller;
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+
+  static const std::string CONFIG_JSON =
+      R"(
+{
+  "parameterProviders": [
+    {
+        "identifier": "d26ee5f5-0192-1000-0482-4e333725e089",
+        "name": "DummyParameterProvider",
+        "type": "DummyParameterProvider",
+        "properties": {
+          "Dummy1 Value": "value1",
+          "Dummy2 Value": "value2",
+          "Dummy3 Value": "value3"
+        }
+    }
+  ],
+  "parameterContexts": [
+    {
+      "identifier": "721e10b7-8e00-3188-9a27-476cca376978",
+      "name": "dummycontext",
+      "description": "my parameter context",
+      "parameters": [
+        {
+          "name": "file_size",
+          "description": "",
+          "sensitive": false,
+          "value": "10 B"
+        }
+      ]
+    }
+  ],
+  "rootGroup": {
+    "name": "MiNiFi Flow",
+    "processors": [{
+      "identifier": "00000000-0000-0000-0000-000000000001",
+      "name": "MyProcessor",
+      "type": "org.apache.nifi.processors.DummyProcessor",
+      "schedulingStrategy": "TIMER_DRIVEN",
+      "schedulingPeriod": "3 sec",
+      "properties": {
+        "Simple Property": "#{dummy1}"
+      }
+    }],
+    "parameterContextName": "dummycontext"
+  }
+})";
+
+  REQUIRE_THROWS_WITH(config.getRootFromPayload(CONFIG_JSON), "Parameter provider 'DummyParameterProvider' cannot create parameter context 'dummycontext' because parameter context already exists "
+    "with no parameter provider or generated by other parameter provider");
+}
+
 }  // namespace org::apache::nifi::minifi::test
