@@ -131,12 +131,6 @@ TEST_CASE("GetFile ignores files smaller than MinSize", "[GetFile]") {
   REQUIRE(LogTestController::getInstance().contains("Size:67 Offset:0"));
 }
 
-TEST_CASE("GetFile onSchedule() throws if the required Directory property is not set", "[GetFile]") {
-  GetFileTestController test_controller;
-  test_controller.setProperty(minifi::processors::GetFile::Directory, "");
-  REQUIRE_THROWS_AS(test_controller.runSession(), minifi::Exception);
-}
-
 TEST_CASE("GetFile removes the source file if KeepSourceFile is false") {
   GetFileTestController test_controller;
   SECTION("KeepSourceFile is not set, so defaults to false") {}
@@ -200,7 +194,7 @@ TEST_CASE("Only older files are read when MinAge property is set", "[getFileProp
   test_controller.setProperty(minifi::processors::GetFile::MinAge, "1 hour");
 
   const auto more_than_an_hour_ago = std::chrono::file_clock::now() - 65min;
-  utils::file::FileUtils::set_last_write_time(test_controller.getInputFilePath(), more_than_an_hour_ago);
+  REQUIRE(utils::file::FileUtils::set_last_write_time(test_controller.getInputFilePath(), more_than_an_hour_ago));
 
   test_controller.runSession();
 
@@ -214,7 +208,7 @@ TEST_CASE("Only newer files are read when MaxAge property is set", "[getFileProp
   test_controller.setProperty(minifi::processors::GetFile::MaxAge, "1 hour");
 
   const auto more_than_an_hour_ago = std::chrono::file_clock::now() - 65min;
-  utils::file::FileUtils::set_last_write_time(test_controller.getInputFilePath(), more_than_an_hour_ago);
+  REQUIRE(utils::file::FileUtils::set_last_write_time(test_controller.getInputFilePath(), more_than_an_hour_ago));
 
   test_controller.runSession();
 
@@ -271,10 +265,10 @@ TEST_CASE("GetFile sets attributes correctly") {
   using minifi::processors::GetFile;
 
   LogTestController::getInstance().setTrace<GetFile>();
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<GetFile>("GetFile"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<GetFile>("GetFile"));
   const auto get_file = test_controller.getProcessor();
   std::filesystem::path dir = test_controller.createTempDirectory();
-  get_file->setProperty(GetFile::Directory, dir.string());
+  REQUIRE(get_file->setProperty(GetFile::Directory.name, dir.string()));
   SECTION("File in subdirectory of input directory") {
     std::filesystem::create_directories(dir / "a" / "b");
     minifi::test::utils::putFileToDir(dir / "a" / "b", "alpha.txt", "The quick brown fox jumps over the lazy dog\n");
@@ -303,14 +297,14 @@ TEST_CASE("GetFile can use expression language in Directory property") {
   using minifi::processors::GetFile;
   LogTestController::getInstance().setTrace<GetFile>();
 
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<GetFile>("GetFile"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<GetFile>("GetFile"));
   const auto get_file = test_controller.getProcessor();
 
   std::filesystem::path base_dir = test_controller.createTempDirectory();
   auto date_str = date::format("%Y-%m-%d", std::chrono::system_clock::now());
   auto dir = base_dir/ date_str;
   std::filesystem::create_directories(dir);
-  get_file->setProperty(GetFile::Directory, base_dir.string() + "/${now():format('%Y-%m-%d')}");
+  REQUIRE(get_file->setProperty(GetFile::Directory.name, base_dir.string() + "/${now():format('%Y-%m-%d')}"));
   minifi::test::utils::putFileToDir(dir, "testfile.txt", "The quick brown fox jumps over the lazy dog\n");
 
   auto result = test_controller.trigger();
