@@ -28,10 +28,10 @@ namespace org::apache::nifi::minifi::test {
 // NOLINTBEGIN(readability-container-size-empty)
 
 TEST_CASE("Shiftr successful case") {
-  SingleProcessorTestController controller{std::make_unique<minifi::processors::JoltTransformJSON>("JoltProc")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::JoltTransformJSON>("JoltProc")};
   auto proc = controller.getProcessor();
-  proc->setProperty(processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
-  proc->setProperty(processors::JoltTransformJSON::JoltSpecification, R"json(
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltSpecification, R"json(
     {
       "a": "a_out",
       "b": {
@@ -76,10 +76,10 @@ TEST_CASE("Shiftr successful case") {
 }
 
 TEST_CASE("Shiftr multiple destination") {
-  SingleProcessorTestController controller{std::make_unique<minifi::processors::JoltTransformJSON>("JoltProc")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::JoltTransformJSON>("JoltProc")};
   auto proc = controller.getProcessor();
-  proc->setProperty(processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
-  proc->setProperty(processors::JoltTransformJSON::JoltSpecification, R"json(
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltSpecification, R"json(
     {
       "a": ["out1", "out2.inner"]
     }
@@ -128,10 +128,10 @@ TEST_CASE("Shiftr invalid reference") {
 }
 
 TEST_CASE("Shiftr matches are correctly ordered") {
-  SingleProcessorTestController controller{std::make_unique<minifi::processors::JoltTransformJSON>("JoltProc")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::JoltTransformJSON>("JoltProc")};
   auto proc = controller.getProcessor();
-  proc->setProperty(processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
-  proc->setProperty(processors::JoltTransformJSON::JoltSpecification, R"json(
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltSpecification, R"json(
     {
       "a": {
         "a": {
@@ -172,10 +172,10 @@ TEST_CASE("Shiftr matches are correctly ordered") {
 }
 
 TEST_CASE("Shiftr arrays are maps with numeric keys") {
-  SingleProcessorTestController controller{std::make_unique<minifi::processors::JoltTransformJSON>("JoltProc")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::JoltTransformJSON>("JoltProc")};
   auto proc = controller.getProcessor();
-  proc->setProperty(processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
-  proc->setProperty(processors::JoltTransformJSON::JoltSpecification, R"json(
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltSpecification, R"json(
     {
       "a": {
         "0": "a_&",
@@ -204,10 +204,10 @@ TEST_CASE("Shiftr arrays are maps with numeric keys") {
 }
 
 TEST_CASE("Shiftr put into array at index") {
-  SingleProcessorTestController controller{std::make_unique<minifi::processors::JoltTransformJSON>("JoltProc")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::JoltTransformJSON>("JoltProc")};
   auto proc = controller.getProcessor();
-  proc->setProperty(processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
-  proc->setProperty(processors::JoltTransformJSON::JoltSpecification, R"json(
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltSpecification, R"json(
     {
       "a": "out[1]",
       "b": "out[2].inner",
@@ -238,10 +238,10 @@ TEST_CASE("Shiftr put into array at index") {
 
 TEST_CASE("Shiftr multiple patterns") {
   // this is an extension, so we can escape and match on a '|' character
-  SingleProcessorTestController controller{std::make_unique<minifi::processors::JoltTransformJSON>("JoltProc")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::JoltTransformJSON>("JoltProc")};
   auto proc = controller.getProcessor();
-  proc->setProperty(processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
-  proc->setProperty(processors::JoltTransformJSON::JoltSpecification, R"json(
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
+  controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltSpecification, R"json(
     {
       "a|b": "out1",
       "b\\||c": "out2"
@@ -305,11 +305,11 @@ TEST_CASE("Run tests from https://github.com/bazaarvoice/jolt") {
       throw std::logic_error(fmt::format("Error in test json '{}' at {}:{} : {}", entry.string(), cursor.first, cursor.second, rapidjson::GetParseError_En(parse_res.Code())));
     }
 
-    SingleProcessorTestController controller{std::make_unique<minifi::processors::JoltTransformJSON>("JoltProc")};
+    SingleProcessorTestController controller{minifi::test::utils::make_processor<minifi::processors::JoltTransformJSON>("JoltProc")};
     auto proc = controller.getProcessor();
     LogTestController::getInstance().setTrace<minifi::processors::JoltTransformJSON>();
-    proc->setProperty(processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
-    proc->setProperty(processors::JoltTransformJSON::JoltSpecification, to_string(doc["spec"]));
+    controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltTransform, magic_enum::enum_name(processors::jolt_transform_json::JoltTransform::Shift));
+    controller.plan->setProperty(proc, processors::JoltTransformJSON::JoltSpecification, to_string(doc["spec"]));
 
     auto res = controller.trigger(to_string(doc["input"]));
 
