@@ -249,16 +249,16 @@ void check_parsed_attributes(const core::FlowFile& flow_file, const ValidRFC3164
 }
 
 TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
-  SingleProcessorTestController controller{std::make_unique<ListenSyslog>("ListenSyslog")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenSyslog>("ListenSyslog")};
   const auto listen_syslog = controller.getProcessor<ListenSyslog>();
   LogTestController::getInstance().setTrace<ListenSyslog>();
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "2"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages, "false"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize.name, "2"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages.name, "false"));
   std::string protocol;
   uint16_t port = 0;
 
   SECTION("UDP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "UDP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "UDP"));
     protocol = "UDP";
 
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
@@ -278,7 +278,7 @@ TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
   }
 
   SECTION("TCP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "TCP"));
     protocol = "TCP";
 
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
@@ -305,16 +305,16 @@ TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
 }
 
 TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog][NetworkListenerProcessor]") {
-  SingleProcessorTestController controller{std::make_unique<ListenSyslog>("ListenSyslog")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenSyslog>("ListenSyslog")};
   const auto listen_syslog = controller.getProcessor<ListenSyslog>();
   LogTestController::getInstance().setTrace<ListenSyslog>();
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "100"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages, "true"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize.name, "100"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages.name, "true"));
 
   std::string protocol;
   uint16_t port = 0;
   SECTION("UDP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "UDP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "UDP"));
     protocol = "UDP";
 
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
@@ -344,7 +344,7 @@ TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog][NetworkListenerProce
   }
 
   SECTION("TCP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "TCP"));
     protocol = "TCP";
 
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
@@ -410,21 +410,21 @@ TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog][NetworkListenerProce
 }
 
 TEST_CASE("ListenSyslog can be rescheduled", "[ListenSyslog][NetworkListenerProcessor]") {
-  SingleProcessorTestController controller{std::make_unique<ListenSyslog>("ListenSyslog")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenSyslog>("ListenSyslog")};
   const auto listen_syslog = controller.getProcessor<ListenSyslog>();
   LogTestController::getInstance().setTrace<ListenSyslog>();
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::Port, "0"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "100"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages, "true"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::Port.name, "0"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize.name, "100"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages.name, "true"));
   SECTION("UDP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "UDP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "UDP"));
     REQUIRE_NOTHROW(controller.plan->scheduleProcessor(listen_syslog));
     REQUIRE_NOTHROW(controller.plan->reset(true));
     REQUIRE_NOTHROW(controller.plan->scheduleProcessor(listen_syslog));
   }
 
   SECTION("TCP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "TCP"));
     REQUIRE_NOTHROW(controller.plan->scheduleProcessor(listen_syslog));
     REQUIRE_NOTHROW(controller.plan->reset(true));
     REQUIRE_NOTHROW(controller.plan->scheduleProcessor(listen_syslog));
@@ -432,18 +432,18 @@ TEST_CASE("ListenSyslog can be rescheduled", "[ListenSyslog][NetworkListenerProc
 }
 
 TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog][NetworkListenerProcessor]") {
-  SingleProcessorTestController controller{std::make_unique<ListenSyslog>("ListenSyslog")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenSyslog>("ListenSyslog")};
   const auto listen_syslog = controller.getProcessor<ListenSyslog>();
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "10"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages, "false"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxQueueSize, "50"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize.name, "10"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages.name, "false"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxQueueSize.name, "50"));
 
   LogTestController::getInstance().setWarn<ListenSyslog>();
 
   uint16_t port = 0;
 
   SECTION("UDP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "UDP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "UDP"));
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::udp::endpoint endpoint;
@@ -462,7 +462,7 @@ TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog][Netw
   }
 
   SECTION("TCP") {
-    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
+    REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "TCP"));
     port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
     asio::ip::tcp::endpoint endpoint;
@@ -490,7 +490,7 @@ TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog][Netw
 }
 
 TEST_CASE("Test ListenSyslog via TCP with SSL connection", "[ListenSyslog][NetworkListenerProcessor]") {
-  SingleProcessorTestController controller{std::make_unique<ListenSyslog>("ListenSyslog")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenSyslog>("ListenSyslog")};
   const auto listen_syslog = controller.getProcessor<ListenSyslog>();
 
   auto ssl_context_service = controller.plan->addController("SSLContextService", "SSLContextService");
@@ -501,10 +501,10 @@ TEST_CASE("Test ListenSyslog via TCP with SSL connection", "[ListenSyslog][Netwo
   ssl_context_service->enable();
 
   LogTestController::getInstance().setTrace<ListenSyslog>();
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "2"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages, "false"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
-  REQUIRE(listen_syslog->setProperty(ListenSyslog::SSLContextService, "SSLContextService"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize.name, "2"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages.name, "false"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty.name, "TCP"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::SSLContextService.name, "SSLContextService"));
 
   auto port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_syslog);
 
