@@ -36,11 +36,11 @@ void check_for_attributes(core::FlowFile& flow_file, uint16_t port) {
 }
 
 TEST_CASE("ListenUDP test multiple messages", "[ListenUDP][NetworkListenerProcessor]") {
-  SingleProcessorTestController controller{std::make_unique<ListenUDP>("ListenUDP")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenUDP>("ListenUDP")};
   const auto listen_udp = controller.getProcessor<ListenUDP>();
   LogTestController::getInstance().setTrace<ListenUDP>();
 
-  REQUIRE(listen_udp->setProperty(ListenUDP::MaxBatchSize, "2"));
+  REQUIRE(listen_udp->setProperty(ListenUDP::MaxBatchSize.name, "2"));
 
   auto port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_udp);
 
@@ -68,11 +68,11 @@ TEST_CASE("ListenUDP test multiple messages", "[ListenUDP][NetworkListenerProces
 }
 
 TEST_CASE("ListenUDP can be rescheduled", "[ListenUDP][NetworkListenerProcessor]") {
-  SingleProcessorTestController controller{std::make_unique<ListenUDP>("ListenUDP")};
-  const auto listen_udp = controller.getProcessor<ListenUDP>();
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenUDP>("ListenUDP")};
+  const auto listen_udp = controller.getProcessor();
   LogTestController::getInstance().setTrace<ListenUDP>();
-  REQUIRE(listen_udp->setProperty(ListenUDP::Port, "0"));
-  REQUIRE(listen_udp->setProperty(ListenUDP::MaxBatchSize, "100"));
+  REQUIRE(listen_udp->setProperty(ListenUDP::Port.name, "0"));
+  REQUIRE(listen_udp->setProperty(ListenUDP::MaxBatchSize.name, "100"));
 
   REQUIRE_NOTHROW(controller.plan->scheduleProcessor(listen_udp));
   REQUIRE_NOTHROW(controller.plan->reset(true));
@@ -80,10 +80,10 @@ TEST_CASE("ListenUDP can be rescheduled", "[ListenUDP][NetworkListenerProcessor]
 }
 
 TEST_CASE("ListenUDP max queue and max batch size test", "[ListenUDP][NetworkListenerProcessor]") {
-  SingleProcessorTestController controller{std::make_unique<ListenUDP>("ListenUDP")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<ListenUDP>("ListenUDP")};
   const auto listen_udp = controller.getProcessor<ListenUDP>();
-  REQUIRE(listen_udp->setProperty(ListenUDP::MaxBatchSize, "10"));
-  REQUIRE(listen_udp->setProperty(ListenUDP::MaxQueueSize, "50"));
+  REQUIRE(listen_udp->setProperty(ListenUDP::MaxBatchSize.name, "10"));
+  REQUIRE(listen_udp->setProperty(ListenUDP::MaxQueueSize.name, "50"));
 
   auto port = utils::scheduleProcessorOnRandomPort(controller.plan, listen_udp);
 
