@@ -26,6 +26,7 @@
 #include <fstream>
 #include <GenerateFlowFile.h>
 #ifdef WIN32
+#include <windows.h>
 #include <fileapi.h>
 #include <system_error>
 #endif /* WIN32 */
@@ -42,18 +43,18 @@
 #include "core/Processor.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
-#include "core/ProcessorNode.h"
 #include "core/reporting/SiteToSiteProvenanceReportingTask.h"
 #include "core/Resource.h"
 #include "utils/gsl.h"
-#include "utils/PropertyErrors.h"
+#include "utils/PropertyExceptions.h"
 #include "unit/TestUtils.h"
 #include "io/BufferStream.h"
 #include "fmt/format.h"
+#include "processors/TailFile.h"
 
 TEST_CASE("Test Creation of GetFile", "[getfileCreate]") {
   TestController testController;
-  auto processor = std::make_shared<minifi::processors::GetFile>("processorname");
+  auto processor = minifi::test::utils::make_processor<minifi::processors::GetFile>("processorname");
   REQUIRE(processor->getName() == "processorname");
 }
 
@@ -63,19 +64,19 @@ TEST_CASE("Test Creation of GetFile", "[getfileCreate]") {
 TEST_CASE("Test GetFileMultiple", "[getfileCreate3]") {
   TestController testController;
   LogTestController::getInstance().setDebug<minifi::processors::GetFile>();
-  auto config = std::make_shared<minifi::Configure>();
+  auto config = std::make_shared<minifi::ConfigureImpl>();
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
   content_repo->initialize(config);
-  auto processor = std::make_shared<minifi::processors::GetFile>("getfileCreate2");
+  auto processor = minifi::test::utils::make_processor<minifi::processors::GetFile>("getfileCreate2");
   processor->initialize();
   std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
-  std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
+  std::shared_ptr<TestRepository> repo = std::dynamic_pointer_cast<TestRepository>(test_repo);
 
   auto dir = testController.createTempDirectory();
   utils::Identifier processoruuid = processor->getUUID();
   REQUIRE(processoruuid);
 
-  auto connection = std::make_unique<minifi::Connection>(test_repo, content_repo, "getfileCreate2Connection");
+  auto connection = std::make_unique<minifi::ConnectionImpl>(test_repo, content_repo, "getfileCreate2Connection");
 
   connection->addRelationship(core::Relationship("success", "description"));
 
@@ -89,19 +90,18 @@ TEST_CASE("Test GetFileMultiple", "[getfileCreate3]") {
   processor->addConnection(connection.get());
   REQUIRE(!dir.empty());
 
-  auto node = std::make_shared<core::ProcessorNode>(processor.get());
-  auto context = std::make_shared<core::ProcessContext>(node, nullptr, repo, repo, content_repo);
+  auto context = std::make_shared<core::ProcessContextImpl>(*processor, nullptr, repo, repo, content_repo);
 
-  context->setProperty(minifi::processors::GetFile::Directory, dir.string());
+  REQUIRE(context->setProperty(minifi::processors::GetFile::Directory.name, dir.string()));
   // replicate 10 threads
   processor->setScheduledState(core::ScheduledState::RUNNING);
 
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context);
 
   processor->onSchedule(*context, *factory);
 
   for (int i = 1; i < 10; i++) {
-    auto session = std::make_shared<core::ProcessSession>(context);
+    auto session = std::make_shared<core::ProcessSessionImpl>(context);
     REQUIRE(processor->getName() == "getfileCreate2");
 
     std::shared_ptr<core::FlowFile> record;
@@ -147,18 +147,18 @@ TEST_CASE("Test GetFile Ignore", "[getfileCreate3]") {
   TestController testController;
   LogTestController::getInstance().setDebug<minifi::processors::GetFile>();
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
-  auto processor = std::make_shared<minifi::processors::GetFile>("getfileCreate2");
+  auto processor = minifi::test::utils::make_processor<minifi::processors::GetFile>("getfileCreate2");
   processor->initialize();
 
   std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
-  std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
+  std::shared_ptr<TestRepository> repo = std::dynamic_pointer_cast<TestRepository>(test_repo);
 
   const auto dir = testController.createTempDirectory();
 
   utils::Identifier processoruuid = processor->getUUID();
   REQUIRE(processoruuid);
 
-  std::shared_ptr<minifi::Connection> connection = std::make_shared<minifi::Connection>(test_repo, content_repo, "getfileCreate2Connection");
+  std::shared_ptr<minifi::Connection> connection = std::make_shared<minifi::ConnectionImpl>(test_repo, content_repo, "getfileCreate2Connection");
 
   connection->addRelationship(core::Relationship("success", "description"));
 
@@ -172,18 +172,17 @@ TEST_CASE("Test GetFile Ignore", "[getfileCreate3]") {
   processor->addConnection(connection.get());
   REQUIRE(!dir.empty());
 
-  auto node = std::make_shared<core::ProcessorNode>(processor.get());
-  auto context = std::make_shared<core::ProcessContext>(node, nullptr, repo, repo, content_repo);
+  auto context = std::make_shared<core::ProcessContextImpl>(*processor, nullptr, repo, repo, content_repo);
 
-  context->setProperty(minifi::processors::GetFile::Directory, dir.string());
+  REQUIRE(context->setProperty(minifi::processors::GetFile::Directory.name, dir.string()));
   // replicate 10 threads
   processor->setScheduledState(core::ScheduledState::RUNNING);
 
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context);
 
   processor->onSchedule(*context, *factory);
 
-  auto session = std::make_shared<core::ProcessSession>(context);
+  auto session = std::make_shared<core::ProcessSessionImpl>(context);
   REQUIRE(processor->getName() == "getfileCreate2");
 
   std::shared_ptr<core::FlowFile> record;
@@ -233,16 +232,16 @@ TEST_CASE("TestConnectionFull", "[ConnectionFull]") {
   TestController testController;
   LogTestController::getInstance().setDebug<minifi::processors::GenerateFlowFile>();
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
-  content_repo->initialize(std::make_shared<minifi::Configure>());
-  auto processor = std::make_shared<minifi::processors::GenerateFlowFile>("GFF");
+  content_repo->initialize(std::make_shared<minifi::ConfigureImpl>());
+  auto processor = minifi::test::utils::make_processor<org::apache::nifi::minifi::processors::GenerateFlowFile>("GFF");
   processor->initialize();
-  processor->setProperty(minifi::processors::GenerateFlowFile::BatchSize, "10");
-  processor->setProperty(minifi::processors::GenerateFlowFile::FileSize, "0");
+  REQUIRE(processor->setProperty(minifi::processors::GenerateFlowFile::BatchSize.name, "10"));
+  REQUIRE(processor->setProperty(minifi::processors::GenerateFlowFile::FileSize.name, "0"));
 
   std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
-  std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
+  std::shared_ptr<TestRepository> repo = std::dynamic_pointer_cast<TestRepository>(test_repo);
 
-  std::shared_ptr<minifi::Connection> connection = std::make_shared<minifi::Connection>(test_repo, content_repo, "GFF2Connection");
+  std::shared_ptr<minifi::Connection> connection = std::make_shared<minifi::ConnectionImpl>(test_repo, content_repo, "GFF2Connection");
   connection->setBackpressureThresholdCount(5);
   connection->addRelationship(core::Relationship("success", "description"));
 
@@ -258,14 +257,13 @@ TEST_CASE("TestConnectionFull", "[ConnectionFull]") {
   processor->addConnection(connection.get());
   processor->setScheduledState(core::ScheduledState::RUNNING);
 
-  auto node = std::make_shared<core::ProcessorNode>(processor.get());
-  auto context = std::make_shared<core::ProcessContext>(node, nullptr, repo, repo, content_repo);
+  auto context = std::make_shared<core::ProcessContextImpl>(*processor, nullptr, repo, repo, content_repo);
 
-  auto factory = std::make_shared<core::ProcessSessionFactory>(context);
+  auto factory = std::make_shared<core::ProcessSessionFactoryImpl>(context);
 
   processor->onSchedule(*context, *factory);
 
-  auto session = std::make_shared<core::ProcessSession>(context);
+  auto session = std::make_shared<core::ProcessSessionImpl>(context);
 
   CHECK_FALSE(session->outgoingConnectionsFull("success"));
   CHECK_FALSE(connection->backpressureThresholdReached());
@@ -333,9 +331,9 @@ TEST_CASE("LogAttributeTestInvalid", "[TestLogAttribute]") {
 
   auto dir = testController.createTempDirectory();
 
-  plan->setProperty(getfile, minifi::processors::GetFile::Directory, dir.string());
-  plan->setProperty(getfile, minifi::processors::GetFile::BatchSize, "1");
-  REQUIRE_THROWS_AS(plan->setProperty(loggattr, minifi::processors::LogAttribute::FlowFilesToLog, "-1"), utils::internal::ParseException);
+  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::Directory, dir.string());
+  plan->setProperty(getfile, org::apache::nifi::minifi::processors::GetFile::BatchSize, "1");
+  REQUIRE_FALSE(plan->setProperty(loggattr, org::apache::nifi::minifi::processors::LogAttribute::FlowFilesToLog, "-1"));
   LogTestController::getInstance().reset();
 }
 
@@ -412,8 +410,9 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
   LogTestController::getInstance().setDebug<minifi::provenance::ProvenanceReporter>();
   std::shared_ptr<TestPlan> plan = testController.createPlan();
   auto processor = plan->addProcessor("GetFile", "getfileCreate2");
-  auto processorReport = plan->addProcessor(std::make_unique<minifi::core::reporting::SiteToSiteProvenanceReportingTask>(
-      std::make_shared<minifi::Configure>()), "reporter", core::Relationship("success", "description"), false);
+  TypedProcessorWrapper<minifi::core::reporting::SiteToSiteProvenanceReportingTask> processorReport = plan->addProcessor(
+      minifi::test::utils::make_custom_processor<minifi::core::reporting::SiteToSiteProvenanceReportingTask>(std::make_shared<minifi::ConfigureImpl>()),
+      "reporter", core::Relationship("success", "description"), false);
 
   auto dir = testController.createTempDirectory();
   plan->setProperty(processor, minifi::processors::GetFile::Directory, dir.string());
@@ -439,11 +438,11 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
   std::shared_ptr<core::FlowFile> ffr = plan->getCurrentFlowFile();
   REQUIRE(ffr != nullptr);
   ffr->getResourceClaim()->decreaseFlowFileRecordOwnedCount();
-  auto repo = std::static_pointer_cast<TestRepository>(plan->getProvenanceRepo());
+  auto repo = std::dynamic_pointer_cast<TestRepository>(plan->getProvenanceRepo());
   REQUIRE(2 == repo->getRepoMap().size());
 
   for (auto entry : repo->getRepoMap()) {
-    minifi::provenance::ProvenanceEventRecord newRecord;
+    minifi::provenance::ProvenanceEventRecordImpl newRecord;
     minifi::io::BufferStream stream(gsl::make_span(entry.second).as_span<const std::byte>());
     newRecord.deserialize(stream);
 
@@ -463,10 +462,10 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
       throw std::runtime_error("Did not find record");
     }
   }
-  auto taskReport = static_cast<minifi::core::reporting::SiteToSiteProvenanceReportingTask*>(processorReport);
+  auto taskReport = &processorReport.get();
   taskReport->setBatchSize(1);
   std::vector<std::shared_ptr<core::SerializableComponent>> recordsReport;
-  recordsReport.push_back(std::make_shared<minifi::provenance::ProvenanceEventRecord>());
+  recordsReport.push_back(std::make_shared<minifi::provenance::ProvenanceEventRecordImpl>());
   processorReport->incrementActiveTasks();
   processorReport->setScheduledState(core::ScheduledState::RUNNING);
   std::string jsonStr;
@@ -483,11 +482,9 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
   testController.runSession(plan, false, verifyReporter);
 }
 
-class TestProcessorNoContent : public minifi::core::Processor {
+class TestProcessorNoContent : public minifi::core::ProcessorImpl {
  public:
-  explicit TestProcessorNoContent(std::string_view name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   static constexpr const char* Description = "test resource";
   static constexpr auto Properties = std::array<core::PropertyReference, 0>{};
@@ -539,20 +536,19 @@ void testRPGBypass(const std::string &host, const std::string &port, bool has_er
   LogTestController::getInstance().setTrace<minifi::core::ProcessSession>();
   LogTestController::getInstance().setTrace<TestPlan>();
 
-  auto configuration = std::make_shared<minifi::Configure>();
+  auto configuration = std::make_shared<minifi::ConfigureImpl>();
 
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
 
   std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
-  std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
+  std::shared_ptr<TestRepository> repo = std::dynamic_pointer_cast<TestRepository>(test_repo);
 
-  auto rpg = std::make_shared<minifi::RemoteProcessorGroupPort>("rpg", "http://localhost:8989/nifi", configuration);
+  auto rpg = minifi::test::utils::make_custom_processor<minifi::RemoteProcessorGroupPort>("rpg", "http://localhost:8989/nifi", configuration, utils::IdGenerator::getIdGenerator()->generate());
   rpg->initialize();
-  REQUIRE(rpg->setProperty(minifi::RemoteProcessorGroupPort::hostName, host));
-  rpg->setProperty(minifi::RemoteProcessorGroupPort::port, port);
-  auto node = std::make_shared<core::ProcessorNode>(rpg.get());
-  auto context = std::make_shared<core::ProcessContext>(node, nullptr, repo, repo, content_repo);
-  auto psf = std::make_shared<core::ProcessSessionFactory>(context);
+  REQUIRE(rpg->setProperty(minifi::RemoteProcessorGroupPort::hostName.name, host));
+  REQUIRE(rpg->setProperty(minifi::RemoteProcessorGroupPort::port.name, port));
+  auto context = std::make_shared<core::ProcessContextImpl>(*rpg, nullptr, repo, repo, content_repo);
+  auto psf = std::make_shared<core::ProcessSessionFactoryImpl>(context);
   if (has_error) {
     rpg->onSchedule(*context, *psf);
     auto expected_error = "No peers selected during scheduling";
@@ -597,7 +593,7 @@ class ProcessorWithIncomingConnectionTest {
   ~ProcessorWithIncomingConnectionTest();
 
  protected:
-  std::shared_ptr<minifi::processors::LogAttribute> processor_;
+  std::shared_ptr<minifi::core::Processor> processor_;
   std::shared_ptr<minifi::Connection> incoming_connection_;
   std::shared_ptr<core::ProcessSession> session_;
 };
@@ -607,18 +603,17 @@ ProcessorWithIncomingConnectionTest::ProcessorWithIncomingConnectionTest() {
 
   const auto repo = std::make_shared<TestRepository>();
   const auto content_repo = std::make_shared<core::repository::VolatileContentRepository>();
-  content_repo->initialize(std::make_shared<minifi::Configure>());
+  content_repo->initialize(std::make_shared<minifi::ConfigureImpl>());
 
-  processor_ = std::make_shared<minifi::processors::LogAttribute>("test_processor");
-  incoming_connection_ = std::make_shared<minifi::Connection>(repo, content_repo, "incoming_connection");
+  processor_ = minifi::test::utils::make_processor<minifi::processors::LogAttribute>("test_processor");
+  incoming_connection_ = std::make_shared<minifi::ConnectionImpl>(repo, content_repo, "incoming_connection");
   incoming_connection_->addRelationship(core::Relationship{"success", ""});
   incoming_connection_->setDestinationUUID(processor_->getUUID());
   processor_->addConnection(incoming_connection_.get());
   processor_->initialize();
 
-  const auto processor_node = std::make_shared<core::ProcessorNode>(processor_.get());
-  const auto context = std::make_shared<core::ProcessContext>(processor_node, nullptr, repo, repo, content_repo);
-  const auto session_factory = std::make_shared<core::ProcessSessionFactory>(context);
+  const auto context = std::make_shared<core::ProcessContextImpl>(*processor_, nullptr, repo, repo, content_repo);
+  const auto session_factory = std::make_shared<core::ProcessSessionFactoryImpl>(context);
   session_ = session_factory->createSession();
 }
 
@@ -793,6 +788,7 @@ TEST_CASE("isSingleThreaded - one thread for a single threaded processor", "[isS
 TEST_CASE("isSingleThreaded - two threads for a single threaded processor", "[isSingleThreaded]") {
   TestController testController;
   LogTestController::getInstance().setDebug<minifi::core::Processor>();
+  LogTestController::getInstance().setDebug<minifi::processors::TailFile>();
 
   std::shared_ptr<TestPlan> plan = testController.createPlan();
   auto processor = plan->addProcessor("TailFile", "myProc");
@@ -813,7 +809,7 @@ TEST_CASE("Test getProcessorType", "[getProcessorType]") {
 }
 
 TEST_CASE("IsYield and getYieldTime is consistent") {
-  auto processor = TestProcessorNoContent("test_processor");
-  processor.yield(1ms);
-  REQUIRE(processor.isYield() == (processor.getYieldTime() != 0ms));
+  auto processor = minifi::test::utils::make_processor<TestProcessorNoContent>("test_processor");
+  processor->yield(1ms);
+  REQUIRE(processor->isYield() == (processor->getYieldTime() != 0ms));
 }
