@@ -50,7 +50,7 @@ class CancellableTcpServer : public utils::net::TcpServer {
 
   void cancelEverything() {
     for (auto& timer : cancellable_timers_)
-      io_context_.post([=]{timer->cancel();});
+      asio::post(io_context_, [=]{timer->cancel();});
   }
 
   asio::awaitable<void> doReceive() override {
@@ -98,14 +98,14 @@ utils::net::SslData createSslDataForServer() {
 class PutTCPTestFixture {
  public:
   PutTCPTestFixture() :
-      controller_(std::make_unique<PutTCP>("PutTCP")),
-      put_tcp_(controller_.getProcessor<PutTCP>()) {
+      controller_(minifi::test::utils::make_processor<PutTCP>("PutTCP")),
+      put_tcp_(controller_.getProcessor()) {
     LogTestController::getInstance().setTrace<PutTCP>();
     LogTestController::getInstance().setInfo<core::ProcessSession>();
     LogTestController::getInstance().setTrace<utils::net::Server>();
-    put_tcp_->setProperty(PutTCP::Hostname, "${literal('localhost')}");
-    put_tcp_->setProperty(PutTCP::Timeout, "200 ms");
-    put_tcp_->setProperty(PutTCP::OutgoingMessageDelimiter, "\n");
+    REQUIRE(put_tcp_->setProperty(PutTCP::Hostname.name, "${literal('localhost')}"));
+    REQUIRE(put_tcp_->setProperty(PutTCP::Timeout.name, "200 ms"));
+    REQUIRE(put_tcp_->setProperty(PutTCP::OutgoingMessageDelimiter.name, "\n"));
   }
 
   PutTCPTestFixture(PutTCPTestFixture&&) = delete;
@@ -179,7 +179,7 @@ class PutTCPTestFixture {
     }
     ssl_context_service_node->enable();
 
-    put_tcp_->setProperty(PutTCP::SSLContextService, "SSLContextService");
+    REQUIRE(put_tcp_->setProperty(PutTCP::SSLContextService.name, "SSLContextService"));
   }
 
   void setHostname(const std::string& hostname) {
@@ -210,11 +210,11 @@ class PutTCPTestFixture {
   }
 
   void setPutTCPPort(uint16_t port) {
-    put_tcp_->setProperty(PutTCP::Port, utils::string::join_pack("${literal('", std::to_string(port), "')}"));
+    CHECK(put_tcp_->setProperty(PutTCP::Port.name, utils::string::join_pack("${literal('", std::to_string(port), "')}")));
   }
 
   void setPutTCPPort(const std::string& port_str) {
-    put_tcp_->setProperty(PutTCP::Port, port_str);
+    CHECK(put_tcp_->setProperty(PutTCP::Port.name, port_str));
   }
 
   [[nodiscard]] uint16_t getSinglePort() const {
@@ -230,7 +230,7 @@ class PutTCPTestFixture {
   }
 
   test::SingleProcessorTestController controller_;
-  PutTCP* put_tcp_;
+  minifi::core::Processor* put_tcp_;
 
   class Server {
    public:
