@@ -27,6 +27,7 @@
 #include "utils/net/UdpServer.h"
 #include "utils/expected.h"
 #include "utils/StringUtils.h"
+#include "unit/TestUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -46,12 +47,12 @@ std::optional<utils::net::Message> tryDequeueWithTimeout(utils::net::UdpServer&
 }  // namespace
 
 TEST_CASE("PutUDP", "[putudp]") {
-  test::SingleProcessorTestController controller{std::make_unique<PutUDP>("PutUDP")};
+  test::SingleProcessorTestController controller{minifi::test::utils::make_processor<PutUDP>("PutUDP")};
   const auto put_udp = controller.getProcessor();
 
   LogTestController::getInstance().setTrace<PutUDP>();
   LogTestController::getInstance().setTrace<core::ProcessContext>();
-  put_udp->setProperty(PutUDP::Hostname, "${literal('localhost')}");
+  REQUIRE(put_udp->setProperty(PutUDP::Hostname.name, "${literal('localhost')}"));
 
   utils::net::UdpServer listener{std::nullopt, 0, core::logging::LoggerFactory<utils::net::UdpServer>::getLogger()};
 
@@ -66,7 +67,7 @@ TEST_CASE("PutUDP", "[putudp]") {
     listener.stop();
     server_thread.join();
   });
-  put_udp->setProperty(PutUDP::Port, utils::string::join_pack("${literal('", std::to_string(port), "')}"));
+  REQUIRE(put_udp->setProperty(PutUDP::Port.name, utils::string::join_pack("${literal('", std::to_string(port), "')}")));
 
   {
     const char* const message = "first message: hello";
