@@ -27,7 +27,13 @@ struct ReplaceTextTestAccessor {
   ReplaceText processor_;
   ReplaceText::Parameters parameters_;
 
-  ReplaceTextTestAccessor() : processor_{"replace_text"} {}
+  ReplaceTextTestAccessor()
+    : processor_{minifi::core::ProcessorMetadata{
+        .uuid = minifi::utils::IdGenerator::getIdGenerator()->generate(),
+        .name = "replace_text",
+        .logger = minifi::core::logging::LoggerFactory<ReplaceText>::getLogger()
+      }}
+  {}
 
   void setEvaluationMode(EvaluationModeType evaluation_mode) { processor_.evaluation_mode_ = evaluation_mode; }
   void setReplacementStrategy(ReplacementStrategyType replacement_strategy) { processor_.replacement_strategy_ = replacement_strategy; }
@@ -165,7 +171,7 @@ TEST_CASE("Substitute Variables works correctly in ReplaceText", "[applyReplacem
   replace_text.setEvaluationMode(minifi::processors::EvaluationModeType::ENTIRE_TEXT);
   replace_text.setReplacementStrategy(minifi::processors::ReplacementStrategyType::SUBSTITUTE_VARIABLES);
 
-  const auto flow_file = std::make_shared<minifi::FlowFileRecord>();
+  const auto flow_file = std::make_shared<minifi::FlowFileRecordImpl>();
   flow_file->setAttribute("color", "green");
   flow_file->setAttribute("food", "eggs and ham");
 
