@@ -22,6 +22,8 @@
 #include "unit/Catch.h"
 #include "unit/SingleProcessorTestController.h"
 #include "unit/TestBase.h"
+#include "utils/ConfigurationUtils.h"
+#include "unit/TestUtils.h"
 
 namespace org::apache::nifi::minifi::processors::test {
 
@@ -31,22 +33,22 @@ std::vector<std::byte> createByteVector(Bytes... bytes) {
 }
 
 TEST_CASE("WithoutByteSequence") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading)}));
 
-  REQUIRE_THROWS_WITH(controller.trigger("rub-a-dub-dub"), "General Operation: Required property is empty: Byte Sequence");
+  REQUIRE_THROWS_WITH(controller.trigger("rub-a-dub-dub"), "Expected valid value from \"SplitContent::Byte Sequence\", but got PropertyNotSet (Property Error:2)");
 }
 
 TEST_CASE("EmptyFlowFile") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "ub");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "ub"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading)}));
 
   auto trigger_results = controller.trigger("");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -59,12 +61,12 @@ TEST_CASE("EmptyFlowFile") {
 }
 
 TEST_CASE("TextFormatLeadingPosition", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "ub");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "ub"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading)}));
 
   auto trigger_results = controller.trigger("rub-a-dub-dub");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -82,13 +84,13 @@ TEST_CASE("TextFormatLeadingPosition", "[NiFi]") {
 }
 
 TEST_CASE("TextFormatTrailingPosition", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "ub");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "ub"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing)}));
 
   auto trigger_results = controller.trigger("rub-a-dub-dub");
 
@@ -106,11 +108,11 @@ TEST_CASE("TextFormatTrailingPosition", "[NiFi]") {
 }
 
 TEST_CASE("TextFormatSplits", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "test");
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "test"));
 
   constexpr std::string_view input_1 = "This is a test. This is another test. And this is yet another test. Finally this is the last Test.";
   constexpr std::string_view input_2 = "This is a test. This is another test. And this is yet another test. Finally this is the last test";
@@ -123,8 +125,8 @@ TEST_CASE("TextFormatSplits", "[NiFi]") {
       std::make_tuple("true", "Leading", input_2, std::vector<std::string_view>{"This is a ", "test. This is another ", "test. And this is yet another ", "test. Finally this is the last ", "test"}),
       std::make_tuple("true", "Trailing", input_2, std::vector<std::string_view>{"This is a test", ". This is another test", ". And this is yet another test", ". Finally this is the last test"}));
 
-  split_content->setProperty(SplitContent::KeepByteSequence, keep_byte_sequence);
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, byte_sequence_location);
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, keep_byte_sequence));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, byte_sequence_location));
 
   auto trigger_results = controller.trigger(input);
 
@@ -144,11 +146,11 @@ TEST_CASE("TextFormatSplits", "[NiFi]") {
 }
 
 TEST_CASE("SmallSplits", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "false");
-  split_content->setProperty(SplitContent::ByteSequence, "FFFF");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "false"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "FFFF"));
 
   const auto input_data = createByteVector(1, 2, 3, 4, 5, 0xFF, 0xFF, 0xFF, 5, 4, 3, 2, 1);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -169,11 +171,11 @@ TEST_CASE("SmallSplits", "[NiFi]") {
 }
 
 TEST_CASE("WithSingleByteSplit", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "false");
-  split_content->setProperty(SplitContent::ByteSequence, "FF");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "false"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "FF"));
 
   const auto input_data = createByteVector(1, 2, 3, 4, 5, 0xFF, 5, 4, 3, 2, 1);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -194,11 +196,11 @@ TEST_CASE("WithSingleByteSplit", "[NiFi]") {
 }
 
 TEST_CASE("WithLargerSplit", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "false");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "false"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
 
   const auto input_data = createByteVector(1, 2, 3, 4, 5, 5, 5, 5, 5, 5, 4, 3, 2, 1);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -219,11 +221,11 @@ TEST_CASE("WithLargerSplit", "[NiFi]") {
 }
 
 TEST_CASE("KeepingSequence", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
 
   const auto input_data = createByteVector(1, 2, 3, 4, 5, 5, 5, 5, 5, 5, 4, 3, 2, 1);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -244,11 +246,11 @@ TEST_CASE("KeepingSequence", "[NiFi]") {
 }
 
 TEST_CASE("EndsWithSequence", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "false");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "false"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
 
   const auto input_data = createByteVector(1, 2, 3, 4, 5, 5, 5, 5);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -267,11 +269,11 @@ TEST_CASE("EndsWithSequence", "[NiFi]") {
 }
 
 TEST_CASE("EndsWithSequenceAndKeepSequence", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
 
   const auto input_data = createByteVector(1, 2, 3, 4, 5, 5, 5, 5);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -290,11 +292,11 @@ TEST_CASE("EndsWithSequenceAndKeepSequence", "[NiFi]") {
 }
 
 TEST_CASE("StartsWithSequence", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "false");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "false"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
 
   const auto input_data = createByteVector(5, 5, 5, 5, 1, 2, 3, 4);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -313,12 +315,12 @@ TEST_CASE("StartsWithSequence", "[NiFi]") {
 }
 
 TEST_CASE("StartsWithSequenceAndKeepTrailingSequence", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, "Trailing");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, "Trailing"));
 
   const auto input_data = createByteVector(5, 5, 5, 5, 1, 2, 3, 4);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -339,12 +341,12 @@ TEST_CASE("StartsWithSequenceAndKeepTrailingSequence", "[NiFi]") {
 }
 
 TEST_CASE("StartsWithSequenceAndKeepLeadingSequence") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, "Leading");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, "Leading"));
 
   const auto input_data = createByteVector(5, 5, 5, 5, 1, 2, 3, 4);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -361,12 +363,12 @@ TEST_CASE("StartsWithSequenceAndKeepLeadingSequence") {
 }
 
 TEST_CASE("StartsWithDoubleSequenceAndKeepLeadingSequence") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequence, "05050505");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, "Leading");
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "05050505"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, "Leading"));
 
   const auto input_data = createByteVector(5, 5, 5, 5, 5, 5, 5, 5, 1, 2, 3, 4);
   std::string_view input(reinterpret_cast<const char*>(input_data.data()), input_data.size());
@@ -387,13 +389,13 @@ TEST_CASE("StartsWithDoubleSequenceAndKeepLeadingSequence") {
 }
 
 TEST_CASE("NoSplitterInString", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, ",");
-  split_content->setProperty(SplitContent::KeepByteSequence, "false");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, ","));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "false"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing)}));
 
   constexpr std::string_view input = "UVAT";
   auto trigger_results = controller.trigger(input);
@@ -415,10 +417,11 @@ TEST_CASE("NoSplitterInString", "[NiFi]") {
 }
 
 TEST_CASE("ByteSequenceAtBufferTargetSize") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
 
-  auto x = SplitContent::BUFFER_TARGET_SIZE-10;
+  static_assert(utils::configuration::DEFAULT_BUFFER_SIZE >= 10);
+  auto x = utils::configuration::DEFAULT_BUFFER_SIZE - 10;
 
   auto [pre_fix_size, separator_size, post_fix_size] = GENERATE_COPY(
     std::make_tuple(x, x, x),
@@ -435,10 +438,10 @@ TEST_CASE("ByteSequenceAtBufferTargetSize") {
   const std::string separator = utils::string::repeat("b", separator_size);
   const std::string post_fix = utils::string::repeat("c", post_fix_size);
 
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, separator);
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, "Trailing");
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, separator));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, "Trailing"));
 
   auto input = pre_fix + separator + post_fix;
   auto trigger_results = controller.trigger(input);
@@ -456,12 +459,12 @@ TEST_CASE("ByteSequenceAtBufferTargetSize") {
 }
 
 TEST_CASE("TrickyWithLeading", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "aab");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "aab"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading)}));
 
   auto trigger_results = controller.trigger("aaabc");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -477,12 +480,12 @@ TEST_CASE("TrickyWithLeading", "[NiFi]") {
 }
 
 TEST_CASE("TrickyWithTrailing", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "aab");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "aab"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing)}));
 
   auto trigger_results = controller.trigger("aaabc");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -498,12 +501,12 @@ TEST_CASE("TrickyWithTrailing", "[NiFi]") {
 }
 
 TEST_CASE("TrickierWithLeading", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "abcd");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "abcd"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading)}));
 
   auto trigger_results = controller.trigger("abcabcabcdabc");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -519,12 +522,12 @@ TEST_CASE("TrickierWithLeading", "[NiFi]") {
 }
 
 TEST_CASE("TrickierWithTrailing", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "abcd");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "abcd"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing)}));
 
   auto trigger_results = controller.trigger("abcabcabcdabc");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -540,12 +543,12 @@ TEST_CASE("TrickierWithTrailing", "[NiFi]") {
 }
 
 TEST_CASE("OnlyByteSequencesNoKeep", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "ab");
-  split_content->setProperty(SplitContent::KeepByteSequence, "false");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "ab"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "false"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing)}));
 
   auto trigger_results = controller.trigger("ababab");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -556,12 +559,12 @@ TEST_CASE("OnlyByteSequencesNoKeep", "[NiFi]") {
 }
 
 TEST_CASE("OnlyByteSequencesTrailing", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "ab");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "ab"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Trailing)}));
 
   auto trigger_results = controller.trigger("ababab");
   auto original = trigger_results.at(processors::SplitContent::Original);
@@ -576,12 +579,12 @@ TEST_CASE("OnlyByteSequencesTrailing", "[NiFi]") {
 }
 
 TEST_CASE("OnlyByteSequencesLeading", "[NiFi]") {
-  minifi::test::SingleProcessorTestController controller{std::make_unique<SplitContent>("SplitContent")};
+  minifi::test::SingleProcessorTestController controller{minifi::test::utils::make_processor<SplitContent>("SplitContent")};
   const auto split_content = controller.getProcessor();
-  split_content->setProperty(SplitContent::ByteSequenceFormatProperty, magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text));
-  split_content->setProperty(SplitContent::ByteSequence, "ab");
-  split_content->setProperty(SplitContent::KeepByteSequence, "true");
-  split_content->setProperty(SplitContent::ByteSequenceLocationProperty, magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceFormatProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceFormat::Text)}));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequence.name, "ab"));
+  REQUIRE(split_content->setProperty(SplitContent::KeepByteSequence.name, "true"));
+  REQUIRE(split_content->setProperty(SplitContent::ByteSequenceLocationProperty.name, std::string{magic_enum::enum_name(SplitContent::ByteSequenceLocation::Leading)}));
 
   auto trigger_results = controller.trigger("ababab");
   auto original = trigger_results.at(processors::SplitContent::Original);
