@@ -22,18 +22,22 @@
 #include "processors/SplitText.h"
 #include "unit/SingleProcessorTestController.h"
 #include "io/BufferStream.h"
+#include "utils/ConfigurationUtils.h"
+#include "unit/TestUtils.h"
 
 namespace org::apache::nifi::minifi::test {
 
+inline constexpr auto BUFFER_SIZE = minifi::utils::configuration::DEFAULT_BUFFER_SIZE;
+
 TEST_CASE("Test LineReader with nullptr") {
-  processors::detail::LineReader reader{nullptr};
+  processors::detail::LineReader reader{nullptr, BUFFER_SIZE};
   CHECK(reader.readNextLine() == std::nullopt);
   CHECK(reader.getState() == processors::detail::StreamReadState::EndOfStream);
 }
 
 TEST_CASE("Test LineReader with empty stream") {
   auto stream = std::make_shared<io::BufferStream>();
-  processors::detail::LineReader reader{stream};
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
   CHECK(reader.readNextLine() == std::nullopt);
   CHECK(reader.getState() == processors::detail::StreamReadState::EndOfStream);
 }
@@ -42,7 +46,7 @@ TEST_CASE("Test LineReader with trailing endline") {
   auto stream = std::make_shared<io::BufferStream>();
   std::string input = "this is a new line\nand another line\r\nthirdline\n";
   stream->write(reinterpret_cast<const uint8_t*>(input.data()), input.size());
-  processors::detail::LineReader reader{stream};
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = 19, .endline_size = 1});
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 19, .size = 18, .endline_size = 2});
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 37, .size = 10, .endline_size = 1});
@@ -54,7 +58,7 @@ TEST_CASE("Test LineReader without trailing endlines") {
   auto stream = std::make_shared<io::BufferStream>();
   std::string input = "this is a new line\nand another line\r\nthirdline";
   stream->write(reinterpret_cast<const uint8_t*>(input.data()), input.size());
-  processors::detail::LineReader reader{stream};
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = 19, .endline_size = 1});
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 19, .size = 18, .endline_size = 2});
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 37, .size = 9, .endline_size = 0});
@@ -64,11 +68,11 @@ TEST_CASE("Test LineReader without trailing endlines") {
 
 TEST_CASE("Test LineReader with input larger than buffer length") {
   auto stream = std::make_shared<io::BufferStream>();
-  const auto first_line_size = static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.5);
-  const auto second_line_size = static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.7);
+  const auto first_line_size = static_cast<size_t>(BUFFER_SIZE * 1.5);
+  const auto second_line_size = static_cast<size_t>(BUFFER_SIZE * 1.7);
   std::string input = std::string(first_line_size, 'a') + "\n" + std::string(second_line_size, 'b') + "\n";
   stream->write(reinterpret_cast<const uint8_t*>(input.data()), input.size());
-  processors::detail::LineReader reader{stream};
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = first_line_size + 1, .endline_size = 1});
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = first_line_size +1 , .size = second_line_size + 1, .endline_size = 1});
   CHECK(reader.readNextLine() == std::nullopt);
@@ -77,23 +81,23 @@ TEST_CASE("Test LineReader with input larger than buffer length") {
 
 TEST_CASE("Test LineReader with input of same size as buffer length") {
   auto stream = std::make_shared<io::BufferStream>();
-  std::string input = std::string(processors::detail::SPLIT_TEXT_BUFFER_SIZE - 1, 'a') + "\n" + std::string(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 2 - 1, 'b') + "\n";
+  std::string input = std::string(BUFFER_SIZE - 1, 'a') + "\n" + std::string(BUFFER_SIZE * 2 - 1, 'b') + "\n";
   stream->write(reinterpret_cast<const uint8_t*>(input.data()), input.size());
-  processors::detail::LineReader reader{stream};
-  CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = processors::detail::SPLIT_TEXT_BUFFER_SIZE, .endline_size = 1});
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
+  CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = BUFFER_SIZE, .endline_size = 1});
   CHECK(reader.readNextLine() ==
-    processors::detail::LineReader::LineInfo{.offset = processors::detail::SPLIT_TEXT_BUFFER_SIZE, .size = processors::detail::SPLIT_TEXT_BUFFER_SIZE * 2, .endline_size = 1});
+    processors::detail::LineReader::LineInfo{.offset = BUFFER_SIZE, .size = BUFFER_SIZE * 2, .endline_size = 1});
   CHECK(reader.readNextLine() == std::nullopt);
   CHECK(reader.getState() == processors::detail::StreamReadState::EndOfStream);
 }
 
 TEST_CASE("Test LineReader with input larger than buffer length without trailing endline") {
   auto stream = std::make_shared<io::BufferStream>();
-  const auto first_line_size = static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.5);
-  const auto second_line_size = static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.7);
+  const auto first_line_size = static_cast<size_t>(BUFFER_SIZE * 1.5);
+  const auto second_line_size = static_cast<size_t>(BUFFER_SIZE * 1.7);
   std::string input = std::string(first_line_size, 'a') + "\n" + std::string(second_line_size, 'b');
   stream->write(reinterpret_cast<const uint8_t*>(input.data()), input.size());
-  processors::detail::LineReader reader{stream};
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = first_line_size + 1, .endline_size = 1});
   CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = first_line_size + 1, .size = second_line_size, .endline_size = 0});
   CHECK(reader.readNextLine() == std::nullopt);
@@ -102,12 +106,12 @@ TEST_CASE("Test LineReader with input larger than buffer length without trailing
 
 TEST_CASE("Test LineReader with input of same size as buffer length without trailing endline") {
   auto stream = std::make_shared<io::BufferStream>();
-  std::string input = std::string(processors::detail::SPLIT_TEXT_BUFFER_SIZE - 1, 'a') + "\n" + std::string(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 2, 'b');
+  std::string input = std::string(BUFFER_SIZE - 1, 'a') + "\n" + std::string(BUFFER_SIZE * 2, 'b');
   stream->write(reinterpret_cast<const uint8_t*>(input.data()), input.size());
-  processors::detail::LineReader reader{stream};
-  CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = processors::detail::SPLIT_TEXT_BUFFER_SIZE, .endline_size = 1});
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
+  CHECK(reader.readNextLine() == processors::detail::LineReader::LineInfo{.offset = 0, .size = BUFFER_SIZE, .endline_size = 1});
   CHECK(reader.readNextLine() ==
-    processors::detail::LineReader::LineInfo{.offset = processors::detail::SPLIT_TEXT_BUFFER_SIZE, .size = processors::detail::SPLIT_TEXT_BUFFER_SIZE * 2, .endline_size = 0});
+    processors::detail::LineReader::LineInfo{.offset = BUFFER_SIZE, .size = BUFFER_SIZE * 2, .endline_size = 0});
   CHECK(reader.readNextLine() == std::nullopt);
   CHECK(reader.getState() == processors::detail::StreamReadState::EndOfStream);
 }
@@ -116,7 +120,7 @@ TEST_CASE("Test LineReader with starts with filter") {
   auto stream = std::make_shared<io::BufferStream>();
   std::string input = "header this is a new line\nheader and another line\r\nthirdline\nheader line\n";
   stream->write(reinterpret_cast<const uint8_t*>(input.data()), input.size());
-  processors::detail::LineReader reader{stream};
+  processors::detail::LineReader reader{stream, BUFFER_SIZE};
   CHECK(reader.readNextLine("header") == processors::detail::LineReader::LineInfo{.offset = 0, .size = 26, .endline_size = 1, .matches_starts_with = true});
   CHECK(reader.readNextLine("header") == processors::detail::LineReader::LineInfo{.offset = 26, .size = 25, .endline_size = 2, .matches_starts_with = true});
   CHECK(reader.readNextLine("header") == processors::detail::LineReader::LineInfo{.offset = 51, .size = 10, .endline_size = 1, .matches_starts_with = false});
@@ -164,20 +168,20 @@ void verifySplitResults(const SingleProcessorTestController& controller, const P
 }
 
 void runSplitTextTest(const std::string& input, const std::vector<ExpectedSplitTextResult>& expected_results, const SplitTextProperties& properties) {
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::LineSplitCount, std::to_string(properties.line_split_count));
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, std::to_string(properties.line_split_count)));
   if (properties.maximum_fragment_size) {
-    split_text->setProperty(processors::SplitText::MaximumFragmentSize, std::to_string(*properties.maximum_fragment_size) + " B");
+    REQUIRE(split_text->setProperty(processors::SplitText::MaximumFragmentSize.name, std::to_string(*properties.maximum_fragment_size) + " B"));
   }
   if (properties.trim_trailing_newlines) {
-    split_text->setProperty(processors::SplitText::RemoveTrailingNewlines, properties.trim_trailing_newlines.value() ? "true" : "false");
+    REQUIRE(split_text->setProperty(processors::SplitText::RemoveTrailingNewlines.name, properties.trim_trailing_newlines.value() ? "true" : "false"));
   }
   if (properties.header_line_count) {
-    split_text->setProperty(processors::SplitText::HeaderLineCount, std::to_string(*properties.header_line_count));
+    REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineCount.name, std::to_string(*properties.header_line_count)));
   }
   if (properties.header_line_marker_characters) {
-    split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters, *properties.header_line_marker_characters);
+    REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters.name, *properties.header_line_marker_characters));
   }
   const auto trigger_results = controller.trigger(input, {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Failure).empty());
@@ -188,39 +192,39 @@ void runSplitTextTest(const std::string& input, const std::vector<ExpectedSplitT
 }
 
 TEST_CASE("Line Split Count property is required") {
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
-  REQUIRE_THROWS_AS(controller.trigger("", {}), minifi::Exception);
+SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
+  REQUIRE_THROWS_WITH(controller.trigger("", {}), "Expected parsable uint64_t from \"SplitText::Line Split Count\", but got PropertyNotSet (Property Error:2)");
 }
 
 TEST_CASE("Line Split Count property can only be 0 if Maximum Fragment Size is set") {
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::LineSplitCount, "0");
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "0"));
   REQUIRE_THROWS_AS(controller.trigger("", {}), minifi::Exception);
 }
 
 TEST_CASE("Maximum Fragment Size cannot be set to 0") {
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::LineSplitCount, "0");
-  split_text->setProperty(processors::SplitText::MaximumFragmentSize, "0 B");
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "0"));
+  REQUIRE(split_text->setProperty(processors::SplitText::MaximumFragmentSize.name, "0 B"));
   REQUIRE_THROWS_AS(controller.trigger("", {}), minifi::Exception);
 }
 
 TEST_CASE("Header Line Marker Characters size cannot be equal or larger than split text buffer size") {
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::LineSplitCount, "1");
-  std::string header_marker_character(processors::detail::SPLIT_TEXT_BUFFER_SIZE, 'A');
-  split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters, header_marker_character);
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "1"));
+  std::string header_marker_character(BUFFER_SIZE, 'A');
+  REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters.name, header_marker_character));
   REQUIRE_THROWS_AS(controller.trigger("", {}), minifi::Exception);
 }
 
 
 TEST_CASE("SplitText only forwards empty flowfile") {
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::LineSplitCount, "1");
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "1"));
   const auto trigger_results = controller.trigger("", {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Splits).empty());
   CHECK(trigger_results.at(processors::SplitText::Failure).empty());
@@ -249,7 +253,7 @@ TEST_CASE("SplitText creates new flow file for a single line") {
     expected_results[0].content = line;
   }
   SECTION("Line size larger than buffer size") {
-    line = std::string(static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.5), 'a') + "\n";
+    line = std::string(static_cast<size_t>(BUFFER_SIZE * 1.5), 'a') + "\n";
     expected_results[0].content = line;
   }
   SECTION("Content without endline is a single line") {
@@ -294,12 +298,12 @@ TEST_CASE("SplitText creates new flow file with 2 lines") {
     expected_results[0].content = "this is a new line\r\nand another line";
   }
   SECTION("Line size larger than buffer size") {
-    std::string str(static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.5), 'a');
+    std::string str(static_cast<size_t>(BUFFER_SIZE * 1.5), 'a');
     input = str + "\n" + str + "\n";
     expected_results[0].content = input;
   }
   SECTION("Line size larger than buffer size without endline at the end") {
-    std::string str(static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.5), 'a');
+    std::string str(static_cast<size_t>(BUFFER_SIZE * 1.5), 'a');
     input = str + "\n" + str;
     expected_results[0].content = input;
   }
@@ -337,13 +341,13 @@ TEST_CASE("SplitText creates separate flow files from 2 lines") {
     expected_results[1].content = "and another line\r\n";
   }
   SECTION("Line size larger than buffer size") {
-    std::string str(static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.5), 'a');
+    std::string str(static_cast<size_t>(BUFFER_SIZE * 1.5), 'a');
     input = str + "\n" + str + "\n";
     expected_results[0].content = str + "\n";
     expected_results[1].content = str + "\n";
   }
   SECTION("Line size larger than buffer size without endline at the end") {
-    std::string str(static_cast<size_t>(processors::detail::SPLIT_TEXT_BUFFER_SIZE * 1.5), 'a');
+    std::string str(static_cast<size_t>(BUFFER_SIZE * 1.5), 'a');
     input = str + "\n" + str;
     expected_results[0].content = str + "\n";
     expected_results[1].content = str;
@@ -403,13 +407,13 @@ TEST_CASE("Endlines are trimmed when Remove Trailing Newlines is set to true and
 }
 
 TEST_CASE("If flowfile is empty after trailing new lines are removed then flow file is not emitted") {
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
   SECTION("Line split count 1") {
-    split_text->setProperty(processors::SplitText::LineSplitCount, "1");
+    REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "1"));
   }
   SECTION("Line split count 2") {
-    split_text->setProperty(processors::SplitText::LineSplitCount, "2");
+    REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "2"));
   }
   const auto trigger_results = controller.trigger("\n\n", {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Splits).empty());
@@ -599,10 +603,10 @@ TEST_CASE("If the header defined by the header line count is larger than the flo
   SECTION("Header line count is one line shorter larger than the flow file") {
     input = "header line 1\nheader line 2\nthis is a new line\n";
   }
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::LineSplitCount, "1");
-  split_text->setProperty(processors::SplitText::HeaderLineCount, "4");
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "1"));
+  REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineCount.name, "4"));
   const auto trigger_results = controller.trigger(input, {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Splits).empty());
   REQUIRE(trigger_results.at(processors::SplitText::Original).empty());
@@ -613,11 +617,11 @@ TEST_CASE("If the header defined by the header line count is larger than the flo
 TEST_CASE("If the header defined by the header line count is larger than the max fragment size then the processor should fail") {
   std::string input;
   input = "header line 1\nheader line 2\nthis is a new line\n";
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::MaximumFragmentSize, "20 B");
-  split_text->setProperty(processors::SplitText::HeaderLineCount, "2");
-  split_text->setProperty(processors::SplitText::LineSplitCount, "0");
+  REQUIRE(split_text->setProperty(processors::SplitText::MaximumFragmentSize.name, "20 B"));
+  REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineCount.name, "2"));
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "0"));
   const auto trigger_results = controller.trigger(input, {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Splits).empty());
   REQUIRE(trigger_results.at(processors::SplitText::Original).empty());
@@ -627,10 +631,10 @@ TEST_CASE("If the header defined by the header line count is larger than the max
 
 TEST_CASE("If header line count is the same as the flow file line count then no new flow file should be emitted") {
   std::string input = "header line 1\nheader line 2\nthis is a new line\n";
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::LineSplitCount, "1");
-  split_text->setProperty(processors::SplitText::HeaderLineCount, "3");
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "1"));
+  REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineCount.name, "3"));
   const auto trigger_results = controller.trigger(input, {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Splits).empty());
   REQUIRE(trigger_results.at(processors::SplitText::Failure).empty());
@@ -806,11 +810,11 @@ TEST_CASE("If a split fragment would only consist of new lines then only the tri
 TEST_CASE("If the header defined by header marker characters is larger than the max fragments size then the processor should fail") {
   std::string input;
   input = "header line 1\nheader line 2\nthis is a new line\n";
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::MaximumFragmentSize, "20 B");
-  split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters, "hea");
-  split_text->setProperty(processors::SplitText::LineSplitCount, "0");
+  REQUIRE(split_text->setProperty(processors::SplitText::MaximumFragmentSize.name, "20 B"));
+  REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters.name, "hea"));
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "0"));
   const auto trigger_results = controller.trigger(input, {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Splits).empty());
   REQUIRE(trigger_results.at(processors::SplitText::Original).empty());
@@ -821,11 +825,11 @@ TEST_CASE("If the header defined by header marker characters is larger than the
 TEST_CASE("If the header defined by header marker characters is the only content in the flow file then the processor should not emit new flow files") {
   std::string input;
   input = "header line 1\nheader line 2\n";
-  SingleProcessorTestController controller{std::make_unique<processors::SplitText>("SplitText")};
+  SingleProcessorTestController controller{minifi::test::utils::make_processor<processors::SplitText>("SplitText")};
   const auto split_text = controller.getProcessor();
-  split_text->setProperty(processors::SplitText::MaximumFragmentSize, "40 B");
-  split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters, "hea");
-  split_text->setProperty(processors::SplitText::LineSplitCount, "0");
+  REQUIRE(split_text->setProperty(processors::SplitText::MaximumFragmentSize.name, "40 B"));
+  REQUIRE(split_text->setProperty(processors::SplitText::HeaderLineMarkerCharacters.name, "hea"));
+  REQUIRE(split_text->setProperty(processors::SplitText::LineSplitCount.name, "0"));
   const auto trigger_results = controller.trigger(input, {{std::string(core::SpecialFlowAttribute::FILENAME), "a.foo"}});
   CHECK(trigger_results.at(processors::SplitText::Splits).empty());
   REQUIRE(trigger_results.at(processors::SplitText::Failure).empty());
