@@ -16,30 +16,31 @@
  * limitations under the License.
  */
 
+#include <algorithm>
 #include <cstdio>
 #include <fstream>
-#include <string>
 #include <iostream>
-#include <set>
-#include <algorithm>
 #include <random>
+#include <set>
+#include <string>
+
 #include "FlowController.h"
-#include "unit/TestBase.h"
-#include "unit/Catch.h"
+#include "LogAttribute.h"
+#include "TailFile.h"
+#include "TextFragmentUtils.h"
+#include "catch2/generators/catch_generators.hpp"
 #include "core/Core.h"
-#include "utils/file/FileUtils.h"
-#include "utils/file/PathUtils.h"
-#include "unit/ProvenanceTestHelper.h"
-#include "core/Processor.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
+#include "core/Processor.h"
 #include "core/Resource.h"
-#include "TailFile.h"
-#include "LogAttribute.h"
+#include "unit/Catch.h"
+#include "unit/ProvenanceTestHelper.h"
+#include "unit/SingleProcessorTestController.h"
+#include "unit/TestBase.h"
 #include "unit/TestUtils.h"
 #include "utils/StringUtils.h"
-#include "unit/SingleProcessorTestController.h"
-#include "TextFragmentUtils.h"
+#include "utils/file/FileUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -76,7 +77,7 @@ void appendTempFile(const std::filesystem::path& directory, const std::filesyste
 
 TEST_CASE("TailFile reads the file until the first delimiter then picks up the second line if a delimiter is written between runs", "[simple]") {
   // Create and write to the test file
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<minifi::processors::TailFile>("TailFile"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<minifi::processors::TailFile>("TailFile"));
 
   auto dir = test_controller.createTempDirectory();
   auto temp_file_path = dir / TMP_FILE;
@@ -284,7 +285,7 @@ TEST_CASE("TailFile converts the old-style state file to the new-style state", "
       REQUIRE(it != state.end());
       REQUIRE(it->second == key_value_pair.second);
     }
-    REQUIRE(state.find("file.0.last_read_time") != state.end());
+    REQUIRE(state.contains("file.0.last_read_time"));
   }
 
   SECTION("multiple") {
@@ -334,8 +335,8 @@ TEST_CASE("TailFile converts the old-style state file to the new-style state", "
       REQUIRE(it != state.end());
       REQUIRE(it->second == key_value_pair.second);
     }
-    REQUIRE(state.find("file.0.last_read_time") != state.end());
-    REQUIRE(state.find("file.1.last_read_time") != state.end());
+    REQUIRE(state.contains("file.0.last_read_time"));
+    REQUIRE(state.contains("file.1.last_read_time"));
   }
 }
 
@@ -551,7 +552,7 @@ TEST_CASE("TailFile processes a very long line correctly", "[simple]") {
   std::generate_n(line2.begin(), line2.size() - 1, [&] {
     // Make sure to only generate from characters that don't intersect with line1 and 3-4
     // Starting generation from 64 ensures that no numeric digit characters are added
-    return gsl::narrow<char>(64 + gen() % (127 - 64));
+    return gsl::narrow<char>(64 + (gen() % (127 - 64)));
   });
   line2.back() = '\n';
   std::string line3("345\n");
@@ -626,7 +627,7 @@ TEST_CASE("TailFile processes a long line followed by multiple newlines correctl
   std::generate_n(line1.begin(), 4095, [&] {
     // Make sure to only generate from characters that don't intersect with line2-4
     // Starting generation from 64 ensures that no numeric digit characters are added
-    return gsl::narrow<char>(64 + gen() % (127 - 64));
+    return gsl::narrow<char>(64 + (gen() % (127 - 64)));
   });
   std::string line2("012\n");
   std::string line3("345\n");
@@ -744,7 +745,7 @@ TEST_CASE("TailFile onSchedule throws in Multiple mode if the Base Directory doe
 }
 
 TEST_CASE("TailFile finds and finishes the renamed file and continues with the new log file", "[rotation]") {
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<minifi::processors::TailFile>("TailFile"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<minifi::processors::TailFile>("TailFile"));
 
   constexpr char DELIM = ',';
   constexpr size_t expected_pieces = std::ranges::count(NEWLINE_FILE, DELIM);  // The last piece is left as considered unfinished
@@ -811,7 +812,7 @@ TEST_CASE("TailFile finds and finishes the renamed file and continues with the n
 }
 
 TEST_CASE("TailFile finds and finishes multiple rotated files and continues with the new log file", "[rotation]") {
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<minifi::processors::TailFile>("TailFile"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<minifi::processors::TailFile>("TailFile"));
 
   LogTestController::getInstance().setTrace<minifi::processors::TailFile>();
 
@@ -820,8 +821,8 @@ TEST_CASE("TailFile finds and finishes multiple rotated files and continues with
   auto dir = test_controller.createTempDirectory();
   auto fruits_log_path = dir / "fruits.log";
 
-  test_controller.getProcessor()->setProperty(minifi::processors::TailFile::FileName, fruits_log_path.string());
-  test_controller.getProcessor()->setProperty(minifi::processors::TailFile::Delimiter, std::string(1, DELIM));
+  REQUIRE(test_controller.getProcessor()->setProperty(minifi::processors::TailFile::FileName.name, fruits_log_path.string()));
+  REQUIRE(test_controller.getProcessor()->setProperty(minifi::processors::TailFile::Delimiter.name, std::string(1, DELIM)));
 
   const auto file_modi_time_t0 = std::chrono::file_clock::now();
   {
@@ -1043,7 +1044,7 @@ TEST_CASE("TailFile finds and finishes the renamed file and continues with the n
   auto log_dir = testController.createTempDirectory();
 
   const auto file_modi_time_t0 = std::chrono::file_clock::now();
-  auto test_file_1 = createTempFile(log_dir, "test.1", "line one\nline two\nline three\n");  // old rotated file
+  [[maybe_unused]] auto test_file_1 = createTempFile(log_dir, "test.1", "line one\nline two\nline three\n");  // old rotated file
   std::filesystem::last_write_time(log_dir/"test.1", file_modi_time_t0 - 1100ms);
   auto test_file = createTempFile(log_dir, "test.log", "line four\nline five\nline six\n");  // current log file
   std::filesystem::last_write_time(log_dir/"test.log", file_modi_time_t0 - 100ms);
@@ -1054,8 +1055,7 @@ TEST_CASE("TailFile finds and finishes the renamed file and continues with the n
   const core::Relationship success_relationship{"success", "everything is fine"};
 
   // use persistent state storage that defaults to rocksDB, not volatile
-  const auto configuration = std::make_shared<minifi::Configure>();
-  configuration->setHome(log_dir);
+  const auto configuration = std::make_shared<minifi::ConfigureImpl>();
   {
     auto test_plan = testController.createPlan(configuration, state_dir);
     auto tail_file = test_plan->addProcessor("TailFile", tail_file_uuid, "Tail", {success_relationship});
@@ -1406,7 +1406,7 @@ TEST_CASE("TailFile interprets the lookup frequency property correctly", "[multi
 
   auto plan = testController.createPlan();
 
-  auto tail_file = plan->addProcessor("TailFile", "Tail");
+  auto tail_file = plan->addProcessor<minifi::processors::TailFile>("Tail");
   plan->setProperty(tail_file, minifi::processors::TailFile::TailMode, "Multiple file");
   plan->setProperty(tail_file, minifi::processors::TailFile::BaseDirectory, directory.string());
   plan->setProperty(tail_file, minifi::processors::TailFile::FileName, ".*\\.log");
@@ -1417,9 +1417,7 @@ TEST_CASE("TailFile interprets the lookup frequency property correctly", "[multi
   SECTION("Lookup frequency not set => defaults to 10 minutes") {
     TestController::runSession(plan, true);
 
-    const auto tail_file_processor = dynamic_cast<minifi::processors::TailFile*>(tail_file);
-    REQUIRE(tail_file_processor);
-    REQUIRE(tail_file_processor->getLookupFrequency() == std::chrono::minutes{10});
+    REQUIRE(tail_file.get().getLookupFrequency() == std::chrono::minutes{10});
   }
 
   SECTION("Lookup frequency set to zero => new files are picked up immediately") {
@@ -1690,15 +1688,8 @@ TEST_CASE("Initial Start Position is set to invalid or empty value", "[initialSt
   plan->setProperty(tailfile, org::apache::nifi::minifi::processors::TailFile::FileName, temp_file_path.string());
   plan->setProperty(tailfile, org::apache::nifi::minifi::processors::TailFile::Delimiter, "\n");
 
-  SECTION("Initial Start Position is empty") {
-    plan->setProperty(tailfile, org::apache::nifi::minifi::processors::TailFile::InitialStartPosition, "");
-  }
-
-  SECTION("Initial Start Position is invalid") {
-    plan->setProperty(tailfile, org::apache::nifi::minifi::processors::TailFile::InitialStartPosition, "Invalid Value");
-  }
-
-  REQUIRE_THROWS_AS(TestController::runSession(plan), minifi::Exception);
+  CHECK_FALSE(plan->setProperty(tailfile, org::apache::nifi::minifi::processors::TailFile::InitialStartPosition, ""));
+  CHECK_FALSE(plan->setProperty(tailfile, org::apache::nifi::minifi::processors::TailFile::InitialStartPosition, "Invalid Value"));
 }
 
 TEST_CASE("TailFile onSchedule throws if an invalid Attribute Provider Service is found", "[configuration][AttributeProviderService]") {
@@ -1717,9 +1708,9 @@ TEST_CASE("TailFile onSchedule throws if an invalid Attribute Provider Service i
 
 namespace {
 
-class TestAttributeProviderService final : public minifi::controllers::AttributeProviderService {
+class TestAttributeProviderService final : public minifi::controllers::AttributeProviderServiceImpl {
  public:
-  using AttributeProviderService::AttributeProviderService;
+  using AttributeProviderServiceImpl::AttributeProviderServiceImpl;
 
   static constexpr const char* Description = "An attribute provider service which provides a constant set of records.";
   static constexpr auto Properties = std::array<core::PropertyReference, 0>{};
@@ -1791,7 +1782,7 @@ TEST_CASE("TailFile can use an AttributeProviderService", "[AttributeProviderSer
 TEST_CASE("TailFile honors batch size for maximum lines processed", "[batchSize]") {
   LogTestController::getInstance().setTrace<minifi::processors::TailFile>();
 
-  minifi::test::SingleProcessorTestController test_controller(std::make_unique<minifi::processors::TailFile>("TailFile"));
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<minifi::processors::TailFile>("TailFile"));
   auto tailfile = test_controller.getProcessor();
 
   auto temp_file_path  = test_controller.createTempDirectory() / TMP_FILE;
@@ -1803,11 +1794,40 @@ TEST_CASE("TailFile honors batch size for maximum lines processed", "[batchSize]
   }
   tmpfile.close();
 
-  tailfile->setProperty(minifi::processors::TailFile::FileName, temp_file_path.string());
-  tailfile->setProperty(minifi::processors::TailFile::Delimiter, "\n");
-  tailfile->setProperty(minifi::processors::TailFile::BatchSize, "10");
+  REQUIRE(tailfile->setProperty(minifi::processors::TailFile::FileName.name, temp_file_path.string()));
+  REQUIRE(tailfile->setProperty(minifi::processors::TailFile::Delimiter.name, "\n"));
+  REQUIRE(tailfile->setProperty(minifi::processors::TailFile::BatchSize.name, "10"));
 
   const auto result = test_controller.trigger();
   const auto& file_contents = result.at(minifi::processors::TailFile::Success);
   REQUIRE(file_contents.size() == 10);
 }
+
+TEST_CASE("Result mode tests") {
+  LogTestController::getInstance().setTrace<minifi::processors::TailFile>();
+
+  minifi::test::SingleProcessorTestController test_controller(minifi::test::utils::make_processor<minifi::processors::TailFile>("TailFile"));
+  auto tail_file = test_controller.getProcessor();
+
+  auto temp_file_path  = test_controller.createTempDirectory() / TMP_FILE;
+
+  const auto [result_mode, ff_count] = GENERATE(
+    std::make_tuple(minifi::processors::TailResultFormat::FlowFilePerBatch, std::size_t{1}),
+    std::make_tuple(minifi::processors::TailResultFormat::FlowFilePerDelimiter, std::size_t{5}));
+
+  std::ofstream tmp_file;
+  tmp_file.open(temp_file_path, std::ios::out | std::ios::binary);
+  for (auto i = 0; i < 20; ++i) {
+    tmp_file << NEW_TAIL_DATA;
+  }
+  tmp_file.close();
+
+  CHECK(tail_file->setProperty(minifi::processors::TailFile::FileName.name, temp_file_path.string()));
+  CHECK(tail_file->setProperty(minifi::processors::TailFile::Delimiter.name, "\n"));
+  CHECK(tail_file->setProperty(minifi::processors::TailFile::BatchSize.name, "5"));
+  CHECK(tail_file->setProperty(minifi::processors::TailFile::ResultFormat.name, std::string(magic_enum::enum_name(result_mode))));
+
+  const auto result = test_controller.trigger();
+  const auto& file_contents = result.at(minifi::processors::TailFile::Success);
+  CHECK(file_contents.size() == ff_count);
+}
