@@ -31,6 +31,8 @@
 #include "unit/TestUtils.h"
 #include "core/Resource.h"
 #include "utils/crypto/property_encryption/PropertyEncryptionUtils.h"
+#include "unit/DummyProcessor.h"
+#include "catch2/generators/catch_generators.hpp"
 
 using namespace std::literals::chrono_literals;
 
@@ -100,6 +102,7 @@ Processors:
       scheduling period: 1 sec
       penalization period: 30 sec
       yield period: 1 sec
+      bulletin level: ERROR
       run duration nanos: 0
       auto-terminated relationships list:
       Properties:
@@ -157,6 +160,7 @@ Provenance Reporting:
     REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getSchedulingPeriod());
     REQUIRE(30s == rootFlowConfig->findProcessorByName("TailFile")->getPenalizationPeriod());
     REQUIRE(1s == rootFlowConfig->findProcessorByName("TailFile")->getYieldPeriod());
+    REQUIRE(rootFlowConfig->findProcessorByName("TailFile")->getLogBulletinLevel() == logging::LOG_LEVEL::err);
     REQUIRE(0s == rootFlowConfig->findProcessorByName("TailFile")->getRunDurationNano());
 
     std::map<std::string, minifi::Connection*> connectionMap;
@@ -214,7 +218,7 @@ Remote Processing Groups: []
 Provenance Reporting:
       )";
 
-    REQUIRE_THROWS_AS(yamlConfig.getRootFromPayload(CONFIG_YAML_EMPTY_RETRY_ATTRIBUTE), minifi::utils::internal::InvalidValueException);
+    REQUIRE_THROWS_WITH(yamlConfig.getRootFromPayload(CONFIG_YAML_EMPTY_RETRY_ATTRIBUTE), "Unable to parse configuration file for component named 'RetryFlowFile' because ValidationFailed");
     REQUIRE(LogTestController::getInstance().contains("Invalid value was set for property 'Retry Attribute' creating component 'RetryFlowFile'"));
   }
 }
@@ -535,8 +539,7 @@ Processors:
     REQUIRE(!rootFlowConfig->findProcessorByName("GetFile")->getUUIDStr().empty());
   } catch (const std::exception &e) {
     caught_exception = true;
-    REQUIRE("Unable to parse configuration file for component named 'XYZ' because required property "
-        "'Input Directory' is not set [in '/Processors/0/Properties' section of configuration file]" == std::string(e.what()));
+    REQUIRE("Unable to parse configuration file for component named 'XYZ' because ValidationFailed" == std::string(e.what()));
   }
 
   REQUIRE(caught_exception);
@@ -566,8 +569,10 @@ Processors:
   REQUIRE(!rootFlowConfig->findProcessorByName("XYZ")->getUUIDStr().empty());
 }
 
-class DummyComponent : public core::ConfigurableComponent {
+class DummyComponent : public core::ConfigurableComponentImpl, public core::CoreComponentImpl {
  public:
+  DummyComponent() : ConfigurableComponentImpl(), CoreComponentImpl("DummyComponent") {}
+
   bool supportsDynamicProperties() const override {
     return false;
   }
@@ -1261,31 +1266,6 @@ NiFi Properties Overrides: {}
     "Parameter Operation: Parameter name 'lookup.frequency' already exists, parameter names must be unique within a parameter context!");
 }
 
-class DummyFlowYamlProcessor : public core::Processor {
- public:
-  using core::Processor::Processor;
-
-  static constexpr const char* Description = "A processor that does nothing.";
-  static constexpr auto SimpleProperty = core::PropertyDefinitionBuilder<>::createProperty("Simple Property")
-      .withDescription("Just a simple string property")
-      .build();
-  static constexpr auto SensitiveProperty = core::PropertyDefinitionBuilder<>::createProperty("Sensitive Property")
-      .withDescription("Sensitive property")
-      .isSensitive(true)
-      .build();
-  static constexpr auto Properties = std::to_array<core::PropertyReference>({SimpleProperty, SensitiveProperty});
-  static constexpr auto Relationships = std::array<core::RelationshipDefinition, 0>{};
-  static constexpr bool SupportsDynamicProperties = true;
-  static constexpr bool SupportsDynamicRelationships = true;
-  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
-  static constexpr bool IsSingleThreaded = false;
-  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
-
-  void initialize() override { setSupportedProperties(Properties); }
-};
-
-REGISTER_RESOURCE(DummyFlowYamlProcessor, Processor);
-
 TEST_CASE("Cannot use non-sensitive parameter in sensitive property", "[YamlConfiguration]") {
   ConfigurationTestController test_controller;
   core::YamlConfiguration yaml_config(test_controller.getContext());
@@ -1307,7 +1287,7 @@ Parameter Contexts:
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
   name: TailFile
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1349,7 +1329,7 @@ Parameter Contexts:
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
   name: TailFile
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1531,7 +1511,7 @@ Flow Controller:
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
   name: TailFile
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1555,7 +1535,7 @@ Flow Controller:
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
   name: TailFile
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1594,7 +1574,7 @@ Parameter Contexts:
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
   name: DummyProcessor
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1610,12 +1590,11 @@ Parameter Context Name: my-context
   REQUIRE(flow);
   auto* proc = flow->findProcessorByName("DummyProcessor");
   REQUIRE(proc);
-  core::Property property("Simple Property", "");
-  proc->getProperty("Simple Property", property);
-  auto values = property.getValues();
-  REQUIRE(values.size() == 2);
-  CHECK(values[0] == "value1");
-  CHECK(values[1] == "value2");
+  auto values = proc->getAllPropertyValues("Simple Property");
+  REQUIRE(values);
+  REQUIRE(values->size() == 2);
+  CHECK((*values)[0] == "value1");
+  CHECK((*values)[1] == "value2");
 }
 
 TEST_CASE("Dynamic properties can use parameters", "[YamlConfiguration]") {
@@ -1643,7 +1622,7 @@ Parameter Contexts:
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
   name: DummyProcessor
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1659,17 +1638,16 @@ Parameter Context Name: my-context
   std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
   REQUIRE(flow);
 
+  core::Property property("My Dynamic Property Sequence", "");
   auto* proc = flow->findProcessorByName("DummyProcessor");
   REQUIRE(proc);
-  core::Property property("My Dynamic Property Sequence", "");
-  proc->getDynamicProperty("My Dynamic Property Sequence", property);
-  auto values = property.getValues();
-  REQUIRE(values.size() == 2);
-  CHECK(values[0] == "value1");
-  CHECK(values[1] == "value2");
-  std::string value;
-  REQUIRE(proc->getDynamicProperty("My Dynamic Property", value));
-  CHECK(value == "value1");
+  auto values = proc->getAllDynamicPropertyValues("My Dynamic Property Sequence");
+  REQUIRE(values);
+  REQUIRE(values->size() == 2);
+  CHECK((*values)[0] == "value1");
+  CHECK((*values)[1] == "value2");
+
+  REQUIRE(proc->getDynamicProperty("My Dynamic Property") == "value1");
 }
 
 TEST_CASE("Test sensitive parameters in sensitive properties", "[YamlConfiguration]") {
@@ -1695,8 +1673,8 @@ Parameter Contexts:
       value: {encrypted_parameter_value}
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
-  name: DummyFlowYamlProcessor
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1709,7 +1687,7 @@ Parameter Context Name: my-context
 
   std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
   REQUIRE(flow);
-  auto* proc = flow->findProcessorByName("DummyFlowYamlProcessor");
+  auto* proc = flow->findProcessorByName("DummyProcessor");
   REQUIRE(proc);
   REQUIRE(proc->getProperty("Simple Property") == "simple");
   REQUIRE(proc->getProperty("Sensitive Property") == "value1");
@@ -1744,8 +1722,8 @@ Parameter Contexts:
       value: {encrypted_parameter_value_2}
 Processors:
 - id: b0c04f28-0158-1000-0000-000000000000
-  name: DummyFlowYamlProcessor
-  class: org.apache.nifi.processors.DummyFlowYamlProcessor
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
   max concurrent tasks: 1
   scheduling strategy: TIMER_DRIVEN
   scheduling period: 1 sec
@@ -1761,13 +1739,12 @@ Parameter Context Name: my-context
 
   std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
   REQUIRE(flow);
-  auto* proc = flow->findProcessorByName("DummyFlowYamlProcessor");
-  core::Property property("Sensitive Property", "");
-  proc->getProperty("Sensitive Property", property);
-  auto values = property.getValues();
-  REQUIRE(values.size() == 2);
-  CHECK(values[0] == "value1");
-  CHECK(values[1] == "value2");
+  auto* proc = flow->findProcessorByName("DummyProcessor");
+  auto values = proc->getAllPropertyValues("Sensitive Property");
+  REQUIRE(values);
+  REQUIRE(values->size() == 2);
+  CHECK((*values)[0] == "value1");
+  CHECK((*values)[1] == "value2");
 }
 
 TEST_CASE("Test parameters in controller services", "[YamlConfiguration]") {
@@ -1876,4 +1853,554 @@ Process Groups:
   CHECK(impl->getProperty("Private Key").value() == "/opt/secrets/private-key.pem");
 }
 
+TEST_CASE("Test parameter context inheritance", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_parameter_value = minifi::utils::crypto::property_encryption::encrypt("value1", *context.sensitive_values_encryptor);
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{my_new_parameter}", *context.sensitive_values_encryptor);
+  core::YamlConfiguration yaml_config(context);
+
+  static const std::string TEST_CONFIG_YAML =
+      fmt::format(R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Contexts:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: inherited-context
+    description: my parameter context
+    Parameters:
+    - name: my_new_parameter
+      description: inherited parameter context
+      sensitive: true
+      value: {}
+    Inherited Parameter Contexts: [base-context]
+  - id: 521e10b7-8e00-3188-9a27-476cca376351
+    name: base-context
+    description: my base parameter context
+    Parameters:
+    - name: my_old_parameter
+      description: ''
+      sensitive: false
+      value: old_value
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{{my_old_parameter}}"
+    Sensitive Property: {}
+Parameter Context Name: inherited-context
+      )", encrypted_parameter_value, encrypted_sensitive_property_value);
+
+  std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
+  REQUIRE(flow);
+  auto* proc = flow->findProcessorByName("DummyProcessor");
+  REQUIRE(proc);
+  REQUIRE(proc->getProperty("Simple Property") == "old_value");
+  REQUIRE(proc->getProperty("Sensitive Property") == "value1");
+}
+
+TEST_CASE("Parameter context can not inherit from a itself", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+
+  static const std::string TEST_CONFIG_YAML =
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Contexts:
+  - id: 521e10b7-8e00-3188-9a27-476cca376351
+    name: base-context
+    description: my base parameter context
+    Parameters:
+    - name: my_old_parameter
+      description: ''
+      sensitive: false
+      value: old_value
+    Inherited Parameter Contexts:
+    - base-context
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{my_old_parameter}"
+Parameter Context Name: inherited-context
+      )";
+
+  REQUIRE_THROWS_WITH(yaml_config.getRootFromPayload(TEST_CONFIG_YAML), "Inherited parameter context 'base-context' cannot be the same as the parameter context!");
+}
+
+TEST_CASE("Parameter context can not inherit from non-existing parameter context", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+
+  static const std::string TEST_CONFIG_YAML =
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Contexts:
+  - id: 521e10b7-8e00-3188-9a27-476cca376351
+    name: base-context
+    description: my base parameter context
+    Parameters:
+    - name: my_old_parameter
+      description: ''
+      sensitive: false
+      value: old_value
+    Inherited Parameter Contexts: [unknown]
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{my_old_parameter}"
+Parameter Context Name: inherited-context
+      )";
+
+  REQUIRE_THROWS_WITH(yaml_config.getRootFromPayload(TEST_CONFIG_YAML), "Inherited parameter context 'unknown' does not exist!");
+}
+
+TEST_CASE("Cycles are not allowed in parameter context inheritance", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+
+  static const std::string TEST_CONFIG_YAML =
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Contexts:
+  - id: 123e10b7-8e00-3188-9a27-476cca376351
+    name: a-context
+    description: ''
+    Parameters:
+    - name: a_parameter
+      description: ''
+      sensitive: false
+      value: a_value
+    Inherited Parameter Contexts:
+    - c-context
+  - id: 456e10b7-8e00-3188-9a27-476cca376351
+    name: b-context
+    description: ''
+    Parameters:
+    - name: b_parameter
+      description: ''
+      sensitive: false
+      value: b_value
+    Inherited Parameter Contexts:
+    - a-context
+  - id: 789e10b7-8e00-3188-9a27-476cca376351
+    name: c-context
+    description: ''
+    Parameters:
+    - name: c_parameter
+      description: ''
+      sensitive: false
+      value: c_value
+    Inherited Parameter Contexts:
+    - d-context
+    - b-context
+  - id: 101e10b7-8e00-3188-9a27-476cca376351
+    name: d-context
+    description: ''
+    Parameters:
+    - name: d_parameter
+      description: ''
+      sensitive: false
+      value: d_value
+    Inherited Parameter Contexts: []
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{{my_old_parameter}}"
+    Sensitive Property: {}
+Parameter Context Name: inherited-context
+      )";
+
+  REQUIRE_THROWS_AS(yaml_config.getRootFromPayload(TEST_CONFIG_YAML), std::invalid_argument);
+  REQUIRE(minifi::test::utils::verifyLogLinePresenceInPollTime(0s, "Circular references in Parameter Context inheritance are not allowed. Inheritance cycle was detected in parameter context"));
+}
+
+TEST_CASE("Parameter context inheritance order is respected", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+
+  static const std::string TEST_CONFIG_YAML =
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Contexts:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: a-context
+    description: ''
+    Parameters:
+    - name: a_parameter
+      description: ''
+      sensitive: false
+      value: 1
+    - name: b_parameter
+      description: ''
+      sensitive: false
+      value: 2
+  - id: 521e10b7-8e00-3188-9a27-476cca376351
+    name: b-context
+    description: ''
+    Parameters:
+    - name: b_parameter
+      description: ''
+      sensitive: false
+      value: 3
+    - name: c_parameter
+      description: ''
+      sensitive: false
+      value: 4
+  - id: 123e10b7-8e00-3188-9a27-476cca376351
+    name: c-context
+    description: ''
+    Parameters:
+    - name: c_parameter
+      description: ''
+      sensitive: false
+      value: 5
+    Inherited Parameter Contexts:
+    - b-context
+    - a-context
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    My A Property: "#{a_parameter}"
+    My B Property: "#{b_parameter}"
+    My C Property: "#{c_parameter}"
+Parameter Context Name: c-context
+      )";
+
+  std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
+  REQUIRE(flow);
+  auto* proc = flow->findProcessorByName("DummyProcessor");
+  REQUIRE(proc);
+  std::string value;
+  REQUIRE("1" == proc->getDynamicProperty("My A Property"));
+  REQUIRE("3" == proc->getDynamicProperty("My B Property"));
+  REQUIRE("5" == proc->getDynamicProperty("My C Property"));
+}
+
+TEST_CASE("Parameter providers can be used for parameter values", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+
+  static const std::string TEST_CONFIG_YAML =
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flow
+Parameter Providers:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: DummyParameterProvider
+    type: DummyParameterProvider
+    Properties:
+      Dummy1 Value: value1
+      Dummy2 Value: value2
+      Dummy3 Value: value3
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{dummy1}"
+    My Dynamic Property Sequence:
+    - value: "#{dummy2}"
+    - value: "#{dummy3}"
+Parameter Context Name: dummycontext
+      )";
+
+  std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("DummyProcessor");
+  REQUIRE(proc);
+  auto values = proc->getAllDynamicPropertyValues("My Dynamic Property Sequence");
+  CHECK((*values)[0] == "value2");
+  CHECK((*values)[1] == "value3");
+}
+
+TEST_CASE("Parameter providers can be configured to select which parameters to be sensitive", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{dummy1}", *context.sensitive_values_encryptor);
+  core::YamlConfiguration yaml_config(context);
+
+  static const std::string TEST_CONFIG_YAML =
+      fmt::format(R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Providers:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: DummyParameterProvider
+    type: DummyParameterProvider
+    Properties:
+      Sensitive Parameter Scope: selected
+      Sensitive Parameter List: dummy1
+      Dummy1 Value: value1
+      Dummy3 Value: value3
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{{dummy3}}"
+    Sensitive Property: {}
+Parameter Context Name: dummycontext
+      )", encrypted_sensitive_property_value);
+
+  std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("DummyProcessor");
+  REQUIRE(proc);
+  REQUIRE(proc->getProperty("Sensitive Property") == "value1");
+  REQUIRE(proc->getProperty("Simple Property") == "value3");
+}
+
+TEST_CASE("If sensitive parameter scope is set to selected sensitive parameter list is required", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{dummy1}", *context.sensitive_values_encryptor);
+  core::YamlConfiguration yaml_config(context);
+
+  static const std::string TEST_CONFIG_YAML =
+      fmt::format(R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Providers:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: DummyParameterProvider
+    type: DummyParameterProvider
+    Properties:
+      Sensitive Parameter Scope: selected
+      Sensitive Parameter List:
+      Dummy1 Value: value1
+      Dummy3 Value: value3
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{{dummy3}}"
+    Sensitive Property: {}
+Parameter Context Name: dummycontext
+      )", encrypted_sensitive_property_value);
+
+  REQUIRE_THROWS_WITH(yaml_config.getRootFromPayload(TEST_CONFIG_YAML), "Parameter Operation: Sensitive Parameter Scope is set to 'selected' but Sensitive Parameter List is empty");
+}
+
+TEST_CASE("Parameter providers can be configured to make all parameters sensitive", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  auto context = test_controller.getContext();
+  auto encrypted_sensitive_property_value = minifi::utils::crypto::property_encryption::encrypt("#{dummy1}", *context.sensitive_values_encryptor);
+  core::YamlConfiguration yaml_config(context);
+
+  static const std::string TEST_CONFIG_YAML =
+      fmt::format(R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flowconfig
+Parameter Providers:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: DummyParameterProvider
+    type: DummyParameterProvider
+    Properties:
+      Sensitive Parameter Scope: all
+      Dummy1 Value: value1
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Sensitive Property: {}
+Parameter Context Name: dummycontext
+      )", encrypted_sensitive_property_value);
+
+  std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("DummyProcessor");
+  REQUIRE(proc);
+  REQUIRE(proc->getProperty("Sensitive Property") == "value1");
+}
+
+TEST_CASE("Parameter context can be inherited from parameter provider generated parameter context", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+
+  static const std::string TEST_CONFIG_YAML =
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flow
+Parameter Providers:
+  - id: d26ee5f5-0192-1000-0482-4e333725e089
+    name: DummyParameterProvider
+    type: DummyParameterProvider
+    Properties:
+      Dummy1 Value: value1
+      Dummy2 Value: value2
+      Dummy3 Value: value3
+Parameter Contexts:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: my-context
+    description: my parameter context
+    Parameters:
+    - name: file_size
+      description: ''
+      sensitive: false
+      value: 10 B
+    Inherited Parameter Contexts: [dummycontext]
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{dummy1}"
+Parameter Context Name: my-context
+      )";
+
+  std::unique_ptr<core::ProcessGroup> flow = yaml_config.getRootFromPayload(TEST_CONFIG_YAML);
+  REQUIRE(flow);
+
+  auto* proc = flow->findProcessorByName("DummyProcessor");
+  REQUIRE(proc);
+  REQUIRE(proc->getProperty("Simple Property") == "value1");
+}
+
+TEST_CASE("Parameter context names cannot conflict with parameter provider generated parameter context names", "[YamlConfiguration]") {
+  ConfigurationTestController test_controller;
+  core::YamlConfiguration yaml_config(test_controller.getContext());
+
+  static const std::string TEST_CONFIG_YAML =
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: flow
+Parameter Providers:
+  - id: d26ee5f5-0192-1000-0482-4e333725e089
+    name: DummyParameterProvider
+    type: DummyParameterProvider
+    Properties:
+      Dummy1 Value: value1
+      Dummy2 Value: value2
+      Dummy3 Value: value3
+Parameter Contexts:
+  - id: 721e10b7-8e00-3188-9a27-476cca376978
+    name: dummycontext
+    description: my parameter context
+    Parameters:
+    - name: file_size
+      description: ''
+      sensitive: false
+      value: 10 B
+Processors:
+- id: b0c04f28-0158-1000-0000-000000000000
+  name: DummyProcessor
+  class: org.apache.nifi.processors.DummyProcessor
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 1 sec
+  auto-terminated relationships list: [success]
+  Properties:
+    Simple Property: "#{dummy1}"
+Parameter Context Name: dummycontext
+      )";
+
+  REQUIRE_THROWS_WITH(yaml_config.getRootFromPayload(TEST_CONFIG_YAML), "Parameter provider 'DummyParameterProvider' cannot create parameter context 'dummycontext' because parameter context already "
+    "exists with no parameter provider or generated by other parameter provider");
+}
+
+TEST_CASE("Cannot use invalid property values") {
+  ConfigurationTestController test_controller;
+  core::flow::AdaptiveConfiguration config(test_controller.getContext());
+  auto [file_size_property_str, throws] = GENERATE(
+    std::make_tuple(R"(12 dogBytes)", true),
+    std::make_tuple(R"(1 kB)", false),
+    std::make_tuple(R"(
+    - value: 1 kB
+    - value: 2 MB)", false),
+    std::make_tuple(R"(foo)", true),
+    std::make_tuple(R"(
+    - value: 1 kB
+    - value: bar KB)", true));
+  const std::string CONFIG_YAML = fmt::format(
+      R"(
+MiNiFi Config Version: 3
+Flow Controller:
+  name: root
+  comment: ''
+Processors:
+- id: 0eac51eb-d76c-4ba6-9f0c-351795b2d243
+  name: GenerateFlowFile1
+  class: org.apache.nifi.minifi.processors.GenerateFlowFile
+  max concurrent tasks: 1
+  scheduling strategy: TIMER_DRIVEN
+  scheduling period: 10000 ms
+  Properties:
+    File Size: {}
+)", file_size_property_str);
+  if (throws) {
+    REQUIRE_THROWS_WITH(config.getRootFromPayload(CONFIG_YAML), "Unable to parse configuration file for component named 'GenerateFlowFile1' because ValidationFailed");
+  } else {
+    REQUIRE_NOTHROW(config.getRootFromPayload(CONFIG_YAML));
+  }
+}
+
 }  // namespace org::apache::nifi::minifi::test
