@@ -24,7 +24,7 @@
 static core::YamlConfiguration config{core::ConfigurationContext{
     .flow_file_repo = nullptr,
     .content_repo = nullptr,
-    .configuration = std::make_shared<minifi::Configure>(),
+    .configuration = std::make_shared<minifi::ConfigureImpl>(),
     .path = "",
     .filesystem = std::make_shared<utils::file::FileSystem>(),
     .sensitive_values_encryptor = utils::crypto::EncryptionProvider{utils::crypto::XSalsa20Cipher{utils::crypto::XSalsa20Cipher::generateKey()}}
