@@ -19,11 +19,11 @@
 #include <string>
 #include <utility>
 
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
 #include "core/Core.h"
 
@@ -31,7 +31,7 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-class KamikazeProcessor : public core::Processor {
+class KamikazeProcessor : public core::ProcessorImpl {
  public:
   EXTENSIONAPI static const std::string OnScheduleExceptionStr;
   EXTENSIONAPI static const std::string OnTriggerExceptionStr;
@@ -39,22 +39,20 @@ class KamikazeProcessor : public core::Processor {
   EXTENSIONAPI static const std::string OnTriggerLogStr;
   EXTENSIONAPI static const std::string OnUnScheduleLogStr;
 
-  explicit KamikazeProcessor(std::string_view name, const utils::Identifier& uuid = utils::Identifier())
-      : Processor(name, uuid) {
-  }
+  using ProcessorImpl::ProcessorImpl;
 
   EXTENSIONAPI static constexpr const char* Description = "This processor can throw exceptions in onTrigger and onSchedule calls based on configuration. Only for testing purposes.";
 
   EXTENSIONAPI static constexpr auto ThrowInOnSchedule = core::PropertyDefinitionBuilder<>::createProperty("Throw in onSchedule")
       .withDescription("Set to throw expcetion during onSchedule call")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto ThrowInOnTrigger = core::PropertyDefinitionBuilder<>::createProperty("Throw in onTrigger")
       .withDescription("Set to throw expcetion during onTrigger call")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
@@ -79,7 +77,6 @@ class KamikazeProcessor : public core::Processor {
 
  private:
   bool _throwInOnTrigger = false;
-  std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<KamikazeProcessor>::getLogger(uuid_);
 };
 
 }  // namespace org::apache::nifi::minifi::processors
