@@ -1,7 +1,4 @@
 /**
- * @file ConsumeWindowsEventLog.h
- * ConsumeWindowsEventLog class declaration
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -35,12 +32,13 @@
 #include <string>
 
 #include "core/Core.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/RelationshipDefinition.h"
+#include "core/StateManager.h"
 #include "utils/OsUtils.h"
 #include "wel/WindowsEventLog.h"
 #include "wel/EventPath.h"
@@ -51,10 +49,8 @@
 #include "utils/Export.h"
 #include "utils/RegexUtils.h"
 
-namespace org::apache::nifi::minifi::processors {
-
-namespace cwel {
-struct EventRender {
+namespace org::apache::nifi::minifi::wel {
+struct ProcessedEvent {
   std::map<std::string, std::string> matched_fields;
   std::string xml;
   std::string plaintext;
@@ -73,13 +69,17 @@ enum class JsonFormat {
   Simple,
   Flattened,
 };
-}  // namespace cwel
+
+std::function<bool(std::string_view)> parseSidMatcher(const std::optional<std::string>& sid_matcher);
 
 class Bookmark;
+}  // namespace org::apache::nifi::minifi::wel
 
-class ConsumeWindowsEventLog : public core::Processor {
+namespace org::apache::nifi::minifi::processors {
+
+class ConsumeWindowsEventLog : public core::ProcessorImpl {
  public:
-  explicit ConsumeWindowsEventLog(const std::string& name, const utils::Identifier& uuid = {});
+  explicit ConsumeWindowsEventLog(core::ProcessorMetadata metadata);
 
   ~ConsumeWindowsEventLog() override;
 
@@ -99,7 +99,7 @@ class ConsumeWindowsEventLog : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto MaxBufferSize = core::PropertyDefinitionBuilder<>::createProperty("Max Buffer Size")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .withDefaultValue("1 MB")
       .withDescription("The individual Event Log XMLs are rendered to a buffer."
           " This specifies the maximum size in bytes that the buffer will be allowed to grow to. (Limiting the maximum size of an individual Event XML.)")
@@ -107,7 +107,7 @@ class ConsumeWindowsEventLog : public core::Processor {
   // !!! This property is obsolete since now subscription is not used, but leave since it might be is used already in config.yml.
   EXTENSIONAPI static constexpr auto InactiveDurationToReconnect = core::PropertyDefinitionBuilder<>::createProperty("Inactive Duration To Reconnect")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+      .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
       .withDefaultValue("10 min")
       .withDescription("If no new event logs are processed for the specified time period, "
           " this processor will try reconnecting to recover from a state where any further messages cannot be consumed."
@@ -121,13 +121,13 @@ class ConsumeWindowsEventLog : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto IdentifierFunction = core::PropertyDefinitionBuilder<>::createProperty("Apply Identifier Function")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .withDescription("If true it will resolve SIDs matched in the 'Identifier Match Regex' to the DOMAIN\\USERNAME associated with that ID")
       .build();
   EXTENSIONAPI static constexpr auto ResolveAsAttributes = core::PropertyDefinitionBuilder<>::createProperty("Resolve Metadata in Attributes")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .withDescription("If true, any metadata that is resolved ( such as IDs or keyword metadata ) will be placed into attributes, otherwise it will be replaced in the XML or text output")
       .build();
@@ -142,21 +142,21 @@ class ConsumeWindowsEventLog : public core::Processor {
       .withDescription("Comma seperated list of key/value pairs with the following keys LOG_NAME, SOURCE, TIME_CREATED,EVENT_RECORDID,"
           "EVENTID,TASK_CATEGORY,LEVEL,KEYWORDS,USER,COMPUTER, and EVENT_TYPE. Eliminating fields will remove them from the header.")
       .build();
-  EXTENSIONAPI static constexpr auto OutputFormatProperty = core::PropertyDefinitionBuilder<magic_enum::enum_count<cwel::OutputFormat>() - 1>::createProperty("Output Format")
+  EXTENSIONAPI static constexpr auto OutputFormatProperty = core::PropertyDefinitionBuilder<magic_enum::enum_count<wel::OutputFormat>()>::createProperty("Output Format")
       .isRequired(true)
-      .withDefaultValue(magic_enum::enum_name(cwel::OutputFormat::XML))
-      .withAllowedValues(std::array{magic_enum::enum_name(cwel::OutputFormat::XML), magic_enum::enum_name(cwel::OutputFormat::Plaintext), magic_enum::enum_name(cwel::OutputFormat::JSON)})
+      .withDefaultValue(magic_enum::enum_name(wel::OutputFormat::XML))
+      .withAllowedValues(magic_enum::enum_names<wel::OutputFormat>())
       .withDescription("The format of the output flow files.")
       .build();
-  EXTENSIONAPI static constexpr auto JsonFormatProperty = core::PropertyDefinitionBuilder<magic_enum::enum_count<cwel::JsonFormat>()>::createProperty("JSON Format")
+  EXTENSIONAPI static constexpr auto JsonFormatProperty = core::PropertyDefinitionBuilder<magic_enum::enum_count<wel::JsonFormat>()>::createProperty("JSON Format")
       .isRequired(true)
-      .withDefaultValue(magic_enum::enum_name(cwel::JsonFormat::Simple))
-      .withAllowedValues(magic_enum::enum_names<cwel::JsonFormat>())
+      .withDefaultValue(magic_enum::enum_name(wel::JsonFormat::Simple))
+      .withAllowedValues(magic_enum::enum_names<wel::JsonFormat>())
       .withDescription("Set the json format type. Only applicable if Output Format is set to 'JSON'")
       .build();
   EXTENSIONAPI static constexpr auto BatchCommitSize = core::PropertyDefinitionBuilder<>::createProperty("Batch Commit Size")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::UNSIGNED_LONG_TYPE)
+      .withValidator(core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR)
       .withDefaultValue("1000")
       .withDescription("Maximum number of Events to consume and create to Flow Files from before committing.")
       .build();
@@ -167,13 +167,13 @@ class ConsumeWindowsEventLog : public core::Processor {
       .build();
   EXTENSIONAPI static constexpr auto ProcessOldEvents = core::PropertyDefinitionBuilder<>::createProperty("Process Old Events")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .withDescription("This property defines if old events (which are created before first time server is started) should be processed.")
       .build();
   EXTENSIONAPI static constexpr auto CacheSidLookups = core::PropertyDefinitionBuilder<>::createProperty("Cache SID Lookups")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .withDescription("Determines whether SID to name lookups are cached in memory")
       .build();
@@ -213,49 +213,36 @@ class ConsumeWindowsEventLog : public core::Processor {
 
  private:
   void refreshTimeZoneData();
-  void putEventRenderFlowFileToSession(const cwel::EventRender& eventRender, core::ProcessSession& session) const;
-  wel::WindowsEventLogHandler& getEventLogHandler(const std::string& name);
-  static bool insertHeaderName(wel::METADATA_NAMES& header, const std::string& key, const std::string& value);
-  nonstd::expected<cwel::EventRender, std::string> createEventRender(EVT_HANDLE eventHandle);
+  void createAndCommitFlowFile(const wel::ProcessedEvent& processed_event, core::ProcessSession& session) const;
+  wel::WindowsEventLogProvider& getEventLogProvider(const std::string& name);
+  wel::HeaderNames createHeaderNames(const std::optional<std::string>& event_header_property) const;
+  nonstd::expected<wel::ProcessedEvent, std::string> processEvent(EVT_HANDLE event_handle);
   void substituteXMLPercentageItems(pugi::xml_document& doc);
   std::function<std::string(const std::string&)> userIdToUsernameFunction() const;
-
   nonstd::expected<std::string, std::string> renderEventAsXml(EVT_HANDLE event_handle);
-
-  struct TimeDiff {
-    auto operator()() const {
-      return std::chrono::steady_clock::now() - time_;
-    }
-    const decltype(std::chrono::steady_clock::now()) time_ = std::chrono::steady_clock::now();
-  };
-
   bool commitAndSaveBookmark(const std::wstring& bookmarkXml, core::ProcessContext& context, core::ProcessSession& session);
+  std::tuple<size_t, std::wstring> processEventLogs(core::ProcessSession& session, EVT_HANDLE event_query_results);
+  std::unique_ptr<wel::Bookmark> createBookmark(const core::ProcessContext& context) const;
 
-  std::tuple<size_t, std::wstring> processEventLogs(core::ProcessSession& session,
-                                                    const EVT_HANDLE& event_query_results);
-
-  void addMatchedFieldsAsAttributes(const cwel::EventRender &eventRender, core::ProcessSession &session, const std::shared_ptr<core::FlowFile> &flowFile) const;
-
-  std::shared_ptr<core::logging::Logger> logger_;
   core::StateManager* state_manager_{nullptr};
-  wel::METADATA_NAMES header_names_;
+  wel::HeaderNames header_names_;
   std::optional<std::string> header_delimiter_;
   wel::EventPath path_;
   std::wstring wstr_query_;
-  std::optional<utils::Regex> regex_;
+  std::function<bool(std::string_view)> sid_matcher_;
   bool resolve_as_attributes_{false};
   bool apply_identifier_function_{false};
   std::string provenanceUri_;
   std::string computerName_;
   uint64_t max_buffer_size_{};
-  std::map<std::string, wel::WindowsEventLogHandler> providers_;
+  std::map<std::string, wel::WindowsEventLogProvider> providers_;
   uint64_t batch_commit_size_{};
   bool cache_sid_lookups_ = true;
 
-  cwel::OutputFormat output_format_;
-  cwel::JsonFormat json_format_;
+  wel::OutputFormat output_format_;
+  wel::JsonFormat json_format_;
 
-  std::unique_ptr<Bookmark> bookmark_;
+  std::unique_ptr<wel::Bookmark> bookmark_;
   std::mutex on_trigger_mutex_;
   std::unordered_map<std::string, std::string> xmlPercentageItemsResolutions_;
   HMODULE hMsobjsDll_{};
