@@ -32,7 +32,7 @@
 #include <utility>
 
 #include "core/Core.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "FlowFileRecord.h"
 #include "WindowsEventLog.h"
@@ -49,44 +49,24 @@ namespace org::apache::nifi::minifi::wel {
  */
 class MetadataWalker : public pugi::xml_tree_walker {
  public:
-  MetadataWalker(const WindowsEventLogMetadata& windows_event_log_metadata, std::string log_name, bool update_xml, bool resolve, utils::Regex const* regex,
+  MetadataWalker(const WindowsEventLogMetadata& windows_event_log_metadata, std::string log_name, bool update_xml, bool resolve,
+      std::function<bool(std::string_view)> sid_matcher,
       std::function<std::string(std::string)> user_id_to_username_fn)
       : windows_event_log_metadata_(windows_event_log_metadata),
         log_name_(std::move(log_name)),
-        regex_(regex),
+        sid_matcher_(std::move(sid_matcher)),
         update_xml_(update_xml),
         resolve_(resolve),
         user_id_to_username_fn_(std::move(user_id_to_username_fn)) {
   }
 
-  /**
-   * Overloaded function to visit a node
-   * @param node Node that we are visiting.
-   */
   bool for_each(pugi::xml_node &node) override;
-
   [[nodiscard]] std::map<std::string, std::string> getFieldValues() const;
-
   [[nodiscard]] std::map<std::string, std::string> getIdentifiers() const;
-
-  [[nodiscard]] std::string getMetadata(METADATA metadata) const;
+  [[nodiscard]] std::string getMetadata(Metadata metadata) const;
 
  private:
   static std::vector<std::string> getIdentifiers(const std::string &text);
-
-  static std::string getString(const std::map<std::string, std::string> &map, const std::string &field) {
-    auto srch = map.find(field);
-    if (srch != std::end(map)) {
-      return srch->second;
-    }
-    return "N/A";
-  }
-
-  static std::string to_string(const wchar_t* pChar);
-
-  /**
-   * Updates text within the XML representation
-   */
   template<typename Fn>
   requires std::is_convertible_v<std::invoke_result_t<Fn, std::string>, std::string>
   void updateText(pugi::xml_node &node, const std::string &field_name, Fn &&fn);
@@ -96,7 +76,7 @@ class MetadataWalker : public pugi::xml_tree_walker {
 
   const WindowsEventLogMetadata& windows_event_log_metadata_;
   const std::string log_name_;
-  utils::Regex const * const regex_;
+  std::function<bool(std::string_view)> sid_matcher_;
   const bool update_xml_;
   const bool resolve_;
   std::function<std::string(const std::string&)> user_id_to_username_fn_;
