@@ -17,15 +17,11 @@
 
 #pragma once
 
-#include <windows.h>
+#include <Windows.h>
 
 #include <memory>
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace wel {
+namespace org::apache::nifi::minifi::wel {
 
 struct unique_evt_handle_deleter {
   void operator()(EVT_HANDLE event) const noexcept { EvtClose(event); }
@@ -33,9 +29,4 @@ struct unique_evt_handle_deleter {
 
 using unique_evt_handle = std::unique_ptr<std::remove_pointer<EVT_HANDLE>::type, unique_evt_handle_deleter>;
 
-} /* namespace wel */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
-
+}  // namespace org::apache::nifi::minifi::wel
