@@ -42,6 +42,18 @@ std::string getEventTimestampStr(uint64_t event_timestamp) {
 }
 }  // namespace
 
+std::optional<std::string> EventDataCache::get(EVT_FORMAT_MESSAGE_FLAGS field, const std::string& key) const {
+    std::lock_guard<std::mutex> lock{mutex_};
+    const auto it = cache_.find(CacheKey{field, key});
+    if (it != cache_.end() && it->second.expiry > std::chrono::system_clock::now()) { return it->second.value; }
+    return std::nullopt;
+}
+
+void EventDataCache::set(EVT_FORMAT_MESSAGE_FLAGS field, const std::string& key, std::string value) {
+  std::lock_guard<std::mutex> lock{mutex_};
+  cache_.insert_or_assign(CacheKey{field, key}, CacheItem{std::move(value), std::chrono::system_clock::now() + lifetime_});
+}
+
 void WindowsEventLogMetadataImpl::renderMetadata() {
   DWORD status = ERROR_SUCCESS;
   EVT_VARIANT stackBuffer[4096];
@@ -55,7 +67,7 @@ void WindowsEventLogMetadataImpl::renderMetadata() {
   if (!context)
     return;
 
-  if (!EvtRender(context.get(), event_ptr_, EvtRenderEventValues, dwBufferSize, rendered_values.get(), &dwBufferUsed, &dwPropertyCount)) {
+  if (!EvtRender(context.get(), event_handle_, EvtRenderEventValues, dwBufferSize, rendered_values.get(), &dwBufferUsed, &dwPropertyCount)) {
     if (ERROR_INSUFFICIENT_BUFFER != (status = GetLastError())) {
       return;
     }
@@ -66,7 +78,7 @@ void WindowsEventLogMetadataImpl::renderMetadata() {
       return;
     }
 
-    EvtRender(context.get(), event_ptr_, EvtRenderEventValues, dwBufferSize, rendered_values.get(), &dwBufferUsed, &dwPropertyCount);
+    EvtRender(context.get(), event_handle_, EvtRenderEventValues, dwBufferSize, rendered_values.get(), &dwBufferUsed, &dwPropertyCount);
     if (ERROR_SUCCESS != (status = GetLastError())) {
       return;
     }
@@ -108,44 +120,54 @@ void WindowsEventLogMetadataImpl::renderMetadata() {
   }
 }
 
-std::string WindowsEventLogMetadataImpl::getEventData(EVT_FORMAT_MESSAGE_FLAGS flags) const {
+std::string WindowsEventLogMetadataImpl::getEventData(EVT_FORMAT_MESSAGE_FLAGS field, const std::string& key) const {
+  return event_log_provider_.getEventData(field, key, event_handle_);
+}
+
+std::string WindowsEventLogProvider::getEventData(EVT_FORMAT_MESSAGE_FLAGS field, const std::string& key, EVT_HANDLE event_handle) const {
+  auto cached_value = event_data_cache_.get(field, key);
+  if (cached_value) { return *cached_value; }
+  auto new_value = getEventDataImpl(field, event_handle);
+  event_data_cache_.set(field, key, new_value);
+  return new_value;
+}
+
+std::string WindowsEventLogProvider::getEventDataImpl(EVT_FORMAT_MESSAGE_FLAGS field, EVT_HANDLE event_handle) const {
   WCHAR stack_buffer[4096];
   DWORD num_chars_in_buffer = sizeof(stack_buffer) / sizeof(stack_buffer[0]);
   using Deleter = utils::StackAwareDeleter<WCHAR, utils::FreeDeleter>;
   std::unique_ptr<WCHAR, Deleter> buffer{stack_buffer, Deleter{stack_buffer}};
   DWORD num_chars_used = 0;
 
-  std::string event_data;
-
-  if (!metadata_ptr_ || !event_ptr_) {
-    return event_data;
+  if (!provider_handle_ || !event_handle) {
+    return {};
   }
 
-  if (!EvtFormatMessage(metadata_ptr_, event_ptr_, 0, 0, nullptr, flags, num_chars_in_buffer, buffer.get(), &num_chars_used)) {
+  if (!EvtFormatMessage(provider_handle_.get(), event_handle, 0, 0, nullptr, field, num_chars_in_buffer, buffer.get(), &num_chars_used)) {
     auto last_error = GetLastError();
     if (ERROR_INSUFFICIENT_BUFFER == last_error) {
       num_chars_in_buffer = num_chars_used;
 
       buffer.reset((LPWSTR) malloc(num_chars_in_buffer * sizeof(WCHAR)));
       if (!buffer) {
-        return event_data;
+        return {};
       }
 
-      EvtFormatMessage(metadata_ptr_, event_ptr_, 0, 0, nullptr, flags, num_chars_in_buffer, buffer.get(), &num_chars_used);
+      EvtFormatMessage(provider_handle_.get(), event_handle, 0, 0, nullptr, field, num_chars_in_buffer, buffer.get(), &num_chars_used);
     }
   }
 
   if (num_chars_used == 0) {
-    return event_data;
+    return {};
   }
 
-  if (EvtFormatMessageKeyword == flags) {
+  if (EvtFormatMessageKeyword == field) {
     buffer.get()[num_chars_used - 1] = L'\0';
   }
   return utils::to_string(std::wstring{buffer.get()});
 }
 
-nonstd::expected<std::string, std::error_code> WindowsEventLogHandler::getEventMessage(EVT_HANDLE eventHandle) const {
+nonstd::expected<std::string, std::error_code> WindowsEventLogProvider::getEventMessage(EVT_HANDLE event_handle) const {
   std::string returnValue;
   WCHAR stack_buffer[4096];
   DWORD num_chars_in_buffer = sizeof(stack_buffer) / sizeof(stack_buffer[0]);
@@ -153,7 +175,7 @@ nonstd::expected<std::string, std::error_code> WindowsEventLogHandler::getEventM
   std::unique_ptr<WCHAR, Deleter> buffer{stack_buffer, Deleter{stack_buffer}};
   DWORD num_chars_used = 0;
 
-  bool evt_format_succeeded = EvtFormatMessage(metadata_provider_.get(), eventHandle, 0, 0, nullptr, EvtFormatMessageEvent, num_chars_in_buffer, buffer.get(), &num_chars_used);
+  bool evt_format_succeeded = EvtFormatMessage(provider_handle_.get(), event_handle, 0, 0, nullptr, EvtFormatMessageEvent, num_chars_in_buffer, buffer.get(), &num_chars_used);
   if (evt_format_succeeded)
     return utils::to_string(std::wstring{buffer.get()});
 
@@ -166,7 +188,7 @@ nonstd::expected<std::string, std::error_code> WindowsEventLogHandler::getEventM
   buffer.reset((LPWSTR) malloc(num_chars_in_buffer * sizeof(WCHAR)));
   if (!buffer)
     return nonstd::make_unexpected(utils::OsUtils::windowsErrorToErrorCode(ERROR_OUTOFMEMORY));
-  if (EvtFormatMessage(metadata_provider_.get(), eventHandle, 0, 0, nullptr,
+  if (EvtFormatMessage(provider_handle_.get(), event_handle, 0, 0, nullptr,
                        EvtFormatMessageEvent, num_chars_in_buffer,
                        buffer.get(), &num_chars_used))
     return utils::to_string(std::wstring{buffer.get()});
@@ -174,7 +196,7 @@ nonstd::expected<std::string, std::error_code> WindowsEventLogHandler::getEventM
 }
 
 namespace {
-size_t findLongestHeaderNameSize(const METADATA_NAMES& header_names, const size_t minimum_size) {
+size_t findLongestHeaderNameSize(const HeaderNames& header_names, const size_t minimum_size) {
   size_t max = minimum_size;
   for (const auto& option : header_names) {
     max = (std::max(max, option.second.size()));
@@ -183,7 +205,7 @@ size_t findLongestHeaderNameSize(const METADATA_NAMES& header_names, const size_
 }
 }  // namespace
 
-WindowsEventLogHeader::WindowsEventLogHeader(const METADATA_NAMES& header_names, const std::optional<std::string>& custom_delimiter, const size_t minimum_size)
+WindowsEventLogHeader::WindowsEventLogHeader(const HeaderNames& header_names, const std::optional<std::string>& custom_delimiter, const size_t minimum_size)
     : header_names_(header_names),
       custom_delimiter_(custom_delimiter),
       longest_header_name_(findLongestHeaderNameSize(header_names, minimum_size)) {
@@ -203,8 +225,4 @@ std::string WindowsEventLogHeader::createDefaultDelimiter(size_t length) const {
   }
 }
 
-EVT_HANDLE WindowsEventLogHandler::getMetadata() const {
-  return metadata_provider_.get();
-}
-
 }  // namespace org::apache::nifi::minifi::wel
