@@ -38,9 +38,8 @@ build_deps(){
     wget https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
     sudo yum -y install epel-release-latest-7.noarch.rpm
 
-    COMMAND="sudo yum -y install libuuid libuuid-devel patch"
+    COMMAND="sudo yum -y install libuuid libuuid-devel patch perl bzip2-devel"
     INSTALLED=()
-    INSTALLED+=("bzip2-devel")
     for option in "${OPTIONS[@]}" ; do
         option_value="${!option}"
         if [ "$option_value" = "${TRUE}" ]; then
@@ -52,20 +51,10 @@ build_deps(){
                 if [ "$KEY" = "$option" ]; then
                     FOUND_VALUE="$VALUE"
                     echo "$FOUND_VALUE"
-                    if [ "$FOUND_VALUE" = "libpcap" ]; then
-                        INSTALLED+=("libpcap-devel")
-                    elif [ "$FOUND_VALUE" = "libusb" ]; then
-                        INSTALLED+=("libusb1-devel")
-                    elif [ "$FOUND_VALUE" = "libpng" ]; then
-                        INSTALLED+=("libpng-devel")
-                    elif [ "$FOUND_VALUE" = "bison" ]; then
+                    if [ "$FOUND_VALUE" = "bison" ]; then
                         INSTALLED+=("bison")
                     elif [ "$FOUND_VALUE" = "flex" ]; then
                         INSTALLED+=("flex")
-                    elif [ "$FOUND_VALUE" = "jnibuild" ]; then
-                        INSTALLED+=("java-1.8.0-openjdk")
-                        INSTALLED+=("java-1.8.0-openjdk-devel")
-                        INSTALLED+=("maven")
                     elif [ "$FOUND_VALUE" = "python" ]; then
                         INSTALLED+=("python3-devel")
                     elif [ "$FOUND_VALUE" = "libtool" ]; then
@@ -74,14 +63,10 @@ build_deps(){
                         INSTALLED+=("autoconf")
                     elif [ "$FOUND_VALUE" = "automake" ]; then
                         INSTALLED+=("automake")
-                    elif [ "$FOUND_VALUE" = "gpsd" ]; then
-                        INSTALLED+=("gpsd-devel")
                     elif [ "$FOUND_VALUE" = "libarchive" ]; then
                         INSTALLED+=("xz-devel")
                     elif [ "$FOUND_VALUE" = "libssh2" ]; then
                         INSTALLED+=("libssh2-devel")
-                    elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
-                        INSTALLED+=("perl")
                     fi
                 fi
             done
