@@ -38,6 +38,7 @@
 #include "Connection.h"
 #include "io/OutputStream.h"
 #include "io/StreamPipe.h"
+#include "minifi-cpp/FlowFileRecord.h"
 
 namespace org::apache::nifi::minifi {
 
@@ -47,16 +48,20 @@ namespace core {
 class ProcessSession;
 }
 
-class FlowFileRecord : public core::FlowFile {
+class FlowFileRecordImpl : public core::FlowFileImpl, public virtual FlowFileRecord {
   friend class core::ProcessSession;
 
  public:
-  FlowFileRecord();
+  FlowFileRecordImpl();
 
-  bool Serialize(io::OutputStream &outStream);
+  void copy(const core::FlowFile& other) override {
+    *this = *dynamic_cast<const FlowFileRecordImpl*>(&other);
+  }
+
+  bool Serialize(io::OutputStream &outStream) override;
 
   //! Serialize and Persistent to the repository
-  bool Persist(const std::shared_ptr<core::Repository>& flowRepository);
+  bool Persist(const std::shared_ptr<core::Repository>& flowRepository) override;
 
   static std::shared_ptr<FlowFileRecord> DeSerialize(std::span<const std::byte> buffer, const std::shared_ptr<core::ContentRepository> &content_repo, utils::Identifier &container) {
     io::BufferStream inStream{buffer};
@@ -64,9 +69,9 @@ class FlowFileRecord : public core::FlowFile {
   }
   static std::shared_ptr<FlowFileRecord> DeSerialize(io::InputStream &stream, const std::shared_ptr<core::ContentRepository> &content_repo, utils::Identifier &container);
   static std::shared_ptr<FlowFileRecord> DeSerialize(const std::string& key, const std::shared_ptr<core::Repository>& flowRepository,
-      const std::shared_ptr<core::ContentRepository> &content_repo, utils::Identifier &container);
+                                                     const std::shared_ptr<core::ContentRepository> &content_repo, utils::Identifier &container);
 
-  std::string getContentFullPath() const {
+  std::string getContentFullPath() const override {
     return claim_ ? claim_->getContentFullPath() : "";
   }
 
