@@ -29,15 +29,16 @@
 #include "http/BaseHTTPClient.h"
 #include "concurrentqueue.h"
 #include "FlowFileRecord.h"
-#include "core/Processor.h"
+#include "core/ProcessorImpl.h"
 #include "core/ProcessSession.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "core/RelationshipDefinition.h"
 #include "sitetosite/SiteToSiteClient.h"
-#include "controllers/SSLContextService.h"
+#include "minifi-cpp/controllers/SSLContextServiceInterface.h"
 #include "core/logging/LoggerFactory.h"
 #include "utils/Export.h"
+#include "core/ClassLoader.h"
 
 namespace org::apache::nifi::minifi {
 
@@ -74,17 +75,16 @@ struct RPG {
   std::string protocol_;
 };
 
-class RemoteProcessorGroupPort : public core::Processor {
+class RemoteProcessorGroupPort : public core::ProcessorImpl {
  public:
-  RemoteProcessorGroupPort(std::string_view name, std::string url, std::shared_ptr<Configure> configure, const utils::Identifier &uuid = {})
-      : core::Processor(name, uuid),
+  RemoteProcessorGroupPort(std::string_view name, std::string url, std::shared_ptr<Configure> configure, const utils::Identifier &uuid, std::shared_ptr<core::logging::Logger> logger = nullptr)
+      : core::ProcessorImpl({.uuid = uuid, .name = std::string{name}, .logger = logger ? logger : core::logging::LoggerFactory<RemoteProcessorGroupPort>::getLogger(uuid)}),
         configure_(std::move(configure)),
         direction_(sitetosite::SEND),
         transmitting_(false),
         timeout_(0),
         bypass_rest_api_(false),
-        ssl_service(nullptr),
-        logger_(core::logging::LoggerFactory<RemoteProcessorGroupPort>::getLogger(uuid)) {
+        ssl_service(nullptr) {
     client_type_ = sitetosite::CLIENT_TYPE::RAW;
     protocol_uuid_ = uuid;
     site2site_secure_ = false;
@@ -108,10 +108,11 @@ class RemoteProcessorGroupPort : public core::Processor {
       .build();
   MINIFIAPI static constexpr auto idleTimeout = core::PropertyDefinitionBuilder<>::createProperty("Idle Timeout")
     .withDescription("Max idle time for remote service")
-    .isRequired(false)
-    .withPropertyType(core::StandardPropertyTypes::TIME_PERIOD_TYPE)
+    .isRequired(true)
+    .withValidator(core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR)
     .withDefaultValue("15 s")
     .build();
+
   MINIFIAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       hostName,
       SSLContext,
@@ -210,7 +211,7 @@ class RemoteProcessorGroupPort : public core::Processor {
   }
 
   std::unique_ptr<sitetosite::SiteToSiteClient> getNextProtocol(bool create);
-  void returnProtocol(std::unique_ptr<sitetosite::SiteToSiteClient> protocol);
+  void returnProtocol(core::ProcessContext& context, std::unique_ptr<sitetosite::SiteToSiteClient> protocol);
 
   moodycamel::ConcurrentQueue<std::unique_ptr<sitetosite::SiteToSiteClient>> available_protocols_;
 
@@ -246,10 +247,9 @@ class RemoteProcessorGroupPort : public core::Processor {
   std::string rest_user_name_;
   std::string rest_password_;
 
-  std::shared_ptr<controllers::SSLContextService> ssl_service;
+  std::shared_ptr<controllers::SSLContextServiceInterface> ssl_service;
 
  private:
-  std::shared_ptr<core::logging::Logger> logger_;
   static const char* RPG_SSL_CONTEXT_SERVICE_NAME;
 };
 
