@@ -86,9 +86,14 @@ class SchedulingAgent {
     logger_->log_trace("Destroying scheduling agent");
   }
 
-  nonstd::expected<void, std::exception_ptr> onTrigger(core::Processor* processor,
+  bool processorYields(core::Processor* processor) const;
+
+  nonstd::expected<void, std::exception_ptr> triggerAndCommit(core::Processor* processor,
       const std::shared_ptr<core::ProcessContext>& process_context,
       const std::shared_ptr<core::ProcessSessionFactory>& session_factory);
+  nonstd::expected<bool, std::exception_ptr> trigger(core::Processor* processor,
+      const std::shared_ptr<core::ProcessContext>& process_context,
+      const std::shared_ptr<core::ProcessSession>& process_session);
 
   void start() {
     running_ = true;
@@ -145,8 +150,8 @@ class SchedulingAgent {
   };
 
   std::shared_ptr<core::logging::Logger> logger_;
-  mutable std::mutex watchdog_mtx_;  // used to protect the set below
-  std::set<SchedulingInfo> scheduled_processors_;  // set was chosen to avoid iterator invalidation
+  mutable std::mutex watchdog_mtx_;  // used to protect the vector below
+  std::vector<gsl::not_null<SchedulingInfo*>> scheduled_processors_;
   std::unique_ptr<utils::CallBackTimer> watchDogTimer_;
   std::chrono::milliseconds alert_time_;
 };
