@@ -24,7 +24,7 @@
 #include <atomic>
 
 #include "io/BaseStream.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "core/state/nodes/StateMonitor.h"
 #include "core/controller/ControllerServiceProvider.h"
 #include "ControllerSocketReporter.h"
@@ -32,6 +32,7 @@
 #include "asio/ip/tcp.hpp"
 #include "asio/ssl/context.hpp"
 #include "utils/net/AsioCoro.h"
+#include "minifi-cpp/controllers/SSLContextServiceInterface.h"
 
 namespace org::apache::nifi::minifi::c2 {
 
@@ -45,6 +46,7 @@ class ControllerSocketProtocol {
     std::shared_ptr<Configure> configuration, const std::shared_ptr<ControllerSocketReporter>& controller_socket_reporter);
   ~ControllerSocketProtocol();
   void initialize();
+  void setRoot(core::ProcessGroup* root);
 
  private:
   void handleStart(io::BaseStream &stream);
@@ -58,13 +60,14 @@ class ControllerSocketProtocol {
   void writeGetFullResponse(io::BaseStream &stream);
   void writeManifestResponse(io::BaseStream &stream);
   void writeJstackResponse(io::BaseStream &stream);
+  void writeFlowStatusResponse(io::BaseStream &stream);
   void writeDebugBundleResponse(io::BaseStream &stream);
   void handleDescribe(io::BaseStream &stream);
   asio::awaitable<void> handleCommand(std::unique_ptr<io::BaseStream> stream);
-  asio::awaitable<void> handshakeAndHandleCommand(asio::ip::tcp::socket&& socket, std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service);
+  asio::awaitable<void> handshakeAndHandleCommand(asio::ip::tcp::socket&& socket, std::shared_ptr<minifi::controllers::SSLContextServiceInterface> ssl_context_service);
   std::string getJstack();
   asio::awaitable<void> startAccept();
-  asio::awaitable<void> startAcceptSsl(std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service);
+  asio::awaitable<void> startAcceptSsl(std::shared_ptr<minifi::controllers::SSLContextServiceInterface> ssl_context_service);
   void stopListener();
 
   core::controller::ControllerServiceProvider& controller_;
@@ -83,7 +86,7 @@ class ControllerSocketProtocol {
   // These commands are handled on a separate thread, and while these commands are handled other incoming commands are dropped
   class SocketRestartCommandProcessor {
    public:
-    explicit SocketRestartCommandProcessor(state::StateMonitor& update_sink_);
+    explicit SocketRestartCommandProcessor(state::StateMonitor& update_sink_, const std::shared_ptr<core::logging::Logger>& logger);
     ~SocketRestartCommandProcessor();
 
     enum class Command {
@@ -111,6 +114,7 @@ class ControllerSocketProtocol {
     std::thread command_processor_thread_;
     std::atomic_bool running_ = true;
     utils::ConditionConcurrentQueue<CommandData> command_queue_;
+    std::shared_ptr<core::logging::Logger> logger_;
   };
 
   SocketRestartCommandProcessor socket_restart_processor_;
