@@ -19,6 +19,13 @@
 #include <unordered_map>
 #include <unordered_set>
 #include <string>
+#include <vector>
+#include <filesystem>
+
+#include "core/ProcessGroup.h"
+#include "utils/StringUtils.h"
+#include "FlowStatusRequest.h"
+#include "core/BulletinStore.h"
 
 namespace org::apache::nifi::minifi::c2 {
 
@@ -33,6 +40,9 @@ class ControllerSocketReporter {
   virtual std::unordered_set<std::string> getFullConnections() = 0;
   virtual std::unordered_set<std::string> getConnections() = 0;
   virtual std::string getAgentManifest() = 0;
+  virtual void setRoot(core::ProcessGroup* root) = 0;
+  virtual void setFlowStatusDependencies(core::BulletinStore* bulletin_store, const std::filesystem::path& flowfile_repo_dir, const std::filesystem::path& content_repo_dir) = 0;
+  virtual std::string getFlowStatus(const std::vector<FlowStatusRequest>& requests) = 0;
   virtual ~ControllerSocketReporter() = default;
 };
 
