@@ -25,12 +25,11 @@
 
 #include "utils/StringUtils.h"
 #include "io/validation.h"
-#include "controllers/SSLContextService.h"
 #include "core/controller/ControllerService.h"
 #include "core/logging/LoggerFactory.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "ThreadManagementService.h"
 #include "io/NetworkPrioritizer.h"
 #include "utils/Export.h"
@@ -40,12 +39,12 @@ namespace org::apache::nifi::minifi::controllers {
 /**
  * Purpose: Network prioritizer for selecting network interfaces through the flow configuration.
  */
-class NetworkPrioritizerService : public core::controller::ControllerService, public minifi::io::NetworkPrioritizer, public std::enable_shared_from_this<NetworkPrioritizerService> {
+class NetworkPrioritizerService : public core::controller::ControllerServiceImpl, public minifi::io::NetworkPrioritizer, public utils::EnableSharedFromThis {
  public:
   explicit NetworkPrioritizerService(std::string_view name,
                                      const utils::Identifier& uuid = {},
                                      std::shared_ptr<utils::timeutils::Clock> clock = std::make_shared<utils::timeutils::SteadyClock>())
-      : ControllerService(name, uuid),
+      : ControllerServiceImpl(name, uuid),
         enabled_(false),
         max_throughput_(std::numeric_limits<uint64_t>::max()),
         max_payload_(std::numeric_limits<uint64_t>::max()),
@@ -72,34 +71,34 @@ class NetworkPrioritizerService : public core::controller::ControllerService, pu
   MINIFIAPI static constexpr auto MaxThroughput = core::PropertyDefinitionBuilder<>::createProperty("Max Throughput")
       .withDescription("Max throughput ( per second ) for these network controllers")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .withDefaultValue("1 MB")
       .build();
   MINIFIAPI static constexpr auto MaxPayload = core::PropertyDefinitionBuilder<>::createProperty("Max Payload")
       .withDescription("Maximum payload for these network controllers")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::DATA_SIZE_TYPE)
+      .withValidator(core::StandardPropertyValidators::DATA_SIZE_VALIDATOR)
       .withDefaultValue("1 GB")
       .build();
   MINIFIAPI static constexpr auto VerifyInterfaces = core::PropertyDefinitionBuilder<>::createProperty("Verify Interfaces")
       .withDescription("Verify that interfaces are operational")
       .isRequired(true)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("true")
       .build();
   MINIFIAPI static constexpr auto DefaultPrioritizer = core::PropertyDefinitionBuilder<>::createProperty("Default Prioritizer")
       .withDescription("Sets this controller service as the default prioritizer for all comms")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   MINIFIAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
-      NetworkControllers,
-      MaxThroughput,
-      MaxPayload,
-      VerifyInterfaces,
-      DefaultPrioritizer
-  });
+                                                                                          NetworkControllers,
+                                                                                          MaxThroughput,
+                                                                                          MaxPayload,
+                                                                                          VerifyInterfaces,
+                                                                                          DefaultPrioritizer
+                                                                                      });
 
 
   MINIFIAPI static constexpr bool SupportsDynamicProperties = false;
