@@ -25,26 +25,28 @@
 #include <wincrypt.h>
 #endif
 
-#include <openssl/err.h>
-#include <openssl/ssl.h>
-#include <openssl/bio.h>
-#include <openssl/pkcs12.h>
-
 #include <iostream>
 #include <memory>
 #include <string>
 #include <utility>
 
-#include "utils/StringUtils.h"
-#include "utils/tls/ExtendedKeyUsage.h"
-#include "io/validation.h"
-#include "../core/controller/ControllerService.h"
-#include "core/logging/LoggerFactory.h"
+#include "openssl/bio.h"
+#include "openssl/err.h"
+#include "openssl/pkcs12.h"
+#include "openssl/ssl.h"
+
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "core/controller/ControllerService.h"
+#include "core/logging/LoggerFactory.h"
+#include "io/validation.h"
+#include "minifi-cpp/controllers/SSLContextServiceInterface.h"
+#include "minifi-cpp/core/PropertyValidator.h"
+#include "utils/ConfigurationUtils.h"
 #include "utils/Export.h"
+#include "utils/StringUtils.h"
 #include "utils/tls/CertificateUtils.h"
+#include "utils/tls/ExtendedKeyUsage.h"
 
 namespace org::apache::nifi::minifi::controllers {
 
@@ -70,74 +72,82 @@ class SSLContext {
  * Justification: Abstracts SSL support out of processors into a
  * configurable controller service.
  */
-class SSLContextService : public core::controller::ControllerService {
+class SSLContextService : public core::controller::ControllerServiceImpl, public SSLContextServiceInterface {
  public:
   explicit SSLContextService(std::string_view name, const utils::Identifier &uuid = {})
-      : ControllerService(name, uuid),
+      : ControllerServiceImpl(name, uuid),
         initialized_(false),
         logger_(core::logging::LoggerFactory<SSLContextService>::getLogger(uuid_)) {
   }
 
   explicit SSLContextService(std::string_view name, const std::shared_ptr<Configure> &configuration)
-      : ControllerService(name),
+      : ControllerServiceImpl(name),
         initialized_(false),
         logger_(core::logging::LoggerFactory<SSLContextService>::getLogger(uuid_)) {
-    setConfiguration(configuration);
-    initialize();
+    ControllerServiceImpl::setConfiguration(configuration);
+    SSLContextService::initialize();
+    auto setPropertyAndHandleError = [this](std::string_view property_name, std::string value) {
+      auto result = ControllerServiceImpl::setProperty(property_name, std::move(value));
+      if (!result) {
+        logger_->log_error("Failed to set property {}: {}", property_name, result.error().message());
+      }
+    };
 
     // set the properties based on the configuration
     std::string value;
     if (configuration_->get(Configure::nifi_security_client_certificate, value)) {
-      setProperty(ClientCertificate, value);
+      setPropertyAndHandleError(ClientCertificate.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_client_private_key, value)) {
-      setProperty(PrivateKey, value);
+      setPropertyAndHandleError(PrivateKey.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_client_pass_phrase, value)) {
-      setProperty(Passphrase, value);
+      setPropertyAndHandleError(Passphrase.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_client_ca_certificate, value)) {
-      setProperty(CACertificate, value);
+      setPropertyAndHandleError(CACertificate.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_use_system_cert_store, value)) {
-      setProperty(UseSystemCertStore, value);
+      setPropertyAndHandleError(UseSystemCertStore.name, std::move(value));
     }
 
 #ifdef WIN32
     if (configuration_->get(Configure::nifi_security_windows_cert_store_location, value)) {
-      setProperty(CertStoreLocation, value);
+      setPropertyAndHandleError(CertStoreLocation.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_windows_server_cert_store, value)) {
-      setProperty(ServerCertStore, value);
+      setPropertyAndHandleError(ServerCertStore.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_windows_client_cert_store, value)) {
-      setProperty(ClientCertStore, value);
+      setPropertyAndHandleError(ClientCertStore.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_windows_client_cert_cn, value)) {
-      setProperty(ClientCertCN, value);
+      setPropertyAndHandleError(ClientCertCN.name, std::move(value));
     }
 
     if (configuration_->get(Configure::nifi_security_windows_client_cert_key_usage, value)) {
-      setProperty(ClientCertKeyUsage, value);
+      setPropertyAndHandleError(ClientCertKeyUsage.name, std::move(value));
     }
 #endif  // WIN32
   }
 
+  static constexpr auto ImplementsApis = std::array{ SSLContextServiceInterface::ProvidesApi };
+
   void initialize() override;
 
   std::unique_ptr<SSLContext> createSSLContext();
 
-  const std::filesystem::path& getCertificateFile() const;
-  const std::string& getPassphrase() const;
-  const std::filesystem::path& getPrivateKeyFile() const;
-  const std::filesystem::path& getCACertificate() const;
+  const std::filesystem::path& getCertificateFile() const override;
+  const std::string& getPassphrase() const override;
+  const std::filesystem::path& getPrivateKeyFile() const override;
+  const std::filesystem::path& getCACertificate() const override;
 
   void yield() override {
   }
@@ -150,14 +160,14 @@ class SSLContextService : public core::controller::ControllerService {
     return false;
   }
 
-  void setMinTlsVersion(long min_version) {  // NOLINT(runtime/int) long due to SSL lib API
+  void setMinTlsVersion(long min_version) override {  // NOLINT(runtime/int) long due to SSL lib API
     minimum_tls_version_ = min_version;
   }
 
-  void setMaxTlsVersion(long max_version) {  // NOLINT(runtime/int) long due to SSL lib API
+  void setMaxTlsVersion(long max_version) override {  // NOLINT(runtime/int) long due to SSL lib API
     maximum_tls_version_ = max_version;
   }
-  bool configure_ssl_context(SSL_CTX *ctx);
+  bool configure_ssl_context(void* ctx) override;
 
   void onEnable() override;
 
@@ -210,7 +220,7 @@ class SSLContextService : public core::controller::ControllerService {
   MINIFIAPI static constexpr auto UseSystemCertStore = core::PropertyDefinitionBuilder<>::createProperty("Use System Cert Store")
       .withDescription("Whether to use the certificates in the OS's certificate store")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   MINIFIAPI static constexpr auto Properties =
@@ -224,12 +234,12 @@ class SSLContextService : public core::controller::ControllerService {
 #else
       std::to_array<core::PropertyReference>({
 #endif  // WIN32
-          ClientCertificate,
-          PrivateKey,
-          Passphrase,
-          CACertificate,
-          UseSystemCertStore
-      });
+                                                 ClientCertificate,
+                                                 PrivateKey,
+                                                 Passphrase,
+                                                 CACertificate,
+                                                 UseSystemCertStore
+                                             });
 
   MINIFIAPI static constexpr bool SupportsDynamicProperties = false;
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
@@ -253,13 +263,14 @@ class SSLContextService : public core::controller::ControllerService {
 #endif  // WIN32
 
   static std::string getLatestOpenSSLErrorString() {
-    unsigned long err = ERR_peek_last_error(); // NOLINT
-    if (err == 0U) {
+    const auto err = ERR_peek_last_error();
+    if (err == 0) {
       return "";
     }
-    char buf[4096];
-    ERR_error_string_n(err, buf, sizeof(buf));
-    return buf;
+    static_assert(utils::configuration::DEFAULT_BUFFER_SIZE >= 1);
+    std::array<char, utils::configuration::DEFAULT_BUFFER_SIZE> buffer{};
+    ERR_error_string_n(err, buffer.data(), buffer.size() - 1);
+    return {buffer.data()};
   }
 
   static bool isFileTypeP12(const std::filesystem::path& filename) {
