@@ -28,7 +28,7 @@
 #include "core/logging/LoggerFactory.h"
 #include "core/PropertyDefinition.h"
 #include "core/PropertyDefinitionBuilder.h"
-#include "core/PropertyType.h"
+#include "minifi-cpp/core/PropertyValidator.h"
 #include "core/state/UpdatePolicy.h"
 #include "utils/Export.h"
 
@@ -38,30 +38,30 @@ namespace org::apache::nifi::minifi::controllers {
  * Purpose: UpdatePolicyControllerService allows a flow specific policy on allowing or disallowing updates.
  * Since the flow dictates the purpose of a device it will also be used to dictate updates to specific components.
  */
-class UpdatePolicyControllerService : public core::controller::ControllerService, public std::enable_shared_from_this<UpdatePolicyControllerService> {
+class UpdatePolicyControllerService : public core::controller::ControllerServiceImpl {
  public:
   explicit UpdatePolicyControllerService(std::string_view name, const utils::Identifier &uuid = {})
-      : ControllerService(name, uuid) {
+      : ControllerServiceImpl(name, uuid) {
   }
 
   explicit UpdatePolicyControllerService(std::string_view name, const std::shared_ptr<Configure> &configuration)
       : UpdatePolicyControllerService(name) {
-    setConfiguration(configuration);
-    initialize();
+    ControllerServiceImpl::setConfiguration(configuration);
+    UpdatePolicyControllerService::initialize();
   }
 
   MINIFIAPI static constexpr const char* Description = "UpdatePolicyControllerService allows a flow specific policy on allowing or disallowing updates. "
-      "Since the flow dictates the purpose of a device it will also be used to dictate updates to specific components.";
+                                                       "Since the flow dictates the purpose of a device it will also be used to dictate updates to specific components.";
 
   MINIFIAPI static constexpr auto AllowAllProperties = core::PropertyDefinitionBuilder<>::createProperty("Allow All Properties")
       .withDescription("Allows all properties, which are also not disallowed, to be updated")
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   MINIFIAPI static constexpr auto PersistUpdates = core::PropertyDefinitionBuilder<>::createProperty("Persist Updates")
       .withDescription("Property that dictates whether updates should persist after a restart")
       .isRequired(false)
-      .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
+      .withValidator(core::StandardPropertyValidators::BOOLEAN_VALIDATOR)
       .withDefaultValue("false")
       .build();
   MINIFIAPI static constexpr auto AllowedProperties = core::PropertyDefinitionBuilder<>::createProperty("Allowed Properties")
@@ -73,11 +73,11 @@ class UpdatePolicyControllerService : public core::controller::ControllerService
       .isRequired(false)
       .build();
   MINIFIAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
-      AllowAllProperties,
-      PersistUpdates,
-      AllowedProperties,
-      DisallowedProperties
-  });
+                                                                                          AllowAllProperties,
+                                                                                          PersistUpdates,
+                                                                                          AllowedProperties,
+                                                                                          DisallowedProperties
+                                                                                      });
 
   MINIFIAPI static constexpr bool SupportsDynamicProperties = false;
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
