@@ -25,7 +25,7 @@
 
 #include "core/FlowConfiguration.h"
 #include "core/logging/LoggerConfiguration.h"
-#include "core/ProcessorConfig.h"
+#include "minifi-cpp/core/ProcessorConfig.h"
 #include "Exception.h"
 #include "io/validation.h"
 #include "sitetosite/SiteToSite.h"
@@ -108,7 +108,7 @@ class StructuredConfiguration : public FlowConfiguration {
    */
   std::unique_ptr<core::ProcessGroup> parseRootProcessGroup(const Node& root_flow_node);
 
-  void parseParameterContexts(const Node& parameter_contexts_node);
+  void parseParameterContexts(const Node& parameter_contexts_node, const Node& parameter_providers_node);
   void parseControllerServices(const Node& controller_services_node, core::ProcessGroup* parent_group);
 
   /**
@@ -220,10 +220,14 @@ class StructuredConfiguration : public FlowConfiguration {
   std::shared_ptr<logging::Logger> logger_;
 
  private:
-  PropertyValue getValidatedProcessorPropertyForDefaultTypeInfo(const core::Property& property_from_processor, const Node& property_value_node, ParameterContext* parameter_context);
+  std::optional<std::string> getReplacedParametersValueOrDefault(std::string_view property_name,
+    bool is_sensitive,
+    std::optional<std::string_view> default_value,
+    const Node& property_value_node,
+    ParameterContext* parameter_context);
   void parsePropertyValueSequence(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& component, ParameterContext* parameter_context);
-  void parseSingleProperty(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& processor, ParameterContext* parameter_context);
-  void parsePropertyNodeElement(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& processor, ParameterContext* parameter_context);
+  void parseSingleProperty(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& component, ParameterContext* parameter_context);
+  void parsePropertyNodeElement(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& component, ParameterContext* parameter_context);
   void addNewId(const std::string& uuid);
 
   /**
@@ -234,6 +238,10 @@ class StructuredConfiguration : public FlowConfiguration {
    * @param reason
    */
   void raiseComponentError(const std::string &component_name, const std::string &section, const std::string &reason) const;
+  void parseParameterProvidersNode(const Node& parameter_providers_node);
+  void parseParameterContextsNode(const Node& parameter_contexts_node);
+  void parseParameterContextInheritance(const Node& parameter_contexts_node);
+  void verifyNoInheritanceCycles() const;
 };
 
 }  // namespace org::apache::nifi::minifi::core::flow
