@@ -48,8 +48,6 @@
 
 #include "core/state/nodes/MetricsBase.h"
 #include "Connection.h"
-#include "utils/OsUtils.h"
-#include "utils/NetworkInterfaceInfo.h"
 #include "utils/SystemCpuUsageTracker.h"
 #include "utils/Export.h"
 
