@@ -27,6 +27,7 @@
 #include "Connection.h"
 #include "core/state/ConnectionStore.h"
 #include "core/Processor.h"
+#include "core/BulletinStore.h"
 
 namespace org::apache::nifi::minifi::state::response {
 
@@ -51,7 +52,7 @@ class FlowVersion : public DeviceInformation {
     return "FlowVersion";
   }
 
-  std::shared_ptr<state::FlowIdentifier> getFlowIdentifier() const override {
+  std::shared_ptr<state::FlowIdentifier> getFlowIdentifier() const {
     std::lock_guard<std::mutex> lock(guard);
     return identifier;
   }
@@ -77,7 +78,7 @@ class FlowVersion : public DeviceInformation {
 
   void setFlowVersion(const std::string &url, const std::string &bucket_id, const std::string &flow_id) {
     std::lock_guard<std::mutex> lock(guard);
-    identifier = std::make_shared<FlowIdentifier>(url, bucket_id, flow_id.empty() ? utils::IdGenerator::getIdGenerator()->generate().to_string() : flow_id);
+    identifier = std::make_shared<FlowIdentifierImpl>(url, bucket_id, flow_id.empty() ? utils::IdGenerator::getIdGenerator()->generate().to_string() : flow_id);
   }
 
   std::vector<SerializedResponseNode> serialize() override;
@@ -121,6 +122,10 @@ class FlowInformation : public StateMonitorNode {
     processors_ = std::move(processors);
   }
 
+  void setBulletinStore(core::BulletinStore* bulletin_store) {
+    bulletin_store_ = bulletin_store;
+  }
+
   std::vector<SerializedResponseNode> serialize() override;
   std::vector<PublishedMetric> calculateMetrics() override;
 
@@ -128,6 +133,7 @@ class FlowInformation : public StateMonitorNode {
   std::shared_ptr<state::response::FlowVersion> flow_version_;
   ConnectionStore connection_store_;
   std::vector<core::Processor*> processors_;
+  core::BulletinStore* bulletin_store_ = nullptr;
 };
 
 }  // namespace org::apache::nifi::minifi::state::response
