@@ -29,15 +29,11 @@
 #include "core/logging/Logger.h"
 #include "utils/ChecksumCalculator.h"
 #include "utils/StringUtils.h"
+#include "minifi-cpp/properties/Properties.h"
 
 namespace org::apache::nifi::minifi {
 
-enum class PropertyChangeLifetime {
-  TRANSIENT,  // the changed value will not be committed to disk
-  PERSISTENT  // the changed value will be written to the source file
-};
-
-class Properties {
+class PropertiesImpl : public virtual Properties {
   struct PropertyValue {
     std::string persisted_value;
     std::string active_value;
@@ -45,24 +41,22 @@ class Properties {
   };
 
  public:
-  explicit Properties(std::string name = "");
+  explicit PropertiesImpl(std::string name = "");
 
-  virtual ~Properties() = default;
+  ~PropertiesImpl() override = default;
 
-  virtual const std::string& getName() const {
+  const std::string& getName() const override {
     return name_;
   }
 
-  // Clear the load config
-  void clear() {
+  void clear() override {
     std::lock_guard<std::mutex> lock(mutex_);
     properties_.clear();
   }
-  void set(const std::string& key, const std::string& value) {
+  void set(const std::string& key, const std::string& value) override {
     set(key, value, PropertyChangeLifetime::PERSISTENT);
   }
-  // Set the config value
-  virtual void set(const std::string &key, const std::string &value, PropertyChangeLifetime lifetime) {
+  void set(const std::string &key, const std::string &value, PropertyChangeLifetime lifetime) override {
     auto active_value = utils::string::replaceEnvironmentVariables(value);
     std::lock_guard<std::mutex> lock(mutex_);
     bool should_persist = lifetime == PropertyChangeLifetime::PERSISTENT;
@@ -82,8 +76,7 @@ class Properties {
       dirty_ = true;
     }
   }
-  // Check whether the config value existed
-  bool has(const std::string& key) const {
+  bool has(const std::string& key) const override {
     std::lock_guard<std::mutex> lock(mutex_);
     return properties_.count(key) > 0;
   }
@@ -93,13 +86,13 @@ class Properties {
    * @param value value in which to place the map's stored property value
    * @returns true if found, false otherwise.
    */
-  bool getString(const std::string &key, std::string &value) const;
+  bool getString(const std::string &key, std::string &value) const override;
 
   /**
    * Returns the configuration value or an empty string.
    * @return value corresponding to key or empty value.
    */
-  int getInt(const std::string &key, int default_value) const;
+  int getInt(const std::string &key, int default_value) const override;
 
   /**
    * Returns the config value.
@@ -107,20 +100,12 @@ class Properties {
    * @param key key to look up
    * @returns the value if found, nullopt otherwise.
    */
-  std::optional<std::string> getString(const std::string& key) const;
+  std::optional<std::string> getString(const std::string& key) const override;
 
-  /**
-   * Load configure file
-   * @param fileName path of the configuration file RELATIVE to MINIFI_HOME set by setHome()
-   */
-  void loadConfigureFile(const std::filesystem::path& configuration_file, std::string_view prefix = "");
+  void loadConfigureFile(const std::filesystem::path& configuration_file, std::string_view prefix = "") override;
 
-  // Set the determined MINIFI_HOME
-  void setHome(std::filesystem::path minifiHome) {
-    minifi_home_ = std::move(minifiHome);
-  }
 
-  std::vector<std::string> getConfiguredKeys() const {
+  std::vector<std::string> getConfiguredKeys() const override {
     std::vector<std::string> keys;
     for (auto &property : properties_) {
       keys.push_back(property.first);
@@ -128,18 +113,13 @@ class Properties {
     return keys;
   }
 
-  // Get the determined MINIFI_HOME
-  std::filesystem::path getHome() const {
-    return minifi_home_;
-  }
+  bool commitChanges() override;
 
-  virtual bool commitChanges();
+  utils::ChecksumCalculator& getChecksumCalculator() override { return checksum_calculator_; }
 
-  utils::ChecksumCalculator& getChecksumCalculator() { return checksum_calculator_; }
+  std::filesystem::path getFilePath() const override;
 
-  std::filesystem::path getFilePath() const;
-
-  std::map<std::string, std::string> getProperties() const;
+  std::map<std::string, std::string> getProperties() const override;
 
  private:
   std::map<std::string, PropertyValue> properties_;
@@ -152,10 +132,7 @@ class Properties {
 
   // Mutex for protection
   mutable std::mutex mutex_;
-  // Logger
   std::shared_ptr<core::logging::Logger> logger_;
-  // Home location for this executable
-  std::filesystem::path minifi_home_;
 
   std::string name_;
 };
