@@ -70,7 +70,7 @@ static std::unique_ptr<SiteToSiteClient> createClient(const SiteToSiteClientConf
     case HTTP:
       auto http_protocol = core::ClassLoader::getDefaultClassLoader().instantiateRaw("HttpProtocol", "HttpProtocol");
       if (nullptr != http_protocol) {
-        auto ptr = std::unique_ptr<SiteToSiteClient>(static_cast<SiteToSiteClient*>(http_protocol));
+        auto ptr = std::unique_ptr<SiteToSiteClient>(dynamic_cast<SiteToSiteClient*>(http_protocol));
         ptr->setSSLContextService(client_configuration.getSecurityContext());
         auto peer = std::unique_ptr<SiteToSitePeer>(new SiteToSitePeer(client_configuration.getPeer()->getHost(), client_configuration.getPeer()->getPort(),
             client_configuration.getInterface()));
