@@ -52,10 +52,16 @@ void RootProcessGroupWrapper::setNewRoot(std::unique_ptr<core::ProcessGroup> new
   }
 
   if (metrics_publisher_store_) { metrics_publisher_store_->clearMetricNodes(); }
+  if (controller_socket_protocol_) {
+    controller_socket_protocol_->setRoot(nullptr);
+  }
   backup_root_ = std::move(root_);
   root_ = std::move(new_root);
   processor_to_controller_.clear();
   if (metrics_publisher_store_) { metrics_publisher_store_->loadMetricNodes(root_.get()); }
+  if (controller_socket_protocol_) {
+    controller_socket_protocol_->setRoot(root_.get());
+  }
 }
 
 void RootProcessGroupWrapper::restoreBackup() {
@@ -177,14 +183,7 @@ state::StateController* RootProcessGroupWrapper::getProcessorController(const st
 }
 
 std::optional<std::chrono::milliseconds> RootProcessGroupWrapper::loadShutdownTimeoutFromConfiguration() {
-  std::string shutdown_timeout_str;
-  if (configuration_->get(minifi::Configure::nifi_flowcontroller_drain_timeout, shutdown_timeout_str)) {
-    const auto time_from_config = core::TimePeriodValue::fromString(shutdown_timeout_str);
-    if (time_from_config) {
-      return { std::chrono::milliseconds{ time_from_config.value().getMilliseconds() }};
-    }
-  }
-  return std::nullopt;
+  return configuration_->get(Configure::nifi_flowcontroller_drain_timeout) | utils::andThen([] (const auto& s) { return parsing::parseDuration(s) | utils::toOptional(); });
 }
 
 }  // namespace org::apache::nifi::minifi
