@@ -31,7 +31,7 @@
 
 #include "core/ClassLoader.h"
 #include "core/Connectable.h"
-#include "core/ProcessorNode.h"
+#include "core/Processor.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessContextBuilder.h"
 #include "core/ProcessSessionFactory.h"
@@ -46,21 +46,19 @@ void ThreadedSchedulingAgent::schedule(core::Processor* processor) {
   std::lock_guard<std::mutex> lock(mutex_);
 
   admin_yield_duration_ = 100ms;  // We should prevent burning CPU in case of rollbacks
-  std::string yieldValue;
+  std::string yield_value_str;
 
-  if (configure_->get(Configure::nifi_administrative_yield_duration, yieldValue)) {
-    std::optional<core::TimePeriodValue> value = core::TimePeriodValue::fromString(yieldValue);
-    if (value) {
-      admin_yield_duration_ = value->getMilliseconds();
+  if (configure_->get(Configure::nifi_administrative_yield_duration, yield_value_str)) {
+    if (const auto yield_value = parsing::parseDuration(yield_value_str)) {
+      admin_yield_duration_ = *yield_value;
       logger_->log_debug("nifi_administrative_yield_duration: [{}]", admin_yield_duration_);
     }
   }
 
   bored_yield_duration_ = 0ms;
-  if (configure_->get(Configure::nifi_bored_yield_duration, yieldValue)) {
-    std::optional<core::TimePeriodValue> value = core::TimePeriodValue::fromString(yieldValue);
-    if (value) {
-      bored_yield_duration_ = value->getMilliseconds();
+  if (configure_->get(Configure::nifi_bored_yield_duration, yield_value_str)) {
+    if (const auto yield_value = parsing::parseDuration(yield_value_str)) {
+      bored_yield_duration_ = *yield_value;
       logger_->log_debug("nifi_bored_yield_duration: [{}]", bored_yield_duration_);
     }
   }
@@ -75,16 +73,14 @@ void ThreadedSchedulingAgent::schedule(core::Processor* processor) {
     return;
   }
 
-  std::shared_ptr<core::ProcessorNode> processor_node = std::make_shared<core::ProcessorNode>(processor);
-
   std::shared_ptr<core::ProcessContextBuilder> contextBuilder = core::ClassLoader::getDefaultClassLoader().instantiate<core::ProcessContextBuilder>("ProcessContextBuilder", "ProcessContextBuilder");
 
   contextBuilder = contextBuilder->withContentRepository(content_repo_)->withFlowFileRepository(flow_repo_)->withProvider(controller_service_provider_)->withProvenanceRepository(repo_)
       ->withConfiguration(configure_);
 
-  auto process_context = contextBuilder->build(processor_node);
+  auto process_context = contextBuilder->build(*processor);
 
-  auto session_factory = std::make_shared<core::ProcessSessionFactory>(process_context);
+  auto session_factory = std::make_shared<core::ProcessSessionFactoryImpl>(process_context);
 
   processor->onSchedule(*process_context, *session_factory);
 
