@@ -19,6 +19,20 @@
 
 namespace org::apache::nifi::minifi {
 
-std::map<std::string, Components> AgentDocs::class_mappings_;
+namespace {
+std::map<std::string, Components>& getAgentDocsClassMappings() {
+  static std::map<std::string, Components> mappings;
+  return mappings;
+}
+}  // namespace
+
+const std::map<std::string, Components>& AgentDocs::getClassDescriptions() {
+  return getAgentDocsClassMappings();
+}
+
+std::map<std::string, Components>& AgentDocs::getMutableClassDescriptions() {
+  return getAgentDocsClassMappings();
+}
+
 
 }  // namespace org::apache::nifi::minifi
