@@ -30,12 +30,10 @@
 #include <vector>
 
 #include "core/ProcessContext.h"
-#include "core/StateManager.h"
 #include "core/state/UpdateController.h"
 #include "core/logging/Logger.h"
 #include "core/logging/LoggerConfiguration.h"
 #include "utils/file/FileUtils.h"
-#include "utils/file/FileManager.h"
 #include "utils/file/FileSystem.h"
 #include "http/BaseHTTPClient.h"
 #include "utils/file/PathUtils.h"
@@ -445,7 +443,7 @@ void C2Agent::handle_clear(const C2ContentResponse &resp) {
     }
     case ClearOperand::corecomponentstate: {
       for (const auto& corecomponent : resp.operation_arguments) {
-        auto state_storage = core::ProcessContext::getStateStorage(logger_, controller_, configuration_);
+        auto state_storage = core::ProcessContextImpl::getStateStorage(logger_, controller_, configuration_);
         if (state_storage != nullptr) {
           update_sink_->executeOnComponent(corecomponent.second.to_string(), [this, &state_storage] (state::StateController& component) {
             logger_->log_debug("Clearing state for component {}", component.getComponentName());
@@ -557,7 +555,7 @@ void C2Agent::handle_describe(const C2ContentResponse &resp) {
       response.setLabel("corecomponentstate");
       C2Payload states(Operation::acknowledge, resp.ident, true);
       states.setLabel("corecomponentstate");
-      auto state_storage = core::ProcessContext::getStateStorage(logger_, controller_, configuration_);
+      auto state_storage = core::ProcessContextImpl::getStateStorage(logger_, controller_, configuration_);
       if (state_storage != nullptr) {
         auto core_component_states = state_storage->getAllStates();
         for (const auto& core_component_state : core_component_states) {
