@@ -18,32 +18,38 @@
 #include "c2/ControllerSocketProtocol.h"
 
 #include <fstream>
+#include <sstream>
+#include <string>
 #include <utility>
 #include <vector>
-#include <string>
-#include <sstream>
 
-#include "utils/gsl.h"
-#include "utils/StringUtils.h"
-#include "c2/C2Payload.h"
-#include "properties/Configuration.h"
-#include "io/AsioStream.h"
-#include "asio/ssl/stream.hpp"
 #include "asio/detached.hpp"
-#include "utils/net/AsioSocketUtils.h"
+#include "asio/ssl/stream.hpp"
+#include "c2/C2Payload.h"
 #include "c2/C2Utils.h"
+#include "controllers/SSLContextService.h"
+#include "io/AsioStream.h"
+#include "properties/Configuration.h"
+#include "utils/ConfigurationUtils.h"
+#include "utils/StringUtils.h"
+#include "utils/gsl.h"
+#include "utils/net/AsioSocketUtils.h"
 
 namespace org::apache::nifi::minifi::c2 {
 
-ControllerSocketProtocol::SocketRestartCommandProcessor::SocketRestartCommandProcessor(state::StateMonitor& update_sink) :
-    update_sink_(update_sink) {
+ControllerSocketProtocol::SocketRestartCommandProcessor::SocketRestartCommandProcessor(state::StateMonitor& update_sink, const std::shared_ptr<core::logging::Logger>& logger) :
+    update_sink_(update_sink),
+    logger_(logger) {
   command_queue_.start();
   command_processor_thread_ = std::thread([this] {
     while (running_) {
       CommandData command_data;
       if (command_queue_.dequeueWait(command_data)) {
         if (command_data.command == Command::FLOW_UPDATE) {
-          update_sink_.applyUpdate("ControllerSocketProtocol", command_data.data, true);
+          auto result = update_sink_.applyUpdate("ControllerSocketProtocol", command_data.data, true);
+          if (!result) {
+            logger_->log_error("Failed to apply flow update: {}", result.error());
+          }
         } else if (command_data.command == Command::START) {
           update_sink_.executeOnComponent(command_data.data, [](state::StateController& component) {
             component.start();
@@ -69,7 +75,7 @@ ControllerSocketProtocol::ControllerSocketProtocol(core::controller::ControllerS
         update_sink_(update_sink),
         controller_socket_reporter_(controller_socket_reporter),
         configuration_(std::move(configuration)),
-        socket_restart_processor_(update_sink_) {
+        socket_restart_processor_(update_sink_, logger_) {
   gsl_Expects(configuration_);
 }
 
@@ -105,7 +111,7 @@ asio::awaitable<void> ControllerSocketProtocol::startAccept() {
   }
 }
 
-asio::awaitable<void> ControllerSocketProtocol::handshakeAndHandleCommand(asio::ip::tcp::socket&& socket, std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service) {
+asio::awaitable<void> ControllerSocketProtocol::handshakeAndHandleCommand(asio::ip::tcp::socket&& socket, std::shared_ptr<minifi::controllers::SSLContextServiceInterface> ssl_context_service) {
   asio::ssl::context ssl_context = utils::net::getSslContext(*ssl_context_service, asio::ssl::context::tls_server);
   ssl_context.set_options(utils::net::MINIFI_SSL_OPTIONS);
   asio::ssl::stream<asio::ip::tcp::socket> ssl_socket(std::move(socket), ssl_context);
@@ -120,7 +126,7 @@ asio::awaitable<void> ControllerSocketProtocol::handshakeAndHandleCommand(asio::
   co_return co_await handleCommand(std::move(stream));
 }
 
-asio::awaitable<void> ControllerSocketProtocol::startAcceptSsl(std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service) {
+asio::awaitable<void> ControllerSocketProtocol::startAcceptSsl(std::shared_ptr<minifi::controllers::SSLContextServiceInterface> ssl_context_service) {
   while (true) {  // NOLINT(clang-analyzer-core.NullDereference) suppressing asio library linter warning
     auto [accept_error, socket] = co_await acceptor_->async_accept(utils::net::use_nothrow_awaitable);
     if (accept_error) {
@@ -138,12 +144,12 @@ asio::awaitable<void> ControllerSocketProtocol::startAcceptSsl(std::shared_ptr<m
 
 void ControllerSocketProtocol::initialize() {
   std::unique_lock<std::mutex> lock(initialization_mutex_);
-  std::shared_ptr<minifi::controllers::SSLContextService> secure_context;
+  std::shared_ptr<minifi::controllers::SSLContextServiceInterface> secure_context;
   std::string context_name;
   if (configuration_->get(Configure::controller_ssl_context_service, context_name)) {
     std::shared_ptr<core::controller::ControllerService> service = controller_.getControllerService(context_name);
     if (nullptr != service) {
-      secure_context = std::static_pointer_cast<minifi::controllers::SSLContextService>(service);
+      secure_context = std::dynamic_pointer_cast<minifi::controllers::SSLContextServiceInterface>(service);
     }
   }
   if (nullptr == secure_context) {
@@ -182,6 +188,12 @@ void ControllerSocketProtocol::initialize() {
   }
 }
 
+void ControllerSocketProtocol::setRoot(core::ProcessGroup* root) {
+  if (auto controller_socket_reporter = controller_socket_reporter_.lock()) {
+    controller_socket_reporter->setRoot(root);
+  }
+}
+
 void ControllerSocketProtocol::handleStart(io::BaseStream &stream) {
   std::string component_str;
   const auto size = stream.read(component_str);
@@ -357,6 +369,35 @@ void ControllerSocketProtocol::writeJstackResponse(io::BaseStream &stream) {
   stream.write(resp.getBuffer());
 }
 
+void ControllerSocketProtocol::writeFlowStatusResponse(io::BaseStream &stream) {
+  std::string query;
+  {
+    const auto size = stream.read(query);
+    if (io::isError(size)) {
+      logger_->log_error("Connection broke");
+      return;
+    }
+  }
+  auto request_strings = utils::string::splitAndTrimRemovingEmpty(query, ";");
+  std::vector<FlowStatusRequest> requests;
+  for (const auto& request_string : request_strings) {
+    try {
+      requests.push_back(FlowStatusRequest(request_string));
+    } catch (const std::exception& e) {
+      logger_->log_error("Invalid flow status request: {}", e.what());
+    }
+  }
+  io::BufferStream resp;
+  auto op = static_cast<uint8_t>(Operation::describe);
+  resp.write(&op, 1);
+  std::string flowstatus_response;
+  if (auto controller_socket_reporter = controller_socket_reporter_.lock()) {
+    flowstatus_response = controller_socket_reporter->getFlowStatus(requests);
+  }
+  resp.write(flowstatus_response, true);
+  stream.write(resp.getBuffer());
+}
+
 void ControllerSocketProtocol::handleDescribe(io::BaseStream &stream) {
   std::string what;
   const auto size = stream.read(what);
@@ -376,6 +417,8 @@ void ControllerSocketProtocol::handleDescribe(io::BaseStream &stream) {
     writeManifestResponse(stream);
   } else if (what == "jstack") {
     writeJstackResponse(stream);
+  } else if (what == "flowstatus") {
+    writeFlowStatusResponse(stream);
   } else {
     logger_->log_error("Unknown C2 describe parameter: {}", what);
   }
@@ -396,7 +439,7 @@ void ControllerSocketProtocol::writeDebugBundleResponse(io::BaseStream &stream)
 
   size_t bundle_size = bundle.value()->size();
   resp.write(bundle_size);
-  const size_t BUFFER_SIZE = 4096;
+  static constexpr auto BUFFER_SIZE = utils::configuration::DEFAULT_BUFFER_SIZE;
   std::array<std::byte, BUFFER_SIZE> out_buffer{};
   while (bundle_size > 0) {
     const auto next_write_size = (std::min)(bundle_size, BUFFER_SIZE);
