@@ -78,14 +78,15 @@ void SSLContextService::initialize() {
     return;
   }
 
-  ControllerService::initialize();
+  ControllerServiceImpl::initialize();
 
   initializeProperties();
 
   initialized_ = true;
 }
 
-bool SSLContextService::configure_ssl_context(SSL_CTX *ctx) {
+bool SSLContextService::configure_ssl_context(void* raw_ctx) {
+  auto* const ctx = static_cast<SSL_CTX*>(raw_ctx);
   if (!certificate_.empty()) {
     if (isFileTypeP12(certificate_)) {
       if (!addP12CertificateToSSLContext(ctx)) {
@@ -142,25 +143,25 @@ bool SSLContextService::configure_ssl_context(SSL_CTX *ctx) {
 
 bool SSLContextService::addP12CertificateToSSLContext(SSL_CTX* ctx) const {
   auto error = utils::tls::processP12Certificate(certificate_, passphrase_, {
-    .cert_cb = [&] (auto cert) -> std::error_code {
-      if (SSL_CTX_use_certificate(ctx, cert.get()) != 1) {
-        return utils::tls::get_last_ssl_error_code();
+      .cert_cb = [&] (auto cert) -> std::error_code {
+        if (SSL_CTX_use_certificate(ctx, cert.get()) != 1) {
+          return utils::tls::get_last_ssl_error_code();
+        }
+        return {};
+      },
+      .chain_cert_cb = [&] (auto cacert) -> std::error_code {
+        if (SSL_CTX_add_extra_chain_cert(ctx, cacert.get()) != 1) {
+          return utils::tls::get_last_ssl_error_code();
+        }
+        static_cast<void>(cacert.release());  // a successful SSL_CTX_add_extra_chain_cert() takes ownership of cacert
+        return {};
+      },
+      .priv_key_cb = [&] (auto priv_key) -> std::error_code {
+        if (SSL_CTX_use_PrivateKey(ctx, priv_key.get()) != 1) {
+          return utils::tls::get_last_ssl_error_code();
+        }
+        return {};
       }
-      return {};
-    },
-    .chain_cert_cb = [&] (auto cacert) -> std::error_code {
-      if (SSL_CTX_add_extra_chain_cert(ctx, cacert.get()) != 1) {
-        return utils::tls::get_last_ssl_error_code();
-      }
-      static_cast<void>(cacert.release());  // a successful SSL_CTX_add_extra_chain_cert() takes ownership of cacert
-      return {};
-    },
-    .priv_key_cb = [&] (auto priv_key) -> std::error_code {
-      if (SSL_CTX_use_PrivateKey(ctx, priv_key.get()) != 1) {
-        return utils::tls::get_last_ssl_error_code();
-      }
-      return {};
-    }
   });
   if (error) {
     logger_->log_error("{}", error.message());
@@ -411,7 +412,7 @@ void SSLContextService::onEnable() {
   logger_->log_trace("onEnable()");
 
   certificate_.clear();
-  if (auto certificate = getProperty(ClientCertificate)) {
+  if (auto certificate = getProperty(ClientCertificate.name)) {
     if (is_valid_and_readable_path(*certificate)) {
       certificate_ = *certificate;
     } else {
@@ -428,7 +429,7 @@ void SSLContextService::onEnable() {
 
   private_key_.clear();
   if (!certificate_.empty() && !isFileTypeP12(certificate_)) {
-    if (auto private_key = getProperty(PrivateKey)) {
+    if (auto private_key = getProperty(PrivateKey.name)) {
       if (is_valid_and_readable_path(*private_key)) {
         private_key_ = *private_key;
       } else {
@@ -446,9 +447,8 @@ void SSLContextService::onEnable() {
   }
 
   passphrase_.clear();
-  if (!getProperty(Passphrase, passphrase_)) {
-    logger_->log_debug("No pass phrase for {}", certificate_);
-  } else {
+  if (auto passphrase = getProperty(Passphrase.name)) {
+    passphrase_ = *passphrase;
     std::ifstream passphrase_file(passphrase_);
     if (passphrase_file.good()) {
       // we should read it from the file
@@ -464,10 +464,12 @@ void SSLContextService::onEnable() {
       passphrase_file_test.close();
     }
     passphrase_file.close();
+  } else {
+    logger_->log_debug("No pass phrase for {}", certificate_);
   }
 
   ca_certificate_.clear();
-  if (auto ca_certificate = getProperty(CACertificate)) {
+  if (auto ca_certificate = getProperty(CACertificate.name)) {
     if (is_valid_and_readable_path(*ca_certificate)) {
       ca_certificate_ = *ca_certificate;
     } else {
@@ -483,16 +485,15 @@ void SSLContextService::onEnable() {
     logger_->log_debug("CA Certificate empty");
   }
 
-  getProperty(UseSystemCertStore, use_system_cert_store_);
+  use_system_cert_store_ = (getProperty(UseSystemCertStore.name) | utils::andThen(parsing::parseBool)).value_or(false);
 
 #ifdef WIN32
-  getProperty(CertStoreLocation, cert_store_location_);
-  getProperty(ServerCertStore, server_cert_store_);
-  getProperty(ClientCertStore, client_cert_store_);
-  getProperty(ClientCertCN, client_cert_cn_);
+  cert_store_location_ = getProperty(CertStoreLocation.name).value_or("");
+  server_cert_store_ = getProperty(ServerCertStore.name).value_or("");
+  client_cert_store_ = getProperty(ClientCertStore.name).value_or("");
+  client_cert_cn_ = getProperty(ClientCertCN.name).value_or("");
 
-  std::string client_cert_key_usage;
-  getProperty(ClientCertKeyUsage, client_cert_key_usage);
+  std::string client_cert_key_usage = getProperty(ClientCertKeyUsage.name).value_or("");
   client_cert_key_usage_ = utils::tls::ExtendedKeyUsage{client_cert_key_usage};
 #endif  // WIN32
 
@@ -593,6 +594,6 @@ void SSLContextService::verifyCertificateExpiration() {
 #endif
 }
 
-REGISTER_RESOURCE(SSLContextService, ControllerService);
+REGISTER_RESOURCE_IMPLEMENTATION(SSLContextService, "SSLContextService", ControllerService);
 
 }  // namespace org::apache::nifi::minifi::controllers
