@@ -25,17 +25,20 @@
 #include "core/ClassLoader.h"
 #include "processors/ProcessorUtils.h"
 #include "utils/StringUtils.h"
+#include "utils/file/FileUtils.h"
 
 namespace org::apache::nifi::minifi::core {
 
 FlowConfiguration::FlowConfiguration(ConfigurationContext ctx)
-    : CoreComponent(core::className<FlowConfiguration>()),
+    : CoreComponentImpl(core::className<FlowConfiguration>()),
       flow_file_repo_(std::move(ctx.flow_file_repo)),
       content_repo_(std::move(ctx.content_repo)),
       configuration_(std::move(ctx.configuration)),
       service_provider_(std::make_shared<core::controller::StandardControllerServiceProvider>(std::make_unique<core::controller::ControllerServiceNodeMap>(), configuration_)),
       filesystem_(std::move(ctx.filesystem)),
       sensitive_values_encryptor_(std::move(ctx.sensitive_values_encryptor.value())),
+      asset_manager_(ctx.asset_manager),
+      bulletin_store_(ctx.bulletin_store),
       logger_(logging::LoggerFactory<FlowConfiguration>::getLogger()) {
   std::string flowUrl;
   std::string bucket_id = "default";
@@ -68,26 +71,17 @@ FlowConfiguration::~FlowConfiguration() {
   }
 }
 
-std::unique_ptr<core::Processor> FlowConfiguration::createProcessor(const std::string &name, const utils::Identifier &uuid) {
-  auto processor = minifi::processors::ProcessorUtils::createProcessor(name, name, uuid);
+std::unique_ptr<core::Processor> FlowConfiguration::createProcessor(const std::string &class_short, const std::string &fullclass, const std::string &object_name, const utils::Identifier &uuid) {
+  auto processor = minifi::processors::ProcessorUtils::createProcessor(class_short, fullclass, object_name, uuid);
   if (nullptr == processor) {
-    logger_->log_error("No Processor defined for {}", name);
+    logger_->log_error("No Processor defined for {}", fullclass);
     return nullptr;
   }
   return processor;
 }
 
-std::unique_ptr<core::Processor> FlowConfiguration::createProcessor(const std::string &name, const std::string &fullname, const utils::Identifier &uuid) {
-  auto processor = minifi::processors::ProcessorUtils::createProcessor(name, fullname, uuid);
-  if (nullptr == processor) {
-    logger_->log_error("No Processor defined for {}", fullname);
-    return nullptr;
-  }
-  return processor;
-}
-
-std::unique_ptr<core::reporting::SiteToSiteProvenanceReportingTask> FlowConfiguration::createProvenanceReportTask() {
-  auto processor = std::make_unique<org::apache::nifi::minifi::core::reporting::SiteToSiteProvenanceReportingTask>(this->configuration_);
+std::unique_ptr<core::Processor> FlowConfiguration::createProvenanceReportTask() {
+  auto processor = std::make_unique<core::Processor>("", std::make_unique<core::reporting::SiteToSiteProvenanceReportingTask>(this->configuration_));
   processor->initialize();
   return processor;
 }
@@ -95,9 +89,17 @@ std::unique_ptr<core::reporting::SiteToSiteProvenanceReportingTask> FlowConfigur
 std::unique_ptr<core::ProcessGroup> FlowConfiguration::updateFromPayload(const std::string& url, const std::string& yamlConfigPayload, const std::optional<std::string>& flow_id) {
   auto old_provider = service_provider_;
   auto old_parameter_contexts = std::move(parameter_contexts_);
+  auto old_parameter_providers = std::move(parameter_providers_);
   service_provider_ = std::make_shared<core::controller::StandardControllerServiceProvider>(std::make_unique<core::controller::ControllerServiceNodeMap>(), configuration_);
   auto payload = getRootFromPayload(yamlConfigPayload);
-  if (!url.empty() && payload != nullptr) {
+  if (!payload) {
+    service_provider_ = old_provider;
+    parameter_contexts_ = std::move(old_parameter_contexts);
+    parameter_providers_ = std::move(old_parameter_providers);
+    return nullptr;
+  }
+
+  if (!url.empty()) {
     std::string payload_flow_id;
     std::string bucket_id;
     auto path_split = utils::string::split(url, "/");
@@ -109,10 +111,8 @@ std::unique_ptr<core::ProcessGroup> FlowConfiguration::updateFromPayload(const s
       }
     }
     flow_version_->setFlowVersion(url, bucket_id, flow_id ? *flow_id : payload_flow_id);
-  } else {
-    service_provider_ = old_provider;
-    parameter_contexts_ = std::move(old_parameter_contexts);
   }
+
   return payload;
 }
 
@@ -140,10 +140,14 @@ bool FlowConfiguration::persist(const std::string& serialized_flow) {
     logger_->log_debug("Copy {} to {}", *config_path_, config_file_backup);
   }
 
-  const bool status = filesystem_->write(*config_path_, serialized_flow);
-  logger_->log_info("Result of updating the config file {}: {}", *config_path_, status ? "success" : "failure");
+  const bool is_write_successful = filesystem_->write(*config_path_, serialized_flow);
+  if (is_write_successful) {
+    logger_->log_info("Successfully updated the flow configuration file {}", *config_path_);
+  } else {
+    logger_->log_error("Failed to update the flow configuration file {}", *config_path_);
+  }
   checksum_calculator_.invalidateChecksum();
-  return status;
+  return is_write_successful;
 }
 
 std::unique_ptr<core::ProcessGroup> FlowConfiguration::createRootProcessGroup(const std::string &name, const utils::Identifier &uuid, int version) {
@@ -165,18 +169,36 @@ std::unique_ptr<minifi::Connection> FlowConfiguration::createConnection(const st
   if (flow_file_repo_) {
     auto swap_manager = std::dynamic_pointer_cast<SwapManager>(flow_file_repo_);
     if (swap_manager) {
-      return std::make_unique<minifi::Connection>(flow_file_repo_, content_repo_, std::move(swap_manager), name, uuid);
+      return std::make_unique<minifi::ConnectionImpl>(flow_file_repo_, content_repo_, std::move(swap_manager), name, uuid);
     }
   }
-  return std::make_unique<minifi::Connection>(flow_file_repo_, content_repo_, name, uuid);
+  return std::make_unique<minifi::ConnectionImpl>(flow_file_repo_, content_repo_, name, uuid);
 }
 
-std::shared_ptr<core::controller::ControllerServiceNode> FlowConfiguration::createControllerService(const std::string &class_name, const std::string &full_class_name, const std::string &name,
+std::shared_ptr<core::controller::ControllerServiceNode> FlowConfiguration::createControllerService(const std::string &class_name, const std::string &name,
     const utils::Identifier& uuid) {
-  std::shared_ptr<core::controller::ControllerServiceNode> controllerServicesNode = service_provider_->createControllerService(class_name, full_class_name, name, true);
+  std::shared_ptr<core::controller::ControllerServiceNode> controllerServicesNode = service_provider_->createControllerService(class_name, name);
   if (nullptr != controllerServicesNode)
     controllerServicesNode->setUUID(uuid);
   return controllerServicesNode;
 }
 
+std::unique_ptr<core::ParameterProvider> FlowConfiguration::createParameterProvider(const std::string &class_name, const std::string &full_class_name, const utils::Identifier& uuid) {
+  auto ptr = core::ClassLoader::getDefaultClassLoader().instantiate(class_name, uuid);
+  if (ptr == nullptr) {
+    ptr = core::ClassLoader::getDefaultClassLoader().instantiate(full_class_name, uuid);
+  }
+  if (ptr == nullptr) {
+    return nullptr;
+  }
+
+  auto returnPtr = utils::dynamic_unique_cast<core::ParameterProvider>(std::move(ptr));
+  if (!returnPtr) {
+    throw std::runtime_error("Invalid parameter provider type: " + full_class_name + " is not a subclass of ParameterProvider");
+  }
+
+  returnPtr->initialize();
+  return returnPtr;
+}
+
 }  // namespace org::apache::nifi::minifi::core
