@@ -44,7 +44,7 @@ ProcessGroup::ProcessGroup(ProcessGroupType type, std::string_view name, const u
 }
 
 ProcessGroup::ProcessGroup(ProcessGroupType type, std::string_view name, const utils::Identifier& uuid, int version, ProcessGroup* parent)
-    : CoreComponent(name, uuid, id_generator_),
+    : CoreComponentImpl(name, uuid, id_generator_),
       config_version_(version),
       type_(type),
       parent_process_group_(parent),
@@ -56,7 +56,7 @@ ProcessGroup::ProcessGroup(ProcessGroupType type, std::string_view name, const u
 }
 
 ProcessGroup::ProcessGroup(ProcessGroupType type, std::string_view name)
-    : CoreComponent(name, {}, id_generator_),
+    : CoreComponentImpl(name, {}, id_generator_),
       config_version_(0),
       type_(type),
       parent_process_group_(nullptr),
@@ -87,6 +87,8 @@ std::tuple<Processor*, bool> ProcessGroup::addProcessor(std::unique_ptr<Processo
   const auto name = processor->getName();
   std::lock_guard<std::recursive_mutex> lock(mutex_);
   processor->setProcessGroupUUIDStr(getUUIDStr());
+  processor->setProcessGroupName(getName());
+  processor->setProcessGroupPath(buildGroupPath());
   const auto [iter, inserted] = processors_.insert(std::move(processor));
   if (inserted) {
     logger_->log_debug("Add processor {} into process group {}", name, name_);
@@ -100,7 +102,7 @@ void ProcessGroup::addPort(std::unique_ptr<Port> port) {
   auto [processor, inserted] = addProcessor(std::move(port));
   if (inserted) {
     std::lock_guard<std::recursive_mutex> lock(mutex_);
-    ports_.insert(static_cast<Port*>(processor));
+    ports_.insert(dynamic_cast<Port*>(processor));
   }
 }
 
@@ -318,7 +320,10 @@ void ProcessGroup::updatePropertyValue(const std::string& processorName, const s
   std::lock_guard<std::recursive_mutex> lock(mutex_);
   for (auto& processor : processors_) {
     if (processor->getName() == processorName) {
-      processor->setProperty(propertyName, propertyValue);
+      auto result = processor->setProperty(propertyName, propertyValue);
+      if (!result) {
+        logger_->log_error("Failed to update property '{}' for processor '{}': {}", propertyName, processorName, result.error().message());
+      }
     }
   }
   for (auto& processGroup : child_process_groups_) {
@@ -401,13 +406,13 @@ void ProcessGroup::addConnection(std::unique_ptr<Connection> connection) {
   // only allow connections between processors of the same process group or in/output ports of child process groups
   // check input and output ports connection restrictions inside and outside a process group
   Processor* source = findPortById(insertedConnection->getSourceUUID());
-  if (source && static_cast<Port*>(source)->getPortType() == PortType::OUTPUT) {
+  if (source && dynamic_cast<Port*>(source)->getPortType() == PortType::OUTPUT) {
     logger_->log_error("Output port [id = '{}'] cannot be a source inside the process group in the connection [name = '{}', id = '{}']",
                        insertedConnection->getSourceUUID().to_string(), insertedConnection->getName(), insertedConnection->getUUIDStr());
     source = nullptr;
   } else if (!source) {
     source = findChildPortById(insertedConnection->getSourceUUID());
-    if (source && static_cast<Port*>(source)->getPortType() == PortType::INPUT) {
+    if (source && dynamic_cast<Port*>(source)->getPortType() == PortType::INPUT) {
       logger_->log_error("Input port [id = '{}'] cannot be a source outside the process group in the connection [name = '{}', id = '{}']",
                           insertedConnection->getSourceUUID().to_string(), insertedConnection->getName(), insertedConnection->getUUIDStr());
       source = nullptr;
@@ -425,13 +430,13 @@ void ProcessGroup::addConnection(std::unique_ptr<Connection> connection) {
   }
 
   Processor* destination = findPortById(insertedConnection->getDestinationUUID());
-  if (destination && static_cast<Port*>(destination)->getPortType() == PortType::INPUT) {
+  if (destination && dynamic_cast<Port*>(destination)->getPortType() == PortType::INPUT) {
     logger_->log_error("Input port [id = '{}'] cannot be a destination inside the process group in the connection [name = '{}', id = '{}']",
                        insertedConnection->getDestinationUUID().to_string(), insertedConnection->getName(), insertedConnection->getUUIDStr());
     destination = nullptr;
   } else if (!destination) {
     destination = findChildPortById(insertedConnection->getDestinationUUID());
-    if (destination && static_cast<Port*>(destination)->getPortType() == PortType::OUTPUT) {
+    if (destination && dynamic_cast<Port*>(destination)->getPortType() == PortType::OUTPUT) {
       logger_->log_error("Output port [id = '{}'] cannot be a destination outside the process group in the connection [name = '{}', id = '{}']",
                           insertedConnection->getDestinationUUID().to_string(), insertedConnection->getName(), insertedConnection->getUUIDStr());
       destination = nullptr;
@@ -485,4 +490,15 @@ ParameterContext* ProcessGroup::getParameterContext() const {
   return parameter_context_;
 }
 
+std::string ProcessGroup::buildGroupPath() const {
+  std::lock_guard<std::recursive_mutex> lock(mutex_);
+  std::string path = name_;
+  auto parent = parent_process_group_;
+  while (parent != nullptr) {
+    path.insert(0, parent->getName() + " / ");
+    parent = parent->getParent();
+  }
+  return path;
+}
+
 }  // namespace org::apache::nifi::minifi::core
