@@ -34,6 +34,7 @@
 #include "io/StreamSlice.h"
 #include "io/StreamPipe.h"
 #include "utils/gsl.h"
+#include "core/Processor.h"
 
 /* This implementation is only for native Windows systems.  */
 #if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
@@ -53,23 +54,21 @@ int getpagesize(void) {
   // GetSystemInfo(&system_info);
   // return system_info.dwPageSize;
 }
+#else
+#include <unistd.h>
 #endif
 
 namespace org::apache::nifi::minifi::core {
 
-std::string detail::to_string(const detail::ReadBufferResult& read_buffer_result) {
-  return {reinterpret_cast<const char*>(read_buffer_result.buffer.data()), read_buffer_result.buffer.size()};
-}
+std::shared_ptr<utils::IdGenerator> ProcessSessionImpl::id_generator_ = utils::IdGenerator::getIdGenerator();
 
-std::shared_ptr<utils::IdGenerator> ProcessSession::id_generator_ = utils::IdGenerator::getIdGenerator();
-
-ProcessSession::ProcessSession(std::shared_ptr<ProcessContext> processContext)
+ProcessSessionImpl::ProcessSessionImpl(std::shared_ptr<ProcessContext> processContext)
         : process_context_(std::move(processContext)),
           logger_(logging::LoggerFactory<ProcessSession>::getLogger()),
           stateManager_(process_context_->hasStateManager() ? process_context_->getStateManager() : nullptr) {
-  logger_->log_trace("ProcessSession created for {}", process_context_->getProcessorNode()->getName());
+  logger_->log_trace("ProcessSession created for {}", process_context_->getProcessor().getName());
   auto repo = process_context_->getProvenanceRepository();
-  provenance_report_ = std::make_shared<provenance::ProvenanceReporter>(repo, process_context_->getProcessorNode()->getName(), process_context_->getProcessorNode()->getName());
+  provenance_report_ = std::make_shared<provenance::ProvenanceReporterImpl>(repo, process_context_->getProcessor().getName(), process_context_->getProcessor().getName());
   content_session_ = process_context_->getContentRepository()->createSession();
 
   if (stateManager_ && !stateManager_->beginTransaction()) {
@@ -77,7 +76,7 @@ ProcessSession::ProcessSession(std::shared_ptr<ProcessContext> processContext)
   }
 }
 
-ProcessSession::~ProcessSession() {
+ProcessSessionImpl::~ProcessSessionImpl() {
   if (stateManager_ && stateManager_->isTransactionInProgress()) {
     logger_->log_critical("Session has ended without decision on state (commit or rollback).");
     std::terminate();
@@ -85,7 +84,7 @@ ProcessSession::~ProcessSession() {
   removeReferences();
 }
 
-void ProcessSession::add(const std::shared_ptr<core::FlowFile> &record) {
+void ProcessSessionImpl::add(const std::shared_ptr<core::FlowFile> &record) {
   utils::Identifier uuid = record->getUUID();
   if (updated_flowfiles_.find(uuid) != updated_flowfiles_.end()) {
     throw Exception(ExceptionType::PROCESSOR_EXCEPTION, "Mustn't add file that was provided by this session");
@@ -94,9 +93,9 @@ void ProcessSession::add(const std::shared_ptr<core::FlowFile> &record) {
   record->setDeleted(false);
 }
 
-std::shared_ptr<core::FlowFile> ProcessSession::create(const core::FlowFile* const parent) {
-  auto record = std::make_shared<FlowFileRecord>();
-  auto flow_version = process_context_->getProcessorNode()->getFlowIdentifier();
+std::shared_ptr<core::FlowFile> ProcessSessionImpl::create(const core::FlowFile* const parent) {
+  auto record = std::make_shared<FlowFileRecordImpl>();
+  auto flow_version = process_context_->getProcessor().getFlowIdentifier();
   if (flow_version != nullptr) {
     record->setAttribute(SpecialFlowAttribute::FLOW_ID, flow_version->getFlowId());
   }
@@ -118,13 +117,13 @@ std::shared_ptr<core::FlowFile> ProcessSession::create(const core::FlowFile* con
   added_flowfiles_[uuid].flow_file = record;
   logger_->log_debug("Create FlowFile with UUID {}", record->getUUIDStr());
   std::stringstream details;
-  details << process_context_->getProcessorNode()->getName() << " creates flow record " << record->getUUIDStr();
+  details << process_context_->getProcessor().getName() << " creates flow record " << record->getUUIDStr();
   provenance_report_->create(*record, details.str());
 
   return record;
 }
 
-std::shared_ptr<core::FlowFile> ProcessSession::clone(const core::FlowFile& parent) {
+std::shared_ptr<core::FlowFile> ProcessSessionImpl::clone(const core::FlowFile& parent) {
   std::shared_ptr<core::FlowFile> record = this->create(&parent);
   if (record) {
     logger_->log_debug("Cloned parent flow files {} to {}", parent.getUUIDStr(), record->getUUIDStr());
@@ -140,10 +139,10 @@ std::shared_ptr<core::FlowFile> ProcessSession::clone(const core::FlowFile& pare
   return record;
 }
 
-std::shared_ptr<core::FlowFile> ProcessSession::cloneDuringTransfer(const core::FlowFile& parent) {
-  auto record = std::make_shared<FlowFileRecord>();
+std::shared_ptr<core::FlowFile> ProcessSessionImpl::cloneDuringTransfer(const core::FlowFile& parent) {
+  auto record = std::make_shared<FlowFileRecordImpl>();
 
-  auto flow_version = process_context_->getProcessorNode()->getFlowIdentifier();
+  auto flow_version = process_context_->getProcessor().getFlowIdentifier();
   if (flow_version != nullptr) {
     record->setAttribute(SpecialFlowAttribute::FLOW_ID, flow_version->getFlowId());
   }
@@ -175,7 +174,7 @@ std::shared_ptr<core::FlowFile> ProcessSession::cloneDuringTransfer(const core::
   return record;
 }
 
-std::shared_ptr<core::FlowFile> ProcessSession::clone(const FlowFile& parent, int64_t offset, int64_t size) {
+std::shared_ptr<core::FlowFile> ProcessSessionImpl::clone(const FlowFile& parent, int64_t offset, int64_t size) {
   if (gsl::narrow<uint64_t>(offset + size) > parent.getSize()) {
     // Set offset and size
     logger_->log_error("clone offset {} and size {} exceed parent size {}", offset, size, parent.getSize());
@@ -197,34 +196,34 @@ std::shared_ptr<core::FlowFile> ProcessSession::clone(const FlowFile& parent, in
   return record;
 }
 
-void ProcessSession::remove(const std::shared_ptr<core::FlowFile> &flow) {
+void ProcessSessionImpl::remove(const std::shared_ptr<core::FlowFile> &flow) {
   logger_->log_debug("Removing flow file with UUID: {}", flow->getUUIDStr());
   flow->setDeleted(true);
   deleted_flowfiles_.push_back(flow);
-  std::string reason = process_context_->getProcessorNode()->getName() + " drop flow record " + flow->getUUIDStr();
+  std::string reason = process_context_->getProcessor().getName() + " drop flow record " + flow->getUUIDStr();
   provenance_report_->drop(*flow, reason);
 }
 
-void ProcessSession::putAttribute(core::FlowFile& flow_file, std::string_view key, const std::string& value) {
+void ProcessSessionImpl::putAttribute(core::FlowFile& flow_file, std::string_view key, const std::string& value) {
   flow_file.setAttribute(key, value);
-  std::string details = fmt::format("{} modify flow record {} attribute {}:{}", process_context_->getProcessorNode()->getName(), flow_file.getUUIDStr(), key, value);
+  std::string details = fmt::format("{} modify flow record {} attribute {}:{}", process_context_->getProcessor().getName(), flow_file.getUUIDStr(), key, value);
   provenance_report_->modifyAttributes(flow_file, details);
 }
 
-void ProcessSession::removeAttribute(core::FlowFile& flow_file, std::string_view key) {
+void ProcessSessionImpl::removeAttribute(core::FlowFile& flow_file, std::string_view key) {
   flow_file.removeAttribute(key);
-  std::string details = fmt::format("{} remove flow record {} attribute {}", process_context_->getProcessorNode()->getName(), flow_file.getUUIDStr(), key);
+  std::string details = fmt::format("{} remove flow record {} attribute {}", process_context_->getProcessor().getName(), flow_file.getUUIDStr(), key);
   provenance_report_->modifyAttributes(flow_file, details);
 }
 
-void ProcessSession::penalize(const std::shared_ptr<core::FlowFile> &flow) {
-  const std::chrono::milliseconds penalization_period = process_context_->getProcessorNode()->getPenalizationPeriod();
-  logger_->log_info("Penalizing {} for {} at {}", flow->getUUIDStr(), penalization_period, process_context_->getProcessorNode()->getName());
-  flow->penalize(penalization_period);
+void ProcessSessionImpl::penalize(const std::shared_ptr<core::FlowFile> &flow) {
+  const std::chrono::milliseconds penalization_period = process_context_->getProcessor().getPenalizationPeriod();
+  logger_->log_info("Penalizing {} for {} at {}", flow->getUUIDStr(), penalization_period, process_context_->getProcessor().getName());
+  std::dynamic_pointer_cast<FlowFileImpl>(flow)->penalize(penalization_period);
 }
 
-void ProcessSession::transfer(const std::shared_ptr<core::FlowFile>& flow, const Relationship& relationship) {
-  logger_->log_debug("Transferring {} from {} to relationship {}", flow->getUUIDStr(), process_context_->getProcessorNode()->getName(), relationship.getName());
+void ProcessSessionImpl::transfer(const std::shared_ptr<core::FlowFile>& flow, const Relationship& relationship) {
+  logger_->log_debug("Transferring {} from {} to relationship {}", flow->getUUIDStr(), process_context_->getProcessor().getName(), relationship.getName());
   utils::Identifier uuid = flow->getUUID();
   if (auto it = added_flowfiles_.find(uuid); it != added_flowfiles_.end()) {
     it->second.rel = &*relationships_.insert(relationship).first;
@@ -234,15 +233,15 @@ void ProcessSession::transfer(const std::shared_ptr<core::FlowFile>& flow, const
   flow->setDeleted(false);
 }
 
-void ProcessSession::transferToCustomRelationship(const std::shared_ptr<core::FlowFile>& flow, const std::string& relationship_name) {
+void ProcessSessionImpl::transferToCustomRelationship(const std::shared_ptr<core::FlowFile>& flow, const std::string& relationship_name) {
   transfer(flow, Relationship{relationship_name, relationship_name});
 }
 
-void ProcessSession::write(const std::shared_ptr<core::FlowFile> &flow, const io::OutputStreamCallback& callback) {
+void ProcessSessionImpl::write(const std::shared_ptr<core::FlowFile> &flow, const io::OutputStreamCallback& callback) {
   return write(*flow, callback);
 }
 
-void ProcessSession::write(core::FlowFile &flow, const io::OutputStreamCallback& callback) {
+void ProcessSessionImpl::write(core::FlowFile &flow, const io::OutputStreamCallback& callback) {
   gsl_ExpectsAudit(updated_flowfiles_.contains(flow.getUUID())
       || added_flowfiles_.contains(flow.getUUID())
       || std::any_of(cloned_flowfiles_.begin(), cloned_flowfiles_.end(), [&flow](const auto& flow_file) { return &flow == flow_file.get(); }));
@@ -265,11 +264,11 @@ void ProcessSession::write(core::FlowFile &flow, const io::OutputStreamCallback&
     flow.setResourceClaim(claim);
 
     stream->close();
-    std::string details = process_context_->getProcessorNode()->getName() + " modify flow record content " + flow.getUUIDStr();
+    std::string details = process_context_->getProcessor().getName() + " modify flow record content " + flow.getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
     provenance_report_->modifyContent(flow, details, duration);
     if (metrics_) {
-      metrics_->bytes_written += stream->size();
+      metrics_->bytesWritten() += stream->size();
     }
   } catch (const std::exception& exception) {
     logger_->log_debug("Caught Exception during process session write, type: {}, what: {}", typeid(exception).name(), exception.what());
@@ -280,18 +279,18 @@ void ProcessSession::write(core::FlowFile &flow, const io::OutputStreamCallback&
   }
 }
 
-void ProcessSession::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const char> buffer) {
+void ProcessSessionImpl::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const char> buffer) {
   writeBuffer(flow_file, as_bytes(buffer));
 }
 
-void ProcessSession::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const std::byte> buffer) {
+void ProcessSessionImpl::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const std::byte> buffer) {
   write(flow_file, [buffer](const std::shared_ptr<io::OutputStream>& output_stream) {
     const auto write_status = output_stream->write(buffer);
     return io::isError(write_status) ? -1 : gsl::narrow<int64_t>(write_status);
   });
 }
 
-void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const io::OutputStreamCallback& callback) {
+void ProcessSessionImpl::append(const std::shared_ptr<core::FlowFile> &flow, const io::OutputStreamCallback& callback) {
   gsl_ExpectsAudit(updated_flowfiles_.contains(flow->getUUID())
       || added_flowfiles_.contains(flow->getUUID())
       || std::any_of(cloned_flowfiles_.begin(), cloned_flowfiles_.end(), [&flow](const auto& flow_file) { return flow == flow_file; }));
@@ -321,11 +320,11 @@ void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const i
     }
     flow->setSize(flow_file_size + (stream->size() - stream_size_before_callback));
     if (metrics_) {
-      metrics_->bytes_written += stream->size() - stream_size_before_callback;
+      metrics_->bytesWritten() += stream->size() - stream_size_before_callback;
     }
 
     std::stringstream details;
-    details << process_context_->getProcessorNode()->getName() << " modify flow record content " << flow->getUUIDStr();
+    details << process_context_->getProcessor().getName() << " modify flow record content " << flow->getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
     provenance_report_->modifyContent(*flow, details.str(), duration);
   } catch (const std::exception& exception) {
@@ -336,10 +335,10 @@ void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const i
     throw;
   }
 }
-void ProcessSession::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const char> buffer) {
+void ProcessSessionImpl::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const char> buffer) {
   appendBuffer(flow_file, as_bytes(buffer));
 }
-void ProcessSession::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const std::byte> buffer) {
+void ProcessSessionImpl::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const std::byte> buffer) {
   if (buffer.empty()) { return; }
   append(flow_file, [buffer](const std::shared_ptr<io::OutputStream>& output_stream) {
     const auto write_status = output_stream->write(buffer);
@@ -347,7 +346,7 @@ void ProcessSession::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_fi
   });
 }
 
-std::shared_ptr<io::InputStream> ProcessSession::getFlowFileContentStream(const core::FlowFile& flow_file) {
+std::shared_ptr<io::InputStream> ProcessSessionImpl::getFlowFileContentStream(const core::FlowFile& flow_file) {
   if (flow_file.getResourceClaim() == nullptr) {
     logger_->log_debug("For {}, no resource claim but size is {}", flow_file.getUUIDStr(), flow_file.getSize());
     if (flow_file.getSize() == 0) {
@@ -365,11 +364,11 @@ std::shared_ptr<io::InputStream> ProcessSession::getFlowFileContentStream(const
   return std::make_shared<io::StreamSlice>(stream, flow_file.getOffset(), flow_file.getSize());
 }
 
-int64_t ProcessSession::read(const std::shared_ptr<core::FlowFile>& flow_file, const io::InputStreamCallback& callback) {
+int64_t ProcessSessionImpl::read(const std::shared_ptr<core::FlowFile>& flow_file, const io::InputStreamCallback& callback) {
   return read(*flow_file, callback);
 }
 
-int64_t ProcessSession::read(const core::FlowFile& flow_file, const io::InputStreamCallback& callback) {
+int64_t ProcessSessionImpl::read(const core::FlowFile& flow_file, const io::InputStreamCallback& callback) {
   try {
     auto flow_file_stream = getFlowFileContentStream(flow_file);
     if (!flow_file_stream) {
@@ -381,7 +380,7 @@ int64_t ProcessSession::read(const core::FlowFile& flow_file, const io::InputStr
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to process flowfile content");
     }
     if (metrics_) {
-      metrics_->bytes_read += ret;
+      metrics_->bytesRead() += ret;
     }
     return ret;
   } catch (const std::exception& exception) {
@@ -393,7 +392,7 @@ int64_t ProcessSession::read(const core::FlowFile& flow_file, const io::InputStr
   }
 }
 
-int64_t ProcessSession::readWrite(const std::shared_ptr<core::FlowFile> &flow, const io::InputOutputStreamCallback& callback) {
+int64_t ProcessSessionImpl::readWrite(const std::shared_ptr<core::FlowFile> &flow, const io::InputOutputStreamCallback& callback) {
   gsl_Expects(callback);
 
   try {
@@ -430,8 +429,8 @@ int64_t ProcessSession::readWrite(const std::shared_ptr<core::FlowFile> &flow, c
     flow->setOffset(0);
     flow->setResourceClaim(output_claim);
     if (metrics_) {
-      metrics_->bytes_written += read_write_result->bytes_written;
-      metrics_->bytes_read += read_write_result->bytes_read;
+      metrics_->bytesWritten() += read_write_result->bytes_written;
+      metrics_->bytesRead() += read_write_result->bytes_read;
     }
 
     return read_write_result->bytes_written;
@@ -444,7 +443,7 @@ int64_t ProcessSession::readWrite(const std::shared_ptr<core::FlowFile> &flow, c
   }
 }
 
-detail::ReadBufferResult ProcessSession::readBuffer(const std::shared_ptr<core::FlowFile>& flow) {
+detail::ReadBufferResult ProcessSessionImpl::readBuffer(const std::shared_ptr<core::FlowFile>& flow) {
   detail::ReadBufferResult result;
   result.status = read(flow, [&result, this](const std::shared_ptr<io::InputStream>& input_stream) {
     result.buffer.resize(input_stream->size());
@@ -458,7 +457,7 @@ detail::ReadBufferResult ProcessSession::readBuffer(const std::shared_ptr<core::
   return result;
 }
 
-void ProcessSession::importFrom(io::InputStream&& stream, const std::shared_ptr<core::FlowFile> &flow) {
+void ProcessSessionImpl::importFrom(io::InputStream&& stream, const std::shared_ptr<core::FlowFile> &flow) {
   importFrom(stream, flow);
 }
 /**
@@ -467,7 +466,7 @@ void ProcessSession::importFrom(io::InputStream&& stream, const std::shared_ptr<
  * @param flow flow file
  *
  */
-void ProcessSession::importFrom(io::InputStream &stream, const std::shared_ptr<core::FlowFile> &flow) {
+void ProcessSessionImpl::importFrom(io::InputStream &stream, const std::shared_ptr<core::FlowFile> &flow) {
   const std::shared_ptr<ResourceClaim> claim = content_session_->create();
   const auto max_read = gsl::narrow_cast<size_t>(getpagesize());
   std::vector<std::byte> buffer(max_read);
@@ -500,10 +499,10 @@ void ProcessSession::importFrom(io::InputStream &stream, const std::shared_ptr<c
 
     content_stream->close();
     if (metrics_) {
-      metrics_->bytes_written += content_stream->size();
+      metrics_->bytesWritten() += content_stream->size();
     }
     std::stringstream details;
-    details << process_context_->getProcessorNode()->getName() << " modify flow record content " << flow->getUUIDStr();
+    details << process_context_->getProcessor().getName() << " modify flow record content " << flow->getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
     provenance_report_->modifyContent(*flow, details.str(), duration);
   } catch (const std::exception& exception) {
@@ -515,7 +514,7 @@ void ProcessSession::importFrom(io::InputStream &stream, const std::shared_ptr<c
   }
 }
 
-void ProcessSession::import(const std::string& source, const std::shared_ptr<FlowFile> &flow, bool keepSource, uint64_t offset) {
+void ProcessSessionImpl::import(const std::string& source, const std::shared_ptr<FlowFile> &flow, bool keepSource, uint64_t offset) {
   std::shared_ptr<ResourceClaim> claim = content_session_->create();
   size_t size = getpagesize();
   std::vector<uint8_t> charBuffer(size);
@@ -564,14 +563,14 @@ void ProcessSession::import(const std::string& source, const std::shared_ptr<Flo
 
         stream->close();
         if (metrics_) {
-          metrics_->bytes_written += stream->size();
+          metrics_->bytesWritten() += stream->size();
         }
         input.close();
         if (!keepSource) {
           (void)std::remove(source.c_str());
         }
         std::stringstream details;
-        details << process_context_->getProcessorNode()->getName() << " modify flow record content " << flow->getUUIDStr();
+        details << process_context_->getProcessor().getName() << " modify flow record content " << flow->getUUIDStr();
         auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
         provenance_report_->modifyContent(*flow, details.str(), duration);
       } else {
@@ -591,7 +590,7 @@ void ProcessSession::import(const std::string& source, const std::shared_ptr<Flo
   }
 }
 
-void ProcessSession::import(const std::string& source, std::vector<std::shared_ptr<FlowFile>> &flows, uint64_t offset, char inputDelimiter) {
+void ProcessSessionImpl::import(const std::string& source, std::vector<std::shared_ptr<FlowFile>> &flows, uint64_t offset, char inputDelimiter) {
   std::shared_ptr<ResourceClaim> claim;
   std::shared_ptr<io::BaseStream> stream;
   std::shared_ptr<core::FlowFile> flowFile;
@@ -669,9 +668,9 @@ void ProcessSession::import(const std::string& source, std::vector<std::shared_p
             flowFile->getOffset(), flowFile->getSize(), flowFile->getResourceClaim()->getContentFullPath(), flowFile->getUUIDStr());
         stream->close();
         if (metrics_) {
-          metrics_->bytes_written += stream->size();
+          metrics_->bytesWritten() += stream->size();
         }
-        std::string details = process_context_->getProcessorNode()->getName() + " modify flow record content " + flowFile->getUUIDStr();
+        std::string details = process_context_->getProcessor().getName() + " modify flow record content " + flowFile->getUUIDStr();
         auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
         provenance_report_->modifyContent(*flowFile, details, duration);
         flows.push_back(flowFile);
@@ -694,7 +693,7 @@ void ProcessSession::import(const std::string& source, std::vector<std::shared_p
   }
 }
 
-void ProcessSession::import(const std::string& source, std::vector<std::shared_ptr<FlowFile>> &flows, bool keepSource, uint64_t offset, char inputDelimiter) {
+void ProcessSessionImpl::import(const std::string& source, std::vector<std::shared_ptr<FlowFile>> &flows, bool keepSource, uint64_t offset, char inputDelimiter) {
 // this function calls a deprecated function, but it is itself deprecated, so suppress warnings
 #if defined(__clang__)
 #pragma clang diagnostic push
@@ -720,7 +719,7 @@ void ProcessSession::import(const std::string& source, std::vector<std::shared_p
   }
 }
 
-bool ProcessSession::exportContent(const std::string &destination, const std::string &tmpFile, const std::shared_ptr<core::FlowFile> &flow, bool /*keepContent*/) {
+bool ProcessSessionImpl::exportContent(const std::string &destination, const std::string &tmpFile, const std::shared_ptr<core::FlowFile> &flow, bool /*keepContent*/) {
   logger_->log_debug("Exporting content of {} to {}", flow->getUUIDStr(), destination);
 
   ProcessSessionReadCallback cb(tmpFile, destination, logger_);
@@ -737,7 +736,7 @@ bool ProcessSession::exportContent(const std::string &destination, const std::st
   return commit_ok;
 }
 
-bool ProcessSession::exportContent(const std::string &destination, const std::shared_ptr<core::FlowFile> &flow, bool keepContent) {
+bool ProcessSessionImpl::exportContent(const std::string &destination, const std::shared_ptr<core::FlowFile> &flow, bool keepContent) {
   utils::Identifier tmpFileUuid = id_generator_->generate();
   std::stringstream tmpFileSs;
   tmpFileSs << destination << "." << tmpFileUuid.to_string();
@@ -746,7 +745,7 @@ bool ProcessSession::exportContent(const std::string &destination, const std::sh
   return exportContent(destination, tmpFileName, flow, keepContent);
 }
 
-void ProcessSession::stash(const std::string &key, const std::shared_ptr<core::FlowFile> &flow) {
+void ProcessSessionImpl::stash(const std::string &key, const std::shared_ptr<core::FlowFile> &flow) {
   logger_->log_debug("Stashing content from {} to key {}", flow->getUUIDStr(), key);
 
   auto claim = flow->getResourceClaim();
@@ -764,7 +763,7 @@ void ProcessSession::stash(const std::string &key, const std::shared_ptr<core::F
   flow->clearResourceClaim();
 }
 
-void ProcessSession::restore(const std::string &key, const std::shared_ptr<core::FlowFile> &flow) {
+void ProcessSessionImpl::restore(const std::string &key, const std::shared_ptr<core::FlowFile> &flow) {
   logger_->log_info("Restoring content to {} from key {}", flow->getUUIDStr(), key);
 
   // Restore the claim
@@ -786,7 +785,7 @@ void ProcessSession::restore(const std::string &key, const std::shared_ptr<core:
   flow->clearStashClaim(key);
 }
 
-ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<FlowFile> &record, const std::function<void(const FlowFile&, const Relationship&)>& transfer_callback) {
+ProcessSessionImpl::RouteResult ProcessSessionImpl::routeFlowFile(const std::shared_ptr<FlowFile> &record, const std::function<void(const FlowFile&, const Relationship&)>& transfer_callback) {
   if (record->isDeleted()) {
     return RouteResult::Ok_Deleted;
   }
@@ -801,10 +800,10 @@ ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<
     return RouteResult::Error_NoRelationship;
   }
   // Find the relationship, we need to find the connections for that relationship
-  const auto connections = process_context_->getProcessorNode()->getOutGoingConnections(relationship.getName());
+  const auto connections = process_context_->getProcessor().getOutGoingConnections(relationship.getName());
   if (connections.empty()) {
     // No connection
-    if (!process_context_->getProcessorNode()->isAutoTerminated(relationship)) {
+    if (!process_context_->getProcessor().isAutoTerminated(relationship)) {
       // Not autoterminate, we should have the connect
       std::string message = "Connect empty for non auto terminated relationship " + relationship.getName();
       throw Exception(PROCESS_SESSION_EXCEPTION, message);
@@ -837,7 +836,7 @@ ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<
   return RouteResult::Ok_Routed;
 }
 
-void ProcessSession::commit() {
+void ProcessSessionImpl::commit() {
   const auto commit_start_time = std::chrono::steady_clock::now();
   try {
     std::unordered_map<std::string, TransferMetrics> transfers;
@@ -935,8 +934,8 @@ void ProcessSession::commit() {
 
     if (metrics_) {
       for (const auto& [relationship_name, transfer_metrics] : transfers) {
-        metrics_->transferred_bytes += transfer_metrics.transfer_size;
-        metrics_->transferred_flow_files += transfer_metrics.transfer_count;
+        metrics_->transferredBytes() += transfer_metrics.transfer_size;
+        metrics_->transferredFlowFiles() += transfer_metrics.transfer_count;
         metrics_->increaseRelationshipTransferCount(relationship_name, transfer_metrics.transfer_count);
       }
     }
@@ -951,11 +950,11 @@ void ProcessSession::commit() {
     relationships_.clear();
     // persistent the provenance report
     this->provenance_report_->commit();
-    logger_->log_debug("ProcessSession committed for {}", process_context_->getProcessorNode()->getName());
+    logger_->log_debug("ProcessSession committed for {}", process_context_->getProcessor().getName());
     if (metrics_) {
       auto time_delta = std::chrono::steady_clock::now() - commit_start_time;
       metrics_->addLastSessionCommitRuntime(std::chrono::duration_cast<std::chrono::milliseconds>(time_delta));
-      metrics_->processing_nanos += std::chrono::duration_cast<std::chrono::nanoseconds>(time_delta).count();
+      metrics_->processingNanos() += std::chrono::duration_cast<std::chrono::nanoseconds>(time_delta).count();
     }
   } catch (const std::exception& exception) {
     logger_->log_debug("Caught Exception during process session commit, type: {}, what: {}", typeid(exception).name(), exception.what());
@@ -966,7 +965,7 @@ void ProcessSession::commit() {
   }
 }
 
-void ProcessSession::rollback() {
+void ProcessSessionImpl::rollback() {
   // new FlowFiles are only persisted during commit
   // no need to delete them here
   std::map<Connectable*, std::vector<std::shared_ptr<FlowFile>>> connectionQueues;
@@ -976,10 +975,10 @@ void ProcessSession::rollback() {
     for (const auto &it : updated_flowfiles_) {
       auto flowFile = it.second.modified;
       // restore flowFile to original state
-      *flowFile = *it.second.snapshot;
+      flowFile->copy(*it.second.snapshot);
       penalize(flowFile);
       logger_->log_debug("ProcessSession rollback for {}, record {}, to connection {}",
-          process_context_->getProcessorNode()->getName(),
+          process_context_->getProcessor().getName(),
           flowFile->getUUIDStr(),
           flowFile->getConnection()->getName());
       connectionQueues[flowFile->getConnection()].push_back(flowFile);
@@ -1012,7 +1011,7 @@ void ProcessSession::rollback() {
     updated_flowfiles_.clear();
     deleted_flowfiles_.clear();
     relationships_.clear();
-    logger_->log_warn("ProcessSession rollback for {} executed", process_context_->getProcessorNode()->getName());
+    logger_->log_warn("ProcessSession rollback for {} executed", process_context_->getProcessor().getName());
   } catch (const std::exception& exception) {
     logger_->log_warn("Caught Exception during process session rollback, type: {}, what: {}", typeid(exception).name(), exception.what());
     throw;
@@ -1022,16 +1021,19 @@ void ProcessSession::rollback() {
   }
 }
 
-nonstd::expected<void, std::exception_ptr> ProcessSession::rollbackNoThrow() noexcept {
+nonstd::expected<void, std::string> ProcessSessionImpl::rollbackNoThrow() noexcept {
   try {
     rollback();
     return {};
+  } catch(const std::exception& exception) {
+    return nonstd::make_unexpected(exception.what());
   } catch(...) {
-    return nonstd::make_unexpected(std::current_exception());
+    logger_->log_critical("Caught unknown exception during rollback, type: {}, terminating", getCurrentExceptionTypeName());
+    std::terminate();
   }
 }
 
-void ProcessSession::persistFlowFilesBeforeTransfer(
+void ProcessSessionImpl::persistFlowFilesBeforeTransfer(
     std::map<Connectable*, std::vector<std::shared_ptr<core::FlowFile> > >& transactionMap,
     const std::map<utils::Identifier, FlowFileUpdate>& modifiedFlowFiles) {
 
@@ -1068,7 +1070,7 @@ void ProcessSession::persistFlowFilesBeforeTransfer(
   // collect serialized flowfiles
   forEachFlowFile(Type::Transferred, [&] (auto& ff, auto& /*original*/) {
     auto stream = std::make_unique<io::BufferStream>();
-    std::static_pointer_cast<FlowFileRecord>(ff)->Serialize(*stream);
+    std::dynamic_pointer_cast<FlowFileRecord>(ff)->Serialize(*stream);
 
     flowData.emplace_back(ff->getUUIDStr(), std::move(stream));
   });
@@ -1108,15 +1110,15 @@ void ProcessSession::persistFlowFilesBeforeTransfer(
   });
 }
 
-void ProcessSession::ensureNonNullResourceClaim(
+void ProcessSessionImpl::ensureNonNullResourceClaim(
     const std::map<Connectable*, std::vector<std::shared_ptr<core::FlowFile>>> &transactionMap) {
   for (auto& transaction : transactionMap) {
     for (auto& flowFile : transaction.second) {
       auto claim = flowFile->getResourceClaim();
       if (!claim) {
         logger_->log_debug("Processor {} ({}) did not create a ResourceClaim, creating an empty one",
-                           process_context_->getProcessorNode()->getUUIDStr(),
-                           process_context_->getProcessorNode()->getName());
+                           process_context_->getProcessor().getUUIDStr(),
+                           process_context_->getProcessor().getName());
         io::BufferStream emptyBufferStream;
         write(flowFile, OutputStreamPipe{emptyBufferStream});
       }
@@ -1124,18 +1126,18 @@ void ProcessSession::ensureNonNullResourceClaim(
   }
 }
 
-std::shared_ptr<core::FlowFile> ProcessSession::get() {
-  const auto first = process_context_->getProcessorNode()->pickIncomingConnection();
+std::shared_ptr<core::FlowFile> ProcessSessionImpl::get() {
+  const auto first = process_context_->getProcessor().pickIncomingConnection();
 
   if (first == nullptr) {
-    logger_->log_trace("Get is null for {}", process_context_->getProcessorNode()->getName());
+    logger_->log_trace("Get is null for {}", process_context_->getProcessor().getName());
     return nullptr;
   }
 
   auto current = dynamic_cast<Connection*>(first);
   if (!current) {
     logger_->log_error("The incoming connection [{}] of the processor [{}] \"{}\" is not actually a Connection.",
-                       first->getUUIDStr(), process_context_->getProcessorNode()->getUUIDStr(), process_context_->getProcessorNode()->getName());
+                       first->getUUIDStr(), process_context_->getProcessor().getUUIDStr(), process_context_->getProcessor().getName());
     return {};
   }
 
@@ -1146,7 +1148,7 @@ std::shared_ptr<core::FlowFile> ProcessSession::get() {
       // Remove expired flow record
       for (const auto& record : expired) {
         std::stringstream details;
-        details << process_context_->getProcessorNode()->getName() << " expire flow record " << record->getUUIDStr();
+        details << process_context_->getProcessor().getName() << " expire flow record " << record->getUUIDStr();
         provenance_report_->expire(*record, details.str());
         // there is no rolling back expired FlowFiles
         if (record->isStored() && process_context_->getFlowFileRepository()->Delete(record->getUUIDStr())) {
@@ -1157,33 +1159,33 @@ std::shared_ptr<core::FlowFile> ProcessSession::get() {
     if (ret) {
       // add the flow record to the current process session update map
       ret->setDeleted(false);
-      std::shared_ptr<FlowFile> snapshot = std::make_shared<FlowFileRecord>();
-      *snapshot = *ret;
+      std::shared_ptr<FlowFile> snapshot = std::make_shared<FlowFileRecordImpl>();
+      snapshot->copy(*ret);
       logger_->log_debug("Create Snapshot FlowFile with UUID {}", snapshot->getUUIDStr());
       utils::Identifier uuid = ret->getUUID();
       updated_flowfiles_[uuid] = {ret, snapshot};
-      auto flow_version = process_context_->getProcessorNode()->getFlowIdentifier();
+      auto flow_version = process_context_->getProcessor().getFlowIdentifier();
       if (flow_version != nullptr) {
         ret->setAttribute(SpecialFlowAttribute::FLOW_ID, flow_version->getFlowId());
       }
       if (metrics_) {
-        metrics_->incoming_bytes += ret->getSize();
-        ++metrics_->incoming_flow_files;
+        metrics_->incomingBytes() += ret->getSize();
+        ++metrics_->incomingFlowFiles();
       }
       return ret;
     }
-    current = dynamic_cast<Connection*>(process_context_->getProcessorNode()->pickIncomingConnection());
+    current = dynamic_cast<Connection*>(process_context_->getProcessor().pickIncomingConnection());
   } while (current != nullptr && current != first);
 
   return nullptr;
 }
 
-void ProcessSession::flushContent() {
+void ProcessSessionImpl::flushContent() {
   content_session_->commit();
 }
 
-bool ProcessSession::outgoingConnectionsFull(const std::string& relationship) {
-  std::set<Connectable*> connections = process_context_->getProcessorNode()->getOutGoingConnections(relationship);
+bool ProcessSessionImpl::outgoingConnectionsFull(const std::string& relationship) {
+  std::set<Connectable*> connections = process_context_->getProcessor().getOutGoingConnections(relationship);
   Connection * connection = nullptr;
   for (const auto conn : connections) {
     connection = dynamic_cast<Connection*>(conn);
@@ -1194,7 +1196,7 @@ bool ProcessSession::outgoingConnectionsFull(const std::string& relationship) {
   return false;
 }
 
-bool ProcessSession::existsFlowFileInRelationship(const Relationship &relationship) {
+bool ProcessSessionImpl::existsFlowFileInRelationship(const Relationship &relationship) {
   return std::any_of(updated_relationships_.begin(), updated_relationships_.end(),
       [&](const auto& key_value_pair) {
         return key_value_pair.second && relationship == *key_value_pair.second;
@@ -1204,7 +1206,7 @@ bool ProcessSession::existsFlowFileInRelationship(const Relationship &relationsh
   });
 }
 
-bool ProcessSession::hasBeenTransferred(const core::FlowFile &flow) const {
+bool ProcessSessionImpl::hasBeenTransferred(const core::FlowFile &flow) const {
   return (updated_relationships_.contains(flow.getUUID()) && updated_relationships_.at(flow.getUUID()) != nullptr) ||
     (added_flowfiles_.contains(flow.getUUID()) && added_flowfiles_.at(flow.getUUID()).rel != nullptr);
 }
