@@ -27,30 +27,39 @@
 #include <string>
 #include <vector>
 
-#include "Connection.h"
+#include "minifi-cpp/Connection.h"
 #include "core/Connectable.h"
-#include "core/logging/LoggerConfiguration.h"
-#include "core/ProcessorConfig.h"
-#include "core/ProcessContext.h"
-#include "core/ProcessSessionFactory.h"
+#include "core/logging/LoggerFactory.h"
+#include "minifi-cpp/core/ProcessorConfig.h"
+#include "minifi-cpp/core/ProcessContext.h"
+#include "minifi-cpp/core/ProcessorDescriptor.h"
+#include "minifi-cpp/core/ProcessSessionFactory.h"
 #include "utils/gsl.h"
 #include "range/v3/algorithm/any_of.hpp"
 #include "fmt/format.h"
+#include "Exception.h"
+#include "core/ProcessorMetrics.h"
 
 using namespace std::literals::chrono_literals;
 
 namespace org::apache::nifi::minifi::core {
 
-Processor::Processor(std::string_view name, std::shared_ptr<ProcessorMetrics> metrics)
-    : Connectable(name),
+constexpr std::chrono::microseconds MINIMUM_SCHEDULING_PERIOD{30};
+
+static std::mutex& getGraphMutex() {
+  static std::mutex mutex{};
+  return mutex;
+}
+
+Processor::Processor(std::string_view name, std::unique_ptr<ProcessorApi> impl)
+    : ConnectableImpl(name),
       state_(DISABLED),
       scheduling_period_(MINIMUM_SCHEDULING_PERIOD),
       run_duration_(DEFAULT_RUN_DURATION),
       yield_period_(DEFAULT_YIELD_PERIOD_SECONDS),
       active_tasks_(0),
-      _triggerWhenEmpty(false),
-      metrics_(metrics ? std::move(metrics) : std::make_shared<ProcessorMetrics>(*this)),
-      logger_(logging::LoggerFactory<Processor>::getLogger(uuid_)) {
+      logger_(logging::LoggerFactory<Processor>::getLogger(uuid_)),
+      impl_(std::move(impl)) {
   has_work_.store(false);
   // Setup the default values
   strategy_ = TIMER_DRIVEN;
@@ -60,16 +69,15 @@ Processor::Processor(std::string_view name, std::shared_ptr<ProcessorMetrics> me
   logger_->log_debug("Processor {} created UUID {}", name_, getUUIDStr());
 }
 
-Processor::Processor(std::string_view name, const utils::Identifier& uuid, std::shared_ptr<ProcessorMetrics> metrics)
-    : Connectable(name, uuid),
+Processor::Processor(std::string_view name, const utils::Identifier& uuid, std::unique_ptr<ProcessorApi> impl)
+    : ConnectableImpl(name, uuid),
       state_(DISABLED),
       scheduling_period_(MINIMUM_SCHEDULING_PERIOD),
       run_duration_(DEFAULT_RUN_DURATION),
       yield_period_(DEFAULT_YIELD_PERIOD_SECONDS),
       active_tasks_(0),
-      _triggerWhenEmpty(false),
-      metrics_(metrics ? std::move(metrics) : std::make_shared<ProcessorMetrics>(*this)),
-      logger_(logging::LoggerFactory<Processor>::getLogger(uuid_)) {
+      logger_(logging::LoggerFactory<Processor>::getLogger(uuid_)),
+      impl_(std::move(impl)) {
   has_work_.store(false);
   // Setup the default values
   strategy_ = TIMER_DRIVEN;
@@ -90,7 +98,7 @@ bool Processor::isRunning() const {
 void Processor::setScheduledState(ScheduledState state) {
   state_ = state;
   if (state == STOPPED) {
-    notifyStop();
+    impl_->notifyStop();
   }
 }
 
@@ -164,24 +172,9 @@ bool Processor::addConnection(Connectable* conn) {
   return result != SetAs::NONE;
 }
 
-bool Processor::flowFilesOutGoingFull() const {
-  std::lock_guard<std::mutex> lock(mutex_);
-
-  for (const auto& [_name, existed_connection] : outgoing_connections_) {
-    if (ranges::any_of(existed_connection, [](const Connectable* conn) {
-      const auto connection = dynamic_cast<const Connection*>(conn);
-      return connection && connection->backpressureThresholdReached();
-    })) {
-      return true;
-    }
-  }
-
-  return false;
-}
-
 void Processor::triggerAndCommit(const std::shared_ptr<ProcessContext>& context, const std::shared_ptr<ProcessSessionFactory>& session_factory) {
   const auto process_session = session_factory->createSession();
-  process_session->setMetrics(metrics_);
+  process_session->setMetrics(getMetrics());
   try {
     trigger(context, process_session);
     process_session->commit();
@@ -198,10 +191,10 @@ void Processor::triggerAndCommit(const std::shared_ptr<ProcessContext>& context,
 }
 
 void Processor::trigger(const std::shared_ptr<ProcessContext>& context, const std::shared_ptr<ProcessSession>& process_session) {
-  ++metrics_->invocations;
+  ++impl_->getMetrics()->invocations();
   const auto start = std::chrono::steady_clock::now();
   onTrigger(*context, *process_session);
-  metrics_->addLastOnTriggerRuntime(std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start));
+  impl_->getMetrics()->addLastOnTriggerRuntime(std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start));
 }
 
 bool Processor::isWorkAvailable() {
@@ -226,7 +219,7 @@ bool Processor::isWorkAvailable() {
         getCurrentExceptionTypeName());
   }
 
-  return hasWork;
+  return hasWork || impl_->isWorkAvailable();
 }
 
 // must hold the graphMutex
@@ -245,7 +238,7 @@ void Processor::updateReachability(const std::lock_guard<std::mutex>& graph_lock
       if (reachable_processors_[connection].insert(dest).second) {
         didChange = true;
       }
-      for (auto& reachedIt : dest->reachable_processors_) {
+      for (auto& reachedIt : dest->reachable_processors()) {
         for (auto &reached_proc : reachedIt.second) {
           if (reachable_processors_[connection].insert(reached_proc).second) {
             didChange = true;
@@ -275,8 +268,8 @@ bool Processor::partOfCycle(Connection* conn) {
   if (!source) {
     return false;
   }
-  auto it = source->reachable_processors_.find(conn);
-  if (it == source->reachable_processors_.end()) {
+  auto it = source->reachable_processors().find(conn);
+  if (it == source->reachable_processors().end()) {
     return false;
   }
   return it->second.contains(source);
@@ -355,7 +348,7 @@ void Processor::yield(std::chrono::steady_clock::duration delta_time) {
   yield_expiration_ = std::chrono::steady_clock::now() + delta_time;
 }
 
-bool Processor::isYield() {
+bool Processor::isYield() const {
   return getYieldTime() > 0ms;
 }
 
@@ -367,4 +360,190 @@ std::chrono::steady_clock::duration Processor::getYieldTime() const {
   return std::max(yield_expiration_.load()-std::chrono::steady_clock::now(), std::chrono::steady_clock::duration{0});
 }
 
+namespace {
+
+class ProcessorDescriptorImpl : public ProcessorDescriptor {
+ public:
+  explicit ProcessorDescriptorImpl(Processor* impl): impl_(impl) {}
+  void setSupportedRelationships(std::span<const RelationshipDefinition> relationships) override {
+    impl_->setSupportedRelationships(relationships);
+  }
+
+  void setSupportedProperties(std::span<const PropertyReference> properties) override {
+    impl_->setSupportedProperties(properties);
+  }
+
+ private:
+  Processor* impl_;
+};
+
+}  // namespace
+
+void Processor::initialize() {
+  ProcessorDescriptorImpl self{this};
+  impl_->initialize(self);
+}
+
+ScheduledState Processor::getScheduledState() const {
+  return state_;
+}
+
+void Processor::setSchedulingStrategy(SchedulingStrategy strategy) {
+  strategy_ = strategy;
+}
+
+SchedulingStrategy Processor::getSchedulingStrategy() const {
+  return strategy_;
+}
+
+void Processor::setSchedulingPeriod(std::chrono::steady_clock::duration period) {
+  scheduling_period_ = std::max(std::chrono::steady_clock::duration(MINIMUM_SCHEDULING_PERIOD), period);
+}
+
+std::chrono::steady_clock::duration Processor::getSchedulingPeriod() const {
+  return scheduling_period_;
+}
+
+void Processor::setCronPeriod(const std::string &period) {
+  cron_period_ = period;
+}
+
+std::string Processor::getCronPeriod() const {
+  return cron_period_;
+}
+
+void Processor::setRunDurationNano(std::chrono::steady_clock::duration period) {
+  run_duration_ = period;
+}
+
+std::chrono::steady_clock::duration Processor::getRunDurationNano() const {
+  return (run_duration_);
+}
+
+void Processor::setYieldPeriodMsec(std::chrono::milliseconds period) {
+  yield_period_ = period;
+}
+
+std::chrono::steady_clock::duration Processor::getYieldPeriod() const {
+  return yield_period_;
+}
+
+void Processor::setPenalizationPeriod(std::chrono::milliseconds period) {
+  penalization_period_ = period;
+}
+
+bool Processor::isSingleThreaded() const {
+  return impl_->isSingleThreaded();
+}
+
+std::string Processor::getProcessorType() const {
+  return impl_->getProcessorType();
+}
+
+bool Processor::getTriggerWhenEmpty() const {
+  return impl_->getTriggerWhenEmpty();
+}
+
+uint8_t Processor::getActiveTasks() const {
+  return (active_tasks_);
+}
+
+void Processor::incrementActiveTasks() {
+  ++active_tasks_;
+}
+
+void Processor::decrementActiveTask() {
+  if (active_tasks_ > 0)
+    --active_tasks_;
+}
+
+void Processor::clearActiveTask() {
+  active_tasks_ = 0;
+}
+
+std::string Processor::getProcessGroupUUIDStr() const {
+  return process_group_uuid_;
+}
+
+void Processor::setProcessGroupUUIDStr(const std::string &uuid) {
+  process_group_uuid_ = uuid;
+}
+
+std::string Processor::getProcessGroupName() const {
+  return process_group_name_;
+}
+
+void Processor::setProcessGroupName(const std::string &name) {
+  process_group_name_ = name;
+}
+
+std::string Processor::getProcessGroupPath() const {
+  return process_group_path_;
+}
+
+void Processor::setProcessGroupPath(const std::string &path) {
+  process_group_path_ = path;
+}
+
+logging::LOG_LEVEL Processor::getLogBulletinLevel() const {
+  return log_bulletin_level_;
+}
+
+void Processor::setLogBulletinLevel(logging::LOG_LEVEL level) {
+  log_bulletin_level_ = level;
+}
+
+void Processor::setLoggerCallback(const std::function<void(logging::LOG_LEVEL level, const std::string& message)>& callback) {
+  impl_->setLoggerCallback(callback);
+}
+
+std::chrono::steady_clock::time_point Processor::getYieldExpirationTime() const {
+  return yield_expiration_;
+}
+
+bool Processor::canEdit() {
+  return !isRunning();
+}
+
+void Processor::onTrigger(ProcessContext& context, ProcessSession& session) {
+  impl_->onTrigger(context, session);
+}
+
+void Processor::onSchedule(ProcessContext& context, ProcessSessionFactory& session_factory) {
+  impl_->onSchedule(context, session_factory);
+}
+
+// Hook executed when onSchedule fails (throws). Configuration should be reset in this
+void Processor::onUnSchedule() {
+  impl_->onUnSchedule();
+}
+
+annotation::Input Processor::getInputRequirement() const {
+  return impl_->getInputRequirement();
+}
+
+[[nodiscard]] bool Processor::supportsDynamicProperties() const {
+  return impl_->supportsDynamicProperties();
+}
+
+[[nodiscard]] bool Processor::supportsDynamicRelationships() const {
+  return impl_->supportsDynamicRelationships();
+}
+
+state::response::SharedResponseNode Processor::getResponseNode() {
+  return getMetrics();
+}
+
+gsl::not_null<std::shared_ptr<ProcessorMetrics>> Processor::getMetrics() const {
+  return impl_->getMetrics();
+}
+
+void Processor::restore(const std::shared_ptr<FlowFile>& file) {
+  impl_->restore(file);
+}
+
+const std::unordered_map<Connection*, std::unordered_set<Processor*>>& Processor::reachable_processors() const {
+  return reachable_processors_;
+}
+
 }  // namespace org::apache::nifi::minifi::core
