@@ -18,14 +18,14 @@
 
 #include "core/flow/AdaptiveConfiguration.h"
 
+#include "Defaults.h"
 #include "core/json/JsonFlowSerializer.h"
 #include "core/json/JsonNode.h"
 #include "core/yaml/YamlFlowSerializer.h"
 #include "core/yaml/YamlNode.h"
-#include "yaml-cpp/yaml.h"
-#include "utils/file/FileUtils.h"
-#include "Defaults.h"
 #include "rapidjson/error/en.h"
+#include "utils/file/FileUtils.h"
+#include "yaml-cpp/yaml.h"
 
 namespace org::apache::nifi::minifi::core::flow {
 
@@ -77,7 +77,7 @@ void AdaptiveConfiguration::setSensitivePropertiesEncryptor(utils::crypto::Encry
 
 std::string AdaptiveConfiguration::serializeWithOverrides(const core::ProcessGroup& process_group, const std::unordered_map<utils::Identifier, core::flow::Overrides>& overrides) const {
   gsl_Expects(flow_serializer_);
-  return flow_serializer_->serialize(process_group, schema_, sensitive_values_encryptor_, overrides);
+  return flow_serializer_->serialize(process_group, schema_, sensitive_values_encryptor_, overrides, parameter_contexts_);
 }
 
 }  // namespace org::apache::nifi::minifi::core::flow
