@@ -39,8 +39,56 @@ rapidjson::Value& getMember(rapidjson::Value& node, const std::string& member_na
 }
 }
 
+void JsonFlowSerializer::addProviderCreatedParameterContexts(rapidjson::Value& flow_definition_json, rapidjson::Document::AllocatorType& alloc, const core::flow::FlowSchema& schema,
+    const std::unordered_map<std::string, gsl::not_null<std::unique_ptr<ParameterContext>>>& parameter_contexts) {
+  std::vector<gsl::not_null<ParameterContext*>> provided_parameter_contexts;
+  for (const auto& [parameter_context_name, parameter_context] : parameter_contexts) {
+    if (!parameter_context->getParameterProvider().empty()) {
+      provided_parameter_contexts.push_back(gsl::make_not_null(parameter_context.get()));
+    }
+  }
+
+  if (provided_parameter_contexts.empty()) {
+    return;
+  }
+
+  if (!flow_definition_json.HasMember(schema.parameter_contexts[0])) {
+    flow_definition_json.AddMember(rapidjson::Value(schema.parameter_contexts[0].c_str(), alloc), rapidjson::Value(rapidjson::kArrayType), alloc);
+  }
+
+  for (const auto& parameter_context : provided_parameter_contexts) {
+    rapidjson::Value parameter_context_json(rapidjson::kObjectType);
+    parameter_context_json.AddMember(rapidjson::Value(schema.identifier[0], alloc), rapidjson::Value(parameter_context->getUUIDStr(), alloc), alloc);
+    parameter_context_json.AddMember(rapidjson::Value(schema.name[0], alloc), rapidjson::Value(parameter_context->getName(), alloc), alloc);
+    parameter_context_json.AddMember(rapidjson::Value(schema.parameter_provider[0], alloc), rapidjson::Value(parameter_context->getParameterProvider(), alloc), alloc);
+    auto parameters = parameter_context->getParameters();
+    rapidjson::Value parameters_json(rapidjson::kArrayType);
+    for (const auto& [name, parameter] : parameters) {
+      rapidjson::Value parameter_json(rapidjson::kObjectType);
+      parameter_json.AddMember(rapidjson::Value(schema.name[0], alloc), rapidjson::Value(name, alloc), alloc);
+      parameter_json.AddMember(rapidjson::Value(schema.description[0], alloc), rapidjson::Value(parameter.description, alloc), alloc);
+      parameter_json.AddMember(rapidjson::Value(schema.sensitive[0], alloc), rapidjson::Value(parameter.sensitive), alloc);
+      parameter_json.AddMember(rapidjson::Value(schema.provided[0], alloc), rapidjson::Value(parameter.provided), alloc);
+      parameter_json.AddMember(rapidjson::Value(schema.value[0], alloc), rapidjson::Value(parameter.value, alloc), alloc);
+      parameters_json.PushBack(parameter_json, alloc);
+    }
+    parameter_context_json.AddMember(rapidjson::Value(schema.parameters[0], alloc), parameters_json, alloc);
+
+    auto& parameter_contexts_node = getMember(flow_definition_json, schema.parameter_contexts[0]);
+    auto it = std::find_if(parameter_contexts_node.Begin(), parameter_contexts_node.End(), [&](rapidjson::Value& node) {
+      return getMember(node, schema.name[0]).GetString() == parameter_context->getName();
+    });
+
+    if (it != parameter_contexts_node.End()) {
+      *it = parameter_context_json;
+    } else {
+      parameter_contexts_node.PushBack(parameter_context_json, alloc);
+    }
+  }
+}
+
 void JsonFlowSerializer::encryptSensitiveProperties(rapidjson::Value& property_jsons, rapidjson::Document::AllocatorType& alloc,
-    const std::map<std::string, Property>& properties, const utils::crypto::EncryptionProvider& encryption_provider,
+    const std::map<std::string, Property, std::less<>>& properties, const utils::crypto::EncryptionProvider& encryption_provider,
     const core::flow::Overrides& overrides) const {
   std::unordered_set<std::string> processed_property_names;
 
@@ -118,13 +166,16 @@ void JsonFlowSerializer::encryptSensitiveProcessorProperties(rapidjson::Value& r
       continue;
     }
     const auto processor_overrides = overrides.contains(*processor_id) ? overrides.at(*processor_id) : core::flow::Overrides{};
-    encryptSensitiveProperties(getMember(processor_json, schema.processor_properties[0]), alloc, processor->getProperties(), encryption_provider,
+    encryptSensitiveProperties(getMember(processor_json, schema.processor_properties[0]), alloc, processor->getSupportedProperties(), encryption_provider,
         processor_overrides);
   }
 }
 
 void JsonFlowSerializer::encryptSensitiveControllerServiceProperties(rapidjson::Value& root_group, rapidjson::Document::AllocatorType& alloc, const core::ProcessGroup& process_group,
     const core::flow::FlowSchema& schema, const utils::crypto::EncryptionProvider& encryption_provider, const std::unordered_map<utils::Identifier, core::flow::Overrides>& overrides) const {
+  if (!root_group.HasMember(schema.controller_services[0])) {
+    return;
+  }
   auto controller_services = getMember(root_group, schema.controller_services[0]).GetArray();
   for (auto &controller_service_json : controller_services) {
     const std::string controller_service_id_str{getMember(controller_service_json, schema.identifier[0]).GetString(), getMember(controller_service_json, schema.identifier[0]).GetStringLength()};
@@ -144,23 +195,24 @@ void JsonFlowSerializer::encryptSensitiveControllerServiceProperties(rapidjson::
       continue;
     }
     const auto controller_service_overrides = overrides.contains(*controller_service_id) ? overrides.at(*controller_service_id) : core::flow::Overrides{};
-    encryptSensitiveProperties(getMember(controller_service_json, schema.controller_service_properties[0]), alloc, controller_service->getProperties(), encryption_provider,
+    encryptSensitiveProperties(getMember(controller_service_json, schema.controller_service_properties[0]), alloc, controller_service->getSupportedProperties(), encryption_provider,
         controller_service_overrides);
   }
 }
 
 std::string JsonFlowSerializer::serialize(const core::ProcessGroup& process_group, const core::flow::FlowSchema& schema, const utils::crypto::EncryptionProvider& encryption_provider,
-    const std::unordered_map<utils::Identifier, core::flow::Overrides>& overrides) const {
+    const std::unordered_map<utils::Identifier, core::flow::Overrides>& overrides, const std::unordered_map<std::string, gsl::not_null<std::unique_ptr<ParameterContext>>>& parameter_contexts) const {
   gsl_Expects(schema.root_group.size() == 1 && schema.identifier.size() == 1 &&
       schema.processors.size() == 1 && schema.processor_properties.size() == 1 &&
       schema.controller_services.size() == 1 && schema.controller_service_properties.size() == 1);
 
   rapidjson::Document doc;
-  auto alloc = doc.GetAllocator();
+  auto& alloc = doc.GetAllocator();
   rapidjson::Value flow_definition_json;
   flow_definition_json.CopyFrom(flow_definition_json_, alloc);
   auto& root_group = getMember(flow_definition_json, schema.root_group[0]);
 
+  addProviderCreatedParameterContexts(flow_definition_json, alloc, schema, parameter_contexts);
   encryptSensitiveParameters(flow_definition_json, alloc, schema, encryption_provider, overrides);
   encryptSensitiveProcessorProperties(root_group, alloc, process_group, schema, encryption_provider, overrides);
   encryptSensitiveControllerServiceProperties(root_group, alloc, process_group, schema, encryption_provider, overrides);
