@@ -21,6 +21,9 @@
 #include <array>
 
 #include "core/Resource.h"
+#include "utils/net/NetworkInterfaceInfo.h"
+#include "utils/OsUtils.h"
+#include "core/state/Value.h"
 
 namespace org::apache::nifi::minifi::state::response {
 
