@@ -21,6 +21,18 @@
 
 namespace org::apache::nifi::minifi::state::response {
 
+void RepositoryMetrics::addRepository(const std::shared_ptr<core::RepositoryMetricsSource> &repo) {
+  return repository_metrics_source_store_.addRepository(repo);
+}
+
+std::vector<SerializedResponseNode> RepositoryMetrics::serialize() {
+  return repository_metrics_source_store_.serialize();
+}
+
+std::vector<PublishedMetric> RepositoryMetrics::calculateMetrics() {
+  return repository_metrics_source_store_.calculateMetrics();
+}
+
 REGISTER_RESOURCE(RepositoryMetrics, DescriptionOnly);
 
 }  // namespace org::apache::nifi::minifi::state::response
