@@ -23,7 +23,64 @@
 
 namespace org::apache::nifi::minifi::core::yaml {
 
-void YamlFlowSerializer::encryptSensitiveProperties(YAML::Node property_yamls, const std::map<std::string, Property>& properties, const utils::crypto::EncryptionProvider& encryption_provider,
+void YamlFlowSerializer::addProviderCreatedParameterContexts(YAML::Node flow_definition_yaml, const core::flow::FlowSchema& schema,
+    const std::unordered_map<std::string, gsl::not_null<std::unique_ptr<ParameterContext>>>& parameter_contexts) {
+  std::vector<gsl::not_null<ParameterContext*>> provided_parameter_contexts;
+  for (const auto& [parameter_context_name, parameter_context] : parameter_contexts) {
+    if (!parameter_context->getParameterProvider().empty()) {
+      provided_parameter_contexts.push_back(gsl::make_not_null(parameter_context.get()));
+    }
+  }
+
+  if (provided_parameter_contexts.empty()) {
+    return;
+  }
+
+  auto parameter_contexts_node = flow_definition_yaml[schema.parameter_contexts[0]];
+
+  if (!parameter_contexts_node.IsDefined() || !parameter_contexts_node.IsSequence()) {
+    parameter_contexts_node = YAML::Node(YAML::NodeType::Sequence);
+  }
+
+  for (const auto& parameter_context : provided_parameter_contexts) {
+    YAML::Node parameter_context_node;
+    parameter_context_node[schema.identifier[0]] = std::string(parameter_context->getUUIDStr());
+    parameter_context_node[schema.name[0]] = parameter_context->getName();
+    parameter_context_node[schema.parameter_provider[0]] = parameter_context->getParameterProvider();
+
+    YAML::Node parameters_node = YAML::Node(YAML::NodeType::Sequence);
+    auto parameters = parameter_context->getParameters();
+    for (const auto& [name, parameter] : parameters) {
+      YAML::Node parameter_node;
+      parameter_node[schema.name[0]] = name;
+      parameter_node[schema.description[0]] = parameter.description;
+      parameter_node[schema.sensitive[0]] = parameter.sensitive;
+      parameter_node[schema.provided[0]] = parameter.provided;
+      parameter_node[schema.value[0]] = parameter.value;
+
+      parameters_node.push_back(parameter_node);
+    }
+
+    parameter_context_node[schema.parameters[0]] = parameters_node;
+
+    int64_t index = -1;
+    for (int64_t i = 0; i < gsl::narrow<int64_t>(parameter_contexts_node.size()); ++i) {
+      if (parameter_contexts_node[i][schema.name[0]].as<std::string>() == parameter_context->getName()) {
+        index = i;
+        break;
+      }
+    }
+    if (index != -1) {
+      parameter_contexts_node[index] = parameter_context_node;
+    } else {
+      parameter_contexts_node.push_back(parameter_context_node);
+    }
+  }
+}
+
+void YamlFlowSerializer::encryptSensitiveProperties(YAML::Node property_yamls,
+    const std::map<std::string, Property, std::less<>>& properties,
+    const utils::crypto::EncryptionProvider& encryption_provider,
     const core::flow::Overrides& overrides) const {
   std::unordered_set<std::string> processed_property_names;
 
@@ -99,7 +156,7 @@ void YamlFlowSerializer::encryptSensitiveProcessorProperties(YAML::Node& flow_de
       continue;
     }
     const auto processor_overrides = overrides.contains(*processor_id) ? overrides.at(*processor_id) : core::flow::Overrides{};
-    encryptSensitiveProperties(processor_yaml[schema.processor_properties[0]], processor->getProperties(), encryption_provider, processor_overrides);
+    encryptSensitiveProperties(processor_yaml[schema.processor_properties[0]], processor->getSupportedProperties(), encryption_provider, processor_overrides);
   }
 }
 
@@ -123,18 +180,20 @@ void YamlFlowSerializer::encryptSensitiveControllerServiceProperties(YAML::Node&
       continue;
     }
     const auto controller_service_overrides = overrides.contains(*controller_service_id) ? overrides.at(*controller_service_id) : core::flow::Overrides{};
-    encryptSensitiveProperties(controller_service_yaml[schema.controller_service_properties[0]], controller_service->getProperties(), encryption_provider, controller_service_overrides);
+    encryptSensitiveProperties(controller_service_yaml[schema.controller_service_properties[0]], controller_service->getSupportedProperties(), encryption_provider, controller_service_overrides);
   }
 }
 
 std::string YamlFlowSerializer::serialize(const core::ProcessGroup& process_group, const core::flow::FlowSchema& schema, const utils::crypto::EncryptionProvider& encryption_provider,
-    const std::unordered_map<utils::Identifier, core::flow::Overrides>& overrides) const {
+    const std::unordered_map<utils::Identifier, core::flow::Overrides>& overrides,
+    const std::unordered_map<std::string, gsl::not_null<std::unique_ptr<ParameterContext>>>& parameter_contexts) const {
   gsl_Expects(schema.identifier.size() == 1 &&
       schema.processors.size() == 1 && schema.processor_properties.size() == 1 &&
       schema.controller_services.size() == 1 && schema.controller_service_properties.size() == 1);
 
   auto flow_definition_yaml = YAML::Clone(flow_definition_yaml_);
 
+  addProviderCreatedParameterContexts(flow_definition_yaml, schema, parameter_contexts);
   encryptSensitiveParameters(flow_definition_yaml, schema, encryption_provider, overrides);
   encryptSensitiveProcessorProperties(flow_definition_yaml, process_group, schema, encryption_provider, overrides);
   encryptSensitiveControllerServiceProperties(flow_definition_yaml, process_group, schema, encryption_provider, overrides);
