@@ -29,13 +29,13 @@
 
 namespace org::apache::nifi::minifi {
 
-Properties::Properties(std::string name)
+PropertiesImpl::PropertiesImpl(std::string name)
     : logger_(core::logging::LoggerFactory<Properties>::getLogger()),
     name_(std::move(name)) {
 }
 
 // Get the config value
-bool Properties::getString(const std::string &key, std::string &value) const {
+bool PropertiesImpl::getString(const std::string &key, std::string &value) const {
   std::lock_guard<std::mutex> lock(mutex_);
   auto it = properties_.find(key);
 
@@ -47,14 +47,14 @@ bool Properties::getString(const std::string &key, std::string &value) const {
   }
 }
 
-std::optional<std::string> Properties::getString(const std::string& key) const {
+std::optional<std::string> PropertiesImpl::getString(const std::string& key) const {
   if (std::string result; getString(key, result)) {
     return result;
   }
   return std::nullopt;
 }
 
-int Properties::getInt(const std::string &key, int default_value) const {
+int PropertiesImpl::getInt(const std::string &key, int default_value) const {
   std::lock_guard<std::mutex> lock(mutex_);
   auto it = properties_.find(key);
 
@@ -63,7 +63,7 @@ int Properties::getInt(const std::string &key, int default_value) const {
 
 namespace {
 const core::PropertyValidator* getValidator(const std::string& lookup_value) {
-  auto configuration_property = Configuration::CONFIGURATION_PROPERTIES.find(lookup_value);
+  const auto configuration_property = Configuration::CONFIGURATION_PROPERTIES.find(lookup_value);
 
   if (configuration_property != Configuration::CONFIGURATION_PROPERTIES.end())
     return configuration_property->second;
@@ -81,7 +81,7 @@ bool allDigitsOrSpaces(const std::string& value) {
 }
 
 std::optional<std::string> ensureTimePeriodValidatedPropertyHasExplicitUnit(const core::PropertyValidator* const validator, const std::string& value) {
-  if (validator != &core::StandardPropertyTypes::TIME_PERIOD_TYPE) {
+  if (validator != &core::StandardPropertyValidators::TIME_PERIOD_VALIDATOR) {
     return std::nullopt;
   }
   if (value.empty() || !allDigits(value)) {
@@ -92,7 +92,7 @@ std::optional<std::string> ensureTimePeriodValidatedPropertyHasExplicitUnit(cons
 }
 
 std::optional<std::string> ensureDataSizeValidatedPropertyHasExplicitUnit(const core::PropertyValidator* const validator, const std::string& value) {
-  if (validator != &core::StandardPropertyTypes::DATA_SIZE_TYPE) {
+  if (validator != &core::StandardPropertyValidators::DATA_SIZE_VALIDATOR) {
     return std::nullopt;
   }
   if (value.empty() || !allDigits(value)) {
@@ -103,33 +103,8 @@ std::optional<std::string> ensureDataSizeValidatedPropertyHasExplicitUnit(const
 }
 
 bool integerValidatedProperty(const core::PropertyValidator* const validator) {
-  return validator == &core::StandardPropertyTypes::INTEGER_TYPE
-      || validator == &core::StandardPropertyTypes::UNSIGNED_INT_TYPE
-      || validator == &core::StandardPropertyTypes::LONG_TYPE
-      || validator == &core::StandardPropertyTypes::UNSIGNED_LONG_TYPE;
-}
-
-std::optional<int64_t> stringToDataSize(const std::string_view input) {
-  int64_t value = 0;
-  std::string unit_str;
-  if (!utils::string::splitToValueAndUnit(input, value, unit_str)) {
-    return std::nullopt;
-  }
-
-  if (const auto unit_multiplier = core::DataSizeValue::getUnitMultiplier(unit_str)) {
-    return value * *unit_multiplier;
-  }
-  return std::nullopt;
-}
-
-std::optional<int64_t> stringToDataTransferSpeed(std::string_view input) {
-  std::string data_size;
-  try {
-    data_size = core::DataTransferSpeedValue::removePerSecSuffix(std::string(input));
-  } catch (const utils::internal::ParseException&) {
-    return std::nullopt;
-  }
-  return stringToDataSize(data_size);
+  return validator == &core::StandardPropertyValidators::INTEGER_VALIDATOR
+      || validator == &core::StandardPropertyValidators::UNSIGNED_INTEGER_VALIDATOR;
 }
 
 std::optional<std::string> ensureIntegerValidatedPropertyHasNoUnit(const core::PropertyValidator* const validator, const std::string& value) {
@@ -145,17 +120,15 @@ std::optional<std::string> ensureIntegerValidatedPropertyHasNoUnit(const core::P
     return fmt::format("{}", parsed_time->count());
   }
 
-  if (auto parsed_data_size = stringToDataSize(value)) {
+  if (auto parsed_data_size = parsing::parseDataSize(value)) {
     return fmt::format("{}", *parsed_data_size);
   }
 
-  if (auto parsed_data_transfer_speed = stringToDataTransferSpeed(value)) {
-    return fmt::format("{}", *parsed_data_transfer_speed);
-  }
-
   return std::nullopt;
 }
 
+// If the loaded property is time period or data size validated, and it has no explicit units, then ms or B will be appended.
+// If the loaded property is integer validated, and it has some explicit unit (time period or data size), it will be converted to ms or B, and its unit is cut off.
 void fixValidatedProperty(const std::string& property_name,
     std::string& persisted_value,
     std::string& value,
@@ -186,24 +159,21 @@ void fixValidatedProperty(const std::string& property_name,
 }
 }  // namespace
 
-// Load Configure File
-// If the loaded property is time-period or data-size validated and it has no explicit units ms or B will be appended.
-// If the loaded property is integer validated and it has some explicit unit(time-period or data-size) it will be converted to ms/B and its unit cut off
-void Properties::loadConfigureFile(const std::filesystem::path& configuration_file, std::string_view prefix) {
+void PropertiesImpl::loadConfigureFile(const std::filesystem::path& configuration_file, std::string_view prefix) {
   std::lock_guard<std::mutex> lock(mutex_);
   if (configuration_file.empty()) {
     logger_->log_error("Configuration file path for {} is empty!", getName());
     return;
   }
 
-  if (!utils::file::exists(getHome() / configuration_file)) {
-    if (utils::file::create_dir((getHome() / configuration_file).parent_path()) == 0) {
-      std::ofstream file{getHome() / configuration_file};
+  if (!utils::file::exists(configuration_file)) {
+    if (utils::file::create_dir(configuration_file.parent_path()) == 0) {
+      std::ofstream file{configuration_file};
     }
   }
 
   std::error_code ec;
-  properties_file_ = std::filesystem::canonical(getHome() / configuration_file, ec);
+  properties_file_ = std::filesystem::canonical(configuration_file, ec);
 
   if (ec.value() != 0) {
     logger_->log_warn("Configuration file '{}' does not exist, and it could not be created", configuration_file);
@@ -232,12 +202,12 @@ void Properties::loadConfigureFile(const std::filesystem::path& configuration_fi
   checksum_calculator_.setFileLocation(properties_file_);
 }
 
-std::filesystem::path Properties::getFilePath() const {
+std::filesystem::path PropertiesImpl::getFilePath() const {
   std::lock_guard<std::mutex> lock(mutex_);
   return properties_file_;
 }
 
-bool Properties::commitChanges() {
+bool PropertiesImpl::commitChanges() {
   std::lock_guard<std::mutex> lock(mutex_);
   if (!dirty_) {
     logger_->log_info("Attempt to persist, but properties are not updated");
@@ -284,7 +254,7 @@ bool Properties::commitChanges() {
   return false;
 }
 
-std::map<std::string, std::string> Properties::getProperties() const {
+std::map<std::string, std::string> PropertiesImpl::getProperties() const {
   std::lock_guard<std::mutex> lock(mutex_);
   std::map<std::string, std::string> properties;
   for (const auto& prop : properties_) {
@@ -293,4 +263,8 @@ std::map<std::string, std::string> Properties::getProperties() const {
   return properties;
 }
 
+std::shared_ptr<Properties> Properties::create() {
+  return std::make_shared<PropertiesImpl>();
+}
+
 }  // namespace org::apache::nifi::minifi
