@@ -27,7 +27,7 @@ FileSystem::FileSystem(bool should_encrypt_on_write, std::optional<utils::crypto
       encryptor_(std::move(encryptor)) {
   if (should_encrypt_on_write_ && !encryptor_) {
     std::string err_message = "Requested file encryption but no encryption utility was provided";
-    logger_->log_error(err_message.c_str());
+    logger_->log_error("{}", err_message);
     throw std::invalid_argument(err_message);
   }
 }
@@ -41,11 +41,11 @@ std::optional<std::string> FileSystem::read(const std::filesystem::path& file_na
   std::string content{std::istreambuf_iterator<char>(input), {}};
   if (encryptor_) {
     try {
-      logger_->log_debug("Trying to decrypt file %s", file_name.string());
+      logger_->log_debug("Trying to decrypt file {}", file_name);
       content = encryptor_->decrypt(content);
     } catch(...) {
       // tried to decrypt file but failed, use file as-is
-      logger_->log_debug("Decrypting file %s failed, using the file as-is", file_name.string());
+      logger_->log_debug("Decrypting file {} failed, using the file as-is", file_name);
     }
   }
   return content;
@@ -57,10 +57,10 @@ bool FileSystem::write(const std::filesystem::path& file_name, const std::string
     // allow a possible exception to propagate upward
     // if we fail to encrypt the file DON'T just write
     // it as-is
-    logger_->log_debug("Encrypting file %s", file_name.string());
+    logger_->log_debug("Encrypting file {}", file_name);
     output << encryptor_->encrypt(file_content);
   } else {
-    logger_->log_debug("No encryption is required for file %s", file_name.string());
+    logger_->log_debug("No encryption is required for file {}", file_name);
     output << file_content;
   }
   output.close();
