@@ -36,11 +36,12 @@ struct HookCollection {
 
 class StatefulIntegrationTest : public IntegrationBase {
  public:
-  explicit StatefulIntegrationTest(std::string testCase, HookCollection hookCollection)
-    : on_schedule_hook_(std::move(hookCollection.on_schedule_hook_))
-    , on_trigger_hooks_(std::move(hookCollection.on_trigger_hooks_))
-    , log_checker_(hookCollection.log_checker_)
-    , test_case_(std::move(testCase)) {
+  StatefulIntegrationTest(const std::filesystem::path& test_file_path, std::string testCase, HookCollection hookCollection)
+    : IntegrationBase(test_file_path),
+      on_schedule_hook_(std::move(hookCollection.on_schedule_hook_)),
+      on_trigger_hooks_(std::move(hookCollection.on_trigger_hooks_)),
+      log_checker_(hookCollection.log_checker_),
+      test_case_(std::move(testCase)) {
   }
 
   void testSetup() override {
@@ -69,9 +70,9 @@ class StatefulIntegrationTest : public IntegrationBase {
         // set hooks
         const auto processController = dynamic_cast<ProcessorController*>(&component);
         REQUIRE(processController != nullptr);
-        stateful_processor_ = dynamic_cast<StatefulProcessor*>(&processController->getProcessor());
+        stateful_processor_ = &processController->getProcessor();
         REQUIRE(stateful_processor_);
-        stateful_processor_->setHooks(on_schedule_hook_, on_trigger_hooks_);
+        stateful_processor_.get().setHooks(on_schedule_hook_, on_trigger_hooks_);
       }
 
       ++controllerVecIdx;
@@ -83,7 +84,7 @@ class StatefulIntegrationTest : public IntegrationBase {
 
   void runAssertions() override {
     REQUIRE(utils::verifyEventHappenedInPollTime(std::chrono::milliseconds(wait_time_), [&] {
-      return stateful_processor_->hasFinishedHooks() && log_checker_();
+      return stateful_processor_.get().hasFinishedHooks() && log_checker_();
     }));
   }
 
@@ -92,7 +93,7 @@ class StatefulIntegrationTest : public IntegrationBase {
   const std::vector<StatefulProcessor::HookType> on_trigger_hooks_;
   const LogChecker log_checker_;
   const std::string test_case_;
-  StatefulProcessor* stateful_processor_ = nullptr;
+  TypedProcessorWrapper<StatefulProcessor> stateful_processor_ = nullptr;
   std::shared_ptr<logging::Logger> logger_{logging::LoggerFactory<StatefulIntegrationTest>::getLogger()};
 };
 
@@ -584,9 +585,8 @@ const std::unordered_map<std::string, HookCollection> testCasesToHookLists {
 
 TEST_CASE("Test state transactionality", "[statemanagement]") {
   for (const auto& test : testCasesToHookLists) {
-    StatefulIntegrationTest statefulIntegrationTest(test.first, test.second);
-    const auto test_file_location = std::filesystem::path(TEST_RESOURCES) / "TestStateTransactionality.yml";
-    statefulIntegrationTest.run(test_file_location);
+    StatefulIntegrationTest statefulIntegrationTest(std::filesystem::path(TEST_RESOURCES) / "TestStateTransactionality.yml", test.first, test.second);
+    statefulIntegrationTest.run();
   }
 }
 
