@@ -102,10 +102,10 @@ bool LogTestController::contains(const std::string& ending, std::chrono::millise
 }
 
 bool LogTestController::contains(const std::function<std::string()>& log_string_getter, const std::string& ending, std::chrono::milliseconds timeout, std::chrono::milliseconds sleep_interval) {
-  if (ending.length() == 0) {
+  if (ending.empty()) {
     return false;
   }
-  auto start = std::chrono::steady_clock::now();
+  const auto start = std::chrono::steady_clock::now();
   bool found = false;
   bool timed_out = false;
   do {
@@ -122,7 +122,7 @@ bool LogTestController::contains(const std::function<std::string()>& log_string_
 }
 
 std::optional<std::smatch> LogTestController::matchesRegex(const std::string& regex_str, std::chrono::milliseconds timeout, std::chrono::milliseconds sleep_interval) const {
-  if (regex_str.length() == 0) {
+  if (regex_str.empty()) {
     return std::nullopt;
   }
   auto start = std::chrono::steady_clock::now();
@@ -155,7 +155,7 @@ void LogTestController::reset() {
   modified_loggers.clear();
   if (config)
     config = logging::LoggerConfiguration::newInstance();
-  my_properties_ = std::make_shared<logging::LoggerProperties>();
+  my_properties_ = std::make_shared<logging::LoggerProperties>("");
   clear();
   init(nullptr);
 }
@@ -176,7 +176,7 @@ void LogTestController::init(const std::shared_ptr<logging::LoggerProperties>& l
   my_properties_ = logger_props;
   bool initMain = false;
   if (nullptr == my_properties_) {
-    my_properties_ = std::make_shared<logging::LoggerProperties>();
+    my_properties_ = std::make_shared<logging::LoggerProperties>("");
     initMain = true;
   }
   my_properties_->set("logger.root", "ERROR,ostream");
@@ -225,7 +225,7 @@ TestPlan::TestPlan(std::shared_ptr<minifi::core::ContentRepository> content_repo
   if (!configuration_->get(minifi::Configure::nifi_state_storage_local_path)) {
     configuration_->set(minifi::Configure::nifi_state_storage_local_path, state_dir_->getPath().string());
   }
-  state_storage_ = minifi::core::ProcessContext::getOrCreateDefaultStateStorage(controller_services_provider_.get(), configuration_);
+  state_storage_ = minifi::core::ProcessContextImpl::getOrCreateDefaultStateStorage(controller_services_provider_.get(), configuration_);
 }
 
 TestPlan::~TestPlan() {
@@ -264,7 +264,7 @@ minifi::core::Processor* TestPlan::addProcessor(std::unique_ptr<minifi::core::Pr
     }
     std::stringstream connection_name;
     connection_name << last->getUUIDStr() << "-to-" << processor->getUUIDStr();
-    auto connection = std::make_unique<minifi::Connection>(flow_repo_, content_repo_, connection_name.str());
+    auto connection = std::make_unique<minifi::ConnectionImpl>(flow_repo_, content_repo_, connection_name.str());
     logger_->log_info("Creating {} connection for proc {}", connection_name.str(), processor_queue_.size() + 1);
 
     for (const auto& relationship : relationships) {
@@ -282,13 +282,11 @@ minifi::core::Processor* TestPlan::addProcessor(std::unique_ptr<minifi::core::Pr
     }
     relationships_.push_back(std::move(connection));
   }
-  std::shared_ptr<minifi::core::ProcessorNode> node = std::make_shared<minifi::core::ProcessorNode>(processor.get());
-  processor_nodes_.push_back(node);
   std::shared_ptr<minifi::core::ProcessContextBuilder> contextBuilder =
     minifi::core::ClassLoader::getDefaultClassLoader().instantiate<minifi::core::ProcessContextBuilder>("ProcessContextBuilder", "ProcessContextBuilder");
   contextBuilder = contextBuilder->withContentRepository(content_repo_)->withFlowFileRepository(flow_repo_)->withProvider(controller_services_provider_.get())
     ->withProvenanceRepository(prov_repo_)->withConfiguration(configuration_);
-  auto context = contextBuilder->build(node);
+  auto context = contextBuilder->build(*processor);
   processor_contexts_.push_back(context);
   processor_queue_.push_back(processor.get());
   auto raw_ptr = processor.get();
@@ -333,7 +331,7 @@ minifi::Connection* TestPlan::addConnection(minifi::core::Processor* source_proc
     << (source_proc ? source_proc->getUUIDStr().c_str() : "none")
     << "-to-"
     << (destination_proc ? destination_proc->getUUIDStr().c_str() : "none");
-  auto connection = std::make_unique<minifi::Connection>(flow_repo_, content_repo_, connection_name.str());
+  auto connection = std::make_unique<minifi::ConnectionImpl>(flow_repo_, content_repo_, connection_name.str());
 
   connection->addRelationship(source_relationship);
 
@@ -368,7 +366,7 @@ std::shared_ptr<minifi::core::controller::ControllerServiceNode> TestPlan::addCo
   minifi::utils::Identifier uuid = minifi::utils::IdGenerator::getIdGenerator()->generate();
 
   std::shared_ptr<minifi::core::controller::ControllerServiceNode> controller_service_node =
-      controller_services_provider_->createControllerService(controller_name, controller_name, name, true /*firstTimeAdded*/);
+      controller_services_provider_->createControllerService(controller_name, name);
   if (controller_service_node == nullptr) {
     return nullptr;
   }
@@ -403,9 +401,9 @@ bool TestPlan::setProperty(minifi::core::Processor* processor, const std::string
   }
 
   if (dynamic) {
-    return processor_contexts_.at(i)->setDynamicProperty(property, value);
+    return processor_contexts_.at(i)->setDynamicProperty(property, value).has_value();
   } else {
-    return processor_contexts_.at(i)->setProperty(property, value);
+    return processor_contexts_.at(i)->setProperty(property, value).has_value();
   }
 }
 
@@ -421,25 +419,31 @@ bool TestPlan::setDynamicProperty(minifi::core::Processor* processor, std::strin
   return setProperty(processor, std::string(property), std::string(value), true);
 }
 
-bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, const std::string& property, const std::string& value, bool dynamic) {
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, const std::string& property, const std::string& value, bool dynamic) const {
   if (dynamic) {
-    controller_service_node->setDynamicProperty(property, value);
-    return controller_service_node->getControllerServiceImplementation()->setDynamicProperty(property, value);
+    auto result = controller_service_node->setDynamicProperty(property, value);
+    if (!result.has_value()) {
+      logger_->log_debug("Failed to set dynamic property {} directly to {} for controller service {}", property, value, controller_service_node->getName());
+    }
+    return controller_service_node->getControllerServiceImplementation()->setDynamicProperty(property, value).has_value();
   } else {
-    controller_service_node->setProperty(property, value);
-    return controller_service_node->getControllerServiceImplementation()->setProperty(property, value);
+    auto result = controller_service_node->setProperty(property, value);
+    if (!result.has_value()) {
+      logger_->log_debug("Failed to set property {} directly to {} for controller service {}", property, value, controller_service_node->getName());
+    }
+    return  controller_service_node->getControllerServiceImplementation()->setProperty(property, value).has_value();
   }
 }
 
-bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, const core::PropertyReference& property, std::string_view value) {
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, const core::PropertyReference& property, std::string_view value) const {
   return setProperty(controller_service_node, std::string(property.name), std::string(value), false);
 }
 
-bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, std::string_view property, std::string_view value) {
+bool TestPlan::setProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, std::string_view property, std::string_view value) const {
   return setProperty(controller_service_node, std::string(property), std::string(value), false);
 }
 
-bool TestPlan::setDynamicProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, std::string_view property, std::string_view value) {
+bool TestPlan::setDynamicProperty(const std::shared_ptr<minifi::core::controller::ControllerServiceNode>& controller_service_node, std::string_view property, std::string_view value) const {
   return setProperty(controller_service_node, std::string(property), std::string(value), true);
 }
 
@@ -472,7 +476,7 @@ std::vector<minifi::core::Processor*>::iterator TestPlan::getProcessorItByUuid(c
 
 std::shared_ptr<minifi::core::ProcessContext> TestPlan::getProcessContextForProcessor(minifi::core::Processor* processor) {
   const auto contextMatchesProcessor = [&processor] (const std::shared_ptr<minifi::core::ProcessContext>& context) {
-    return context->getProcessorNode()->getUUIDStr() ==  processor->getUUIDStr();
+    return context->getProcessorInfo().getUUID().to_string() ==  processor->getUUIDStr();
   };
   const auto context_found_at = std::find_if(processor_contexts_.begin(), processor_contexts_.end(), contextMatchesProcessor);
   if (context_found_at == processor_contexts_.end()) {
@@ -484,7 +488,7 @@ std::shared_ptr<minifi::core::ProcessContext> TestPlan::getProcessContextForProc
 void TestPlan::scheduleProcessor(minifi::core::Processor* processor, const std::shared_ptr<minifi::core::ProcessContext>& context) {
   if (std::find(configured_processors_.begin(), configured_processors_.end(), processor) == configured_processors_.end()) {
     // Ordering on factories and list of configured processors do not matter
-    const auto factory = std::make_shared<minifi::core::ProcessSessionFactory>(context);
+    const auto factory = std::make_shared<minifi::core::ProcessSessionFactoryImpl>(context);
     factories_.push_back(factory);
     processor->onSchedule(*context, *factory);
     configured_processors_.push_back(processor);
@@ -508,14 +512,14 @@ bool TestPlan::runProcessor(minifi::core::Processor* processor, const PreTrigger
   return runProcessor(processor_location, verify);
 }
 
-class TestSessionFactory : public minifi::core::ProcessSessionFactory {
+class TestSessionFactory : public minifi::core::ProcessSessionFactoryImpl {
   using SessionCallback = std::function<void(const std::shared_ptr<minifi::core::ProcessSession>&)>;
  public:
   TestSessionFactory(std::shared_ptr<minifi::core::ProcessContext> context, SessionCallback on_new_session)
-    : ProcessSessionFactory(std::move(context)), on_new_session_(std::move(on_new_session)) {}
+    : ProcessSessionFactoryImpl(std::move(context)), on_new_session_(std::move(on_new_session)) {}
 
   std::shared_ptr<minifi::core::ProcessSession> createSession() override {
-    auto session = ProcessSessionFactory::createSession();
+    auto session = ProcessSessionFactoryImpl::createSession();
     on_new_session_(session);
     return session;
   }
@@ -538,13 +542,13 @@ bool TestPlan::runProcessor(size_t target_location, const PreTriggerVerifier& ve
   processor->setScheduledState(minifi::core::ScheduledState::RUNNING);
 
   if (verify) {
-    auto current_session = std::make_shared<minifi::core::ProcessSession>(context);
+    auto current_session = std::make_shared<minifi::core::ProcessSessionImpl>(context);
     current_session->setMetrics(processor->getMetrics());
     process_sessions_.push_back(current_session);
     verify(context, current_session);
     current_session->commit();
   } else {
-    auto session_factory = std::make_shared<TestSessionFactory>(context, [&] (auto current_session) {
+    const auto session_factory = std::make_shared<TestSessionFactory>(context, [&] (const auto& current_session) {
       current_session->setMetrics(processor->getMetrics());
       process_sessions_.push_back(current_session);
     });
@@ -644,7 +648,7 @@ std::unique_ptr<minifi::Connection> TestPlan::buildFinalConnection(minifi::core:
   gsl_Expects(termination_);
   std::stringstream connection_name;
   connection_name << processor->getUUIDStr() << "-to-" << processor->getUUIDStr();
-  auto connection = std::make_unique<minifi::Connection>(flow_repo_, content_repo_, connection_name.str());
+  auto connection = std::make_unique<minifi::ConnectionImpl>(flow_repo_, content_repo_, connection_name.str());
   connection->addRelationship(termination_.value());
 
   // link the connections so that we can test results at the end for this
@@ -706,14 +710,13 @@ TestController::TestController()
     : log(LogTestController::getInstance()) {
   minifi::setDefaultDirectory("./");
   log.reset();
-  minifi::utils::IdGenerator::getIdGenerator()->initialize(std::make_shared<minifi::Properties>());
+  minifi::utils::IdGenerator::getIdGenerator()->initialize(minifi::Properties::create());
   flow_version_ = std::make_shared<minifi::state::response::FlowVersion>("test", "test", "test");
 }
 
 std::shared_ptr<TestPlan> TestController::createPlan(PlanConfig config) {
   if (!config.configuration) {
-    config.configuration = std::make_shared<minifi::Configure>();
-    config.configuration->setHome(createTempDirectory());
+    config.configuration = minifi::Configure::create();
     config.configuration->set(minifi::Configure::nifi_state_storage_local_class_name, "VolatileMapStateStorage");
     config.configuration->set(minifi::Configure::nifi_dbcontent_repository_directory_default, createTempDirectory().string());
   }
