@@ -35,7 +35,10 @@
 #include "core/repository/VolatileFlowFileRepository.h"
 #include "../../extensions/rocksdb-repos/DatabaseContentRepository.h"
 #include "unit/TestUtils.h"
+#include "core/repository/FileSystemRepository.h"
+#include "core/ProcessorImpl.h"
 
+using ConnectionImpl = minifi::ConnectionImpl;
 using Connection = minifi::Connection;
 using MergeContent = minifi::processors::MergeContent;
 
@@ -43,9 +46,9 @@ using minifi::test::utils::verifyEventHappenedInPollTime;
 
 namespace {
 
-class TestProcessor : public minifi::core::Processor {
+class TestProcessor : public minifi::core::ProcessorImpl {
  public:
-  using Processor::Processor;
+  using ProcessorImpl::ProcessorImpl;
 
   static constexpr bool SupportsDynamicProperties = false;
   static constexpr bool SupportsDynamicRelationships = false;
@@ -62,20 +65,18 @@ struct TestFlow{
     auto processor = processorGenerator(mainProcUUID());
     {
       processor_ = processor.get();
-      auto node = std::make_shared<core::ProcessorNode>(processor_);
-      processorContext = std::make_shared<core::ProcessContext>(node, nullptr, prov_repo, ff_repository, content_repo);
+      processorContext = std::make_shared<core::ProcessContextImpl>(*processor_, nullptr, prov_repo, ff_repository, content_repo);
     }
 
     // setup INPUT processor
     {
-      inputProcessor = std::make_shared<TestProcessor>("source", inputProcUUID());
-      auto node = std::make_shared<core::ProcessorNode>(inputProcessor.get());
-      inputContext = std::make_shared<core::ProcessContext>(node, nullptr, prov_repo,
+      inputProcessor = minifi::test::utils::make_processor<TestProcessor>("source", inputProcUUID());
+      inputContext = std::make_shared<core::ProcessContextImpl>(*inputProcessor, nullptr, prov_repo,
                                                             ff_repository, content_repo);
     }
 
     // setup Input Connection
-    auto input = std::make_unique<Connection>(ff_repository, content_repo, "Input", inputConnUUID());
+    auto input = std::make_unique<ConnectionImpl>(ff_repository, content_repo, "Input", inputConnUUID());
     {
       input_ = input.get();
       input->addRelationship({"input", "d"});
@@ -85,7 +86,7 @@ struct TestFlow{
     }
 
     // setup Output Connection
-    auto output = std::make_unique<Connection>(ff_repository, content_repo, "Output", outputConnUUID());
+    auto output = std::make_unique<ConnectionImpl>(ff_repository, content_repo, "Output", outputConnUUID());
     {
       output_ = output.get();
       output->addRelationship(relationshipToOutput);
@@ -102,12 +103,12 @@ struct TestFlow{
 
     // prepare Merge Processor for execution
     processor_->setScheduledState(core::ScheduledState::RUNNING);
-    process_session_factory_ = std::make_unique<core::ProcessSessionFactory>(processorContext);
+    process_session_factory_ = std::make_unique<core::ProcessSessionFactoryImpl>(processorContext);
     processor_->onSchedule(*processorContext, *process_session_factory_);
   }
   std::shared_ptr<core::FlowFile> write(const std::string& data) {
     minifi::io::BufferStream stream(data);
-    core::ProcessSession sessionGenFlowFile(inputContext);
+    core::ProcessSessionImpl sessionGenFlowFile(inputContext);
     std::shared_ptr<core::FlowFile> flow = std::static_pointer_cast<core::FlowFile>(sessionGenFlowFile.create());
     sessionGenFlowFile.importFrom(stream, flow);
     REQUIRE(flow->getResourceClaim()->getFlowFileRecordOwnedCount() == 1);
@@ -116,10 +117,10 @@ struct TestFlow{
     return flow;
   }
   std::string read(const std::shared_ptr<core::FlowFile>& file) {
-    return to_string(core::ProcessSession{processorContext}.readBuffer(file));
+    return to_string(core::ProcessSessionImpl{processorContext}.readBuffer(file));
   }
   void trigger() {
-    auto session = std::make_shared<core::ProcessSession>(processorContext);
+    auto session = std::make_shared<core::ProcessSessionImpl>(processorContext);
     processor_->onTrigger(*processorContext, *session);
     session->commit();
   }
@@ -144,19 +145,19 @@ struct TestFlow{
   std::unique_ptr<core::ProcessSessionFactory> process_session_factory_;
 };
 
-std::unique_ptr<MergeContent> setupMergeProcessor(const utils::Identifier& id) {
-  auto processor = std::make_unique<MergeContent>("MergeContent", id);
+std::unique_ptr<core::Processor> setupMergeProcessor(const utils::Identifier& id) {
+  auto processor = minifi::test::utils::make_processor<MergeContent>("MergeContent", id);
   processor->initialize();
   processor->setAutoTerminatedRelationships(std::array{core::Relationship{"original", "d"}});
 
-  processor->setProperty(MergeContent::MergeFormat, org::apache::nifi::minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
-  processor->setProperty(MergeContent::MergeStrategy, org::apache::nifi::minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
-  processor->setProperty(MergeContent::DelimiterStrategy, org::apache::nifi::minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
-  processor->setProperty(MergeContent::MinEntries, "3");
-  processor->setProperty(MergeContent::Header, "_Header_");
-  processor->setProperty(MergeContent::Footer, "_Footer_");
-  processor->setProperty(MergeContent::Demarcator, "_Demarcator_");
-  processor->setProperty(MergeContent::MaxBinAge, "1 h");
+  REQUIRE(processor->setProperty(MergeContent::MergeFormat.name, std::string{org::apache::nifi::minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE}));
+  REQUIRE(processor->setProperty(MergeContent::MergeStrategy.name, std::string{org::apache::nifi::minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK}));
+  REQUIRE(processor->setProperty(MergeContent::DelimiterStrategy.name, std::string{org::apache::nifi::minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT}));
+  REQUIRE(processor->setProperty(MergeContent::MinEntries.name, "3"));
+  REQUIRE(processor->setProperty(MergeContent::Header.name, "_Header_"));
+  REQUIRE(processor->setProperty(MergeContent::Footer.name, "_Footer_"));
+  REQUIRE(processor->setProperty(MergeContent::Demarcator.name, "_Demarcator_"));
+  REQUIRE(processor->setProperty(MergeContent::MaxBinAge.name, "1 h"));
 
   return processor;
 }
@@ -171,8 +172,7 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
 
   auto dir = testController.createTempDirectory();
 
-  auto config = std::make_shared<minifi::Configure>();
-  config->setHome(dir);
+  auto config = std::make_shared<minifi::ConfigureImpl>();
   config->set(minifi::Configure::nifi_dbcontent_repository_directory_default, (dir / "content_repository").string());
   config->set(minifi::Configure::nifi_flowfile_repository_directory_default, (dir / "flowfile_repository").string());
 
@@ -250,9 +250,9 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
   }
 }
 
-class ContentUpdaterProcessor : public core::Processor {
+class ContentUpdaterProcessor : public core::ProcessorImpl {
  public:
-  ContentUpdaterProcessor(std::string_view name, const utils::Identifier& id) : Processor(name, id) {}
+  using ProcessorImpl::ProcessorImpl;
 
   static constexpr bool SupportsDynamicProperties = false;
   static constexpr bool SupportsDynamicRelationships = false;
@@ -270,7 +270,7 @@ class ContentUpdaterProcessor : public core::Processor {
 };
 
 std::unique_ptr<core::Processor> setupContentUpdaterProcessor(const utils::Identifier& id) {
-  return std::make_unique<ContentUpdaterProcessor>("Updater", id);
+  return minifi::test::utils::make_processor<ContentUpdaterProcessor>("Updater", id);
 }
 
 TEST_CASE("Persisted flowFiles are updated on modification", "[TestP1]") {
@@ -285,8 +285,7 @@ TEST_CASE("Persisted flowFiles are updated on modification", "[TestP1]") {
 
   auto dir = testController.createTempDirectory();
 
-  auto config = std::make_shared<minifi::Configure>();
-  config->setHome(dir);
+  auto config = std::make_shared<minifi::ConfigureImpl>();
   config->set(minifi::Configure::nifi_dbcontent_repository_directory_default, (dir / "content_repository").string());
   config->set(minifi::Configure::nifi_flowfile_repository_directory_default, (dir / "flowfile_repository").string());
   config->set(minifi::Configure::nifi_dbcontent_repository_purge_period, "0 s");
