@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-#include "../TestBase.h"
-#include "../Catch.h"
-#include "utils/TestUtils.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
+#include "unit/TestUtils.h"
 #include "core/state/nodes/ConfigurationChecksums.h"
 #include "utils/ChecksumCalculator.h"
 
@@ -36,7 +36,7 @@ TEST_CASE("If no checksum calculators are added, we get an empty node", "[Config
 TEST_CASE("If one checksum calculator is added, we get a node with one child", "[ConfigurationChecksums]") {
   TestController test_controller;
   auto test_dir = test_controller.createTempDirectory();
-  auto file_location = utils::putFileToDir(test_dir, "simple.txt", "one line of text\n");
+  auto file_location = minifi::test::utils::putFileToDir(test_dir, "simple.txt", "one line of text\n");
 
   utils::ChecksumCalculator checksum_calculator;
   checksum_calculator.setFileLocation(file_location);
@@ -58,8 +58,8 @@ TEST_CASE("If one checksum calculator is added, we get a node with one child", "
 TEST_CASE("If two checksum calculators are added, we get a node with two children", "[ConfigurationChecksums]") {
   TestController test_controller;
   auto test_dir = test_controller.createTempDirectory();
-  auto file_location_1 = utils::putFileToDir(test_dir, "first.txt", "this is the first file\n");
-  auto file_location_2 = utils::putFileToDir(test_dir, "second.txt", "this is the second file\n");
+  auto file_location_1 = minifi::test::utils::putFileToDir(test_dir, "first.txt", "this is the first file\n");
+  auto file_location_2 = minifi::test::utils::putFileToDir(test_dir, "second.txt", "this is the second file\n");
 
   utils::ChecksumCalculator checksum_calculator_1;
   checksum_calculator_1.setFileLocation(file_location_1);
