@@ -23,14 +23,14 @@
 TEST_CASE("Connection::poll() works correctly", "[poll]") {
   const auto flow_repo = std::make_shared<TestRepository>();
   const auto content_repo = std::make_shared<core::repository::VolatileContentRepository>();
-  content_repo->initialize(std::make_shared<minifi::Configure>());
+  content_repo->initialize(std::make_shared<minifi::ConfigureImpl>());
 
   const auto id_generator = utils::IdGenerator::getIdGenerator();
   utils::Identifier connection_id = id_generator->generate();
   utils::Identifier src_id = id_generator->generate();
   utils::Identifier dest_id = id_generator->generate();
 
-  const auto connection = std::make_shared<minifi::Connection>(flow_repo, content_repo, "test_connection", connection_id, src_id, dest_id);
+  const auto connection = std::make_shared<minifi::ConnectionImpl>(flow_repo, content_repo, "test_connection", connection_id, src_id, dest_id);
   std::set<std::shared_ptr<core::FlowFile>> expired_flow_files;
 
   SECTION("when called on an empty Connection, poll() returns nullptr") {
@@ -44,7 +44,7 @@ TEST_CASE("Connection::poll() works correctly", "[poll]") {
     SECTION("without expiration duration") {}
     SECTION("with expiration duration") { connection->setFlowExpirationDuration(1s); }
 
-    const auto flow_file = std::make_shared<core::FlowFile>();
+    const auto flow_file = std::make_shared<core::FlowFileImpl>();
     connection->put(flow_file);
     REQUIRE(flow_file == connection->poll(expired_flow_files));
     REQUIRE(nullptr == connection->poll(expired_flow_files));
@@ -54,14 +54,14 @@ TEST_CASE("Connection::poll() works correctly", "[poll]") {
     SECTION("without expiration duration") {}
     SECTION("with expiration duration") { connection->setFlowExpirationDuration(1s); }
 
-    const auto flow_file = std::make_shared<core::FlowFile>();
+    const auto flow_file = std::make_shared<core::FlowFileImpl>();
     flow_file->penalize(std::chrono::seconds{10});
     connection->put(flow_file);
     REQUIRE(nullptr == connection->poll(expired_flow_files));
   }
 
   SECTION("when called on a connection with a single expired flow file, poll() returns nullptr and returns the expired flow file in the out parameter") {
-    const auto flow_file = std::make_shared<core::FlowFile>();
+    const auto flow_file = std::make_shared<core::FlowFileImpl>();
     connection->setFlowExpirationDuration(1ms);
     connection->put(flow_file);
     std::this_thread::sleep_for(std::chrono::milliseconds{2});
@@ -73,11 +73,11 @@ TEST_CASE("Connection::poll() works correctly", "[poll]") {
     SECTION("without expiration duration") {}
     SECTION("with expiration duration") { connection->setFlowExpirationDuration(1s); }
 
-    const auto penalized_flow_file = std::make_shared<core::FlowFile>();
+    const auto penalized_flow_file = std::make_shared<core::FlowFileImpl>();
     penalized_flow_file->penalize(std::chrono::seconds{10});
     connection->put(penalized_flow_file);
 
-    const auto flow_file = std::make_shared<core::FlowFile>();
+    const auto flow_file = std::make_shared<core::FlowFileImpl>();
     connection->put(flow_file);
 
     REQUIRE(flow_file == connection->poll(expired_flow_files));
@@ -88,10 +88,10 @@ TEST_CASE("Connection::poll() works correctly", "[poll]") {
 TEST_CASE("Connection backpressure tests", "[Connection]") {
   const auto flow_repo = std::make_shared<TestRepository>();
   const auto content_repo = std::make_shared<core::repository::VolatileContentRepository>();
-  content_repo->initialize(std::make_shared<minifi::Configure>());
+  content_repo->initialize(std::make_shared<minifi::ConfigureImpl>());
 
   const auto id_generator = utils::IdGenerator::getIdGenerator();
-  const auto connection = std::make_shared<minifi::Connection>(flow_repo, content_repo, "test_connection", id_generator->generate(), id_generator->generate(), id_generator->generate());
+  const auto connection = std::make_shared<minifi::ConnectionImpl>(flow_repo, content_repo, "test_connection", id_generator->generate(), id_generator->generate(), id_generator->generate());
 
   CHECK(connection->getBackpressureThresholdDataSize() == minifi::Connection::DEFAULT_BACKPRESSURE_THRESHOLD_DATA_SIZE);
   CHECK(connection->getBackpressureThresholdCount() == minifi::Connection::DEFAULT_BACKPRESSURE_THRESHOLD_COUNT);
@@ -99,9 +99,9 @@ TEST_CASE("Connection backpressure tests", "[Connection]") {
   SECTION("The number of flowfiles can be limited") {
     connection->setBackpressureThresholdCount(2);
     CHECK_FALSE(connection->backpressureThresholdReached());
-    connection->put(std::make_shared<core::FlowFile>());
+    connection->put(std::make_shared<core::FlowFileImpl>());
     CHECK_FALSE(connection->backpressureThresholdReached());
-    connection->put(std::make_shared<core::FlowFile>());
+    connection->put(std::make_shared<core::FlowFileImpl>());
     CHECK(connection->backpressureThresholdReached());
     connection->setBackpressureThresholdCount(0);
     CHECK_FALSE(connection->backpressureThresholdReached());
@@ -110,13 +110,13 @@ TEST_CASE("Connection backpressure tests", "[Connection]") {
     connection->setBackpressureThresholdDataSize(3_KB);
     CHECK_FALSE(connection->backpressureThresholdReached());
     {
-      auto flow_file = std::make_shared<core::FlowFile>();
+      auto flow_file = std::make_shared<core::FlowFileImpl>();
       flow_file->setSize(2_KB);
       connection->put(flow_file);
     }
     CHECK_FALSE(connection->backpressureThresholdReached());
     {
-      auto flow_file = std::make_shared<core::FlowFile>();
+      auto flow_file = std::make_shared<core::FlowFileImpl>();
       flow_file->setSize(2_KB);
       connection->put(flow_file);
     }
