@@ -17,14 +17,17 @@
  */
 
 #include <string>
-#include "core/ConfigurableComponent.h"
+#include "core/ConfigurableComponentImpl.h"
+#include "utils/PropertyErrors.h"
 #include "unit/TestBase.h"
 #include "unit/Catch.h"
 
 namespace org::apache::nifi::minifi::core {
 
-class TestConfigurableComponentSupportsDynamic : public ConfigurableComponent {
+class TestConfigurableComponentSupportsDynamic : public ConfigurableComponentImpl, public CoreComponentImpl {
  public:
+  TestConfigurableComponentSupportsDynamic() : ConfigurableComponentImpl(), CoreComponentImpl("TestConfigurableComponentSupportsDynamic") {}
+
   bool supportsDynamicProperties() const override {
     return true;
   }
@@ -38,8 +41,9 @@ class TestConfigurableComponentSupportsDynamic : public ConfigurableComponent {
   }
 };
 
-class TestConfigurableComponentNotSupportsDynamic : public ConfigurableComponent {
+class TestConfigurableComponentNotSupportsDynamic : public ConfigurableComponentImpl, public CoreComponentImpl {
  public:
+  TestConfigurableComponentNotSupportsDynamic() : ConfigurableComponentImpl(), CoreComponentImpl("TestConfigurableComponentNotSupportsDynamic") {}
   bool supportsDynamicProperties() const override {
     return false;
   }
@@ -55,34 +59,28 @@ class TestConfigurableComponentNotSupportsDynamic : public ConfigurableComponent
 
 TEST_CASE("Test Set Dynamic Property", "[testSetDynamicProperty]") {
   TestConfigurableComponentSupportsDynamic component;
-  component.setDynamicProperty("test", "value");
-  std::string value;
-  component.getDynamicProperty("test", value);
-  REQUIRE(value == "value");
+  CHECK(component.setDynamicProperty("test", "value"));
+  CHECK("value" == component.getDynamicProperty("test"));
 }
 
 TEST_CASE("Test Set Dynamic Property 2", "[testSetDynamicProperty2]") {
   TestConfigurableComponentSupportsDynamic component;
-  component.setDynamicProperty("test", "value");
-  component.setDynamicProperty("test", "value2");
-  std::string value;
-  component.getDynamicProperty("test", value);
-  REQUIRE(value == "value2");
+  CHECK(component.setDynamicProperty("test", "value"));
+  CHECK(component.setDynamicProperty("test", "value2"));
+  CHECK("value2" == component.getDynamicProperty("test"));
+  CHECK(component.getDynamicProperty("test2").error() == PropertyErrorCode::PropertyNotSet);
 }
 
 TEST_CASE("Test Set Dynamic Property Fail", "[testSetDynamicPropertyFail]") {
   TestConfigurableComponentNotSupportsDynamic component;
-  REQUIRE(!component.setDynamicProperty("test", "value"));
-  std::string value;
-  component.getDynamicProperty("test", value);
-  REQUIRE(value == "");
+  CHECK(component.setDynamicProperty("test", "value").error() == PropertyErrorCode::DynamicPropertiesNotSupported);
+  CHECK(component.getDynamicProperty("test").error() == PropertyErrorCode::DynamicPropertiesNotSupported);
 }
 
 TEST_CASE("Test Set Dynamic Property 3", "[testSetDynamicProperty2]") {
   TestConfigurableComponentSupportsDynamic component;
-  component.setDynamicProperty("test", "value");
-  component.setDynamicProperty("test2", "value2");
-  std::string value;
+  CHECK(component.setDynamicProperty("test", "value"));
+  CHECK(component.setDynamicProperty("test2", "value2"));
   auto propertyKeys = component.getDynamicPropertyKeys();
   REQUIRE(2 == propertyKeys.size());
   REQUIRE("test" == propertyKeys[0]);
