@@ -17,8 +17,8 @@
  */
 
 
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "Exception.h"
 
 TEST_CASE("Test general exception .what()", "[testi general what]") {
