@@ -22,9 +22,12 @@
 #include "unit/Catch.h"
 #include "utils/expected.h"
 #include "utils/gsl.h"
+#include "unit/TestUtils.h"
 
 namespace utils = org::apache::nifi::minifi::utils;
 
+using org::apache::nifi::minifi::test::utils::ExceptionSubStringMatcher;
+
 // shamelessly copied from https://github.com/TartanLlama/expected/blob/master/tests/extensions.cpp (License: CC0)
 TEST_CASE("expected transform", "[expected][transform]") {
   auto mul2 = [](int a) { return a * 2; };
@@ -91,7 +94,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = e | utils::transform(ret_void);
     REQUIRE(ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
   {
@@ -99,7 +102,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = e | utils::transform(ret_void);
     REQUIRE(ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
   {
@@ -107,7 +110,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = std::move(e) | utils::transform(ret_void);
     REQUIRE(ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
   {
@@ -115,7 +118,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = std::move(e) | utils::transform(ret_void);  // NOLINT(performance-move-const-arg)
     REQUIRE(ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
   {
@@ -123,7 +126,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = e | utils::transform(ret_void);
     REQUIRE(!ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
   {
@@ -131,7 +134,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = e | utils::transform(ret_void);
     REQUIRE(!ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
   {
@@ -139,7 +142,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = std::move(e) | utils::transform(ret_void);
     REQUIRE(!ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
   {
@@ -147,7 +150,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     auto ret = std::move(e) | utils::transform(ret_void);  // NOLINT(performance-move-const-arg)
     REQUIRE(!ret);
     STATIC_REQUIRE(
-        (std::is_same<decltype(ret), nonstd::expected<void, int>>::value));
+        (std::is_same_v<decltype(ret), nonstd::expected<void, int>>));
   }
 
 
@@ -156,7 +159,7 @@ TEST_CASE("expected transform", "[expected][transform]") {
     nonstd::expected<int, int> e(42);
     auto ret = e | utils::transform([](int& i) -> int& { return i; });
     REQUIRE(ret);
-    REQUIRE(ret == 42);
+    REQUIRE(*ret == 42);
   }
 }
 
@@ -341,7 +344,7 @@ TEST_CASE("expected orElse", "[expected][orElse]") {
     nonstd::expected<int, int> e = 21;
     auto ret = std::move(e) | utils::orElse(fail);
     REQUIRE(ret);
-    REQUIRE(ret == 21);
+    REQUIRE(*ret == 21);
   }
 
 
@@ -349,7 +352,7 @@ TEST_CASE("expected orElse", "[expected][orElse]") {
     nonstd::expected<int, eptr> e = 21;
     auto ret = std::move(e) | utils::orElse(efail);
     REQUIRE(ret);
-    REQUIRE(ret == 21);
+    REQUIRE(*ret == 21);
   }
 
   {
@@ -473,7 +476,10 @@ TEST_CASE("expected valueOrElse", "[expected][valueOrElse]") {
   REQUIRE(gsl::narrow<int>("hello"sv.size()) == (ex | utils::valueOrElse([](const std::string& err) { return gsl::narrow<int>(err.size()); })));
   REQUIRE_THROWS_AS(ex | utils::valueOrElse([](std::string){ throw std::exception(); }), std::exception);  // NOLINT(performance-unnecessary-value-param)
   REQUIRE_THROWS_AS(ex | utils::valueOrElse([](const std::string&) -> int { throw std::exception(); }), std::exception);
-  REQUIRE_THROWS_AS(std::move(ex) | utils::valueOrElse([](std::string&&) -> int { throw std::exception(); }), std::exception);
+  REQUIRE_THROWS_MATCHES(
+      std::move(ex) | utils::valueOrElse([](std::string&& error) -> int { const auto err = std::move(error); throw std::runtime_error(err); }),
+      std::runtime_error,
+      ExceptionSubStringMatcher<std::runtime_error>({"hello"}));
 }
 
 TEST_CASE("expected transformError", "[expected][transformError]") {
@@ -486,6 +492,13 @@ TEST_CASE("expected transformError", "[expected][transformError]") {
     REQUIRE(ret.error() == 42);
   }
 
+  {
+    nonstd::expected<size_t, std::string> e = nonstd::make_unexpected("sajt");
+    auto ret = e | utils::transformError([](const std::string& error) -> size_t { return error.length(); });
+    REQUIRE(!ret);
+    REQUIRE(ret.error() == 4);
+  }
+
   {
     const nonstd::expected<int, int> e = nonstd::make_unexpected(21);
     auto ret = e | utils::transformError(mul2);
@@ -535,3 +548,32 @@ TEST_CASE("expected transformError", "[expected][transformError]") {
     REQUIRE(*ret == 21);
   }
 }
+
+TEST_CASE("expected toOptional") {
+  nonstd::expected<int, std::string> unexpected{nonstd::unexpect, "hello"};
+  nonstd::expected<int, std::string> expected{5};
+
+  std::optional<int> res1 = std::move(unexpected) | utils::toOptional();
+  std::optional<int> res2 = std::move(expected) | utils::toOptional();
+
+  CHECK(res1 == std::nullopt);
+  CHECK(res2 == 5);
+}
+
+TEST_CASE("expected orThrow") {
+  nonstd::expected<int, std::string> unexpected{nonstd::unexpect, "hello"};
+  nonstd::expected<int, std::string> expected{5};
+
+
+  REQUIRE_THROWS_MATCHES(std::move(unexpected) | utils::orThrow("should throw"),
+      std::runtime_error,
+      ExceptionSubStringMatcher<std::runtime_error>({"should throw, but got hello"}));
+  CHECK((expected | utils::orThrow("should be 5")) == 5);
+}
+
+TEST_CASE("This fails to compile with std::expected on GCC 15.1 due to https://gcc.gnu.org/bugzilla/show_bug.cgi?id=119714") {
+  nonstd::expected<int, std::string> a;
+  nonstd::expected<int, std::string> b;
+
+  CHECK(a == b);
+}
