@@ -19,8 +19,8 @@
 
 #include <filesystem>
 
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "utils/file/FilePattern.h"
 #include "range/v3/view/map.hpp"
 #include "range/v3/view/join.hpp"
