@@ -39,7 +39,7 @@ TEST_CASE("Test default is time", "[id]") {
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
-  generator->initialize(std::make_shared<minifi::Properties>());
+  generator->initialize(std::make_shared<minifi::PropertiesImpl>());
 
   REQUIRE(true == LogTestController::getInstance().contains("Using uuid_generate_time implementation for uids."));
   LogTestController::getInstance().reset();
@@ -49,7 +49,7 @@ TEST_CASE("Test time", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "TiMe");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -69,7 +69,7 @@ TEST_CASE("Test Generate Move", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "TiMe");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -86,7 +86,7 @@ TEST_CASE("Test random", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "RaNDoM");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -106,7 +106,7 @@ TEST_CASE("Test uuid_default", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "UUID_default");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -120,7 +120,7 @@ TEST_CASE("Test invalid", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "InVaLiD");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -134,7 +134,7 @@ TEST_CASE("Test parse", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "time");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -160,7 +160,7 @@ TEST_CASE("Test parse invalid", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "time");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -187,7 +187,7 @@ TEST_CASE("Test to_string", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "time");
 
   std::shared_ptr<utils::IdGenerator> generator = utils::IdGenerator::getIdGenerator();
@@ -229,7 +229,7 @@ TEST_CASE("Test Hex Device Segment 16 bits correct digits", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "minifi_uid");
   id_props->set("uid.minifi.device.segment", "09aF");
 
@@ -255,7 +255,7 @@ TEST_CASE("Test Hex Device Segment 16 bits too many digits", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "minifi_uid");
   id_props->set("uid.minifi.device.segment", "09aFee");
 
@@ -283,7 +283,7 @@ TEST_CASE("Test Hex Device Segment 18 bits", "[id]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   id_props->set("uid.implementation", "minifi_uid");
   id_props->set("uid.minifi.device.segment.bits", "18");
   id_props->set("uid.minifi.device.segment", "09aF8");
@@ -317,7 +317,7 @@ TEST_CASE("Collision", "[collision]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   SECTION("random") {
     id_props->set("uid.implementation", "random");
   }
@@ -356,7 +356,7 @@ TEST_CASE("Speed", "[speed]") {
   TestController test_controller;
 
   LogTestController::getInstance().setDebug<utils::IdGenerator>();
-  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::Properties>();
+  std::shared_ptr<minifi::Properties> id_props = std::make_shared<minifi::PropertiesImpl>();
   std::string implementation;
   SECTION("random") {
     implementation = "random";
