@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include "LineByLineInputOutputStreamCallback.h"
+#include "utils/LineByLineInputOutputStreamCallback.h"
 
 #include "unit/TestBase.h"
 #include "unit/Catch.h"
