@@ -25,7 +25,7 @@
 #include "unit/Catch.h"
 #include "core/logging/LoggerConfiguration.h"
 #include "io/ZlibStream.h"
-#include "StreamPipe.h"
+#include "io/StreamPipe.h"
 #include "unit/TestUtils.h"
 #include "utils/span.h"
 #include "utils/net/AsioSocketUtils.h"
@@ -33,73 +33,73 @@
 using namespace std::literals::chrono_literals;
 
 TEST_CASE("Test log Levels", "[ttl1]") {
-  LogTestController::getInstance().clear();
+  LogTestController::getInstance().reset();
   LogTestController::getInstance().setTrace<logging::Logger>();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
   logger->log_info("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [info] hello world"));
+  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [info] hello world", 0s, 0ms));
   LogTestController::getInstance().reset();
 }
 
 TEST_CASE("Test log Levels debug", "[ttl2]") {
-  LogTestController::getInstance().clear();
+  LogTestController::getInstance().reset();
   LogTestController::getInstance().setTrace<logging::Logger>();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
   logger->log_debug("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [debug] hello world"));
+  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [debug] hello world", 0s, 0ms));
   LogTestController::getInstance().reset();
 }
 
 TEST_CASE("Test log Levels trace", "[ttl3]") {
-  LogTestController::getInstance().clear();
+  LogTestController::getInstance().reset();
   LogTestController::getInstance().setTrace<logging::Logger>();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
   logger->log_trace("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [trace] hello world"));
+  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [trace] hello world", 0s, 0ms));
   LogTestController::getInstance().reset();
 }
 
 TEST_CASE("Test log Levels error", "[ttl4]") {
-  LogTestController::getInstance().clear();
+  LogTestController::getInstance().reset();
   LogTestController::getInstance().setTrace<logging::Logger>();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
   logger->log_error("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world"));
+  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world", 0s, 0ms));
   LogTestController::getInstance().reset();
 }
 
 TEST_CASE("Test log Levels change", "[ttl5]") {
-  LogTestController::getInstance().clear();
+  LogTestController::getInstance().reset();
   LogTestController::getInstance().setTrace<logging::Logger>();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
   logger->log_error("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world"));
+  REQUIRE(true == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world", 0s, 0ms));
   LogTestController::getInstance().reset();
   LogTestController::getInstance().setOff<logging::Logger>();
   logger->log_error("hello {}", "world");
 
-  REQUIRE(false == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world", std::chrono::seconds(0)));
+  REQUIRE(false == LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world", 0s, 0ms));
   LogTestController::getInstance().reset();
 }
 
 TEST_CASE("Logger configured with an ID prints this ID in every log line", "[logger][id]") {
-  LogTestController::getInstance().clear();
+  LogTestController::getInstance().reset();
   LogTestController::getInstance().setTrace<logging::Logger>();
   const auto uuid = utils::IdGenerator::getIdGenerator()->generate();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger(uuid);
   logger->log_error("hello {}", "world");
 
-  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world (" + uuid.to_string() + ")"));
+  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world (" + uuid.to_string() + ")", 0s, 0ms));
   LogTestController::getInstance().reset();
 }
 
 TEST_CASE("Printing of the ID can be disabled in the config", "[logger][id][configuration]") {
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
 
   bool id_is_present{};
   SECTION("Property not set") {
@@ -117,8 +117,8 @@ TEST_CASE("Printing of the ID can be disabled in the config", "[logger][id][conf
   const auto uuid = utils::IdGenerator::getIdGenerator()->generate();
   std::shared_ptr<logging::Logger> logger = LogTestController::getInstance(properties)->getLogger<logging::Logger>(uuid);
   logger->log_error("hello {}", "world");
-  CHECK(LogTestController::getInstance(properties)->contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world"));
-  CHECK(id_is_present == LogTestController::getInstance(properties)->contains(uuid.to_string()));
+  CHECK(LogTestController::getInstance(properties)->contains("[org::apache::nifi::minifi::core::logging::Logger] [error] hello world", 0s, 0ms));
+  CHECK(id_is_present == LogTestController::getInstance(properties)->contains(uuid.to_string(), 0s, 0ms));
 }
 
 struct CStringConvertible {
@@ -136,7 +136,7 @@ TEST_CASE("Test log custom string formatting", "[ttl6]") {
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
   logger->log_trace("{} {} {}", "one", std::string{"two"}, CStringConvertible{"three"}.c_str());
 
-  REQUIRE(LogTestController::getInstance().contains("[trace] one two three", 0s));
+  REQUIRE(LogTestController::getInstance().contains("[trace] one two three", 0s, 0ms));
   LogTestController::getInstance().reset();
 }
 
@@ -157,7 +157,7 @@ TEST_CASE("Test log lazy string generation", "[ttl7]") {
     return std::string{"hello debug"};
   });
 
-  REQUIRE(LogTestController::getInstance().contains("[debug] hello debug", 0s));
+  REQUIRE(LogTestController::getInstance().contains("[debug] hello debug", 0s, 0ms));
   REQUIRE(call_count == 1);
   LogTestController::getInstance().reset();
 }
@@ -171,25 +171,25 @@ class TestClass2 {
 };
 
 TEST_CASE("Test ShortenNames", "[ttl8]") {
-  LogTestController::getInstance().clear();
-  std::shared_ptr<logging::LoggerProperties> props = std::make_shared<logging::LoggerProperties>();
+  LogTestController::getInstance().reset();
+  std::shared_ptr<logging::LoggerProperties> props = std::make_shared<logging::LoggerProperties>("");
 
   props->set("spdlog.shorten_names", "true");
 
   std::shared_ptr<logging::Logger> logger = LogTestController::getInstance(props)->getLogger<logging::Logger>();
   logger->log_error("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance(props)->contains("[o::a::n::m::c::l::Logger] [error] hello world"));
+  REQUIRE(true == LogTestController::getInstance(props)->contains("[o::a::n::m::c::l::Logger] [error] hello world", 0s, 0ms));
 
   logger = LogTestController::getInstance(props)->getLogger<single::TestClass>();
   logger->log_error("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance(props)->contains("[s::TestClass] [error] hello world"));
+  REQUIRE(true == LogTestController::getInstance(props)->contains("[s::TestClass] [error] hello world", 0s, 0ms));
 
   logger = LogTestController::getInstance(props)->getLogger<TestClass2>();
   logger->log_error("hello {}", "world");
 
-  REQUIRE(true == LogTestController::getInstance(props)->contains("[TestClass2] [error] hello world"));
+  REQUIRE(true == LogTestController::getInstance(props)->contains("[TestClass2] [error] hello world", 0s, 0ms));
 
   LogTestController::getInstance(props)->reset();
   LogTestController::getInstance().reset();
@@ -215,10 +215,10 @@ class LoggerTestAccessor {
   static void setCompressionCompressedSegmentSize(logging::LoggerConfiguration& log_config, size_t value) {
     log_config.compression_manager_.compressed_segment_size = value;
   }
-  static size_t getUncompressedSize(logging::LoggerConfiguration& log_config) {
+  static size_t getUncompressedSize(const logging::LoggerConfiguration& log_config) {
     return log_config.compression_manager_.getSink()->cached_logs_.size();
   }
-  static bool waitForCompressionToHappen(logging::LoggerConfiguration& log_config) {
+  static bool waitForCompressionToHappen(const logging::LoggerConfiguration& log_config) {
     auto sink = log_config.compression_manager_.getSink();
     return !sink || minifi::test::utils::verifyEventHappenedInPollTime(1s, [&]{ return sink->cached_logs_.itemCount() == 0; });
   }
@@ -229,7 +229,7 @@ class LoggerTestAccessor {
 
 TEST_CASE("Test Compression", "[ttl9]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   std::string className;
   SECTION("Using root logger") {
     className = "CompressionTestClassUsingRoot";
@@ -254,7 +254,7 @@ TEST_CASE("Test Compression", "[ttl9]") {
 
 TEST_CASE("Test Compression cache overflow is discarded intermittently", "[ttl10]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   properties->set(logging::internal::CompressionManager::compression_cached_log_max_size_, "10 KB");
   LoggerTestAccessor::setCompressionCacheSegmentSize(*log_config, 1_KiB);
   std::string className = "CompressionTestCacheCleaned";
@@ -273,7 +273,7 @@ TEST_CASE("Test Compression cache overflow is discarded intermittently", "[ttl10
 
 TEST_CASE("Setting either properties to 0 disables in-memory compressed logs", "[ttl11]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   bool is_empty = false;
   SECTION("Cached log size is set to 0") {
     is_empty = true;
@@ -300,7 +300,7 @@ TEST_CASE("Setting either properties to 0 disables in-memory compressed logs", "
 
 TEST_CASE("Setting max log entry length property trims long log entries", "[ttl12]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   properties->set("max.log.entry.length", "2");
   properties->set("logger.root", "INFO");
   log_config->initialize(properties);
@@ -317,7 +317,7 @@ TEST_CASE("Setting max log entry length property trims long log entries", "[ttl1
 
 TEST_CASE("Setting max log entry length property trims long formatted log entries", "[ttl13]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   properties->set("max.log.entry.length", "2");
   properties->set("logger.root", "INFO");
   log_config->initialize(properties);
@@ -334,7 +334,7 @@ TEST_CASE("Setting max log entry length property trims long formatted log entrie
 
 TEST_CASE("Setting max log entry length to a size larger than the internal buffer size", "[ttl14]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   properties->set("max.log.entry.length", "1500");
   properties->set("logger.root", "INFO");
   log_config->initialize(properties);
@@ -353,7 +353,7 @@ TEST_CASE("Setting max log entry length to a size larger than the internal buffe
 
 TEST_CASE("Setting max log entry length to unlimited results in unlimited log entry size", "[ttl15]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   std::string_view logger_name;
   SECTION("Use unlimited value") {
     properties->set("max.log.entry.length", "unlimited");
@@ -378,6 +378,7 @@ TEST_CASE("Setting max log entry length to unlimited results in unlimited log en
 }
 
 TEST_CASE("fmt formatting works with the logger") {
+  LogTestController::getInstance().reset();
   LogTestController::getInstance().setTrace<logging::Logger>();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
   std::chrono::minutes duration{1};
@@ -386,10 +387,10 @@ TEST_CASE("fmt formatting works with the logger") {
   logger->log_critical("{} in hex is {:#x}", 13, 13);
   logger->log_critical("Unix epoch: {}", std::chrono::system_clock::time_point());
   logger->log_critical("{:%Q %q} equals to {:%Q %q}", 2h, std::chrono::duration_cast<std::chrono::seconds>(2h));
-  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] 1m equals to 60s"));
-  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] 13 in hex is 0xd"));
-  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] Unix epoch: 1970-01-01 00:00:00.00"));
-  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] 2 h equals to 7200 s"));
+  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] 1m equals to 60s", 0s, 0ms));
+  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] 13 in hex is 0xd", 0s, 0ms));
+  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] Unix epoch: 1970-01-01 00:00:00.00", 0s, 0ms));
+  CHECK(LogTestController::getInstance().contains("[org::apache::nifi::minifi::core::logging::Logger] [critical] 2 h equals to 7200 s", 0s, 0ms));
 
   LogTestController::getInstance().reset();
 }
@@ -407,7 +408,7 @@ std::vector<std::string> generateRandomStrings() {
   const int index_of_last_char = gsl::narrow<int>(strlen(TEXT_CHARS)) - 1;
   std::uniform_int_distribution<> distr(0, index_of_last_char);
   std::vector<char> data(100);
-  const size_t SEGMENT_COUNT = 5;
+  constexpr size_t SEGMENT_COUNT = 5;
   for (size_t idx = 0; idx < SEGMENT_COUNT; ++idx) {
     std::generate_n(data.begin(), data.size(), [&] { return TEXT_CHARS[static_cast<uint8_t>(distr(eng))]; });
     random_strings.push_back(std::string{data.begin(), data.end()} + "." + std::to_string(idx));
@@ -419,7 +420,7 @@ TEST_CASE("Test sending multiple segments at once", "[ttl16]") {
   auto log_config = logging::LoggerConfiguration::newInstance();
   LoggerTestAccessor::setCompressionCompressedSegmentSize(*log_config, 100);
   LoggerTestAccessor::setCompressionCacheSegmentSize(*log_config, 100);
-  auto properties = std::make_shared<logging::LoggerProperties>();
+  auto properties = std::make_shared<logging::LoggerProperties>("");
   // by default the root logger is OFF
   properties->set("logger.root", "INFO");
   log_config->initialize(properties);
