@@ -21,8 +21,8 @@
 #include <set>
 #include <string>
 
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "utils/MapUtils.h"
 
 namespace MapUtils = org::apache::nifi::minifi::utils::MapUtils;
