@@ -38,10 +38,10 @@ std::shared_ptr<minifi::controllers::NetworkPrioritizerService> createNetworkPri
 TEST_CASE("TestPrioritizerOneInterface", "[test1]") {
   auto controller = createNetworkPrioritizerService("TestService");
   controller->initialize();
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers, "eth0,eth1");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput, "10 B");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxPayload, "10 B");
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers.name, "eth0,eth1"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput.name, "10 B"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxPayload.name, "10 B"));
   controller->onEnable();
   REQUIRE("eth0" == controller->getInterface(0).getInterface());
 }
@@ -49,10 +49,10 @@ TEST_CASE("TestPrioritizerOneInterface", "[test1]") {
 TEST_CASE("TestPrioritizerOneInterfaceMaxPayload", "[test2]") {
   auto controller = createNetworkPrioritizerService("TestService");
   controller->initialize();
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers, "eth0,eth1");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput, "1 kB");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxPayload, "10 B");
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers.name, "eth0,eth1"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput.name, "1 kB"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxPayload.name, "10 B"));
   controller->onEnable();
 
   REQUIRE("eth0" == controller->getInterface(5).getInterface());
@@ -64,9 +64,9 @@ TEST_CASE("TestPrioritizerOneInterfaceMaxThroughput", "[test3]") {
   auto clock = std::make_shared<minifi::test::utils::ManualClock>();
   auto controller = createNetworkPrioritizerService("TestService", clock);
   controller->initialize();
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers, "eth0,eth1");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
-  controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput, "10 B");
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers.name, "eth0,eth1"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
+  REQUIRE(controller->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput.name, "10 B"));
   controller->onEnable();
   REQUIRE("eth0" == controller->getInterface(5).getInterface());
   REQUIRE("eth0" == controller->getInterface(5).getInterface());
@@ -78,22 +78,22 @@ TEST_CASE("TestPrioritizerOneInterfaceMaxThroughput", "[test3]") {
 TEST_CASE("TestPriorotizerMultipleInterfaces", "[test4]") {
   auto clock = std::make_shared<minifi::test::utils::ManualClock>();
   auto parent_controller = createNetworkPrioritizerService("TestService", clock);
-  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
+  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::ConfigureImpl>();
   parent_controller->initialize();
-  parent_controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
+  REQUIRE(parent_controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
 
   auto controller0 = createNetworkPrioritizerService("TestService_eth0", clock);
   controller0->initialize();
-  controller0->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers, "eth0");
-  controller0->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
-  controller0->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput, "10 B");
+  REQUIRE(controller0->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers.name, "eth0"));
+  REQUIRE(controller0->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
+  REQUIRE(controller0->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput.name, "10 B"));
   controller0->onEnable();
 
   auto controller1 = createNetworkPrioritizerService("TestService_eth1", clock);
   controller1->initialize();
-  controller1->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers, "eth1");
-  controller1->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
-  controller1->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput, "10 B");
+  REQUIRE(controller1->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers.name, "eth1"));
+  REQUIRE(controller1->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
+  REQUIRE(controller1->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput.name, "10 B"));
   controller1->onEnable();
 
   std::vector<std::shared_ptr<core::controller::ControllerService> > services;
@@ -121,21 +121,21 @@ TEST_CASE("TestPriorotizerMultipleInterfaces", "[test4]") {
 TEST_CASE("TestPriorotizerMultipleInterfacesMaxPayload", "[test5]") {
   auto parent_controller = createNetworkPrioritizerService("TestService");
   parent_controller->initialize();
-  parent_controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
+  REQUIRE(parent_controller->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
 
   auto controller0 = createNetworkPrioritizerService("TestService_eth0");
   controller0->initialize();
-  controller0->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers, "eth0");
-  controller0->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
-  controller0->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput, "1 kB");
-  controller0->setProperty(minifi::controllers::NetworkPrioritizerService::MaxPayload, "10 B");
+  REQUIRE(controller0->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers.name, "eth0"));
+  REQUIRE(controller0->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
+  REQUIRE(controller0->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput.name, "1 kB"));
+  REQUIRE(controller0->setProperty(minifi::controllers::NetworkPrioritizerService::MaxPayload.name, "10 B"));
   controller0->onEnable();
 
   auto controller1 = createNetworkPrioritizerService("TestService_eth1");
   controller1->initialize();
-  controller1->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers, "eth1");
-  controller1->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces, "false");
-  controller1->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput, "1 kB");
+  REQUIRE(controller1->setProperty(minifi::controllers::NetworkPrioritizerService::NetworkControllers.name, "eth1"));
+  REQUIRE(controller1->setProperty(minifi::controllers::NetworkPrioritizerService::VerifyInterfaces.name, "false"));
+  REQUIRE(controller1->setProperty(minifi::controllers::NetworkPrioritizerService::MaxThroughput.name, "1 kB"));
   controller1->onEnable();
 
   std::vector<std::shared_ptr<core::controller::ControllerService> > services;
