@@ -29,7 +29,7 @@
 
 TEST_CASE("TestEmptyPolicy", "[test1]") {
   auto controller = std::make_shared<minifi::controllers::UpdatePolicyControllerService>("TestService");
-  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
+  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::ConfigureImpl>();
   controller->initialize();
   controller->onEnable();
   REQUIRE(false == controller->canUpdate("anyproperty"));
@@ -37,39 +37,39 @@ TEST_CASE("TestEmptyPolicy", "[test1]") {
 
 TEST_CASE("TestAllowAll", "[test1]") {
   auto controller = std::make_shared<minifi::controllers::UpdatePolicyControllerService>("TestService");
-  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
+  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::ConfigureImpl>();
   controller->initialize();
-  controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties, "true");
+  REQUIRE(controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties.name, "true"));
   controller->onEnable();
   REQUIRE(true == controller->canUpdate("anyproperty"));
 }
 
 TEST_CASE("TestAllowAllFails", "[test1]") {
   auto controller = std::make_shared<minifi::controllers::UpdatePolicyControllerService>("TestService");
-  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
+  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::ConfigureImpl>();
   controller->initialize();
-  controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties, "false");
+  REQUIRE(controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties.name, "false"));
   controller->onEnable();
   REQUIRE(false == controller->canUpdate("anyproperty"));
 }
 
 TEST_CASE("TestEnableProperty", "[test1]") {
   auto controller = std::make_shared<minifi::controllers::UpdatePolicyControllerService>("TestService");
-  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
+  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::ConfigureImpl>();
   controller->initialize();
-  controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties, "false");
-  controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowedProperties, "anyproperty");
+  REQUIRE(controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties.name, "false"));
+  REQUIRE(controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowedProperties.name, "anyproperty"));
   controller->onEnable();
   REQUIRE(true == controller->canUpdate("anyproperty"));
 }
 
 TEST_CASE("TestDisableProperty", "[test1]") {
   auto controller = std::make_shared<minifi::controllers::UpdatePolicyControllerService>("TestService");
-  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
+  std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::ConfigureImpl>();
   controller->initialize();
-  controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties, "true");
-  controller->setProperty(minifi::controllers::UpdatePolicyControllerService::DisallowedProperties, "anyproperty");
-  controller->updateProperty(minifi::controllers::UpdatePolicyControllerService::DisallowedProperties, "anyproperty2");
+  REQUIRE(controller->setProperty(minifi::controllers::UpdatePolicyControllerService::AllowAllProperties.name, "true"));
+  REQUIRE(controller->setProperty(minifi::controllers::UpdatePolicyControllerService::DisallowedProperties.name, "anyproperty"));
+  REQUIRE(controller->appendProperty(minifi::controllers::UpdatePolicyControllerService::DisallowedProperties.name, "anyproperty2"));
   controller->onEnable();
   REQUIRE(false == controller->canUpdate("anyproperty"));
   REQUIRE(false == controller->canUpdate("anyproperty2"));
