@@ -26,9 +26,10 @@
 #include "utils/crypto/EncryptionProvider.h"
 #include "utils/crypto/property_encryption/PropertyEncryptionUtils.h"
 #include "utils/StringUtils.h"
+#include "core/Resource.h"
+#include "utils/Environment.h"
 
-namespace core = org::apache::nifi::minifi::core;
-namespace utils = org::apache::nifi::minifi::utils;
+namespace org::apache::nifi::minifi::test {
 
 constexpr std::string_view config_yaml = R"(MiNiFi Config Version: 3
 Flow Controller:
@@ -179,10 +180,10 @@ Remote Process Groups: []
 NiFi Properties Overrides: {}
 )";
 
-const utils::crypto::Bytes secret_key = utils::string::from_hex("cb76fe6fe4cbfdc3770c0cb0afc910f81ced4d436b11f691395fc2a9dbea27ca");
-const utils::crypto::EncryptionProvider encryption_provider{secret_key};
+const minifi::utils::crypto::Bytes secret_key = minifi::utils::string::from_hex("cb76fe6fe4cbfdc3770c0cb0afc910f81ced4d436b11f691395fc2a9dbea27ca");
+const minifi::utils::crypto::EncryptionProvider encryption_provider{secret_key};
 
-using OverridesMap = std::unordered_map<utils::Identifier, core::flow::Overrides>;
+using OverridesMap = std::unordered_map<minifi::utils::Identifier, core::flow::Overrides>;
 
 TEST_CASE("YamlFlowSerializer can encrypt the sensitive properties") {
   ConfigurationTestController test_controller;
@@ -195,9 +196,9 @@ TEST_CASE("YamlFlowSerializer can encrypt the sensitive properties") {
   YAML::Node root_yaml_node = YAML::Load(std::string{config_yaml});
   const auto flow_serializer = core::yaml::YamlFlowSerializer{root_yaml_node};
 
-  const auto processor_id = utils::Identifier::parse("469617f1-3898-4bbf-91fe-27d8f4dd2a75").value();
-  const auto controller_service_id = utils::Identifier::parse("b9801278-7b5d-4314-aed6-713fd4b5f933").value();
-  const auto parameter_id = utils::Identifier::parse("721e10b7-8e00-3188-9a27-476cca376978").value();
+  const auto processor_id = minifi::utils::Identifier::parse("469617f1-3898-4bbf-91fe-27d8f4dd2a75").value();
+  const auto controller_service_id = minifi::utils::Identifier::parse("b9801278-7b5d-4314-aed6-713fd4b5f933").value();
+  const auto parameter_id = minifi::utils::Identifier::parse("721e10b7-8e00-3188-9a27-476cca376978").value();
 
   const auto [overrides, expected_results] = GENERATE_REF(
       std::make_tuple(OverridesMap{},
@@ -212,7 +213,7 @@ TEST_CASE("YamlFlowSerializer can encrypt the sensitive properties") {
       std::make_tuple(OverridesMap{{parameter_id, core::flow::Overrides{}.add("secret_parameter", "param_value_2")}},
           std::array{"very_secure_password", "very_secure_passphrase", "param_value_2"}));
 
-  std::string config_yaml_encrypted = flow_serializer.serialize(*process_group, schema, encryption_provider, overrides);
+  std::string config_yaml_encrypted = flow_serializer.serialize(*process_group, schema, encryption_provider, overrides, {});
 
   {
     std::regex regex{R"_(invokehttp-proxy-password: (.*))_"};
@@ -221,7 +222,7 @@ TEST_CASE("YamlFlowSerializer can encrypt the sensitive properties") {
 
     REQUIRE(match_results.size() == 2);
     std::string encrypted_value = match_results[1];
-    CHECK(utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == expected_results[0]);
+    CHECK(minifi::utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == expected_results[0]);
   }
 
   {
@@ -231,7 +232,7 @@ TEST_CASE("YamlFlowSerializer can encrypt the sensitive properties") {
 
     REQUIRE(match_results.size() == 2);
     std::string encrypted_value = match_results[1];
-    CHECK(utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == expected_results[1]);
+    CHECK(minifi::utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == expected_results[1]);
   }
 
   {
@@ -241,7 +242,7 @@ TEST_CASE("YamlFlowSerializer can encrypt the sensitive properties") {
 
     REQUIRE(match_results.size() == 2);
     std::string encrypted_value = match_results[1];
-    CHECK(utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == expected_results[2]);
+    CHECK(minifi::utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == expected_results[2]);
   }
 }
 
@@ -256,12 +257,12 @@ TEST_CASE("YamlFlowSerializer with an override can add a new property to the flo
   YAML::Node root_yaml_node = YAML::Load(std::string{config_yaml});
   const auto flow_serializer = core::yaml::YamlFlowSerializer{root_yaml_node};
 
-  const auto second_controller_service_id = utils::Identifier::parse("b418f4ff-e598-4ea2-921f-14f9dd864482").value();
+  const auto second_controller_service_id = minifi::utils::Identifier::parse("b418f4ff-e598-4ea2-921f-14f9dd864482").value();
 
   SECTION("with required overrides") {
     const OverridesMap overrides{{second_controller_service_id, core::flow::Overrides{}.add("Passphrase", "new passphrase")}};
 
-    std::string config_yaml_encrypted = flow_serializer.serialize(*process_group, schema, encryption_provider, overrides);
+    std::string config_yaml_encrypted = flow_serializer.serialize(*process_group, schema, encryption_provider, overrides, {});
 
     std::regex regex{R"_(Passphrase: (.*))_"};
     std::smatch match_results;
@@ -273,15 +274,15 @@ TEST_CASE("YamlFlowSerializer with an override can add a new property to the flo
     REQUIRE(std::regex_search(match_results.suffix().first, config_yaml_encrypted.cend(), match_results, regex));
     REQUIRE(match_results.size() == 2);
     std::string encrypted_value = match_results[1];
-    CHECK(utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == "new passphrase");
+    CHECK(minifi::utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == "new passphrase");
   }
 
   SECTION("with optional overrides: the override is only used if the property is already in the flow config") {
-    const auto first_controller_service_id = utils::Identifier::parse("b9801278-7b5d-4314-aed6-713fd4b5f933").value();
+    const auto first_controller_service_id = minifi::utils::Identifier::parse("b9801278-7b5d-4314-aed6-713fd4b5f933").value();
     const OverridesMap overrides{{first_controller_service_id, core::flow::Overrides{}.addOptional("Passphrase", "first new passphrase")},
                                  {second_controller_service_id, core::flow::Overrides{}.addOptional("Passphrase", "second new passphrase")}};
 
-    std::string config_yaml_encrypted = flow_serializer.serialize(*process_group, schema, encryption_provider, overrides);
+    std::string config_yaml_encrypted = flow_serializer.serialize(*process_group, schema, encryption_provider, overrides, {});
 
     std::regex regex{R"_(Passphrase: (.*))_"};
     std::smatch match_results;
@@ -290,7 +291,7 @@ TEST_CASE("YamlFlowSerializer with an override can add a new property to the flo
     REQUIRE(std::regex_search(config_yaml_encrypted.cbegin(), config_yaml_encrypted.cend(), match_results, regex));
     REQUIRE(match_results.size() == 2);
     std::string encrypted_value = match_results[1];
-    CHECK(utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == "first new passphrase");
+    CHECK(minifi::utils::crypto::property_encryption::decrypt(encrypted_value, encryption_provider) == "first new passphrase");
 
     // check that there is no second match
     CHECK_FALSE(std::regex_search(match_results.suffix().first, config_yaml_encrypted.cend(), match_results, regex));
@@ -309,19 +310,19 @@ TEST_CASE("The encrypted flow configuration can be decrypted with the correct ke
   const auto schema = core::flow::FlowSchema::getDefault();
   YAML::Node root_yaml_node = YAML::Load(std::string{config_yaml});
   const auto flow_serializer_before = core::yaml::YamlFlowSerializer{root_yaml_node};
-  std::string config_yaml_encrypted = flow_serializer_before.serialize(*process_group_before, schema, encryption_provider, {});
+  std::string config_yaml_encrypted = flow_serializer_before.serialize(*process_group_before, schema, encryption_provider, {}, {});
 
   core::flow::AdaptiveConfiguration yaml_configuration_after{configuration_context};
   const auto process_group_after = yaml_configuration_after.getRootFromPayload(config_yaml_encrypted);
   REQUIRE(process_group_after);
 
-  const auto processor_id = utils::Identifier::parse("469617f1-3898-4bbf-91fe-27d8f4dd2a75").value();
+  const auto processor_id = minifi::utils::Identifier::parse("469617f1-3898-4bbf-91fe-27d8f4dd2a75").value();
   const auto* processor_before = process_group_before->findProcessorById(processor_id);
   REQUIRE(processor_before);
   const auto* processor_after = process_group_after->findProcessorById(processor_id);
   REQUIRE(processor_after);
-  CHECK(processor_before->getProperties().at("HTTP Method").getValue() == processor_after->getProperties().at("HTTP Method").getValue());
-  CHECK(processor_before->getProperties().at("invokehttp-proxy-password").getValue() == processor_after->getProperties().at("invokehttp-proxy-password").getValue());
+  CHECK(processor_before->getProperty("HTTP Method") == processor_after->getProperty("HTTP Method"));
+  CHECK(processor_before->getProperty("invokehttp-proxy-password") == processor_after->getProperty("invokehttp-proxy-password"));
 
   const auto controller_service_id = "b9801278-7b5d-4314-aed6-713fd4b5f933";
   const auto* const controller_service_node_before = process_group_before->findControllerService(controller_service_id);
@@ -332,8 +333,8 @@ TEST_CASE("The encrypted flow configuration can be decrypted with the correct ke
   REQUIRE(controller_service_node_after);
   const auto* const controller_service_after = controller_service_node_before->getControllerServiceImplementation();
   REQUIRE(controller_service_after);
-  CHECK(controller_service_before->getProperties().at("CA Certificate").getValue() == controller_service_after->getProperties().at("CA Certificate").getValue());
-  CHECK(controller_service_before->getProperties().at("Passphrase").getValue() == controller_service_after->getProperties().at("Passphrase").getValue());
+  CHECK(controller_service_before->getProperty("CA Certificate") == controller_service_after->getProperty("CA Certificate"));
+  CHECK(controller_service_before->getProperty("Passphrase") == controller_service_after->getProperty("Passphrase"));
 
   const auto& param_contexts = yaml_configuration_after.getParameterContexts();
   CHECK(param_contexts.at("my-context")->getParameter("secret_parameter")->value == "param_value_1");
@@ -351,11 +352,214 @@ TEST_CASE("The encrypted flow configuration cannot be decrypted with an incorrec
   const auto schema = core::flow::FlowSchema::getDefault();
   YAML::Node root_yaml_node = YAML::Load(std::string{config_yaml});
   const auto flow_serializer = core::yaml::YamlFlowSerializer{root_yaml_node};
-  std::string config_yaml_encrypted = flow_serializer.serialize(*process_group_before, schema, encryption_provider, {});
+  std::string config_yaml_encrypted = flow_serializer.serialize(*process_group_before, schema, encryption_provider, {}, {});
 
-  const utils::crypto::Bytes different_secret_key = utils::string::from_hex("ea55b7d0edc22280c9547e4d89712b3fae74f96d82f240a004fb9fbd0640eec7");
-  configuration_context.sensitive_values_encryptor = utils::crypto::EncryptionProvider{different_secret_key};
+  const minifi::utils::crypto::Bytes different_secret_key = minifi::utils::string::from_hex("ea55b7d0edc22280c9547e4d89712b3fae74f96d82f240a004fb9fbd0640eec7");
+  configuration_context.sensitive_values_encryptor = minifi::utils::crypto::EncryptionProvider{different_secret_key};
 
   core::flow::AdaptiveConfiguration yaml_configuration_after{configuration_context};
-  REQUIRE_THROWS_AS(yaml_configuration_after.getRootFromPayload(config_yaml_encrypted), utils::crypto::EncryptionError);
+  REQUIRE_THROWS_AS(yaml_configuration_after.getRootFromPayload(config_yaml_encrypted), minifi::utils::crypto::EncryptionError);
 }
+
+TEST_CASE("Parameter provider generated parameter context is serialized correctly") {
+  ConfigurationTestController test_controller;
+  auto configuration_context = test_controller.getContext();
+  configuration_context.sensitive_values_encryptor = encryption_provider;
+  core::flow::AdaptiveConfiguration yaml_configuration_before{configuration_context};
+
+  const auto schema = core::flow::FlowSchema::getDefault();
+  static const std::string config_yaml =
+      R"(
+Flow Controller:
+  name: root
+  comment: ""
+Parameter Providers:
+  - id: d26ee5f5-0192-1000-0482-4e333725e089
+    name: EnvironmentVariableParameterProvider
+    type: EnvironmentVariableParameterProvider
+    Properties:
+      Environment Variable Inclusion Strategy: Comma-Separated
+      Include Environment Variables: MINIFI_DATA,SECRET_MINIFI_DATA
+      Sensitive Parameter Scope: selected
+      Sensitive Parameter List: SECRET_MINIFI_DATA
+      Parameter Group Name: environment-variable-parameter-context
+Processors:
+  - name: DummyProcessor
+    id: aabb6d26-8a8d-4338-92c9-1b8c67ec18e0
+    type: DummyProcessor
+    scheduling strategy: TIMER_DRIVEN
+    scheduling period: "15 sec"
+    Properties:
+      Simple Property: "#{MINIFI_DATA}"
+      Sensitive Property: "#{SECRET_MINIFI_DATA}"
+Parameter Context Name: environment-variable-parameter-context
+)";
+
+  minifi::utils::Environment::setEnvironmentVariable("MINIFI_DATA", "minifi_data_value");
+  minifi::utils::Environment::setEnvironmentVariable("SECRET_MINIFI_DATA", "secret_minifi_data_value");
+  const auto process_group_before = yaml_configuration_before.getRootFromPayload(std::string{config_yaml});
+  REQUIRE(process_group_before);
+
+  std::string reserialized_config = yaml_configuration_before.serialize(*process_group_before);
+  YAML::Node result_yaml_node = YAML::Load(std::string{reserialized_config});
+
+  REQUIRE(result_yaml_node["Parameter Contexts"].IsDefined());
+  auto parameters = result_yaml_node["Parameter Contexts"][0]["Parameters"];
+  REQUIRE(parameters.size() == 2);
+  for (const auto& parameter : parameters) {
+    auto name = parameter["name"].as<std::string>();
+    auto value = parameter["value"].as<std::string>();
+    if (name == "MINIFI_DATA") {
+      REQUIRE(value == "minifi_data_value");
+    } else if (name == "SECRET_MINIFI_DATA") {
+      REQUIRE(minifi::utils::crypto::property_encryption::decrypt(value, encryption_provider) == "secret_minifi_data_value");
+    }
+  }
+}
+
+TEST_CASE("Parameter provider generated parameter context is not serialized if parameter context already exists") {
+  ConfigurationTestController test_controller;
+  auto configuration_context = test_controller.getContext();
+  configuration_context.sensitive_values_encryptor = encryption_provider;
+  core::flow::AdaptiveConfiguration yaml_configuration_before{configuration_context};
+
+  const auto schema = core::flow::FlowSchema::getDefault();
+  static const std::string config_yaml =
+      R"(
+Flow Controller:
+  name: root
+  comment: ""
+Parameter Providers:
+  - id: d26ee5f5-0192-1000-0482-4e333725e089
+    name: EnvironmentVariableParameterProvider
+    type: EnvironmentVariableParameterProvider
+    Properties:
+      Environment Variable Inclusion Strategy: Comma-Separated
+      Include Environment Variables: MINIFI_DATA,SECRET_MINIFI_DATA
+      Sensitive Parameter Scope: selected
+      Sensitive Parameter List: SECRET_MINIFI_DATA
+      Parameter Group Name: environment-variable-parameter-context
+Parameter Contexts:
+  - id: 123ee5f5-0192-1000-0482-4e333725e345
+    name: environment-variable-parameter-context
+    description: my parameter context
+    Parameters:
+      - name: SECRET_MINIFI_DATA
+        description: ''
+        sensitive: true
+        provided: true
+        value: old_secret_minifi_data_value
+      - name: MINIFI_DATA
+        description: ''
+        sensitive: false
+        provided: true
+        value: old_minifi_data_value
+    Parameter Provider: d26ee5f5-0192-1000-0482-4e333725e089
+Processors:
+  - name: DummyProcessor
+    id: aabb6d26-8a8d-4338-92c9-1b8c67ec18e0
+    type: DummyProcessor
+    scheduling strategy: TIMER_DRIVEN
+    scheduling period: "15 sec"
+    Properties:
+      Simple Property: "#{MINIFI_DATA}"
+      Sensitive Property: "#{SECRET_MINIFI_DATA}"
+Parameter Context Name: environment-variable-parameter-context
+)";
+
+  minifi::utils::Environment::setEnvironmentVariable("MINIFI_DATA", "minifi_data_value");
+  minifi::utils::Environment::setEnvironmentVariable("SECRET_MINIFI_DATA", "secret_minifi_data_value");
+  const auto process_group_before = yaml_configuration_before.getRootFromPayload(std::string{config_yaml});
+  REQUIRE(process_group_before);
+
+  std::string reserialized_config = yaml_configuration_before.serialize(*process_group_before);
+  YAML::Node result_yaml_node = YAML::Load(std::string{reserialized_config});
+
+  REQUIRE(result_yaml_node["Parameter Contexts"].IsDefined());
+  auto parameters = result_yaml_node["Parameter Contexts"][0]["Parameters"];
+  REQUIRE(parameters.size() == 2);
+  for (const auto& parameter : parameters) {
+    auto name = parameter["name"].as<std::string>();
+    auto value = parameter["value"].as<std::string>();
+    if (name == "MINIFI_DATA") {
+      REQUIRE(value == "old_minifi_data_value");
+    } else if (name == "SECRET_MINIFI_DATA") {
+      REQUIRE(minifi::utils::crypto::property_encryption::decrypt(value, encryption_provider) == "old_secret_minifi_data_value");
+    }
+  }
+}
+
+TEST_CASE("Parameter provider generated parameter context is reserialized if Reload Values On Restart is set to true") {
+  ConfigurationTestController test_controller;
+  auto configuration_context = test_controller.getContext();
+  configuration_context.sensitive_values_encryptor = encryption_provider;
+  core::flow::AdaptiveConfiguration yaml_configuration_before{configuration_context};
+
+  const auto schema = core::flow::FlowSchema::getDefault();
+  static const std::string config_yaml =
+      R"(
+Flow Controller:
+  name: root
+  comment: ""
+Parameter Providers:
+  - id: d26ee5f5-0192-1000-0482-4e333725e089
+    name: EnvironmentVariableParameterProvider
+    type: EnvironmentVariableParameterProvider
+    Properties:
+      Environment Variable Inclusion Strategy: Comma-Separated
+      Include Environment Variables: MINIFI_DATA,SECRET_MINIFI_DATA
+      Sensitive Parameter Scope: selected
+      Sensitive Parameter List: SECRET_MINIFI_DATA
+      Parameter Group Name: environment-variable-parameter-context
+      Reload Values On Restart: true
+Parameter Contexts:
+  - id: 123ee5f5-0192-1000-0482-4e333725e345
+    name: environment-variable-parameter-context
+    description: my parameter context
+    Parameters:
+      - name: SECRET_MINIFI_DATA
+        description: ''
+        sensitive: true
+        provided: true
+        value: old_secret_minifi_data_value
+      - name: MINIFI_DATA
+        description: ''
+        sensitive: false
+        provided: true
+        value: old_minifi_data_value
+    Parameter Provider: d26ee5f5-0192-1000-0482-4e333725e089
+Processors:
+  - name: DummyProcessor
+    id: aabb6d26-8a8d-4338-92c9-1b8c67ec18e0
+    type: DummyProcessor
+    scheduling strategy: TIMER_DRIVEN
+    scheduling period: "15 sec"
+    Properties:
+      Simple Property: "#{MINIFI_DATA}"
+      Sensitive Property: "#{SECRET_MINIFI_DATA}"
+Parameter Context Name: environment-variable-parameter-context
+)";
+
+  minifi::utils::Environment::setEnvironmentVariable("MINIFI_DATA", "minifi_data_value");
+  minifi::utils::Environment::setEnvironmentVariable("SECRET_MINIFI_DATA", "secret_minifi_data_value");
+  const auto process_group_before = yaml_configuration_before.getRootFromPayload(std::string{config_yaml});
+  REQUIRE(process_group_before);
+
+  std::string reserialized_config = yaml_configuration_before.serialize(*process_group_before);
+  YAML::Node result_yaml_node = YAML::Load(std::string{reserialized_config});
+
+  REQUIRE(result_yaml_node["Parameter Contexts"].IsDefined());
+  auto parameters = result_yaml_node["Parameter Contexts"][0]["Parameters"];
+  REQUIRE(parameters.size() == 2);
+  for (const auto& parameter : parameters) {
+    auto name = parameter["name"].as<std::string>();
+    auto value = parameter["value"].as<std::string>();
+    if (name == "MINIFI_DATA") {
+      CHECK(value == "minifi_data_value");
+    } else if (name == "SECRET_MINIFI_DATA") {
+      CHECK(minifi::utils::crypto::property_encryption::decrypt(value, encryption_provider) == "secret_minifi_data_value");
+    }
+  }
+}
+
+}  // namespace org::apache::nifi::minifi::test
