@@ -19,8 +19,8 @@
 #include <string>
 #include <random>
 #include <algorithm>
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "io/ZlibStream.h"
 #include "utils/gsl.h"
 #include "utils/StringUtils.h"
