@@ -15,15 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef MAIN_MAINHELPER_H_
-#define MAIN_MAINHELPER_H_
+#pragma once
 
 #include <string>
 #include <filesystem>
 
 #include "core/logging/LoggerConfiguration.h"
-#include "core/logging/Logger.h"
-#include "Defaults.h"
 
 #ifdef WIN32
 extern "C" {
@@ -37,39 +34,59 @@ extern "C" {
 #define WIN32_LEAN_AND_MEAN
 #endif
 
- //! Main thread sleep interval 1 second
+//! Main thread sleep interval 1 second
 #define SLEEP_INTERVAL 1
 //! Main thread stop wait time
 #define STOP_WAIT_TIME_MS 30*1000
 //! Default YAML location
 
-//! Define home environment variable
-#define MINIFI_HOME_ENV_KEY "MINIFI_HOME"
-
 #ifdef _MSC_VER
 #ifndef PATH_MAX
 #define PATH_MAX 260
 #endif
 #endif
 
-/**
- * Validates a MINIFI_HOME value.
- * @param home_path
- * @return true if home_path represents a valid MINIFI_HOME
- */
-bool validHome(const std::string &home_path);
+namespace org::apache::nifi::minifi {
+struct Locations {
+  std::filesystem::path working_dir_;
+  std::filesystem::path lock_path_;
+  std::filesystem::path log_properties_path_;
+  std::filesystem::path uid_properties_path_;
+  std::filesystem::path properties_path_;
+  std::filesystem::path logs_dir_;
+  std::filesystem::path fips_bin_path_;
+  std::filesystem::path fips_conf_path_;
+};
 
 /**
  * Configures the logger to log everything to syslog/Windows Event Log, and for the minimum log level to INFO
  */
 void setSyslogLogger();
 
-/**
- * Determines the full path of MINIFI_HOME
- * @return MINIFI_HOME on success, empty string on failure
- */
 std::filesystem::path determineMinifiHome(const std::shared_ptr<org::apache::nifi::minifi::core::logging::Logger>& logger);
 
+std::optional<Locations> determineLocations(const std::shared_ptr<org::apache::nifi::minifi::core::logging::Logger>& logger);
 
+inline auto format_as(const Locations& loc) {
+  static constexpr std::string_view fmt_str =
+      "\n"
+      "{:<24} {}\n"
+      "{:<24} {}\n"
+      "{:<24} {}\n"
+      "{:<24} {}\n"
+      "{:<24} {}\n"
+      "{:<24} {}\n"
+      "{:<24} {}\n"
+      "{:<24} {}";
 
-#endif /* MAIN_MAINHELPER_H_ */
+  return fmt::format(fmt_str,
+      "Working dir:",         loc.working_dir_,
+      "Lock path:",           loc.lock_path_,
+      "Log properties path:", loc.log_properties_path_,
+      "UID properties path:", loc.uid_properties_path_,
+      "Properties path:",     loc.properties_path_,
+      "Logs dir:",            loc.logs_dir_,
+      "Fips binary path:",    loc.fips_bin_path_,
+      "Fips conf path:",      loc.fips_conf_path_);
+}
+}  // namespace org::apache::nifi::minifi
