@@ -18,7 +18,6 @@
  * limitations under the License.
  */
 
-
 #ifdef WIN32
 #ifndef WIN32_LEAN_AND_MEAN
 #define WIN32_LEAN_AND_MEAN
@@ -35,40 +34,43 @@
 #endif
 
 #include <fcntl.h>
-#include <cstdio>
 #include <semaphore.h>
-#include <csignal>
 #include <sodium.h>
+#include <cstdio>
+#include <csignal>
 
 #include <atomic>
+#include <algorithm>
 #include <cstdlib>
 #include <iostream>
 #include <vector>
 
+#include "AgentDocs.h"
+#include "DiskSpaceWatchdog.h"
+#include "Defaults.h"
+#include "Fips.h"
+#include "FlowController.h"
+#include "MainHelper.h"
 #include "ResourceClaim.h"
+#include "agent/JsonSchema.h"
+#include "agent/agent_version.h"
+#include "argparse/argparse.hpp"
+#include "core/BulletinStore.h"
+#include "core/ConfigurationFactory.h"
 #include "core/Core.h"
 #include "core/FlowConfiguration.h"
-#include "core/ConfigurationFactory.h"
 #include "core/RepositoryFactory.h"
 #include "core/extension/ExtensionManager.h"
 #include "core/repository/VolatileContentRepository.h"
 #include "core/repository/VolatileFlowFileRepository.h"
-#include "DiskSpaceWatchdog.h"
+#include "core/state/MetricsPublisherStore.h"
 #include "properties/Decryptor.h"
-#include "utils/file/PathUtils.h"
-#include "utils/file/FileUtils.h"
-#include "utils/file/AssetManager.h"
 #include "utils/Environment.h"
 #include "utils/FileMutex.h"
-#include "FlowController.h"
-#include "AgentDocs.h"
-#include "MainHelper.h"
-#include "agent/JsonSchema.h"
-#include "core/state/nodes/ResponseNodeLoader.h"
-#include "c2/C2Agent.h"
-#include "core/state/MetricsPublisherStore.h"
-#include "argparse/argparse.hpp"
-#include "agent/agent_version.h"
+#include "utils/file/AssetManager.h"
+#include "utils/file/FileUtils.h"
+#include "utils/file/PathUtils.h"
+#include "range/v3/algorithm/min_element.hpp"
 
 namespace minifi = org::apache::nifi::minifi;
 namespace core = minifi::core;
@@ -83,7 +85,7 @@ static std::atomic_flag process_running;
  *
  * Semaphores are a portable choice when using signal handlers. Threads,
  * mutexes, and condition variables are not guaranteed to work within
- * a signal handler. Consequently we will use the semaphore to avoid thread
+ * a signal handler. Consequently, we will use the semaphore to avoid thread
  * safety issues.
  */
 
@@ -129,7 +131,7 @@ void writeJsonSchema(const std::shared_ptr<minifi::Configure>& configuration, st
     pythoncreator->configure(configuration);
   }
 
-  out << minifi::docs::generateJsonSchema();
+  out << minifi::docs::generateJsonSchema() << '\n';
 }
 
 void overridePropertiesFromCommandLine(const argparse::ArgumentParser& parser, const std::shared_ptr<minifi::Configure>& configure) {
@@ -145,42 +147,42 @@ void overridePropertiesFromCommandLine(const argparse::ArgumentParser& parser, c
   }
 }
 
-void dumpDocsIfRequested(const argparse::ArgumentParser& parser, const std::shared_ptr<minifi::Configure>& configure) {
+[[nodiscard]] std::optional<int /* exit code */> dumpDocsIfRequested(const argparse::ArgumentParser& parser, const std::shared_ptr<minifi::Configure>& configure) {
   if (!parser.is_used("--docs")) {
-    return;
+    return std::nullopt;  // don't exit
   }
   const auto& docs_params = parser.get<std::vector<std::string>>("--docs");
   if (utils::file::create_dir(docs_params[0]) != 0) {
     std::cerr << "Working directory doesn't exist and cannot be created: " << docs_params[0] << std::endl;
-    std::exit(1);
+    return 1;
   }
 
   std::cout << "Dumping docs to " << docs_params[0] << std::endl;
   dumpDocs(configure, docs_params[0]);
-  std::exit(0);
+  return 0;
 }
 
-void writeSchemaIfRequested(const argparse::ArgumentParser& parser, const std::shared_ptr<minifi::Configure>& configure) {
+[[nodiscard]] std::optional<int /* exit code */> writeSchemaIfRequested(const argparse::ArgumentParser& parser, const std::shared_ptr<minifi::Configure>& configure) {
   if (!parser.is_used("--schema")) {
-    return;
+    return std::nullopt;
   }
   const auto& schema_path = parser.get("--schema");
-  if (std::filesystem::exists(schema_path) && !std::filesystem::is_regular_file(schema_path)) {
-    std::cerr << "JSON schema target path already exists, but it is not a regular file: " << schema_path << std::endl;
-    std::exit(1);
+  if (schema_path == "-") {
+    writeJsonSchema(configure, std::cout);
+    return 0;
   }
 
-  const auto parent_dir = std::filesystem::path(schema_path).parent_path();
-  if (utils::file::create_dir(parent_dir) != 0) {
-    std::cerr << "JSON schema parent directory doesn't exist and cannot be created: " << parent_dir << std::endl;
-    std::exit(1);
-  }
   std::cout << "Writing json schema to " << schema_path << std::endl;
   {
     std::ofstream schema_file{schema_path};
+    if (!schema_file) {
+      std::cerr << "Failed to open file \"" << schema_path << "\" for writing: " << std::system_category().default_error_condition(errno).message()
+                << "\n";
+      return 1;
+    }
     writeJsonSchema(configure, schema_file);
   }
-  std::exit(0);
+  return 0;
 }
 
 int main(int argc, char **argv) {
@@ -195,6 +197,7 @@ int main(int argc, char **argv) {
     .help("Generate documentation in the specified directory");
   argument_parser.add_argument("-s", "--schema")
     .metavar("PATH")
+    .default_value("-")
     .help("Generate JSON schema to the specified path");
 
   try {
@@ -218,7 +221,7 @@ int main(int argc, char **argv) {
 #endif
 
   if (utils::Environment::isRunningAsService()) {
-    setSyslogLogger();
+    minifi::setSyslogLogger();
   }
   auto& logger_configuration = core::logging::LoggerConfiguration::getConfiguration();
   const auto logger = logger_configuration.getLogger("main");
@@ -264,25 +267,27 @@ int main(int argc, char **argv) {
     return -1;
   }
 #endif
-  // Determine MINIFI_HOME
-  const auto minifiHome = determineMinifiHome(logger);
-  if (minifiHome.empty()) {
-    // determineMinifiHome already logged everything we need
+  const auto locations = minifi::determineLocations(logger);
+  if (!locations) {
+    // determineLocations already logged everything we need
     return -1;
   }
-  utils::FileMutex minifi_home_mtx(minifiHome / "LOCK");
+  minifi::utils::Environment::setEnvironmentVariable(std::string(MINIFI_HOME_ENV_KEY).c_str(), locations->working_dir_.string().c_str());
+  logger->log_info("MiNiFi Locations={}", *locations);
+
+  utils::FileMutex minifi_home_mtx(locations->lock_path_);
   std::unique_lock minifi_home_lock(minifi_home_mtx, std::defer_lock);
   try {
     minifi_home_lock.lock();
   } catch (const std::exception& ex) {
-    logger->log_error("Could not acquire LOCK for minifi home '{}', maybe another minifi instance is running: {}", minifiHome, ex.what());
+    logger->log_error("Could not acquire LOCK '{}', maybe another minifi instance is running: {}", locations->lock_path_, ex.what());
     std::exit(1);
   }
   // chdir to MINIFI_HOME
   std::error_code current_path_error;
-  std::filesystem::current_path(minifiHome, current_path_error);
+  std::filesystem::current_path(locations->working_dir_, current_path_error);
   if (current_path_error) {
-    logger->log_error("Failed to change working directory to MINIFI_HOME ({})", minifiHome);
+    logger->log_error("Failed to change working directory to {}", locations->working_dir_);
     return -1;
   }
 
@@ -301,42 +306,37 @@ int main(int argc, char **argv) {
   do {
     flow_controller_running.test_and_set();
 
-    std::string graceful_shutdown_seconds;
     std::string prov_repo_class = "provenancerepository";
     std::string flow_repo_class = "flowfilerepository";
     std::string nifi_configuration_class_name = "adaptiveconfiguration";
-    std::string content_repo_class = "filesystemrepository";
+    std::string content_repo_class = "DatabaseContentRepository";
 
-    auto log_properties = std::make_shared<core::logging::LoggerProperties>();
-    log_properties->setHome(minifiHome);
-    log_properties->loadConfigureFile(DEFAULT_LOG_PROPERTIES_FILE, "nifi.log.");
+    auto log_properties = std::make_shared<core::logging::LoggerProperties>(locations->logs_dir_);
+    log_properties->loadConfigureFile(locations->log_properties_path_, "nifi.log.");
 
     logger_configuration.initialize(log_properties);
 
-    std::shared_ptr<minifi::Properties> uid_properties = std::make_shared<minifi::Properties>("UID properties");
-    uid_properties->setHome(minifiHome);
-    uid_properties->loadConfigureFile(DEFAULT_UID_PROPERTIES_FILE);
+    std::shared_ptr<minifi::Properties> uid_properties = std::make_shared<minifi::PropertiesImpl>("UID properties");
+    uid_properties->loadConfigureFile(locations->uid_properties_path_);
     utils::IdGenerator::getIdGenerator()->initialize(uid_properties);
 
-    // Make a record of minifi home in the configured log file.
-    logger->log_info("MINIFI_HOME={}", minifiHome);
-
-    auto decryptor = minifi::Decryptor::create(minifiHome);
+    auto decryptor = minifi::Decryptor::create(locations->working_dir_);
     if (decryptor) {
       logger->log_info("Found encryption key, will decrypt sensitive properties in the configuration");
     } else {
       logger->log_info("No encryption key found, will not decrypt sensitive properties in the configuration");
     }
 
-    const std::shared_ptr<minifi::Configure> configure = std::make_shared<minifi::Configure>(std::move(decryptor), std::move(log_properties));
-    configure->setHome(minifiHome);
-    configure->loadConfigureFile(DEFAULT_NIFI_PROPERTIES_FILE);
+    const std::shared_ptr<minifi::Configure> configure = std::make_shared<minifi::ConfigureImpl>(std::move(decryptor), std::move(log_properties));
+    configure->loadConfigureFile(locations->properties_path_);
     overridePropertiesFromCommandLine(argument_parser, configure);
 
-    minifi::core::extension::ExtensionManager::get().initialize(configure);
+    minifi::fips::initializeFipsMode(configure, *locations, logger);
 
-    dumpDocsIfRequested(argument_parser, configure);
-    writeSchemaIfRequested(argument_parser, configure);
+    minifi::core::extension::ExtensionManagerImpl::get().initialize(configure);
+
+    if (const auto maybe_exit_code = dumpDocsIfRequested(argument_parser, configure)) { return *maybe_exit_code; }
+    if (const auto maybe_exit_code = writeSchemaIfRequested(argument_parser, configure)) { return *maybe_exit_code; }
 
     std::chrono::milliseconds stop_wait_time = configure->get(minifi::Configure::nifi_graceful_shutdown_seconds)
         | utils::andThen(utils::timeutils::StringToDuration<std::chrono::milliseconds>)
@@ -388,7 +388,10 @@ int main(int argc, char **argv) {
 
     auto filesystem = std::make_shared<utils::file::FileSystem>(
         should_encrypt_flow_config,
-        utils::crypto::EncryptionProvider::create(minifiHome));
+        utils::crypto::EncryptionProvider::create(locations->working_dir_));
+
+    auto asset_manager = std::make_unique<utils::file::AssetManager>(*configure);
+    auto bulletin_store = std::make_unique<core::BulletinStore>(*configure);
 
     std::shared_ptr<core::FlowConfiguration> flow_configuration = core::createFlowConfiguration(
         core::ConfigurationContext{
@@ -397,16 +400,16 @@ int main(int argc, char **argv) {
           .configuration = configure,
           .path = configure->get(minifi::Configure::nifi_flow_configuration_file),
           .filesystem = filesystem,
-          .sensitive_values_encryptor = utils::crypto::EncryptionProvider::createSensitivePropertiesEncryptor(minifiHome)
+          .sensitive_values_encryptor = utils::crypto::EncryptionProvider::createSensitivePropertiesEncryptor(locations->working_dir_),
+          .asset_manager = asset_manager.get(),
+          .bulletin_store = bulletin_store.get()
       }, nifi_configuration_class_name);
 
-    auto asset_manager = std::make_unique<utils::file::AssetManager>(*configure);
-
     std::vector<std::shared_ptr<core::RepositoryMetricsSource>> repo_metric_sources{prov_repo, flow_repo, content_repo};
-    auto metrics_publisher_store = std::make_unique<minifi::state::MetricsPublisherStore>(configure, repo_metric_sources, flow_configuration, asset_manager.get());
+    auto metrics_publisher_store = std::make_unique<minifi::state::MetricsPublisherStore>(configure, repo_metric_sources, flow_configuration, asset_manager.get(), bulletin_store.get());
     const auto controller = std::make_unique<minifi::FlowController>(
         prov_repo, flow_repo, configure, std::move(flow_configuration), content_repo,
-        std::move(metrics_publisher_store), filesystem, request_restart, asset_manager.get());
+        std::move(metrics_publisher_store), filesystem, request_restart, asset_manager.get(), bulletin_store.get());
 
     const bool disk_space_watchdog_enable = configure->get(minifi::Configure::minifi_disk_space_watchdog_enable)
         | utils::andThen(utils::string::toBool)
@@ -416,22 +419,22 @@ int main(int argc, char **argv) {
     if (disk_space_watchdog_enable) {
       try {
         const auto repo_paths = [&] {
-          std::vector<std::string> repo_paths;
-          repo_paths.reserve(3);
+          std::vector<std::string> paths;
+          paths.reserve(3);
           // REPOSITORY_DIRECTORY is a dummy path used by noop repositories
           const auto path_valid = [](const std::string& p) { return !p.empty() && p != org::apache::nifi::minifi::core::REPOSITORY_DIRECTORY; };
           auto prov_repo_path = prov_repo->getDirectory();
           auto flow_repo_path = flow_repo->getDirectory();
           auto content_repo_storage_path = content_repo->getStoragePath();
-          if (!prov_repo->isNoop() && path_valid(prov_repo_path)) { repo_paths.push_back(std::move(prov_repo_path)); }
-          if (!flow_repo->isNoop() && path_valid(flow_repo_path)) { repo_paths.push_back(std::move(flow_repo_path)); }
-          if (path_valid(content_repo_storage_path)) { repo_paths.push_back(std::move(content_repo_storage_path)); }
-          return repo_paths;
+          if (!prov_repo->isNoop() && path_valid(prov_repo_path)) { paths.push_back(std::move(prov_repo_path)); }
+          if (!flow_repo->isNoop() && path_valid(flow_repo_path)) { paths.push_back(std::move(flow_repo_path)); }
+          if (path_valid(content_repo_storage_path)) { paths.push_back(std::move(content_repo_storage_path)); }
+          return paths;
         }();
         const auto available_spaces = minifi::disk_space_watchdog::check_available_space(repo_paths, logger.get());
         const auto config = minifi::disk_space_watchdog::read_config(*configure);
         const auto min_space = [](const std::vector<std::uintmax_t>& spaces) {
-          const auto it = std::min_element(std::begin(spaces), std::end(spaces));
+          const auto it = std::ranges::min_element(spaces);
           return it != spaces.end() ? *it : (std::numeric_limits<std::uintmax_t>::max)();
         };
         if (min_space(available_spaces) <= config.stop_threshold_bytes) {
