@@ -21,9 +21,10 @@
 
 #include <Windows.h>
 #include <Strsafe.h>
-#include <tuple>
 #include <tlhelp32.h>
 
+#include <tuple>
+
 #include "MainHelper.h"
 
 namespace minifi = org::apache::nifi::minifi;
@@ -68,7 +69,7 @@ void RunAsServiceIfNeeded() {
     {
       serviceNameMutable,
       [](DWORD argc, LPTSTR *argv) {
-        setSyslogLogger();
+        minifi::setSyslogLogger();
 
         Log()->log_trace("ServiceCtrlDispatcher");
 
@@ -129,8 +130,7 @@ void RunAsServiceIfNeeded() {
                 }
               }
             }
-          }
-        );
+          });
 
         if (!s_statusHandle) {
           Log()->log_error("!RegisterServiceCtrlHandler lastError {:#x}", GetLastError());
