@@ -18,58 +18,25 @@
 
 verify_enable_platform() {
   feature="$1"
-  if [ "$OS_MAJOR" = "6" ]; then
-    if [ "$feature" = "GPS_ENABLED" ]; then
-      echo "false"
-    elif [ "$feature" = "USB_ENABLED" ]; then
-      echo "false"
-    else
-      verify_gcc_enable "$feature"
-    fi
-  else
-    if [ "$feature" = "USB_ENABLED" ]; then
-      echo "false"
-    else
-      verify_gcc_enable "$feature"
-    fi
-  fi
+  verify_gcc_enable "$feature"
 }
 
 add_os_flags() {
-  if [ "$OS_MAJOR" = "6" ]; then
-    CMAKE_BUILD_COMMAND="${CMAKE_BUILD_COMMAND} -DCMAKE_CXX_FLAGS=-lrt "
-  fi
+  :
 }
 install_bison() {
-  if [ "$OS_MAJOR" = "6" ]; then
-    BISON_INSTALLED="false"
-    if [ -x "$(command -v bison)" ]; then
-      BISON_VERSION=$(bison --version | head -n 1 | awk '{print $4}')
-      BISON_MAJOR=$(echo "$BISON_VERSION" | cut -d. -f1)
-      if (( BISON_MAJOR >= 3 )); then
-        BISON_INSTALLED="true"
-      fi
-    fi
-    if [ "$BISON_INSTALLED" = "false" ]; then
-      wget https://ftp.gnu.org/gnu/bison/bison-3.0.4.tar.xz
-      tar xvf bison-3.0.4.tar.xz
-      pushd bison-3.0.4 || exit 1
-      ./configure
-      make
-      make install
-      popd || exit 2
-    fi
-
-  else
-    INSTALLED+=("bison")
-  fi
+  INSTALLED+=("bison")
 }
 
 bootstrap_cmake(){
-  sudo yum -y install wget patch
-  wget https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
-  sudo yum -y install epel-release-latest-7.noarch.rpm
-  sudo yum -y install cmake3
+  if [ "$OS_MAJOR" -lt 8 ]; then
+    sudo yum -y install wget patch
+    wget https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
+    sudo yum -y install epel-release-latest-7.noarch.rpm
+    sudo yum -y install cmake3
+  else
+    sudo dnf -y install cmake
+  fi
 }
 bootstrap_compiler() {
   sudo yum -y install gcc gcc-c++
@@ -77,12 +44,11 @@ bootstrap_compiler() {
 build_deps(){
 # Install epel-release so that cmake3 will be available for installation
   sudo yum -y install wget
-  wget https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
-  sudo yum -y install epel-release-latest-7.noarch.rpm
+  wget "https://dl.fedoraproject.org/pub/epel/epel-release-latest-${OS_MAJOR}.noarch.rpm"
+  sudo yum -y install "epel-release-latest-${OS_MAJOR}.noarch.rpm"
 
-  COMMAND="sudo yum install cmake3 libuuid libuuid-devel"
+  COMMAND="sudo yum install libuuid libuuid-devel perl bzip2-devel"
   INSTALLED=()
-  INSTALLED+=("bzip2-devel")
   for option in "${OPTIONS[@]}" ; do
     option_value="${!option}"
     if [ "$option_value" = "${TRUE}" ]; then
@@ -93,13 +59,7 @@ build_deps(){
         VALUE=${cmake_opt#*:}
         if [ "$KEY" = "$option" ]; then
           FOUND_VALUE="$VALUE"
-          if [ "$FOUND_VALUE" = "libpcap" ]; then
-            INSTALLED+=("libpcap-devel")
-          elif [ "$FOUND_VALUE" = "libusb" ]; then
-            INSTALLED+=("libusb-devel")
-          elif [ "$FOUND_VALUE" = "libpng" ]; then
-            INSTALLED+=("libpng-devel")
-          elif [ "$FOUND_VALUE" = "bison" ]; then
+          if [ "$FOUND_VALUE" = "bison" ]; then
             install_bison
           elif [ "$FOUND_VALUE" = "flex" ]; then
             INSTALLED+=("flex")
@@ -110,15 +70,11 @@ build_deps(){
           elif [ "$FOUND_VALUE" = "libtool" ]; then
             INSTALLED+=("libtool")
           elif [ "$FOUND_VALUE" = "python" ]; then
-            INSTALLED+=("python34-devel")
-          elif [ "$FOUND_VALUE" = "gpsd" ]; then
-            INSTALLED+=("gpsd-devel")
+            INSTALLED+=("python3-devel")
           elif [ "$FOUND_VALUE" = "libarchive" ]; then
             INSTALLED+=("xz-devel")
           elif [ "$FOUND_VALUE" = "libssh2" ]; then
             INSTALLED+=("libssh2-devel")
-          elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
-            INSTALLED+=("perl")
           fi
         fi
       done
