@@ -19,4 +19,4 @@
 set -euo pipefail
 
 directory=${1:-.}
-find "${directory}" -type d \( -path "*thirdparty*" -o -path "*build*" \) -prune -false -o -type f -name "*.sh" | xargs shellcheck --exclude=SC1090,SC1091
+find "${directory}" -type d \( -path "*thirdparty*" -o -path "*build*" -o -path "*venv*" \) -prune -false -o -type f -name "*.sh" | xargs shellcheck --exclude=SC1090,SC1091
