@@ -18,21 +18,7 @@
 
 verify_enable_platform() {
   feature="$1"
-  if [ "$OS_MAJOR" = "6" ]; then
-    if [ "${feature}" = "GPS_ENABLED" ]; then
-      echo "false"
-    elif [ "${feature}" = "USB_ENABLED" ]; then
-      echo "false"
-    else
-      verify_gcc_enable "${feature}"
-    fi
-  else
-    if [ "${feature}" = "USB_ENABLED" ]; then
-      echo "false"
-    else
-      verify_gcc_enable "${feature}"
-    fi
-  fi
+  verify_gcc_enable "${feature}"
 }
 
 add_os_flags() {
@@ -66,9 +52,8 @@ bootstrap_compiler() {
 }
 build_deps(){
   # Install epel-release so that cmake3 will be available for installation
-  COMMAND="sudo zypper in -y libuuid1 libuuid-devel"
+  COMMAND="sudo zypper in -y libuuid1 libuuid-devel perl libbz2-devel"
   INSTALLED=()
-  INSTALLED+=("libbz2-devel")
   for option in "${OPTIONS[@]}" ; do
     option_value="${!option}"
     if [ "$option_value" = "${TRUE}" ]; then
@@ -79,13 +64,7 @@ build_deps(){
         VALUE=${cmake_opt#*:}
         if [ "$KEY" = "$option" ]; then
           FOUND_VALUE="$VALUE"
-          if [ "$FOUND_VALUE" = "libpcap" ]; then
-            INSTALLED+=("libpcap-devel")
-          elif [ "$FOUND_VALUE" = "libusb" ]; then
-            INSTALLED+=("libusb-devel")
-          elif [ "$FOUND_VALUE" = "libpng" ]; then
-            INSTALLED+=("libpng-devel")
-          elif [ "$FOUND_VALUE" = "bison" ]; then
+          if [ "$FOUND_VALUE" = "bison" ]; then
             install_bison
           elif [ "$FOUND_VALUE" = "flex" ]; then
             INSTALLED+=("flex")
@@ -97,14 +76,10 @@ build_deps(){
             INSTALLED+=("libtool")
           elif [ "$FOUND_VALUE" = "python" ]; then
             INSTALLED+=("python3-devel")
-          elif [ "$FOUND_VALUE" = "gpsd" ]; then
-            INSTALLED+=("gpsd-devel")
           elif [ "$FOUND_VALUE" = "libarchive" ]; then
             INSTALLED+=("xz-devel")
           elif [ "$FOUND_VALUE" = "libssh2" ]; then
             INSTALLED+=("libssh2-devel")
-          elif [ "$FOUND_VALUE" = "opensslbuild" ]; then
-            INSTALLED+=("perl")
           fi
         fi
       done
